%% Figure 6 - Gibbs & Kulish (2017)
% This figure compares Argentina when lambda = 0.5 under there own and US
% sized shocks

%% Options

% Note that this option is commented out in runSet.m
SET.options.country = 'Argentina';
runSet;

SET.options.draws   = 1000;

SET.options.unanticipated = 1; % Set to 1 for unanticipated and 0 for anticipated. 
SET.options.anticipated   = 1 - SET.options.unanticipated ; 

SET.param.lambda     = 0.25;
SET.param.Delta_ppi = 30;

%% Argentina Shocks

out = SR(SET)

%% US Shocks with Argentina calibration

%Shocks
SET.param.sig_a      = 0.0139;
SET.param.sig_e      = 0.0008;
SET.param.sig_z      = 0.0090;
SET.param.sig_r      = 0.0040;
SET.param.sig_om     = 0.0000;
SET.param.sig_target = 0.0014;
SET.param.sig_v      = 0.0799;

out_2 = SR(SET)

%% Figure 6

figure(6)
histogram(out.SR.Ycom.draws,50,'Normalization','pdf')
axis([-15 30 0 .33])
hold on
histogram(out_2.SR.Ycom.draws,50,'Normalization','pdf')
axis([-15 30 0 .33])

figure(7)
histogram(out.SR.RE.draws,50,'Normalization','pdf')
axis([-15 30 0 .65])
hold on
histogram(out_2.SR.RE.draws,50,'Normalization','pdf')
axis([-15 30 0 .65])


%% Summary Statistics


disp(' ')
disp('Argentina')
m_re = mean(out.SR.Ycom.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out.SR.Ycom.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out.SR.Ycom.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out.SR.Ycom.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)

disp(' ')
disp('Argentina with US Shocks')
m_re = mean(out_2.SR.Ycom.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_2.SR.Ycom.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_2.SR.Ycom.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_2.SR.Ycom.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)


disp(' ')
disp('RE Argentina')
m_re = mean(out.SR.RE.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out.SR.RE.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out.SR.RE.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out.SR.RE.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)

disp(' ')
disp('RE Argentina with US Shocks')
m_re = mean(out_2.SR.RE.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_2.SR.RE.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_2.SR.RE.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_2.SR.RE.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)