%% Figure 2 - Gibbs and Kulish (2017)
% This figure compares the distribution of sacrifice ratios for the US
% calibration under three different levels of credibility lambda = 0, 0.5,
% 1. It also calculates summary statistics


%% Options

% Note that this option is commented out in runSet.m
SET.options.country = 'USA';
runSet;

SET.param.Delta_ppi = 10;
SET.options.draws   = 750;

SET.options.unanticipated = 1; % Set to 1 for unanticipated and 0 for anticipated. 
SET.options.anticipated   = 1 - SET.options.unanticipated ; 



%% Case 1 and 2: Rational and lambda = 0.5

SET.param.lambda     = 0.5;

out = SR(SET)


%% Case 3: Lambda = 0

SET.param.lambda     = 0;

out_2 = SR(SET)

%% Figure 2

figure(2)
histogram(out.SR.RE.draws,50,'Normalization','pdf')
axis([-5 40 0 1.4])
hold on
histogram(out.SR.Ycom.draws,50,'Normalization','pdf')
axis([-5 40 0 1.4])
hold on
histogram(out_2.SR.Ycom.draws,50,'Normalization','pdf')
axis([-5 40 0 1.4])

%% Summary Statistics

disp('RE')
m_re = mean(out.SR.RE.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out.SR.RE.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out.SR.RE.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out.SR.RE.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)

disp(' ')
disp('Lambda = 0.5')
m_re = mean(out.SR.Ycom.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out.SR.Ycom.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out.SR.Ycom.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out.SR.Ycom.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)

disp(' ')
disp('Lambda = 0')
m_re = mean(out_2.SR.Ycom.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_2.SR.Ycom.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_2.SR.Ycom.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_2.SR.Ycom.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)