% estimation.mod
% Model: Ireland (2004), Review of Economic and Statistics.
%

var a e z x ppi yhat g r ppi_target om m v;

varexo eps_a eps_e eps_z eps_r eps_target eps_v;

parameters beta, rho_a, rho_e, rho_z, rho_v, omega, psi, rho_r, rho_pi, rho_g, rho_x,
           rr_ss, ppibar,  zbar, rho_target, mu_a, mu_e, mu_z, mu_v,
          sig_a, sig_e sig_z sig_r, sig_target, sig_v;


%parameters beta, rho_a, rho_e, omega, psi, rho_r, rho_pi, rho_g, rho_x, rho_om, rho_om_pi
%           rbar, ppibar, rho_target, sig_a, sig_e sig_z sig_r, sig_om, sig_target;

beta   = 0.995;
zbar   = 0.004783;
ppibar = 0.0725;
rho_a  = 0.9470;
rho_e  = 0.9625;
rho_z  = 0.570;
rho_v  = 0.570;
omega  = 0.0617;
psi    = 0.1;
mu_a   = 0.001;
mu_e   = 0.001;
mu_z   = 0.001;
mu_v   = 0.001;


rho_r  = 0.9; 
rho_pi = 0.5;
rho_g  = 0.2536;
rho_x  = 0.0347;

rho_target = 0.85;

% Rbar   =  (exp(zbar)*exp(ppibar)/beta);
% r_ss   = zbar + ppibar - log(beta);
% om_ss  =  zbar + ppibar; 

sig_a  = 0.015;
sig_e  = 0.0012;
sig_z  = 0.0109;
sig_r  = 0.0031;
sig_target = 0.001;
sig_v  = 0.0109;



model;
# Rbar   =  (exp(zbar)*exp(ppibar)/beta);
# r_ss   = zbar + ppibar - log(beta);
# om_ss  =  zbar + ppibar; 


a = rho_a*a(-1) + eps_a ;

e = rho_e*e(-1) + eps_e ;

z  = (1-rho_z)*zbar + rho_z * z(-1) + eps_z ;

x = x(+1) - (r - r_ss) + ppi(+1) - ppibar + (1-omega)*(1-rho_a)*a ;

ppi - ppibar = beta*(ppi(+1)- ppibar) + psi*x - e ;

% x = x(+1) - (r - r_ss) + ppi(+1) - ppi_target(+1) + (1-omega)*(1-rho_a)*a ;

% ppi - ppi_target = beta*(ppi(+1)-ppi_target(+1)) + psi*x - e ;

x = yhat - omega*a ;

g = yhat - yhat(-1) + z ;

om = m - m(-1) + ppi + z;

r = (1-rho_r)*r_ss  + rho_r*r(-1) + rho_pi*(ppi - ppi_target) + rho_g*(g - zbar) + rho_x*x + eps_r ;

m = yhat - a - (1/(Rbar-1)) * (r - r_ss) + v; 

ppi_target = (1-rho_target)*ppibar + rho_target* ppi_target(-1) + mu_a*eps_a + mu_e*eps_e + mu_z*eps_z + mu_v*eps_v + eps_target ;

v = rho_v * v(-1) + eps_v;

end;

initval;
a = 0 ;
e = 0 ;
z = 0 ;
x = 0 ;
ppi = ppibar ;
yhat = 0 ;
g = zbar ;
r = 0.0823 ;
end;


shocks;
var eps_a = sig_a^2;
var eps_e = sig_e^2;
var eps_z = sig_z^2;
var eps_r = sig_r^2;
var eps_target = sig_target^2;
var eps_v = sig_v^2;
end;


estimated_params; 
rho_a,         beta_pdf, 0.85, 0.1; 
rho_e,         beta_pdf, 0.85, 0.1; 
rho_z,         beta_pdf, 0.5, 0.2; 
rho_v,         beta_pdf, 0.85, 0.1; 
% psi,           normal_pdf, 0.25, 0.1;
rho_r,       beta_pdf, 0.7, 0.2; 
rho_pi,      normal_pdf, 0.8, 0.5;
rho_g,       normal_pdf, .2, .1;
rho_x,       normal_pdf, .1, .05;
rho_target,    beta_pdf, 0.7, 0.1; 
ppibar,        normal_pdf, 0.0361, 0.01;
mu_a,          normal_pdf, -0.1, 0.2;
mu_e,          normal_pdf, -0.1, 0.2;
mu_z,          normal_pdf, 0.1, 0.2;
mu_v,          normal_pdf, 0, 0.2;
%stderr eps_a,      inv_gamma_pdf,0.005,inf;
%stderr eps_e,      inv_gamma_pdf,0.007,inf;
%stderr eps_z,      inv_gamma_pdf,0.003,inf;
%stderr eps_r,      inv_gamma_pdf,0.01,inf;
%stderr eps_target, inv_gamma_pdf,0.003,inf;
%stderr eps_v,     inv_gamma_pdf,0.07,inf;

stderr eps_a,      inv_gamma_pdf,0.02,inf;%
stderr eps_e,      inv_gamma_pdf,0.01,inf;
stderr eps_z,      inv_gamma_pdf,0.012,inf;
stderr eps_r,      inv_gamma_pdf,0.02,inf;
stderr eps_target, inv_gamma_pdf,0.01,inf;
stderr eps_v,     inv_gamma_pdf,0.070,inf;
%corr eps_a, eps_e, 0.5, , , beta_pdf, 0, 0.3, -1, 1;
%corr eps_a, eps_z, 0.5, , , beta_pdf, 0, 0.3, -1, 1;
%corr eps_a, eps_target, 0.5, , , beta_pdf, 0, 0.3, -1, 1;
end;

varobs om g ppi r;

estimation(datafile=arg_data,nobs=43,mh_nblocks=1,
mh_jscale=0.5,mh_replic=2000,mode_compute=4,
mode_check, mh_drop=0.3);

stoch_simul(nograph);
