***** Cleaning Data for Gibbs and Kulish (2015) ****
* This file imports data obtained from the OECD, World Bank, and from FRED and puts it into a
* workable format to calculate sacrifice ratios.
* Created: 26/4/2015
* Updated: 8/8/2017

*set appropriate directory
cd "CHANGE DIRECTORY BEFORE USE/Data"
glo drive = "CHANGE DIRECTORY BEFORE USE/Data"

***************************************************************************
*Interest Rates
***************************************************************************

import delimited "$drive\STINT-TOT-PC_PA-Q.csv", delimiter(comma) clear

gen id = _n

drop if id<8

drop id

rename v1 location
forv i=2(1)17 {
drop v`i'
}

forv i=239(1)475 {
drop v`i'
}

*Rename

forv i=18(1)238{
local j = `i' - 18
rename v`i' interest`j'
}

destring interest*, replace

sort location

egen country_id = group(location)

save oecd_interest_rates, replace

*******************************************************************************
* Inflation
*******************************************************************************

import delimited "$drive\CPI-TOT-AGRWTH-Q.csv", delimiter(comma) clear

gen id = _n

drop if id<8

drop id

rename v1 location

drop v2

forv i=220(1)437 {
drop v`i'
}

*Rename

forv i=3(1)219{
local j = `i' - 3
rename v`i' inflation`j'
}

destring inflation*, replace

sort location

egen country_id = group(location)

save oecd_inflation, replace

********************************************************************************
* GDP Growth
********************************************************************************

import delimited "$drive\QGDP-TOT-PC_CHGPP-Q.csv", delimiter(comma) clear

gen id = _n

drop if id<8

drop id

rename v1 location

forv i=222(1)443 {
drop v`i'
}

*Rename

forv i=2(1)221{
local j = `i' - 1
rename v`i' gdp`j'
}

destring gdp*, replace

sort location

egen country_id = group(location)

save oecd_gdp_growth, replace


**** Supplemental Data
 *** GDP

 import excel "$drive\Supplemental_GDP_Data.xls", sheet("FRED Graph") clear
 
 *Drop misc info
 gen temp =_n
 
 drop if temp<20
 
 *Destring
 destring B C D E F G H I J, replace
 
 foreach v in B C D E F G H I J {
 replace `v' = ((1+`v'/100)^(1/4)-1)*100
 }
 
 *Rename Variables
 rename A date
 rename B saudi_arabia
 rename C argentina
 rename D chile
 rename E colombia
 rename F hungary
 rename G india
 rename H indonesia
 rename I poland
 rename J russia
 
 *Creat Time Variable and quarterly observations
 expand 4
 
 sort date
 
 gen quarter = _n + tq(1963q4)
 
 tsset quarter, quarterly
 
 order date quarter
 
 *Now separate out country variables and reassemble dataset
 
 preserve
 
 keep quarter saudi_arabia
 
 gen location = "saudi arabia"
 rename saudi gdp
 
 save "$drive\temp1", replace
 
 restore
 
 preserve
 
 keep quarter argentina
 
 gen location = "argentina"
 rename argentina gdp
 
 save "$drive\temp2", replace
 
 restore
 
  preserve
 
 keep quarter chile
 
 gen location = "chile"
 rename chile gdp
 
 save "$drive\temp3", replace
 
 restore
 
  preserve
 
 keep quarter colombia
 
 gen location = "colombia"
 rename colom gdp
 
 save "$drive\temp4", replace
 
 restore
 
  preserve
 
 keep quarter hungary
 
 gen location = "hungary"
 rename hungary gdp
 
 save "$drive\temp5", replace
 
 restore
 
  preserve
 
 keep quarter india
 
 gen location = "india"
 rename india gdp
 
 save "$drive\temp6", replace
 
 restore
 
  preserve
 
 keep quarter poland
 
 gen location = "poland"
 rename poland gdp
 
 save "$drive\temp7", replace
 
 restore
 
  preserve
 
 keep quarter russia
 
 gen location = "russia"
 rename russia gdp
 
 save "$drive\temp8", replace
 
 restore
 
 ** Add China data
 
 
 import excel "$drive\Supp_China.xls", sheet("FRED Graph") clear
 
 keep A B
 
 gen temp =_n
 
 drop if temp<13
 
 rename A date
 rename B china
 
 destring china, replace
 
 expand 4
 
 sort date
 
 drop if china==.
 
 gen quarter = tq(1959q4)+_n
 
 tsset quarter, quarterly
 
 order date quarter
 
 keep quarter china
 
 gen location = "china"
 rename china gdp
 
 replace gdp = gdp/4
 
 save "$drive\temp9", replace
 
 clear
 
 cd "$drive\"
 
 use temp1
 
 forv i=2(1)9{
 append using temp`i'
 }
 
 
 save supp_gdp_data, replace
 
 **** World Bank Supplemental Data ****
 
 
 import excel "$drive\world_bank_data.xls", sheet("Data") clear
 
 *Drop misc info
 gen temp =_n
 
 drop if temp<4
 drop B C D
 
 rename A location
 replace location = lower(location)
 
 local i = 1960
 foreach v in E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE AF AG AH AI AJ AK AL AM AN AO AP AQ AR AS AT AU AV AW AX AY AZ BA BB BC BD BE BF BG {
 rename `v' gdp`i'
 local i = `i' +1
 }
 
 destring gdp*, replace
 
 reshape long gdp, i(location) j(year)
 expand 4
 
 replace gdp = ((1+gdp/100)^(1/4)-1)*100
 
 sort location year
 
 egen quarter=seq(), by(location)
 
 replace quarter = quarter-1

 drop temp year
 
 save wb_supp_gdp_data, replace
 
 *** Interest Rates

clear

import excel "$drive\Supplemental_Interest.xls", sheet("FRED Graph")

gen temp =_n

drop if temp<=30

gen quarter = _n +tq(1959q4)

tsset quarter, quarterly

destring B C D E F G H I, replace

preserve 

keep quarter B

rename B interest

gen location= "india"

sort quarter

save "$drive\tempa1", replace

restore

preserve 

keep quarter C

rename C interest

gen location= "brazil"

sort quarter

save "$drive\tempa2", replace

restore

preserve 

keep quarter D

rename D interest

gen location= "saudi arabia"

sort quarter

save "$drive\tempa3", replace

restore

preserve 

keep quarter E

rename E interest

gen location= "indonesia"

sort quarter

save "$drive\tempa4", replace

restore

preserve 

keep quarter F

rename F interest

gen location= "turkey"

sort quarter

save "$drive\tempa5", replace

restore

preserve 

keep quarter G

rename G interest

gen location= "south africa"

sort quarter

save "$drive\tempa6", replace

restore

preserve 

keep quarter H

rename H interest

gen location= "russia"

sort quarter

save "$drive\tempa7", replace

restore

preserve 

keep quarter I

rename I interest

gen location= "china"

sort quarter

save "$drive\tempa8", replace

restore

clear 

use "$drive\tempa1"

forv i=2(1)8{
append using tempa`i'
}

order location quarter

sort location quarter

drop if interest==.

save "$drive\supp_interest_data.dta", replace

**** Add onto Argentina and Chilean Data


use argentina_price, clear

merge 1:1 quarter using argentina_actual_price

drop _merge

sort quarter

gen cpi_test = 1200*(cpi/l.cpi -1)

gen inflation = actual_cpi*10

replace inflation = cpi_test if inflation==.

keep if quarter>=tq(1960q1) & quarter<=tq(2014q1)

drop cpi actual_ cpi_test

gen location = "Argentina"

reshape wide inflation, i(location) j(quarter)

save matching_argentina_data, replace

*** Add Extra Chilean Data
/*
clear

import excel "$drive\DataChile.xlsx", sheet("Sheet1")

gen temp = _n

drop if temp<41

gen quarter = _n + tq(1985q4)

rename B gdp

keep quarter gdp

tsset quarter, quarterly

gen location ="Chile"

gen country_id = 7

destring gdp, replace

gen temp = (ln(gdp)-ln(l.gdp))*100

replace gdp = temp

drop temp

drop if quarter>=tq(1995q3)

xtset country_id quarter, quarterly

sort country_id quarter

save matching_chile_data, replace
*/
