*** This Program Creates the Regressions in Table 6 of Gibbs and Kulish (2017)
*** Christopher Gibbs, UNSW 
*** Created: 22/5/2017
*** Last Updates: 8/8/2017

clear
*set appropriate directory
cd "CHANGE DIRECTORY BEFORE USE/Data"
glo drive = "CHANGE DIRECTORY BEFORE USE//Data"

*** Regressions from model implied sacrifice ratios ***


import delimited "XX_L1.csv", clear

rename v1 b_sac
rename v2 change
rename v3 peak
rename v4 duration

replace peak = peak *400

reg b_sac  change peak duration  
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2   change peak duration using "Tab01_final.tex", replace `ops' 

gen lambda=1

save actual_sr_l1, replace

import delimited "XX_L05.csv", clear

rename v1 b_sac
rename v2 change
rename v3 peak
rename v4 duration

replace peak = peak *400

reg b_sac  change peak duration  
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2   change peak duration using "Tab01_final.tex", append `ops' 

gen lambda=0.5

save actual_sr_l05, replace

import delimited "XX_L0.csv", clear

rename v1 b_sac
rename v2 change
rename v3 peak
rename v4 duration

replace peak = peak *400
gen lambda=0

reg b_sac  change peak duration 
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2   change peak duration using "Tab01_final.tex", append `ops' 


*** Mix the results together

append using actual_sr_l1
append using actual_sr_l05

reg b_sac  change peak duration
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2   change peak duration using "Tab01_final.tex", append `ops' 


***** Ball's measure to filter data
**********
** Lambda = 1
**********

 import delimited "simINF_L1.csv", clear

 * Get relevant information about data
 describe
 local num_quarters = `r(k)'
 local num_countries = `r(N)'
 dis `r(N)'
 dis `r(k)'
 
 * Naming Variables

 
 forv i=1(1)`num_quarters'{
 local j = `i'-1
 rename v`i' inflation`j' 
 }
 
 gen country_id = _n 
 gen location = _n
 
 gen developed = 0
 replace developed = 1 if inflation0==12
 
 order location country_id inflation0
 * Create 9-quarter moving average to identify  peaks and troughts
 
 local jj = `num_quarters'-1

forv i=8(1)`jj'{
local j1 = `i' - 8
local j2 = `i' - 7
local j3 = `i' - 6
local j4 = `i' - 5
local j5 = `i' - 4
local j6 = `i' - 3
local j7 = `i' - 2
local j8 = `i' - 1
local j9 = `i' - 0
egen inf_ma9_`j5' = rowmean(inflation`j1' inflation`j2' inflation`j3' inflation`j4' inflation`j5' inflation`j6' inflation`j7' inflation`j8' inflation`j9')
}


* Find Troughs Peaks using Ball's definitions
gen counter = 1
gen type_id= -20

 local jj = `num_quarters'-5
* Find Troughs Peaks
replace type_id= 1
forv i=12(1)`jj' {
local j1 = `i' - 8
local j2 = `i' - 7
local j3 = `i' - 6
local j4 = `i' - 5
local j5 = `i' - 4
local j6 = `i' - 3
local j7 = `i' - 2
local j8 = `i' - 1
local j9 = `i' - 0
gen disinflation_indicator`j5' =0
gen peak_test`j5' = 0
novarabbrev {
replace peak_test`j5' = 1 if type_id==1 & inf_ma9_`j5'> inf_ma9_`j1' & inf_ma9_`j5'> inf_ma9_`j2' & inf_ma9_`j5'> inf_ma9_`j3' & inf_ma9_`j5'> inf_ma9_`j4' & inf_ma9_`j5'> inf_ma9_`j6' & inf_ma9_`j5'> inf_ma9_`j7' & inf_ma9_`j5'> inf_ma9_`j8' & inf_ma9_`j5'> inf_ma9_`j9' 
replace type_id = 2 if type_id==1 & inf_ma9_`j5'> inf_ma9_`j1' & inf_ma9_`j5'> inf_ma9_`j2' & inf_ma9_`j5'> inf_ma9_`j3' & inf_ma9_`j5'> inf_ma9_`j4' & inf_ma9_`j5'> inf_ma9_`j6' & inf_ma9_`j5'> inf_ma9_`j7' & inf_ma9_`j5'> inf_ma9_`j8' & inf_ma9_`j5'> inf_ma9_`j9' 
replace disinflation_indicator`j5' = counter if type_id==2
replace peak_test`j5' = 2 if type_id==2 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
replace type_id = 1 if type_id==2 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
replace counter = counter + 1 if type_id==1 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
}
}



reshape long inflation inf_ma9_ peak_test disinflation_indicator, i(location) j(quarter)

egen test = max(peak_test), by(location disinflation_ind)

replace disinflation_ind = 0 if test!=2


*tsline inf_ma9 peak_ if country_id==15

******************************************************************************
** Keep only the quantities we care about
******************************************************************************
drop type_id 

* Adding disinflation indicator
preserve

drop if peak==0 | peak==.
gen change_inflation = 0

forv i = 1(1) `num_countries'{
replace change_inflation = inf_ma[_n] - inf_ma[_n+1] if country_id == `i'
}

gen indicator = .
forv i = 1(1)`num_countries'{
replace indicator = peak[_n] - peak[_n+1] if country_id == `i'
}

sort location quarter

* Fix an end of sample issue with Argentina data
replace indicator = 1 if peak==2 & indicator==.

gen temp = change[_n-1]

*keep if change>2 | temp>2

replace change_inf = temp if indicator==1

*drop if indicator==0

*drop if change<2

drop temp

save disinflation_episodes, replace

restore

*Put the data set back together

merge 1:1 country_id quarter using disinflation_episodes

drop _merge

*** GDP Data

preserve 


 import delimited "simG_L1.csv", clear
 
  describe
 local num_quarters = `r(k)'
 
  forv i=1(1)`num_quarters' {
 local j = `i'-1
 rename v`i' gdp`j' 
 }
 
 gen country_id = _n 
 gen location = _n
 
 
reshape long gdp , i(location) j(quarter)

 
 save gdp_data_sim, replace
 
 restore

merge 1:1 location quarter using gdp_data_sim

drop _merge
 

****************************************************************************
*Indentify the time periods where disinflation output costs will be calculated
*****************************************************************************

replace disinflation=. if disinflation==0

egen disinflation_id = group(country disinflation)

*replace disinflation_id = . if disinflation_ind==0

drop counter 

egen temp = max(change), by(disinflation_id)
 
replace change = temp

drop temp

drop country_id

egen country_id = group(location)

sort country_id quarter

*****************************************************************************
* ADD length of disinflation *
*****************************************************************************
egen time = seq(), by(disinflation_id)
replace time =. if disinflation_id==.
egen dis_duration = max(time), by(disinflation_id)

***************************************************************************
* Calculate trend output using Ball's Definitions
***************************************************************************

* Generate indicator to ensure there is gdp data to cover the entire episode
egen test2 = count(gdp), by(disinflation_id)

gen test3 = 0
replace test3 = 1 if test2==dis_duration

*rename gdp gdp_growth

rename gdp gdp_growth

*replace missing observations with 0

replace gdp_growth = 0 if gdp_growth==.

*create new variable for log gdp call yhat
gen yhat = 1000

bysort country_id (quarter): replace yhat = yhat[_n-1] *(1+gdp/400) if _n>1

replace yhat = ln(yhat)

* Identify periods to calculate trend
gen ball_def_gdp=.

replace ball_def = yhat if indicator==-1 & test3==1

replace ball_def = yhat[_n+4] if indicator==1  & test3==1

gen ball_def_date=.

replace ball_def_date = quarter if indicator==-1  & test3==1

replace ball_def_date = quarter[_n+4] if indicator==1  & test3==1

gen linear_trend=.

egen dis_trend_id = group(location disinflation_id) if test3==1

sum dis_trend_id

forv i=1(1)`r(max)' {
reg ball_def_gdp ball_def_date if dis_trend_id==`i'
gen slope =_b[ball_def_date]
gen constant = _b[_cons]
replace linear_trend = slope*quarter + constant if dis_trend_id==`i'
drop slope constant

dis `i'
}

*******************************************************************************
*Calculating SaRs
*******************************************************************************

* Ball's measure of sacrifice ration

gen outputgap = (yhat - linear_trend)*100
egen cumulative = sum(outputgap), by(dis_trend_id)
gen b_sacrifice_ratios = -(1/change)*cumu if indicator==-1 & dis_trend_id!=.
gen lambda = 1
keep if change>2
drop peak
save ball_measure_l1, replace

rename change_inf  change
rename inf_ma peak
rename dis_dur duration

reg b_sac  change peak duration
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2   change peak duration using "Tab01_final.tex", append `ops' 

**********
** Lambda = 0.5
**********

 import delimited "simINF_L05.csv", clear

 * Get relevant information about data
 describe
 local num_quarters = `r(k)'
 local num_countries = `r(N)'
 dis `r(N)'
 dis `r(k)'
 
 * Naming Variables

 
 forv i=1(1)`num_quarters'{
 local j = `i'-1
 rename v`i' inflation`j' 
 }
 
 gen country_id = _n 
 gen location = _n
 
 gen developed = 0
 replace developed = 1 if inflation0==12
 
 order location country_id inflation0
 * Create 9-quarter moving average to identify  peaks and troughts
 
 local jj = `num_quarters'-1

forv i=8(1)`jj'{
local j1 = `i' - 8
local j2 = `i' - 7
local j3 = `i' - 6
local j4 = `i' - 5
local j5 = `i' - 4
local j6 = `i' - 3
local j7 = `i' - 2
local j8 = `i' - 1
local j9 = `i' - 0
egen inf_ma9_`j5' = rowmean(inflation`j1' inflation`j2' inflation`j3' inflation`j4' inflation`j5' inflation`j6' inflation`j7' inflation`j8' inflation`j9')
}


* Find Troughs Peaks using Ball's definitions
gen counter = 1
gen type_id= -20

 local jj = `num_quarters'-5
* Find Troughs Peaks
replace type_id= 1
forv i=12(1)`jj' {
local j1 = `i' - 8
local j2 = `i' - 7
local j3 = `i' - 6
local j4 = `i' - 5
local j5 = `i' - 4
local j6 = `i' - 3
local j7 = `i' - 2
local j8 = `i' - 1
local j9 = `i' - 0
gen disinflation_indicator`j5' =0
gen peak_test`j5' = 0
novarabbrev {
replace peak_test`j5' = 1 if type_id==1 & inf_ma9_`j5'> inf_ma9_`j1' & inf_ma9_`j5'> inf_ma9_`j2' & inf_ma9_`j5'> inf_ma9_`j3' & inf_ma9_`j5'> inf_ma9_`j4' & inf_ma9_`j5'> inf_ma9_`j6' & inf_ma9_`j5'> inf_ma9_`j7' & inf_ma9_`j5'> inf_ma9_`j8' & inf_ma9_`j5'> inf_ma9_`j9' 
replace type_id = 2 if type_id==1 & inf_ma9_`j5'> inf_ma9_`j1' & inf_ma9_`j5'> inf_ma9_`j2' & inf_ma9_`j5'> inf_ma9_`j3' & inf_ma9_`j5'> inf_ma9_`j4' & inf_ma9_`j5'> inf_ma9_`j6' & inf_ma9_`j5'> inf_ma9_`j7' & inf_ma9_`j5'> inf_ma9_`j8' & inf_ma9_`j5'> inf_ma9_`j9' 
replace disinflation_indicator`j5' = counter if type_id==2
replace peak_test`j5' = 2 if type_id==2 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
replace type_id = 1 if type_id==2 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
replace counter = counter + 1 if type_id==1 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
}
}



reshape long inflation inf_ma9_ peak_test disinflation_indicator, i(location) j(quarter)

egen test = max(peak_test), by(location disinflation_ind)

replace disinflation_ind = 0 if test!=2


*tsline inf_ma9 peak_ if country_id==15

******************************************************************************
** Keep only the quantities we care about
******************************************************************************
drop type_id 

* Adding disinflation indicator
preserve

drop if peak==0 | peak==.
gen change_inflation = 0

forv i = 1(1) `num_countries'{
replace change_inflation = inf_ma[_n] - inf_ma[_n+1] if country_id == `i'
}

gen indicator = .
forv i = 1(1)`num_countries'{
replace indicator = peak[_n] - peak[_n+1] if country_id == `i'
}

sort location quarter

* Fix an end of sample issue with Argentina data
replace indicator = 1 if peak==2 & indicator==.

gen temp = change[_n-1]

*keep if change>2 | temp>2

replace change_inf = temp if indicator==1

*drop if indicator==0

*drop if change<2

drop temp

save disinflation_episodes, replace

restore

*Put the data set back together

merge 1:1 country_id quarter using disinflation_episodes

drop _merge

*** GDP Data

preserve 


 import delimited "simG_L05.csv", clear
 
  describe
 local num_quarters = `r(k)'
 
  forv i=1(1)`num_quarters' {
 local j = `i'-1
 rename v`i' gdp`j' 
 }
 
 gen country_id = _n 
 gen location = _n
 
 
reshape long gdp , i(location) j(quarter)

 
 save gdp_data_sim, replace
 
 restore

merge 1:1 location quarter using gdp_data_sim

drop _merge
 

****************************************************************************
*Indentify the time periods where disinflation output costs will be calculated
*****************************************************************************

replace disinflation=. if disinflation==0

egen disinflation_id = group(country disinflation)

*replace disinflation_id = . if disinflation_ind==0

drop counter 

egen temp = max(change), by(disinflation_id)
 
replace change = temp

drop temp

drop country_id

egen country_id = group(location)

sort country_id quarter

*****************************************************************************
* ADD length of disinflation *
*****************************************************************************
egen time = seq(), by(disinflation_id)
replace time =. if disinflation_id==.
egen dis_duration = max(time), by(disinflation_id)

***************************************************************************
* Calculate trend output using Ball's Definitions
***************************************************************************

* Generate indicator to ensure there is gdp data to cover the entire episode
egen test2 = count(gdp), by(disinflation_id)

gen test3 = 0
replace test3 = 1 if test2==dis_duration

*rename gdp gdp_growth

rename gdp gdp_growth

*replace missing observations with 0

replace gdp_growth = 0 if gdp_growth==.

*create new variable for log gdp call yhat
gen yhat = 1000

bysort country_id (quarter): replace yhat = yhat[_n-1] *(1+gdp/400) if _n>1

replace yhat = ln(yhat)

* Identify periods to calculate trend
gen ball_def_gdp=.

replace ball_def = yhat if indicator==-1 & test3==1

replace ball_def = yhat[_n+4] if indicator==1  & test3==1

gen ball_def_date=.

replace ball_def_date = quarter if indicator==-1  & test3==1

replace ball_def_date = quarter[_n+4] if indicator==1  & test3==1

gen linear_trend=.

egen dis_trend_id = group(location disinflation_id) if test3==1

sum dis_trend_id

forv i=1(1)`r(max)' {
reg ball_def_gdp ball_def_date if dis_trend_id==`i'
gen slope =_b[ball_def_date]
gen constant = _b[_cons]
replace linear_trend = slope*quarter + constant if dis_trend_id==`i'
drop slope constant

dis `i'
}

*******************************************************************************
*Calculating SaRs
*******************************************************************************

* Ball's measure of sacrifice ration

gen outputgap = (yhat - linear_trend)*100
egen cumulative = sum(outputgap), by(dis_trend_id)
gen b_sacrifice_ratios = -(1/change)*cumu if indicator==-1 & dis_trend_id!=.
gen lambda = 0.5
keep if change>2
drop peak
save ball_measure_l05, replace


rename change_inf  change
rename inf_ma peak
rename dis_dur duration

reg b_sac  change peak duration
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2   change peak duration using "Tab01_final.tex", append `ops' 

**********
** Lambda = 0.0
**********

 import delimited "simINF_L0.csv", clear

 * Get relevant information about data
 describe
 local num_quarters = `r(k)'
 local num_countries = `r(N)'
 dis `r(N)'
 dis `r(k)'
 
 * Naming Variables

 
 forv i=1(1)`num_quarters'{
 local j = `i'-1
 rename v`i' inflation`j' 
 }
 
 gen country_id = _n 
 gen location = _n
 
 gen developed = 0
 replace developed = 1 if inflation0==12
 
 order location country_id inflation0
 * Create 9-quarter moving average to identify  peaks and troughts
 
 local jj = `num_quarters'-1

forv i=8(1)`jj'{
local j1 = `i' - 8
local j2 = `i' - 7
local j3 = `i' - 6
local j4 = `i' - 5
local j5 = `i' - 4
local j6 = `i' - 3
local j7 = `i' - 2
local j8 = `i' - 1
local j9 = `i' - 0
egen inf_ma9_`j5' = rowmean(inflation`j1' inflation`j2' inflation`j3' inflation`j4' inflation`j5' inflation`j6' inflation`j7' inflation`j8' inflation`j9')
}


* Find Troughs Peaks using Ball's definitions
gen counter = 1
gen type_id= -20

 local jj = `num_quarters'-5
* Find Troughs Peaks
replace type_id= 1
forv i=12(1)`jj' {
local j1 = `i' - 8
local j2 = `i' - 7
local j3 = `i' - 6
local j4 = `i' - 5
local j5 = `i' - 4
local j6 = `i' - 3
local j7 = `i' - 2
local j8 = `i' - 1
local j9 = `i' - 0
gen disinflation_indicator`j5' =0
gen peak_test`j5' = 0
novarabbrev {
replace peak_test`j5' = 1 if type_id==1 & inf_ma9_`j5'> inf_ma9_`j1' & inf_ma9_`j5'> inf_ma9_`j2' & inf_ma9_`j5'> inf_ma9_`j3' & inf_ma9_`j5'> inf_ma9_`j4' & inf_ma9_`j5'> inf_ma9_`j6' & inf_ma9_`j5'> inf_ma9_`j7' & inf_ma9_`j5'> inf_ma9_`j8' & inf_ma9_`j5'> inf_ma9_`j9' 
replace type_id = 2 if type_id==1 & inf_ma9_`j5'> inf_ma9_`j1' & inf_ma9_`j5'> inf_ma9_`j2' & inf_ma9_`j5'> inf_ma9_`j3' & inf_ma9_`j5'> inf_ma9_`j4' & inf_ma9_`j5'> inf_ma9_`j6' & inf_ma9_`j5'> inf_ma9_`j7' & inf_ma9_`j5'> inf_ma9_`j8' & inf_ma9_`j5'> inf_ma9_`j9' 
replace disinflation_indicator`j5' = counter if type_id==2
replace peak_test`j5' = 2 if type_id==2 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
replace type_id = 1 if type_id==2 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
replace counter = counter + 1 if type_id==1 & inf_ma9_`j5'< inf_ma9_`j1' & inf_ma9_`j5'< inf_ma9_`j2' & inf_ma9_`j5'< inf_ma9_`j3' & inf_ma9_`j5'< inf_ma9_`j4' & inf_ma9_`j5'< inf_ma9_`j6' & inf_ma9_`j5'< inf_ma9_`j7' & inf_ma9_`j5'< inf_ma9_`j8' & inf_ma9_`j5'< inf_ma9_`j9' 
}
}



reshape long inflation inf_ma9_ peak_test disinflation_indicator, i(location) j(quarter)

egen test = max(peak_test), by(location disinflation_ind)

replace disinflation_ind = 0 if test!=2


*tsline inf_ma9 peak_ if country_id==15

******************************************************************************
** Keep only the quantities we care about
******************************************************************************
drop type_id 

* Adding disinflation indicator
preserve

drop if peak==0 | peak==.
gen change_inflation = 0

forv i = 1(1) `num_countries'{
replace change_inflation = inf_ma[_n] - inf_ma[_n+1] if country_id == `i'
}

gen indicator = .
forv i = 1(1)`num_countries'{
replace indicator = peak[_n] - peak[_n+1] if country_id == `i'
}

sort location quarter

* Fix an end of sample issue with Argentina data
replace indicator = 1 if peak==2 & indicator==.

gen temp = change[_n-1]

*keep if change>2 | temp>2

replace change_inf = temp if indicator==1

*drop if indicator==0

*drop if change<2

drop temp

save disinflation_episodes, replace

restore

*Put the data set back together

merge 1:1 country_id quarter using disinflation_episodes

drop _merge

*** GDP Data

preserve 


 import delimited "simG_L0.csv", clear
 
  describe
 local num_quarters = `r(k)'
 
  forv i=1(1)`num_quarters' {
 local j = `i'-1
 rename v`i' gdp`j' 
 }
 
 gen country_id = _n 
 gen location = _n
 
 
reshape long gdp , i(location) j(quarter)

 
 save gdp_data_sim, replace
 
 restore

merge 1:1 location quarter using gdp_data_sim

drop _merge
 

****************************************************************************
*Indentify the time periods where disinflation output costs will be calculated
*****************************************************************************

replace disinflation=. if disinflation==0

egen disinflation_id = group(country disinflation)

*replace disinflation_id = . if disinflation_ind==0

drop counter 

egen temp = max(change), by(disinflation_id)
 
replace change = temp

drop temp

drop country_id

egen country_id = group(location)

sort country_id quarter

*****************************************************************************
* ADD length of disinflation *
*****************************************************************************
egen time = seq(), by(disinflation_id)
replace time =. if disinflation_id==.
egen dis_duration = max(time), by(disinflation_id)

***************************************************************************
* Calculate trend output using Ball's Definitions
***************************************************************************

* Generate indicator to ensure there is gdp data to cover the entire episode
egen test2 = count(gdp), by(disinflation_id)

gen test3 = 0
replace test3 = 1 if test2==dis_duration

*rename gdp gdp_growth

rename gdp gdp_growth

*replace missing observations with 0

replace gdp_growth = 0 if gdp_growth==.

*create new variable for log gdp call yhat
gen yhat = 1000

bysort country_id (quarter): replace yhat = yhat[_n-1] *(1+gdp/400) if _n>1

replace yhat = ln(yhat)

* Identify periods to calculate trend
gen ball_def_gdp=.

replace ball_def = yhat if indicator==-1 & test3==1

replace ball_def = yhat[_n+4] if indicator==1  & test3==1

gen ball_def_date=.

replace ball_def_date = quarter if indicator==-1  & test3==1

replace ball_def_date = quarter[_n+4] if indicator==1  & test3==1

gen linear_trend=.

egen dis_trend_id = group(location disinflation_id) if test3==1

sum dis_trend_id

forv i=1(1)`r(max)' {
reg ball_def_gdp ball_def_date if dis_trend_id==`i'
gen slope =_b[ball_def_date]
gen constant = _b[_cons]
replace linear_trend = slope*quarter + constant if dis_trend_id==`i'
drop slope constant

dis `i'
}

*******************************************************************************
*Calculating SaRs
*******************************************************************************

* Ball's measure of sacrifice ration

gen outputgap = (yhat - linear_trend)*100
egen cumulative = sum(outputgap), by(dis_trend_id)
gen b_sacrifice_ratios = -(1/change)*cumu if indicator==-1 & dis_trend_id!=.
gen lambda = 0
keep if change>2
drop peak
save ball_measure_l0, replace

rename change_inf  change
rename inf_ma peak
rename dis_dur duration

reg b_sac  change peak duration
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2   change peak duration using "Tab01_final.tex", append `ops' 

use ball_measure_l0, clear

append using ball_measure_l05
append using ball_measure_l1

rename change_inf  change
rename inf_ma peak
rename dis_dur duration

reg b_sac  change peak duration
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2   change peak duration using "Tab01_final.tex", append `ops' 
