(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     50442,       1276]
NotebookOptionsPosition[     49606,       1243]
NotebookOutlinePosition[     49993,       1260]
CellTagsIndexPosition[     49950,       1257]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Simple New Keynesian Model", "Subsection",
 CellChangeTimes->{{3.639096839212618*^9, 3.6390968461855946`*^9}, 
   3.639097023436199*^9}],

Cell[BoxData[{
 FormBox[
  RowBox[{
   SubscriptBox["x", "t"], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["r", "t"], "-", 
       RowBox[{
        SubscriptBox["E", "t"], 
        SubscriptBox["\[Pi]", 
         RowBox[{"t", "+", "1"}]]}]}], ")"}]}], "+", " ", 
    RowBox[{
     SubscriptBox["E", "t"], 
     SubscriptBox["x", 
      RowBox[{"t", "+", "1"}]]}]}]}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   SubscriptBox["\[Pi]", "t"], "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["E", "t"], 
     SubscriptBox["\[Pi]", 
      RowBox[{"t", "+", "1"}]]}], " ", "+", " ", 
    RowBox[{"\[CurlyPhi]", " ", 
     SubscriptBox["x", "t"]}]}]}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   SubscriptBox["r", "t"], " ", "=", " ", 
   RowBox[{"\[Pi]", " ", "+", " ", 
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Pi]", "t"], " ", "-", " ", "\[Pi]"}], ")"}]}]}]}], 
  TraditionalForm]}], "Input",
 CellChangeTimes->{{3.639096938254345*^9, 3.6390970399760933`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Model", " ", "matrices"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "    ", ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "\[Alpha]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[CurlyPhi]"}], ",", "1"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B", "    ", ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "-", "1"}], ")"}], "\[Pi]bar"}], ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CC", "   ", ":=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"BigA", " ", ":=", " ", 
     RowBox[{
      RowBox[{"Inverse", "[", "A", "]"}], ".", "B"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"BigB", " ", ":=", " ", 
     RowBox[{
      RowBox[{"Inverse", "[", "A", "]"}], ".", "CC"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7112229856064167`*^9, 3.7112229942832327`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Imperfectly", " ", "Anchored", " ", "Expectations"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "program", " ", "below", " ", "was", " ", "used", " ", "to", 
    " ", "create", " ", "the", " ", "Figures", " ", "2", " ", "and", " ", "3",
     " ", "in", " ", "the", " ", "appendix"}], "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"FLPAConvergenceShock", "[", 
      RowBox[{
      "T_", ",", "Ta_", ",", "new_", ",", "l_", ",", "g_", ",", "a_", ",", 
       "j_", ",", "d_", ",", "ppibar_", ",", "shockx_", ",", "shockpi_"}], 
      "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "rule", ",", "target", ",", "beliefpath", ",", "plm", ",", 
         "flpbeliefs", ",", "allpath", ",", "outgapbelief", ",", 
         "inflationbelief", ",", "outgappath", ",", "inflationpath", ",", 
         "RealRate", ",", "outinflationbelief", ",", "outinflationpath", ",", 
         " ", "outRealRate", ",", "outoutgappath", ",", "outoutgapbelief"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Rational", " ", "Anchor"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"rule", "=", 
         RowBox[{
          RowBox[{"NestList", "[", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"BigB", ".", "#"}], "+", "BigA"}], " ", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
                RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
                RowBox[{"\[CapitalDelta]", "\[Rule]", "d"}], ",", 
                RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}], ",", 
                RowBox[{"\[Lambda]", "\[Rule]", "l"}], ",", 
                RowBox[{"\[Gamma]", "\[Rule]", "g"}]}], "}"}]}], " ", "&"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "new"}], "}"}], ",", "Ta"}], "]"}], "//", 
          "Simplify"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"beliefpath", " ", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"rule", "[", 
            RowBox[{"[", 
             RowBox[{"Ta", "+", "1", "-", "k"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "Ta", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", "Learning", " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"plm", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0", ",", "ppibar"}], "}"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"flpbeliefs", " ", "=", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"beliefpath", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "\[Lambda]"}], ")"}], "*", 
             RowBox[{"plm", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "/.", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]", "\[Rule]", "l"}], "}"}]}]}], ";", "\n", 
        RowBox[{"allpath", " ", "=", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"BigA", " ", "+", " ", 
            RowBox[{"BigB", ".", 
             RowBox[{"flpbeliefs", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
            RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
            RowBox[{"\[CapitalDelta]", "\[Rule]", "d"}], ",", 
            RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}], ",", 
            RowBox[{"\[Lambda]", "\[Rule]", "l"}], ",", 
            RowBox[{"\[Gamma]", "\[Rule]", "g"}]}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"i", "<", "Ta"}], ",", 
          RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"plm", " ", "=", " ", 
            RowBox[{"Insert", "[", 
             RowBox[{"plm", ",", " ", 
              RowBox[{
               RowBox[{
                RowBox[{"plm", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "+", 
                RowBox[{"\[Gamma]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"allpath", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                   RowBox[{"plm", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}]}], " ", "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
                 RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
                 RowBox[{"\[CapitalDelta]", "\[Rule]", "d"}], ",", 
                 RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}], ",", 
                 RowBox[{"\[Lambda]", "\[Rule]", "l"}], ",", 
                 RowBox[{"\[Gamma]", "\[Rule]", "g"}]}], "}"}]}], ",", 
              RowBox[{"i", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
           
           RowBox[{"flpbeliefs", " ", "=", 
            RowBox[{"Insert", "[", 
             RowBox[{"flpbeliefs", ",", " ", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Lambda]", " ", 
                 RowBox[{"beliefpath", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", "+", "1"}], "]"}], "]"}]}], " ", "+", " ", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "-", "\[Lambda]"}], ")"}], "*", 
                 RowBox[{"plm", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", "+", "1"}], "]"}], "]"}]}]}], " ", "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
                 RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
                 RowBox[{"\[CapitalDelta]", "\[Rule]", "d"}], ",", 
                 RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}], ",", 
                 RowBox[{"\[Lambda]", "\[Rule]", "l"}], ",", 
                 RowBox[{"\[Gamma]", "\[Rule]", "g"}]}], "}"}]}], ",", 
              RowBox[{"i", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
           
           RowBox[{"allpath", " ", "=", " ", 
            RowBox[{"Insert", "[", 
             RowBox[{"allpath", ",", 
              RowBox[{
               RowBox[{"BigA", "+", 
                RowBox[{"BigB", ".", 
                 RowBox[{"flpbeliefs", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", "+", "1"}], "]"}], "]"}]}]}], "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
                 RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
                 RowBox[{"\[CapitalDelta]", "\[Rule]", "d"}], ",", 
                 RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}], ",", 
                 RowBox[{"\[Lambda]", "\[Rule]", "l"}], ",", 
                 RowBox[{"\[Gamma]", "\[Rule]", "g"}]}], "}"}]}], ",", 
              RowBox[{"i", "+", "1"}]}], "]"}]}], ";"}]}], "\n", "]"}], ";", 
        "\n", "\n", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "Ta"}], ",", 
          RowBox[{"i", "<", "T"}], ",", 
          RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"plm", " ", "=", " ", 
            RowBox[{"Insert", "[", 
             RowBox[{"plm", ",", " ", 
              RowBox[{
               RowBox[{
                RowBox[{"plm", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "+", 
                RowBox[{"\[Gamma]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"allpath", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                   RowBox[{"plm", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}]}], " ", "/.", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]", "\[Rule]", "g"}], "}"}]}], ",", 
              RowBox[{"i", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
           
           RowBox[{"flpbeliefs", " ", "=", 
            RowBox[{"Insert", "[", 
             RowBox[{"flpbeliefs", ",", " ", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Lambda]", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "new"}], "}"}]}], "+", " ", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "-", "\[Lambda]"}], ")"}], "*", 
                 RowBox[{"plm", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", "+", "1"}], "]"}], "]"}]}]}], " ", "/.", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]", "\[Rule]", "l"}], "}"}]}], ",", 
              RowBox[{"i", "+", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
           
           RowBox[{"allpath", " ", "=", " ", 
            RowBox[{"Insert", "[", 
             RowBox[{"allpath", ",", 
              RowBox[{
               RowBox[{"BigA", "+", 
                RowBox[{"BigB", ".", 
                 RowBox[{"flpbeliefs", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "+", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"i", "\[Equal]", 
                   RowBox[{"Ta", "+", "2"}]}], ",", 
                  RowBox[{
                   RowBox[{"Inverse", "[", 
                    RowBox[{"A", "-", "CC"}], "]"}], ".", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "shockx", "}"}], ",", 
                    RowBox[{"{", "shockpi", "}"}]}], "}"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", "0", "}"}], ",", 
                    RowBox[{"{", "0", "}"}]}], "}"}]}], "]"}]}], "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
                 RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
                 RowBox[{"\[Pi]bar", "\[Rule]", "new"}], ",", 
                 RowBox[{"\[Lambda]", "\[Rule]", "l"}], ",", 
                 RowBox[{"\[Gamma]", "\[Rule]", "g"}]}], "}"}]}], ",", 
              RowBox[{"i", "+", "1"}]}], "]"}]}], ";"}]}], "\n", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"outgappath", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"allpath", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"inflationpath", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"allpath", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"outgapbelief", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"flpbeliefs", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"inflationbelief", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"flpbeliefs", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", "\[IndentingNewLine]", 
        RowBox[{"RealRate", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Pi]bar", " ", "+", " ", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"inflationpath", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], "-", "\[Pi]bar"}], ")"}]}], 
             " ", "-", " ", 
             RowBox[{"inflationbelief", "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
              RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "Ta", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"RealRate", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"RealRate", ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Pi]bar", " ", "+", " ", 
               RowBox[{"\[Alpha]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"inflationpath", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], "-", "\[Pi]bar"}], ")"}]}],
                " ", "-", " ", 
               RowBox[{"inflationbelief", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
                RowBox[{"\[Pi]bar", "\[Rule]", "new"}]}], "}"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", 
               RowBox[{"Ta", "+", "1"}], ",", "T", ",", "1"}], "}"}]}], 
            "]"}]}], "]"}]}], ";", "\n", 
        RowBox[{"outRealRate", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "RealRate"}], "]"}]}], ";", 
        "\n", "\n", 
        RowBox[{"outinflationbelief", "=", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"ppibar", ",", "ppibar"}], "}"}], ",", 
           "inflationbelief"}], "]"}]}], ";", "\n", 
        RowBox[{"outinflationpath", "=", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"ppibar", ",", "ppibar"}], "}"}], ",", "inflationpath"}], 
          "]"}]}], ";", "\n", 
        RowBox[{"outoutgappath", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "outgappath"}], "]"}]}], ";",
         "\n", 
        RowBox[{"outoutgapbelief", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "outgapbelief"}], "]"}]}], 
        ";", "\n", 
        RowBox[{"target", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ppibar", "-", "d"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"Print", "[", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Total", "[", 
            RowBox[{"Flatten", "@", "outoutgappath"}], "]"}]}], "/", "d"}], 
         "]"}], ";", "\n", 
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Flatten", "@", "outRealRate"}], ",", 
            RowBox[{"Flatten", "@", "outinflationbelief"}], ",", " ", 
            RowBox[{"Flatten", "@", "outinflationpath"}], ",", 
            RowBox[{"Flatten", "@", "outoutgappath"}], ",", 
            RowBox[{"Flatten", "@", "outoutgapbelief"}], ",", "target"}], 
           "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Blue", ",", "Thick"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Thick"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
             RowBox[{"{", "Gray", "}"}]}], "}"}]}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "T"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", ".05"}], ",", ".12"}], "}"}]}], "}"}]}], ",", " ", 
          RowBox[{"BaseStyle", " ", "->", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"FontWeight", " ", "->", " ", "\"\<Bold\>\""}], ",", " ", 
             RowBox[{"FontSize", " ", "->", " ", "12"}]}], "}"}]}]}], 
         "]"}]}]}], "\[IndentingNewLine]", "\n", "]"}]}], ";"}], "\n", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"FLPAConvergenceShock", "[", 
      RowBox[{"20", ",", "Ta", ",", 
       RowBox[{"ppibar", "-", "d"}], ",", "l", ",", "g", ",", "a", ",", "j", 
       ",", "d", ",", "ppibar", ",", "shockx", ",", "shockpi"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Ta", ",", "2"}], "}"}], ",", "2", ",", "25", ",", "1"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "1.5"}], "}"}], ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"j", ",", "0.1"}], "}"}], ",", "0.1", ",", "1"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"d", ",", "0.075"}], "}"}], ",", "0", ",", "0.1"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"ppibar", ",", "0.085"}], "}"}], ",", "0", ",", "1"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"l", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"g", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"shockx", ",", "0"}], "}"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"shockpi", ",", "0"}], "}"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.71122305109448*^9, 3.711223102495821*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1.5, $CellContext`d$$ = 
    0.075, $CellContext`g$$ = 0.5, $CellContext`j$$ = 0.1, $CellContext`l$$ = 
    0.5, $CellContext`ppibar$$ = 0.085, $CellContext`shockpi$$ = 
    0, $CellContext`shockx$$ = 0, $CellContext`Ta$$ = 2, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`Ta$$], 2}, 2, 25, 1}, {{
       Hold[$CellContext`a$$], 1.5}, 0, 3}, {{
       Hold[$CellContext`j$$], 0.1}, 0.1, 1}, {{
       Hold[$CellContext`d$$], 0.075}, 0, 0.1}, {{
       Hold[$CellContext`ppibar$$], 0.085}, 0, 1}, {{
       Hold[$CellContext`l$$], 0.5}, 0, 1}, {{
       Hold[$CellContext`g$$], 0.5}, 0, 1}, {{
       Hold[$CellContext`shockx$$], 0}, -1, 1}, {{
       Hold[$CellContext`shockpi$$], 0}, -1, 1}}, Typeset`size$$ = {
    308., {76., 88.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`Ta$3308$$ = 
    0, $CellContext`a$3309$$ = 0, $CellContext`j$3310$$ = 
    0, $CellContext`d$3311$$ = 0, $CellContext`ppibar$3312$$ = 
    0, $CellContext`l$3313$$ = 0, $CellContext`g$3314$$ = 
    0, $CellContext`shockx$3315$$ = 0, $CellContext`shockpi$3316$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1.5, $CellContext`d$$ = 
        0.075, $CellContext`g$$ = 0.5, $CellContext`j$$ = 
        0.1, $CellContext`l$$ = 0.5, $CellContext`ppibar$$ = 
        0.085, $CellContext`shockpi$$ = 0, $CellContext`shockx$$ = 
        0, $CellContext`Ta$$ = 2}, "ControllerVariables" :> {
        Hold[$CellContext`Ta$$, $CellContext`Ta$3308$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$3309$$, 0], 
        Hold[$CellContext`j$$, $CellContext`j$3310$$, 0], 
        Hold[$CellContext`d$$, $CellContext`d$3311$$, 0], 
        Hold[$CellContext`ppibar$$, $CellContext`ppibar$3312$$, 0], 
        Hold[$CellContext`l$$, $CellContext`l$3313$$, 0], 
        Hold[$CellContext`g$$, $CellContext`g$3314$$, 0], 
        Hold[$CellContext`shockx$$, $CellContext`shockx$3315$$, 0], 
        Hold[$CellContext`shockpi$$, $CellContext`shockpi$3316$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`FLPAConvergenceShock[
       20, $CellContext`Ta$$, $CellContext`ppibar$$ - $CellContext`d$$, \
$CellContext`l$$, $CellContext`g$$, $CellContext`a$$, $CellContext`j$$, \
$CellContext`d$$, $CellContext`ppibar$$, $CellContext`shockx$$, \
$CellContext`shockpi$$], 
      "Specifications" :> {{{$CellContext`Ta$$, 2}, 2, 25, 
         1}, {{$CellContext`a$$, 1.5}, 0, 3}, {{$CellContext`j$$, 0.1}, 0.1, 
         1}, {{$CellContext`d$$, 0.075}, 0, 
         0.1}, {{$CellContext`ppibar$$, 0.085}, 0, 
         1}, {{$CellContext`l$$, 0.5}, 0, 1}, {{$CellContext`g$$, 0.5}, 0, 
         1}, {{$CellContext`shockx$$, 0}, -1, 
         1}, {{$CellContext`shockpi$$, 0}, -1, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{717., {204., 213.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.7112232260476437`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.28789568139730903`"}]], "Print",
 CellChangeTimes->{3.711223226536372*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Ascari", " ", "and", " ", "Ropelle", " ", "Case"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "    ", ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "\[Alpha]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[CurlyPhi]"}], ",", "1"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B", "    ", ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Alpha]", "-", "1"}], ")"}], "\[Pi]bar"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "\[Gamma]"}], ")"}], "\[Pi]old"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Gamma]"}], ")"}], "\[Pi]old"}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CC", "   ", ":=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "\[Gamma]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[Gamma]"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"BigA", " ", ":=", " ", 
     RowBox[{
      RowBox[{"Inverse", "[", "A", "]"}], ".", "B"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"BigB", " ", ":=", " ", 
     RowBox[{
      RowBox[{"Inverse", "[", "A", "]"}], ".", "CC"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"A", "-", "CC"}], "]"}], ".", "B"}], " ", "//", "Simplify"}], "//",
     "MatrixForm"}], " ", 
   RowBox[{"(*", 
    RowBox[{"Steady", " ", "State"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AntREPathExplorationShock", "[", 
      RowBox[{
      "T_", ",", "new_", ",", "a_", ",", "j_", ",", "d_", ",", "ppibar_", ",",
        "L_", ",", "\[Rho]_", ",", "shockx_", ",", "shockpi_"}], "]"}], ":=", 
     
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "rule", ",", "target", ",", "shock", ",", "afteroutgapbelief", ",", 
         "afterinflationbelief", ",", "afterRealRate", ",", "afterpath", ",", 
         "afteroutgappath", ",", "afterinflationpath", ",", "beliefpath", ",",
          "allpath", ",", "outgapbelief", ",", "inflationbelief", ",", 
         "outgappath", ",", "inflationpath", ",", " ", "RealRate", ",", 
         "outinflationbelief", ",", "outinflationpath", ",", " ", 
         "outRealRate", ",", "outoutgappath", ",", "outoutgapbelief", ",", 
         "tempRealRate", ",", "tempinflationbelief", ",", "tempinflationpath",
          ",", "tempgappath", ",", "tempgapbelief"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"rule", " ", "=", " ", 
         RowBox[{
          RowBox[{"NestList", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"BigB", ".", "#"}], " ", "+", " ", "BigA"}], " ", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
                RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
                RowBox[{"\[CapitalDelta]", "\[Rule]", "d"}], ",", 
                RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}], ",", 
                RowBox[{"\[Pi]old", "\[Rule]", "ppibar"}], ",", 
                RowBox[{"\[Gamma]", "\[Rule]", "L"}]}], "}"}]}], " ", "&"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "new"}], "}"}], ",", "T"}], "]"}], "//", 
          "Simplify"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"beliefpath", " ", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"rule", "[", 
            RowBox[{"[", 
             RowBox[{"T", "+", "1", "-", "k"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"allpath", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"BigA", "+", 
             RowBox[{"BigB", ".", 
              RowBox[{"rule", "[", 
               RowBox[{"[", 
                RowBox[{"T", "+", "1", "-", "k"}], "]"}], "]"}]}]}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
              RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
              RowBox[{"\[CapitalDelta]", "\[Rule]", "d"}], ",", 
              RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}], ",", 
              RowBox[{"\[Pi]old", "\[Rule]", "ppibar"}], ",", 
              RowBox[{"\[Gamma]", "\[Rule]", "L"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"outgappath", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"allpath", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"inflationpath", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"allpath", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"outgapbelief", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"beliefpath", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"inflationbelief", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"beliefpath", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"RealRate", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Pi]bar", " ", "+", " ", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"inflationpath", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], "-", "\[Pi]bar"}], ")"}]}], 
             " ", "-", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"inflationbelief", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], "\[Gamma]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[Gamma]"}], ")"}], "ppibar"}]}], ")"}]}],
             "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
              RowBox[{"\[Pi]bar", "\[Rule]", "ppibar"}], ",", 
              RowBox[{"\[Gamma]", "\[Rule]", "L"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "T", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"tempRealRate", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "RealRate"}], "]"}]}], ";", 
        "\n", 
        RowBox[{"tempinflationbelief", "=", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"ppibar", ",", "ppibar"}], "}"}], ",", 
           "inflationbelief"}], "]"}]}], ";", "\n", 
        RowBox[{"tempinflationpath", "=", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"ppibar", ",", "ppibar"}], "}"}], ",", "inflationpath"}], 
          "]"}]}], ";", "\n", 
        RowBox[{"tempgappath", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "outgappath"}], "]"}]}], ";",
         "\n", 
        RowBox[{"tempgapbelief", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "outgapbelief"}], "]"}]}], 
        ";", "\n", 
        RowBox[{"shock", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Inverse", "[", 
            RowBox[{"A", "-", "CC"}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", "shockx", "}"}], ",", 
             RowBox[{"{", "shockpi", "}"}]}], "}"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
            RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
            RowBox[{"\[Pi]bar", "\[Rule]", "new"}], ",", 
            RowBox[{"\[Pi]old", "\[Rule]", "ppibar"}], ",", 
            RowBox[{"\[Gamma]", "\[Rule]", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"\[Rho]", "^", "2"}]}], ")"}]}]}], "}"}]}]}], ";", 
        "\n", 
        RowBox[{"Print", "[", "shock", "]"}], ";", "\n", 
        RowBox[{"afterpath", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Inverse", "[", 
               RowBox[{"A", "-", "CC"}], "]"}], ".", "B"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"k", "\[Equal]", "2"}], ",", "shock", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", "0", "}"}], ",", 
                 RowBox[{"{", "0", "}"}]}], "}"}]}], "]"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Gamma]", "\[Rule]", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"\[Rho]", "^", "k"}]}], ")"}]}], ",", 
              RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
              RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
              RowBox[{"\[Pi]bar", "\[Rule]", "new"}], ",", 
              RowBox[{"\[Pi]old", "\[Rule]", "ppibar"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "25"}], "}"}]}], "]"}]}], ";", "\n", 
        RowBox[{"afteroutgappath", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"afterpath", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "25", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"afteroutgapbelief", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"afterpath", "[", 
             RowBox[{"[", 
              RowBox[{"k", ",", "1"}], "]"}], "]"}], "-", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"k", "\[Equal]", "2"}], ",", 
              RowBox[{"shock", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "0"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "25", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"afterinflationpath", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"afterpath", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "25", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"afterinflationbelief", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"afterpath", "[", 
             RowBox[{"[", 
              RowBox[{"k", ",", "2"}], "]"}], "]"}], "-", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"k", "\[Equal]", "2"}], ",", 
              RowBox[{"shock", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "0"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "25", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"afterRealRate", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Pi]bar", " ", "+", " ", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"afterinflationpath", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], "-", "\[Pi]bar"}], ")"}]}], 
             " ", "-", " ", 
             RowBox[{"afterinflationbelief", "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
              RowBox[{"\[Pi]bar", "\[Rule]", "new"}], ",", 
              RowBox[{"\[Pi]old", "\[Rule]", "ppibar"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "20", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"outRealRate", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"tempRealRate", ",", "afterRealRate"}], "]"}]}], ";", "\n", 
        
        RowBox[{"outinflationbelief", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"tempinflationbelief", ",", " ", "afterinflationbelief"}], 
          "]"}]}], ";", "\n", 
        RowBox[{"outinflationpath", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"tempinflationpath", ",", " ", "afterinflationpath"}], 
          "]"}]}], ";", "\n", 
        RowBox[{"outoutgapbelief", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"tempgapbelief", ",", " ", "afteroutgappath"}], "]"}]}], 
        ";", "\n", 
        RowBox[{"outoutgappath", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"tempgappath", ",", " ", "afteroutgappath"}], "]"}]}], ";", 
        "\n", 
        RowBox[{"target", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ppibar", "-", "d"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "25", ",", "1"}], "}"}]}], "]"}]}], 
        ";", "\n", 
        RowBox[{"Print", "[", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Total", "[", 
            RowBox[{"Flatten", "@", "outoutgappath"}], "]"}]}], "/", "d"}], 
         "]"}], ";", "\n", 
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Flatten", "@", "outRealRate"}], ",", 
            RowBox[{"Flatten", "@", "outinflationbelief"}], ",", " ", 
            RowBox[{"Flatten", "@", "outinflationpath"}], ",", 
            RowBox[{"Flatten", "@", "outoutgappath"}], ",", 
            RowBox[{"Flatten", "@", "outoutgapbelief"}], ",", "target"}], 
           "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Blue", ",", "Thick"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Thick"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
             RowBox[{"{", "Gray", "}"}]}], "}"}]}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "20"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", ".06"}], ",", "0.1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"BaseStyle", " ", "->", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"FontWeight", " ", "->", " ", "\"\<Bold\>\""}], ",", " ", 
             RowBox[{"FontSize", " ", "->", " ", "12"}]}], "}"}]}]}], 
         "]"}]}]}], "\[IndentingNewLine]", "\n", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"AntREPathExplorationShock", "[", 
      RowBox[{"Ta", ",", 
       RowBox[{"ppibar", "-", "d"}], ",", "a", ",", "j", ",", "d", ",", 
       "ppibar", ",", "L", ",", "\[Rho]", ",", "shockx", ",", "shockpi"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Ta", ",", "2"}], "}"}], ",", "2", ",", "100", ",", "1"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "1.5"}], "}"}], ",", "1", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"j", ",", "0.1"}], "}"}], ",", "0.1", ",", "1"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"d", ",", "0.075"}], "}"}], ",", "0", ",", "0.1"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"ppibar", ",", "0.085"}], "}"}], ",", "0", ",", "1"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"L", ",", "0.5"}], "}"}], ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Rho]", ",", "0.05"}], "}"}], ",", "0", ",", "1"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"shockx", ",", "0"}], "}"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"shockpi", ",", "0"}], "}"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.711223137380582*^9, 3.711223147600376*^9}, {
  3.71122320768671*^9, 3.711223208404574*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Gamma]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Pi]bar", "-", "\[Pi]old"}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Alpha]", "-", "\[Gamma]"}], ")"}], " ", 
          "\[CurlyPhi]"}]]}]},
      {
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", "\[Pi]bar"}], 
         "+", "\[Pi]old", "-", 
         RowBox[{"\[Gamma]", " ", "\[Pi]old"}]}], 
        RowBox[{"\[Alpha]", "-", "\[Gamma]"}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.711223231849037*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1.5, $CellContext`d$$ = 
    0.075, $CellContext`j$$ = 0.1, $CellContext`L$$ = 
    0.5, $CellContext`ppibar$$ = 0.085, $CellContext`shockpi$$ = 
    0, $CellContext`shockx$$ = 0, $CellContext`Ta$$ = 
    2, $CellContext`\[Rho]$$ = 0.05, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`Ta$$], 2}, 2, 100, 1}, {{
       Hold[$CellContext`a$$], 1.5}, 1, 10}, {{
       Hold[$CellContext`j$$], 0.1}, 0.1, 1}, {{
       Hold[$CellContext`d$$], 0.075}, 0, 0.1}, {{
       Hold[$CellContext`ppibar$$], 0.085}, 0, 1}, {{
       Hold[$CellContext`L$$], 0.5}, 0, 1}, {{
       Hold[$CellContext`\[Rho]$$], 0.05}, 0, 1}, {{
       Hold[$CellContext`shockx$$], 0}, -1, 1}, {{
       Hold[$CellContext`shockpi$$], 0}, -1, 1}}, Typeset`size$$ = {
    308., {76., 88.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`Ta$4445$$ = 
    0, $CellContext`a$4446$$ = 0, $CellContext`j$4447$$ = 
    0, $CellContext`d$4448$$ = 0, $CellContext`ppibar$4449$$ = 
    0, $CellContext`L$4450$$ = 0, $CellContext`\[Rho]$4451$$ = 
    0, $CellContext`shockx$4452$$ = 0, $CellContext`shockpi$4453$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1.5, $CellContext`d$$ = 
        0.075, $CellContext`j$$ = 0.1, $CellContext`L$$ = 
        0.5, $CellContext`ppibar$$ = 0.085, $CellContext`shockpi$$ = 
        0, $CellContext`shockx$$ = 0, $CellContext`Ta$$ = 
        2, $CellContext`\[Rho]$$ = 0.05}, "ControllerVariables" :> {
        Hold[$CellContext`Ta$$, $CellContext`Ta$4445$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$4446$$, 0], 
        Hold[$CellContext`j$$, $CellContext`j$4447$$, 0], 
        Hold[$CellContext`d$$, $CellContext`d$4448$$, 0], 
        Hold[$CellContext`ppibar$$, $CellContext`ppibar$4449$$, 0], 
        Hold[$CellContext`L$$, $CellContext`L$4450$$, 0], 
        Hold[$CellContext`\[Rho]$$, $CellContext`\[Rho]$4451$$, 0], 
        Hold[$CellContext`shockx$$, $CellContext`shockx$4452$$, 0], 
        Hold[$CellContext`shockpi$$, $CellContext`shockpi$4453$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`AntREPathExplorationShock[$CellContext`Ta$$, \
$CellContext`ppibar$$ - $CellContext`d$$, $CellContext`a$$, $CellContext`j$$, \
$CellContext`d$$, $CellContext`ppibar$$, $CellContext`L$$, \
$CellContext`\[Rho]$$, $CellContext`shockx$$, $CellContext`shockpi$$], 
      "Specifications" :> {{{$CellContext`Ta$$, 2}, 2, 100, 
         1}, {{$CellContext`a$$, 1.5}, 1, 10}, {{$CellContext`j$$, 0.1}, 0.1, 
         1}, {{$CellContext`d$$, 0.075}, 0, 
         0.1}, {{$CellContext`ppibar$$, 0.085}, 0, 
         1}, {{$CellContext`L$$, 0.5}, 0, 1}, {{$CellContext`\[Rho]$$, 0.05}, 
         0, 1}, {{$CellContext`shockx$$, 0}, -1, 
         1}, {{$CellContext`shockpi$$, 0}, -1, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{717., {204., 213.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.7112232318951797`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.711223232984274*^9}],

Cell[BoxData[
 RowBox[{"-", "0.029660422720738426`"}]], "Print",
 CellChangeTimes->{3.711223232998742*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 688},
WindowMargins->{{12, Automatic}, {Automatic, 24}},
Magnification:>1.5 Inherited,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 142, 2, 65, "Subsection"],
Cell[725, 26, 1109, 36, 94, "Input"],
Cell[1837, 64, 1285, 41, 169, "Input"],
Cell[CellGroupData[{
Cell[3147, 109, 18788, 455, 2294, "Input"],
Cell[21938, 566, 3797, 70, 441, "Output"],
Cell[25738, 638, 105, 2, 30, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25880, 645, 18077, 462, 2494, "Input"],
Cell[43960, 1109, 1464, 44, 110, "Output"],
Cell[45427, 1155, 3843, 70, 475, "Output"],
Cell[CellGroupData[{
Cell[49295, 1229, 162, 5, 30, "Print"],
Cell[49460, 1236, 106, 2, 30, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

