(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    855791,      15552]
NotebookOptionsPosition[    854415,      15506]
NotebookOutlinePosition[    854946,      15525]
CellTagsIndexPosition[    854903,      15522]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Stream Plot Figures - Gibbs & Kulish (2017)", "Title",
 CellChangeTimes->{{3.644007641989361*^9, 3.644007659277272*^9}, {
  3.7112225045047913`*^9, 3.711222505960413*^9}}],

Cell["Model Definitions", "Subtitle",
 CellChangeTimes->{{3.6440076800606055`*^9, 3.6440076871118507`*^9}}],

Cell[TextData[{
 "Simple New Keynesian Model:\n",
 Cell[BoxData[{
  FormBox[
   RowBox[{
    SubscriptBox["x", "t"], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["r", "t"], "-", 
        RowBox[{
         SubscriptBox["E", "t"], 
         SubscriptBox["\[Pi]", 
          RowBox[{"t", "+", "1"}]]}]}], ")"}]}], "+", " ", 
     RowBox[{
      SubscriptBox["E", "t"], 
      SubscriptBox["x", 
       RowBox[{"t", "+", "1"}]]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{
    SubscriptBox["\[Pi]", "t"], "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["E", "t"], 
      SubscriptBox["\[Pi]", 
       RowBox[{"t", "+", "1"}]]}], " ", "+", " ", 
     RowBox[{"\[CurlyPhi]", " ", 
      SubscriptBox["x", "t"]}]}]}], TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{
    SubscriptBox["r", "t"], " ", "=", " ", 
    RowBox[{"\[Pi]", " ", "+", " ", 
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Pi]", "t"], " ", "-", " ", "\[Pi]"}], ")"}]}]}]}], 
   TraditionalForm]}],
  CellChangeTimes->{{3.639096938254345*^9, 3.6390970399760933`*^9}}]
}], "Text",
 CellChangeTimes->{{3.6440076974587173`*^9, 3.6440077167580414`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "    ", ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Alpha]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[CurlyPhi]"}], ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B", "    ", ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "-", "1"}], ")"}], "\[Pi]bar"}], ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CC", "   ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BigA", " ", ":=", " ", 
   RowBox[{
    RowBox[{"Inverse", "[", "A", "]"}], ".", "B"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BigB", " ", ":=", " ", 
   RowBox[{
    RowBox[{"Inverse", "[", "A", "]"}], ".", "CC"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.644007874606453*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "This", " ", "Program", " ", "Calculates", " ", "the", " ", "initial", " ", 
   "points", " ", "for", " ", "output", " ", "and", " ", "inflation", " ", 
   "following", " ", "the", " ", "implementation", " ", "of", " ", "the", " ",
    "new", " ", "policy"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.644007798453181*^9, 3.644007843438053*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"InitialPoint", "[", 
    RowBox[{
    "new_", ",", "l_", ",", "g_", ",", "a_", ",", "j_", ",", "d_", ",", 
     "ppibar_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "plm", ",", " ", "flpbeliefs", ",", "allpath", ",", "coldturkey"}], 
      "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "Learning", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"plm", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ppibar"}], "}"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"flpbeliefs", " ", "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", "new"}], "}"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Lambda]"}], ")"}], "*", 
           RowBox[{"plm", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{"\[Lambda]", "\[Rule]", "l"}], "}"}]}]}], ";", "\n", 
      RowBox[{"allpath", " ", "=", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"BigA", " ", "+", " ", 
          RowBox[{"BigB", ".", 
           RowBox[{"flpbeliefs", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Alpha]", "\[Rule]", "a"}], ",", 
          RowBox[{"\[CurlyPhi]", "\[Rule]", "j"}], ",", 
          RowBox[{"\[Pi]bar", "\[Rule]", "new"}], ",", 
          RowBox[{"\[Lambda]", "\[Rule]", "l"}], ",", 
          RowBox[{"\[Gamma]", "\[Rule]", "g"}]}], "}"}]}]}], ";", "\n", 
      "allpath"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6440078853492527`*^9, 3.644007897131253*^9}, {
   3.6440079802948527`*^9, 3.6440079935819645`*^9}, {3.644008082913275*^9, 
   3.644008090138353*^9}, {3.64400813552757*^9, 3.6440082289281635`*^9}, {
   3.644008311602158*^9, 3.6440083171734295`*^9}, {3.6440085519362555`*^9, 
   3.6440085632533293`*^9}, 3.6440086542363386`*^9, {3.6440088954493923`*^9, 
   3.644008896556999*^9}, {3.644009057175558*^9, 3.6440091346791344`*^9}, {
   3.6440091822243795`*^9, 3.6440092152894754`*^9}, {3.6440092817338524`*^9, 
   3.644009307114152*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.644009303836088*^9, 3.644009303851689*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "program", " ", "generates", " ", "the", " ", "stream", " ", 
    "plot"}], " ", "*)"}], "\n", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"initial", " ", "=", " ", 
     RowBox[{"InitialPoint", "[", 
      RowBox[{
      "0.01", ",", "0.5", ",", "0.33", ",", "1.5", ",", ".1", ",", ".07", ",",
        ".08"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "\n", 
    RowBox[{
     RowBox[{"StreamPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"BigA", "+", 
            RowBox[{"\[Lambda]", " ", 
             RowBox[{"BigB", ".", 
              RowBox[{"Inverse", "[", 
               RowBox[{
                RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", "BigB"}], 
               "]"}], ".", "BigA"}]}]}], ")"}], ".", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
            RowBox[{"BigB", ".", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
               RowBox[{"\[Gamma]", " ", 
                RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
             RowBox[{"Inverse", "[", "BigB", "]"}]}]}], ")"}]}], " ", "+", 
         " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"BigB", ".", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
               RowBox[{"\[Gamma]", " ", 
                RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
             RowBox[{"Inverse", "[", "BigB", "]"}]}], "+", 
            RowBox[{"BigB", "*", 
             RowBox[{"(", 
              RowBox[{"1", "-", "\[Lambda]"}], ")"}], "\[Gamma]"}]}], ")"}], 
          ".", 
          RowBox[{"{", 
           RowBox[{"x", ",", "p"}], "}"}]}], "-", 
         RowBox[{"{", 
          RowBox[{"x", ",", "p"}], "}"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
          RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
          RowBox[{"\[Pi]bar", "\[Rule]", ".01"}], ",", 
          RowBox[{"\[Lambda]", "\[Rule]", "0.5"}], ",", 
          RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", ".1"}], ",", ".05"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", 
         RowBox[{"-", "0.01"}], ",", ".09"}], "}"}]}], 
      RowBox[{"(*", 
       RowBox[{",", 
        RowBox[{"StreamPoints", "\[Rule]", "20"}]}], "*)"}], "]"}], "\n", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.08"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.01"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", ".1"}], ",", "0.08"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.08"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", ".1"}], ",", "0.01"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.01"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0.09"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "0.01"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{"First", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], ",", 
            RowBox[{"p", "[", "t", "]"}]}], "}"}], " ", "/.", " ", "\n", 
          RowBox[{"NDSolve", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"x", "'"}], "[", "t", "]"}], "==", 
                RowBox[{
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}]], "\[Gamma]", 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"p", "[", "t", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Lambda]"}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]", "+", "\[Lambda]", 
                    "-", 
                    RowBox[{"\[Alpha]", " ", "\[Lambda]"}]}], ")"}], " ", 
                    "\[Pi]bar"}], "-", 
                   RowBox[{
                    RowBox[{"x", "[", "t", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Lambda]", "+", 
                    RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}], ")"}]}]}], 
                  ")"}]}]}], " ", "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
                 RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
                 RowBox[{"\[Pi]bar", "\[Rule]", "0.01"}], ",", 
                 RowBox[{"\[Lambda]", "\[Rule]", "0.5"}], ",", 
                 RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", 
              "\n", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"p", "'"}], "[", "t", "]"}], "==", 
                RowBox[{
                 FractionBox["1", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}]], "\[Gamma]", 
                 "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                    "\[Pi]bar"}]}], ")"}], " ", "\[CurlyPhi]"}], "+", 
                   RowBox[{"\[Lambda]", " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Pi]bar", "-", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], " ", "\[CurlyPhi]"}], "+", 
                    RowBox[{"\[Pi]bar", " ", "\[CurlyPhi]"}]}], ")"}]}], "-", 
                   RowBox[{
                    RowBox[{"p", "[", "t", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                    "\[CurlyPhi]"}], "+", 
                    RowBox[{"\[Lambda]", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "\[CurlyPhi]"}], ")"}]}]}], ")"}]}]}], 
                  ")"}]}]}], " ", "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
                 RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
                 RowBox[{"\[Pi]bar", "\[Rule]", "0.01"}], ",", 
                 RowBox[{"\[Lambda]", "\[Rule]", "0.5"}], ",", 
                 RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", 
              "\n", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
                 RowBox[{"initial", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
                RowBox[{
                 RowBox[{"p", "[", "0", "]"}], "\[Equal]", 
                 RowBox[{"initial", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "p"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "40"}], "}"}]}], "]"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "40"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}], ",", " ", 
     RowBox[{"BaseStyle", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontWeight", " ", "->", " ", "\"\<Bold\>\""}], ",", " ", 
        RowBox[{"FontSize", " ", "->", " ", "12"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"ImageMargins", "\[Rule]", "10"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6440078853492527`*^9, 3.644007897131253*^9}, {
   3.6440079802948527`*^9, 3.6440079935819645`*^9}, {3.644008082913275*^9, 
   3.644008090138353*^9}, {3.64400813552757*^9, 3.6440082289281635`*^9}, {
   3.644008311602158*^9, 3.6440083171734295`*^9}, {3.6440085519362555`*^9, 
   3.6440085632533293`*^9}, 3.6440086542363386`*^9, {3.6440088954493923`*^9, 
   3.644008896556999*^9}, {3.644009057175558*^9, 3.6440091346791344`*^9}, 
   3.6440091822243795`*^9, {3.644009316406331*^9, 3.644009329432582*^9}, {
   3.644009366697099*^9, 3.644009368990343*^9}, {3.6440094230229855`*^9, 
   3.644009547231536*^9}, {3.644009671060137*^9, 3.64400967155934*^9}, {
   3.6440098384900455`*^9, 3.6440098431856756`*^9}, {3.6440099155464764`*^9, 
   3.6440099612784767`*^9}, {3.644010001025878*^9, 3.6440100261017947`*^9}, {
   3.6440100843815117`*^9, 3.6440101052623825`*^9}, {3.6440101835876417`*^9, 
   3.644010315843935*^9}, {3.644010421727987*^9, 3.644010483088578*^9}, 
   3.6440105171036344`*^9, {3.6440105473294163`*^9, 3.6440105703710594`*^9}, {
   3.7039947438422155`*^9, 3.7039947968048153`*^9}, {3.7039948806896152`*^9, 
   3.7039949313976154`*^9}, 3.703995119185215*^9, {3.7039952286120152`*^9, 
   3.7039952287368155`*^9}, {3.7039973728469467`*^9, 3.703997385515147*^9}, {
   3.703997489632547*^9, 3.703997498306147*^9}, 3.703997589511747*^9, {
   3.7041487942599936`*^9, 3.704148807707021*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.036785746414043155`, 0.09}, {-0.036739933790758524`, 
        0.08934491541648468}, {-0.036609109144105735`, 
        0.08765810161394799}, {-0.03646777840468362, 
        0.08600493496720509}, {-0.036315941572492176`, 
        0.08438541547625594}, {-0.03615359864753141, 
        0.08279954314110058}, {-0.03598074962980132, 
        0.08124731796173898}, {-0.03579739451930191, 
        0.07972873993817116}, {-0.035603533316033165`, 
        0.0782438090703971}, {-0.03551620864078092, 0.07762368598170122}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.03547282897002875, 
        0.07731563175377834}, {-0.0353991660199951, 
        0.07679252535841682}, {-0.03518429263118771, 
        0.07537488880223031}, {-0.03495891314961099, 
        0.07399089940183758}, {-0.03448733877361775, 
        0.07130901733007086}, {-0.03399514575748356, 
        0.06873203440475416}, {-0.033482334101208405`, 
        0.06625995062588745}, {-0.03321675112104059, 0.06508138249147787}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.033148362994586955`, 
        0.0647778989378281}, {-0.0329489038047923, 
        0.06389276599347074}, {-0.032405164188305705`, 
        0.061578030934279035`}, {-0.03186142457181912, 
        0.05926329587508733}, {-0.03131768495533253, 
        0.056948560815895624`}, {-0.030681104592480916`, 
        0.05535166799660556}, {-0.02990571980627977, 0.05278201163278158}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.029815850635978376`, 
        0.052484181588284606`}, {-0.029125812246149373`, 
        0.05019736661427121}, {-0.0283481660729836, 
        0.04762021592310403}, {-0.027530484977698628`, 
        0.04606244175090883}, {-0.02693461689241114, 
        0.04454572108020045}, {-0.026340703572994312`, 
        0.043088522625542754`}, {-0.025748745019448148`, 
        0.04169084638693575}, {-0.025392587537077495`, 
        0.04088306586475385}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.025267081468008247`, 
        0.04059841269016675}, {-0.02515874123177265, 
        0.040352692364379446`}, {-0.025079205468728955`, 
        0.04017602111843744}, {-0.02499973803881323, 
        0.04000034785238884}, {-0.024152659715359116`, 
        0.03835061457152353}, {-0.023305581391904997`, 
        0.03670088129065822}, {-0.02245850306845088, 
        0.03505114800979291}, {-0.021611424744996763`, 
        0.033401414728927596`}, {-0.020919671713067294`, 
        0.03250252261029406}, {-0.020100003735176352`, 
        0.030985290710999057`}, {-0.019360428519558506`, 
        0.0296666175768568}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.019205435922526836`, 
        0.029396896805856332`}, {-0.01851548847052081, 
        0.028215829675549683`}, {-0.017750310623539663`, 
        0.026956007519731845`}, {-0.017002745219834196`, 
        0.02576933357896728}, {-0.016272792259404412`, 
        0.02465580785325599}, {-0.01556045174225031, 
        0.02361543034259797}, {-0.014188608037769147`, 
        0.021754119966441766`}, {-0.012887214106390713`, 
        0.02018540245049866}, {-0.012040856588833146`, 
        0.019256596375403275`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.011831323040149002`, 
        0.019026650957637323`}, {-0.01166347719570642, 
        0.018842454283343375`}, {-0.010524604553307679`, 
        0.017658451953550626`}, {-0.009470596179194496, 
        0.01663339546112042}, {-0.008501452073366864, 
        0.015767284806052745`}, {-0.006808806022165904, 
        0.014360426837382981`}, {-0.005437715755302435, 
        0.013286403876919302`}, {-0.0032506552473375245`, 
        0.011727935569477436`}, {-0.0022692587584729803`, 
        0.011121762943206251`}}]}, 
      {Arrowheads[{{0.0015839870050487392`, 1.}}], 
       ArrowBox[{{-0.002004582906287722, 
        0.010958282374190434`}, {-0.001935008050949549, 
        0.010915308537151773`}, {-0.0011405670109927812`, 
        0.010484443052274188`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, 0.04166482525099589}, {-0.09890083428720697, 
        0.04120185270289407}, {-0.0973236447721784, 
        0.040541544581361715`}, {-0.09577305861155921, 
        0.0398964516581652}, {-0.09424691474188278, 
        0.03926494425946741}, {-0.09274305209968248, 
        0.03864539271143121}, {-0.0912614706849583, 
        0.038037797014056615`}, {-0.08980217049771023, 
        0.03744215716734362}, {-0.0884993753624347, 0.03691299179661348}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08821104011642662, 
        0.036796193191623285`}, {-0.08695041380564252, 
        0.03628674502590243}, {-0.08555795730082286, 
        0.035726972731174235`}, {-0.08418778202347932, 
        0.035179156287107646`}, {-0.08282874735987375, 
        0.03463731776837182}, {-0.08146971269626818, 
        0.034095479249635983`}, {-0.08011067803266261, 
        0.033553640730900156`}, {-0.07875164336905704, 
        0.03301180221216432}, {-0.07739260870545148, 
        0.03246996369342849}, {-0.07665660446671965, 0.03217652346178662}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07636763136039335, 
        0.032061311713271735`}, {-0.07603357404184591, 
        0.03192812517469266}, {-0.07394843546343237, 
        0.0311702468606349}, {-0.0725237288911372, 
        0.03062544674190017}, {-0.07112400924435223, 
        0.030092996846251364`}, {-0.06974927652307747, 
        0.02957289717368848}, {-0.06839953072731292, 
        0.02906514772421152}, {-0.06707477185705857, 
        0.028569748497820478`}, {-0.06577499991231443, 
        0.028086699494515362`}, {-0.06471479018816642, 
        0.027696542000313896`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06442283785912424, 
        0.027589103456287224`}, {-0.06325041679935678, 
        0.027157652157162898`}, {-0.06291628454490748, 
        0.02703554339833693}, {-0.06258384601755619, 
        0.026914251037065025`}, {-0.06072121500946996, 
        0.02625814529058758}, {-0.05885858400138373, 
        0.025602039544110135`}, {-0.0569959529932975, 
        0.024945933797632693`}, {-0.05513332198521127, 
        0.024289828051155246`}, {-0.053727378418023, 
        0.023839193467083398`}, {-0.052679741617837714`, 
        0.023474794272170838`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.052385915076277545`, 
        0.02337259267408882}, {-0.051945339311271696`, 
        0.02321934733750106}, {-0.050217028138743694`, 
        0.02262367428584879}, {-0.04854244490043897, 
        0.02205217431212659}, {-0.046918802204351136`, 
        0.021503297453372053`}, {-0.045343312658473786`, 
        0.020975493746622775`}, {-0.04381597626280692, 
        0.02046876319187875}, {-0.042336793017350535`, 
        0.019983105789139984`}, {-0.04090576292210464, 
        0.019518521538406476`}, {-0.04058801470470004, 
        0.019416614523812024`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04029178333736179, 
        0.019321608312538034`}, {-0.039522885977069225`, 
        0.019075010439678224`}, {-0.038188162182244294`, 
        0.018652572492955228`}, {-0.03690159153762985, 
        0.018251207698237487`}, {-0.034450659812832594`, 
        0.017499090210587518`}, {-0.03214784091647765, 
        0.016806050622498046`}, {-0.029993134848565008`, 
        0.016172088933969077`}, {-0.02838392376272373, 0.0157110541073379}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02808486179880362, 
        0.015625373625826795`}, {-0.02798654160909468, 
        0.01559720514500061}, {-0.026111111962652235`, 
        0.015072643884984959`}, {-0.024349896673823243`, 
        0.014589649783314437`}, {-0.022702895742607712`, 
        0.014148222839989046`}, {-0.021170109169005635`, 
        0.013748363055008785`}, {-0.01948304248011406, 
        0.013319609479574354`}, {-0.017906010230796725`, 
        0.012928370477677724`}, {-0.016439012421053636`, 
        0.012574646049318896`}, {-0.01604552898783709, 
        0.012482953567394053`}}]}, 
      {Arrowheads[{{0.016573577136268666`, 1.}}], 
       ArrowBox[{{-0.015742552770844215`, 
        0.01241235176067202}, {-0.015082049050884786`, 
        0.012258436194497874`}, {-0.01269822562926982, 
        0.011738560205469236`}, {-0.010754539965951822`, 
        0.01136874251059181}, {-0.009139432360254886, 
        0.011099953721304406`}, {-0.007741343111503107, 
        0.010883164449045838`}, {-0.006560272219696479, 
        0.010718374693816106`}, {-0.005596219684835006, 
        0.010605584455615208`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.08576508954823489}, {0.049096241846110736`, 
        0.08501315528260978}, {0.04793271776916072, 0.08403786340113932}, {
        0.04679226858285984, 0.08307469890645183}, {0.045674552941541935`, 
        0.08212353690030533}, {0.04457922949954082, 0.08118425248445785}, {
        0.04350595691119036, 0.0802567207606674}, {0.042454393830824354`, 
        0.079340816830692}, {0.04055374380780476, 0.0776656495994284}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.04032102800451664, 0.07745920087697092}, {
        0.038458409675881704`, 0.07579098108410143}, {0.03658179965899686, 
        0.07408258261940504}, {0.034782469995397206`, 0.07241719817919348}, {
        0.033057689919753414`, 0.07079382857753094}, {0.03137904968359062, 
        0.06918776671382465}, {0.03119121900233015, 0.06900515433954178}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03096816603268719, 0.06878829822155295}, {
        0.029768857504677757`, 0.06762230885108488}, {0.02822459221209269, 
        0.06609648421211439}, {0.0267438437930469, 0.06460934961830485}, {
        0.025324261813368082`, 0.06315997629085468}, {0.023963598997918768`, 
        0.06174746184852653}, {0.022659700767136946`, 0.06037093278544914}, {
        0.02224026683157229, 0.05992055841783621}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.02202824946066489, 0.05969290113679902}, {
        0.021410433468379387`, 0.05902951064014751}, {0.021166950018256248`, 
        0.058765361481414646`}, {0.020925554166709045`, 
        0.05850257593445551}, {0.020686230109113, 0.05824114734614614}, {
        0.02056734058122753, 0.058110940046527504`}, {0.020448963120954646`, 
        0.05798106950396156}, {0.020331095783667878`, 0.05785153489513188}, {
        0.020213736631595213`, 0.0577223353985736}, {0.02009688373295219, 
        0.05759347019444037}, {0.01846675332376584, 0.05577425355283211}, {
        0.01693052360151838, 0.05401947242197111}, {0.015488194566209805`, 
        0.052329126801857376`}, {0.014139766217840126`, 0.0507032166924909}, {
        0.013964029898928351`, 0.05048802317656974}, {0.013835350425070208`, 
        0.05032987938688722}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.013648340237187214`, 0.050081355060809275`}, {
        0.01250989835757083, 0.04853181605013676}, {0.011229978429311978`, 
        0.046789710550607384`}, {0.009950058501053126, 0.04504760505107801}, {
        0.008670138572794273, 0.04330549955154863}, {0.008130284001526834, 
        0.0421853904749576}, {0.006980963842148821, 0.0405530490500644}, {
        0.006532813261507779, 0.03989525806926289}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.006357654403217154, 0.039638161633001996`}, {
        0.005918710195358032, 0.03899388367492865}, {0.004943523061154467, 
        0.037507894349550354`}, {0.004067725016793127, 0.03612280251972643}, {
        0.0032594692431566334`, 0.03479761400406398}, {0.0025187557402449874`,
         0.03353232880256301}, {0.001845584508058188, 0.03232694691522351}, {
        0.0007018688558591286, 0.030095893083028943`}, {
        0.00016283329810045722`, 0.028867043564170754`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0000378660697100333, 
        0.028582153418668765`}, {-0.00017167771344054434`, 
        0.02810445250748028}, {-0.000845944262940813, 
        0.02631193659261765}, {-0.0013918198557416601`, 
        0.024677656742481187`}, {-0.001809304491843085, 
        0.023201612957070888`}, {-0.002098398171245089, 
        0.021883805236386753`}, {-0.00244351366278895, 
        0.01961610562681974}, {-0.002579267333211362, 
        0.0177677655514029}, {-0.0025664507943616863`, 
        0.016514122107370754`}}]}, 
      {Arrowheads[{{0.0019820993310611457`, 1.}}], 
       ArrowBox[{{-0.0025618065428875494`, 
        0.016203117775649343`}, {-0.0024517203394034933`, 
        0.014974804409946805`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08723360662812876, 0.09}, {-0.0864474054667097, 
        0.08888100468232914}, {-0.08550843297536606, 
        0.08755551279849866}, {-0.08457670068791098, 
        0.08625126778860612}, {-0.0836522086043445, 
        0.08496826965265153}, {-0.08273495672466658, 
        0.08370651839063488}, {-0.08182494504887726, 
        0.08246601400255617}, {-0.08092217357697651, 
        0.0812467564884154}, {-0.08002302220701998, 
        0.0800381224112435}, {-0.07993610822404403, 0.07992129313742216}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.07975042152683781, 
        0.07967169415173438}, {-0.07912387083706346, 
        0.0788294883340716}, {-0.07822471946710693, 
        0.07762085425689971}, {-0.07732556809715041, 
        0.07641222017972782}, {-0.07642641672719389, 
        0.07520358610255592}, {-0.07552726535723736, 
        0.07399495202538403}, {-0.0739629318486086, 
        0.07217408000347}, {-0.07287581077245524, 
        0.07081011260113773}, {-0.07210896662463759, 0.06985657637569105}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07191400621387455, 
        0.06961415186906922}, {-0.07180085859160042, 
        0.06947345788715831}, {-0.07073807530604415, 
        0.06816411586153173}, {-0.06968746091578641, 
        0.066882086524258}, {-0.06864901542082723, 
        0.06562736987533714}, {-0.06762273882116657, 
        0.06439996591476911}, {-0.06660863111680447, 
        0.06319987464255394}, {-0.0656066923077409, 
        0.06202709605869162}, {-0.06533776162290468, 
        0.06171407484815546}, {-0.06506970702748593, 
        0.06140287985911655}, {-0.06388833147072227, 0.06010698534465449}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06367874796933153, 
        0.05987708545531019}, {-0.06341352133982173, 
        0.059586148562039296`}, {-0.06175733565215754, 
        0.05776941726496204}, {-0.06010114996449334, 
        0.05595268596788479}, {-0.058444964276829145`, 
        0.054135954670807535`}, {-0.05709682219542833, 
        0.052851841982639036`}, {-0.05549499714416355, 
        0.05112910220478097}, {-0.0551788390986679, 0.05079386177850534}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05496539839058796, 
        0.05056753840960574}, {-0.05392941251716506, 
        0.0494690234397357}, {-0.052400068314432835`, 
        0.047871605687503226`}, {-0.05090581832369254, 
        0.04633300663659828}, {-0.04944551633266982, 
        0.044849383975535596`}, {-0.04801916234136466, 
        0.04342073770431518}, {-0.04662675634977708, 
        0.04204706782293703}, {-0.046252895672409, 0.04168415071770669}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.046029676556212436`, 
        0.04146746562514111}, {-0.04526829835790708, 
        0.04072837433140114}, {-0.04394378836575464, 
        0.03946465722970752}, {-0.04265322637331977, 
        0.03825591651785616}, {-0.04139661238060247, 
        0.03710215219584707}, {-0.04017186074514705, 
        0.03599557962872119}, {-0.03897688582449781, 
        0.0349284141815195}, {-0.037811687618654756`, 
        0.03390065585424198}, {-0.03685273146263356, 0.03306591256103819}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.036617731593023964`, 
        0.03286206608771714}, {-0.03557062135138718, 
        0.03196336055945946}, {-0.03449475328996267, 
        0.031053823591954473`}, {-0.03344866194334433, 
        0.030183693744373657`}, {-0.032432347311532175`, 
        0.029352971016717022`}, {-0.030480254657221137`, 
        0.027787740540362895`}, {-0.028629681791924287`, 
        0.02633612578207871}, {-0.026939808177499146`, 
        0.025043398131417746`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.026690740212198777`, 
        0.02485700891530581}, {-0.02523309542837313, 
        0.02377374341972015}, {-0.02375468687075238, 
        0.02270191966583806}, {-0.022345063277985647`, 
        0.021698796609557928`}, {-0.02100422465007292, 
        0.02076437425087976}, {-0.01973217098701421, 
        0.019898652589803553`}, {-0.01852890228880951, 
        0.019101631626329312`}, {-0.01739441855545882, 
        0.01837331136045703}, {-0.01645312226308785, 
        0.017790691325281372`}}]}, 
      {Arrowheads[{{0.00801011823347622, 1.}}], 
       ArrowBox[{{-0.016186962527959283`, 
        0.01762966543093769}, {-0.015331805983319478`, 
        0.017122772921518356`}, {-0.013499668070143267`, 
        0.016077766230647626`}, {-0.011853339615477274`, 
        0.015169020245504945`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.022012997778176283`}, {0.0486744286908332, 
        0.021837608558287636`}, {0.04686770960786241, 
        0.021592307550852008`}, {0.04512690808297565, 0.02134985247235683}, {
        0.043449714954445995`, 0.021110312106453158`}, {0.041833821060546506`,
         0.020873755236792055`}, {0.040157910688245646`, 
        0.02062259764698413}, {0.038547331747905166`, 
        0.020375272722061015`}, {0.037683630146190424`, 
        0.020239523752806035`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAADgDm0/wioz8IMdL0Aa2UP2gyNOt4
8aI/euDQYXGdlD8Jf/8PTy6iP6QBa4KpXpQ/q8k3mLJyoT8ul4W26yCUPwDX
SdtZvqA/O8fj6jnkkz9Fykm5JZugP1csb4w22JM/Y0Fzmjh4oD9rHZf2PcyT
P4qEbPSRVaA/UIAdK1DAkz9yeAToWESgP6mVuVFdupM/Ko9aRjEzoD9tIYQr
bbSTP2JTbP4aIqA/yl+puH+ukz9xaUf/FRGgP/7rUvmUqJM/oYUHOCIAoD99
FqjtrKKTP0QQMhCPep4/6wGf2fFdkz89Z+iq3QWdP3Gi0rmsGpM/EwsP0IZP
mj+/AvBWhJiSP4nU+zXyIpo/T4FcOO2Pkj9HqovppfaZP0xLWeVch5I/xnof
+wK5mT9DExcHVXqSP6SvjpI=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024815459880080805`, 0.01798043819965419}, {
        0.023765484131298684`, 0.017758459877177304`}, {0.022176017949515466`,
         0.017422426366807908`}, {0.020586551767732247`, 
        0.017086392856438516`}, {0.01899708558594903, 
        0.016750359346069124`}, {0.01677312412755659, 
        0.016200101483076573`}, {0.014167174307094556`, 
        0.015601119956985529`}, {0.012679302080777763`, 
        0.015236758323478771`}}]}, 
      {Arrowheads[{{0.019663784462818926`, 1.}}], 
       ArrowBox[{{0.01237713702714311, 0.015162761813171213`}, {
        0.011963943141902113`, 0.015061575705709483`}, {0.010058974422151562`,
         0.014562395197484493`}, {0.008452268147842905, 
        0.014103578432310557`}, {0.0071438243189761415`, 
        0.013685125410187678`}, {0.005118903131145259, 0.01295284757664908}, {
        0.0036813899922358857`, 0.012349098678422689`}, {
        0.0019193577094871878`, 0.011467844135397153`}, {
        0.0009578345098178169, 0.010907926041324857`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.00247466884086246, 0.09}, {0.002052619692786359, 
        0.08907120810157503}, {0.0009811037668291693, 
        0.08662835775730468}, {-0.00005358882640635267, 
        0.08422414607720902}, {-0.0010882814196418746`, 
        0.08181993439711337}, {-0.0021229740128773968`, 
        0.07941572271701772}, {-0.0023807798985707685`, 
        0.07854945811107814}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0024695169890152015`, 
        0.07825128881025194}, {-0.0026750994070148986`, 
        0.07756050251637954}, {-0.0031739921382296496`, 
        0.07620642088347292}, {-0.0036528983230445073`, 
        0.07487715820579466}, {-0.004550751053474542, 
        0.07229308971612315}, {-0.0053686575983050025`, 
        0.06980829704736505}, {-0.006106617957535889, 
        0.06742278019952032}, {-0.0062008637327578865`, 
        0.06710737799683472}, {-0.006293838151358367, 
        0.06679365020555891}, {-0.006378892254344865, 0.06644173575401216}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0064519761042498855`, 
        0.06613934866093643}, {-0.006740368116050408, 
        0.06494611619948354}, {-0.007186898080742449, 
        0.06309858219340816}, {-0.007633428045434489, 
        0.06125104818733279}, {-0.00807995801012653, 
        0.059403514181257416`}, {-0.008212228836726596, 
        0.05805373874074753}, {-0.00860330130646123, 
        0.05629404448153665}, {-0.008957402112890925, 
        0.054592910053568776`}, {-0.009074460431031729, 
        0.05398660494449282}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.00913343367770124, 
        0.05368115223235396}, {-0.009274531256015683, 
        0.0529503354568439}, {-0.00955806183422991, 
        0.05136299496984822}, {-0.009811366945928018, 
        0.04982756287106793}, {-0.010034446591110009`, 
        0.048344039160503054`}, {-0.010227300769775877`, 
        0.046912423838153576`}, {-0.010522332727559256`, 
        0.044204918358100816`}, {-0.010696462819278156`, 
        0.04170504643090966}, {-0.010708990395526443`, 
        0.04134869774860954}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01071992025835923, 
        0.04103779625090619}, {-0.010777986815719875`, 
        0.03938608479522853}, {-0.01079520048767171, 
        0.037221310189705856`}, {-0.01074810383513366, 
        0.03521072261434163}, {-0.010636696858105726`, 
        0.033354322069135876`}, {-0.010478017312063477`, 
        0.031632513723198856`}, {-0.01028910295248248, 
        0.030025702745640852`}, {-0.010084418051899382`, 
        0.028632351742137546`}}]}, 
      {Arrowheads[{{0.018212891224959796`, 1.}}], 
       ArrowBox[{{-0.010032244742474786`, 
        0.028325702495820212`}, {-0.009820569792704245, 
        0.02715707289566191}, {-0.00946588419316262, 
        0.025506758808396233`}, {-0.009092024332943588, 
        0.023998478706358097`}, {-0.008698990212047147, 
        0.02263223258954751}, {-0.008286781830473296, 
        0.02140802045796446}, {-0.007453308685599289, 
        0.019292489969487743`}, {-0.006640071298627482, 
        0.01755867905993468}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.01112152126705709}, {-0.09860779342713426, 
        0.010991386469566178`}, {-0.09613753041958938, 
        0.010808261955044847`}, {-0.09406517349982116, 
        0.010633667263978673`}, {-0.092033656466364, 
        0.010465381059296917`}, {-0.09004297931921787, 
        0.010303403340999578`}, {-0.08809314205838281, 
        0.010147734109086658`}, {-0.08759770223537358, 
        0.010108970692061205`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08728755651505246, 
        0.01008470476240209}, {-0.08618414468385882, 
        0.009998373363558155}, {-0.08431598719564587, 
        0.00985532110441407}, {-0.08248866959374399, 
        0.009718577331654403}, {-0.08070219187815314, 
        0.009588142045279155}, {-0.08022529450057103, 
        0.009553771711161372}, {-0.07975113179027707, 
        0.009519804848686303}, {-0.07781640152997206, 
        0.009395342997962982}, {-0.07588167126966706, 
        0.009270881147239661}, {-0.07487505115720318, 
        0.009206124935615193}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07456459931955131, 
        0.009186153464104473}, {-0.07394694100936205, 
        0.009146419296516339}, {-0.07201221074905705, 
        0.009021957445793018}, {-0.07046658358202705, 
        0.00894918466358506}, {-0.06860051857347645, 
        0.008833844413187979}, {-0.06678023039942879, 
        0.008724585229675058}, {-0.06500571905988409, 
        0.008621407113046299}, {-0.06327498760475272, 
        0.008523915904952108}, {-0.062142109780059865`, 
        0.0084620729374789}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06183147871399233, 
        0.008445115815981539}, {-0.061586039083945096`, 
        0.008431717447042892}, {-0.05993887349746122, 
        0.008344811739318655}, {-0.058333490845301095`, 
        0.008263198781779394}, {-0.05676989112746471, 
        0.008186878574425108}, {-0.05524807434395207, 
        0.0081158511172558}, {-0.053768040494763185`, 
        0.008050116410271467}, {-0.052329789579898034`, 
        0.007989674453472113}, {-0.04956272391469554, 
        0.007881498720442958}, {-0.04940092799878211, 
        0.007875760042270724}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04909002993563127, 
        0.007864732916408362}, {-0.04693096470990115, 
        0.007788153848182958}, {-0.044434511965514865`, 
        0.007709639836692115}, {-0.04207336568153669, 
        0.007645956685970429}, {-0.03986339001974559, 
        0.007599968062198303}, {-0.03771468806339405, 
        0.007555446523686779}, {-0.03665081034741485, 
        0.0075386533031274695`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0363397555366018, 
        0.007533743329015257}, {-0.03568860123802744, 
        0.007523464913000088}, {-0.03377878387893416, 
        0.007502877763666068}, {-0.03130695799055331, 
        0.007491385703057225}, {-0.029029306524914762`, 
        0.007497390028980394}, {-0.026928658555402406`, 
        0.007517981288360199}, {-0.024987843155400133`, 
        0.007550250028121265}, {-0.023896893050524913`, 
        0.007575147267947643}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.023585880471531238`, 
        0.007582245076301685}, {-0.023189689398291823`, 
        0.007591286795188215}, {-0.02151702635746137, 
        0.007638182136485672}, {-0.019952683106292658`, 
        0.0076880265989382615`}, {-0.018479488718169568`, 
        0.007737910729470606}, {-0.015821617522265827`, 
        0.007843612424897848}, {-0.013537659881731296`, 
        0.0079594365505462}, {-0.01156203812449708, 
        0.008077066546748184}, {-0.011153909701328594`, 
        0.008103237648154333}}]}, 
      {Arrowheads[{{0.004070402225464734, 1.}}], 
       ArrowBox[{{-0.01084345377962589, 
        0.008123145532407882}, {-0.009829174578494294, 
        0.008188185853836329}, {-0.008316705085683624, 
        0.008294329291708244}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.04978612550042228}, {0.04957745440913568, 
        0.049573593947880565`}, {0.04710954124688883, 0.04832651200422817}, {
        0.04464162808464198, 0.04707943006057578}, {0.04217371492239512, 
        0.04583234811692338}, {0.04052857773945201, 0.044863145579740964`}, {
        0.03897677268082012, 0.0440200664707131}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03870341658732091, 0.04387155502562357}, {
        0.03822932484650582, 0.0436139860479865}, {0.03604297952534185, 
        0.042405569758409624`}, {0.03396954177596009, 
        0.041237896711010344`}, {0.032009011598360546`, 
        0.04011096690578866}, {0.031751910101063534`, 0.03996155180499453}, {
        0.03149666397978937, 0.039812833539575286`}, {0.029828874590843008`, 
        0.038776413145845554`}, {0.028161085201896644`, 
        0.037739992752115814`}, {0.02795281588170502, 0.03761056719498885}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02768858641556586, 0.037446366121912135`}, {
        0.026493295812950284`, 0.03670357235838608}, {0.02482550642400392, 
        0.03566715196465635}, {0.023844893135528778`, 0.0349240131117296}, {
        0.022298370117253805`, 0.033939348284023924`}, {0.020832691346093096`,
         0.03298918716700095}, {0.019447856822046646`, 
        0.032073529760660684`}, {0.018137481667889074`, 
        0.03119035800257465}, {0.017294892164021934`, 
        0.030612012029075666`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.017038405327301578`, 0.030435961735792997`}, {
        0.016895181006395005`, 0.030337653830314386`}, {0.01572095483756443, 
        0.029515417243879887`}, {0.014614803161397356`, 
        0.028723648243271158`}, {0.0126067232870537, 0.027231512999531002`}, {
        0.01087094138336404, 0.025861248099093914`}, {0.009353682036467708, 
        0.024596839081752506`}, {0.008001169832504037, 
        0.023422271487299393`}, {0.007265268840001423, 
        0.02275021007344099}}]}, 
      {Arrowheads[{{0.015787692365694384`, 1.}}], 
       ArrowBox[{{0.007035554356677931, 0.02254042337384554}, {
        0.006813404771473028, 0.022337545315734574`}, {0.005790386853374682, 
        0.02134266056705805}, {0.00410586980431692, 0.019575119081524508`}, {
        0.0028148960436716946`, 0.0180723507738534}, {0.001555250710421856, 
        0.016395021481009436`}, {0.0007256194776443242, 
        0.015056750946768848`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, 0.0675096353363349}, {-0.09872296704716596, 
        0.06647455799161318}, {-0.0978020567702959, 
        0.0659154397525051}, {-0.09614782776045122, 
        0.06463721072746206}, {-0.09451791478964644, 
        0.06338550197266152}, {-0.09291231785788155, 
        0.06216031348810344}, {-0.09133103696515656, 
        0.06096164527378785}, {-0.09007434078327163, 0.06001555208328681}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0898258053424651, 
        0.05982844425918842}, {-0.08977407211147145, 
        0.059789497329714746`}, {-0.08824142329682624, 
        0.05864386965588412}, {-0.08673309052122094, 
        0.05752476225229598}, {-0.08524907378465552, 
        0.05643217511895032}, {-0.08485160801614582, 
        0.05614070996006355}, {-0.08445582530783126, 
        0.05585101193777249}, {-0.08249503141464568, 
        0.05446523875211879}, {-0.08053423752146008, 
        0.05307946556646509}, {-0.07975106525847088, 0.05252596571848518}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07949701461628274, 
        0.05234641774612259}, {-0.07857344362827448, 
        0.05169369238081138}, {-0.0766126497350889, 
        0.05030791919515768}, {-0.07501196852284417, 
        0.049268142530736005`}, {-0.0731147239262952, 
        0.04794342755471148}, {-0.07125984552750399, 
        0.04665941805177309}, {-0.06944733332647052, 
        0.045416114021920806`}, {-0.06925288773059549, 0.0452838922369532}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0689956354704125, 
        0.04510896231439426}, {-0.06767560999668731, 
        0.044211353275972906`}, {-0.0659430982116469, 
        0.04304297362474761}, {-0.06424979797134926, 
        0.04191097506824494}, {-0.06259570927579441, 
        0.040815357606464896`}, {-0.060980832124982357`, 
        0.039756121239407465`}, {-0.059405166518913075`, 
        0.038733265967072654`}, {-0.0586250319403094, 
        0.038232383684793106`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05836325018732867, 
        0.03806430775855123}, {-0.05786871245758658, 
        0.037746791789460464`}, {-0.05637146994100287, 
        0.036796698706570895`}, {-0.054910343686237734`, 
        0.035878649210393444`}, {-0.05348223841036693, 
        0.0349883057929176}, {-0.05208715411339047, 
        0.03412566845414336}, {-0.050725090795308354`, 
        0.03329073719407074}, {-0.04939604845612059, 
        0.03248351201269973}, {-0.04810002709582716, 
        0.03170399291003032}, {-0.04778289224579865, 0.03151521536560758}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04751557428255076, 
        0.03135609179821191}, {-0.04683702671442808, 
        0.03095217988606253}, {-0.045607047311923346`, 
        0.03022807294079635}, {-0.043235456522704566`, 
        0.028849972777556604`}, {-0.040974559807278474`, 
        0.027556687911498873`}, {-0.038824357165645085`, 
        0.026348218342623162`}, {-0.03678484859780439, 
        0.025224564070929465`}, {-0.036710867992952284`, 
        0.02518454247770612}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.03643724660562488, 
        0.025036520386203676`}, {-0.03457560241576071, 
        0.024029419043327498`}, {-0.032474722834474806`, 
        0.02291084509690869}, {-0.030482209853946677`, 
        0.021868842231673045`}, {-0.028598063474176327`, 
        0.02090341044762056}, {-0.026822283695163755`, 
        0.020014549744751236`}, {-0.025387834040933158`, 
        0.019315749602016145`}}]}, 
      {Arrowheads[{{0.007641449859704441, 1.}}], 
       ArrowBox[{{-0.025107882866827507`, 
        0.01918008651655545}, {-0.023595823939411946`, 
        0.01846654158256207}, {-0.0221451439626727, 
        0.01780739412324223}, {-0.020783078381110168`, 
        0.01720571869668313}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05977884952128519, 0.09}, {-0.059041873859079275`, 
        0.08831483010473425}, {-0.05841043577021545, 
        0.08665300465631304}, {-0.05777974069950362, 
        0.0850234481198379}, {-0.05714978864694377, 
        0.08342616049530885}, {-0.056520579612535905`, 
        0.08186114178272587}, {-0.05589211359628003, 
        0.08032839198208898}, {-0.05526439059817615, 
        0.07882791109339816}, {-0.05511024601974472, 0.07846694754840482}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05498807138498783, 
        0.07818084868123168}, {-0.054637410618224254`, 
        0.07735969911665344}, {-0.05401117365642434, 
        0.07592375605185478}, {-0.05384216210733914, 
        0.07554034448737597}, {-0.05367327763375204, 
        0.0751590970008381}, {-0.052755796609612354`, 
        0.0732701307357154}, {-0.051838315585472666`, 
        0.0713811644705927}, {-0.05092083456133298, 
        0.06949219820547}, {-0.05000335353719328, 
        0.06760323194034729}, {-0.04962173462729061, 0.06695950866065643}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04946309123503503, 
        0.06669190545202587}, {-0.04915290672699341, 
        0.0661686793129523}, {-0.04824725527001957, 
        0.06435990368978153}, {-0.0473494901911563, 
        0.06260458849457876}, {-0.0464596114904036, 
        0.06090273372734393}, {-0.04557808143525169, 
        0.05925158951757209}, {-0.04470536229319082, 
        0.057648405994758276`}, {-0.043841454064220985`, 
        0.05609318315890247}, {-0.043622129600846854`, 
        0.055706584515879724`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04346862313077188, 
        0.05543600187264323}, {-0.042986356748342176`, 
        0.05458592101000468}, {-0.042140070345554406`, 
        0.0531266195480649}, {-0.041302594855857674`, 
        0.051715278773083136`}, {-0.04047393027925197, 
        0.05035189868505938}, {-0.0396540766157373, 
        0.04903647928399365}, {-0.03884406348496055, 
        0.047763515019991015`}, {-0.038044920506568616`, 
        0.046527500343156586`}, {-0.03725664768056149, 
        0.045328435253490354`}, {-0.03693569686102509, 
        0.04484865568033196}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.03676272382689212, 
        0.044590083576967025`}, {-0.03647924500693919, 
        0.044166319750992326`}, {-0.03495705011684901, 
        0.04195293750750087}, {-0.03347833583629809, 
        0.03988735361268221}, {-0.03204423153962874, 
        0.037952863748897454`}, {-0.030655866601183263`, 
        0.036132763598507686`}, {-0.02941264035942906, 
        0.03455333296099822}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02921823484352155, 
        0.03431047755413422}, {-0.02801635479896395, 
        0.03283573243791314}, {-0.02652780100832713, 
        0.03106627416447614}, {-0.02509486622006528, 
        0.02940980192360803}, {-0.023717550434178388`, 
        0.027866315715308825`}, {-0.022395853650666465`, 
        0.02643581553957852}, {-0.02112977586952951, 
        0.025118301396417114`}, {-0.0209914108866161, 
        0.024980614335638956`}}]}, 
      {Arrowheads[{{0.006850212763907399, 1.}}], 
       ArrowBox[{{-0.02077089497278641, 
        0.024761178844153225`}, {-0.01991931709076752, 
        0.02391377328582461}, {-0.018764477314380495`, 
        0.022822231207801}, {-0.01766525654036844, 0.0218436751623463}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, -0.00038641644801165717`}, {
        0.04952683157891378, -0.0002466450023889988}, {0.04704928247305371, 
        0.0004852098820350879}, {0.044571733367193646`, 
        0.0012170647664591747`}, {0.04292675250973709, 
        0.001630167332309434}, {0.04122381736111482, 0.002100337659282115}, {
        0.03958380446045906, 0.0025475515569368364`}, {0.03801845980426412, 
        0.0029686492026424283`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037717759870082974`, 0.003048390675676961}, {
        0.03649254540304705, 0.0033731100642923977`}, {0.03629233751953194, 
        0.003425747293248362}, {0.036093191097405976`, 
        0.0034780071017010495`}, {0.034399944995526247`, 
        0.0038994582327849057`}, {0.03270669889364652, 
        0.004320909363868761}, {0.031013452791766788`, 
        0.004742360494952617}, {0.02932020668988706, 
        0.0051638116260364735`}, {0.02670782760336545, 
        0.005757035675180082}, {0.025633380355088924`, 
        0.006014257723912132}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.025330835742799276`, 0.0060866867288081996`}, {
        0.025208109780795185`, 0.006116067253007913}, {0.023785803269948703`, 
        0.006450131009533332}, {0.021149494103469155`, 
        0.007052358911978697}, {0.01877497002396885, 0.007572723235817931}, {
        0.016662231031447795`, 0.008011223981051035}, {0.014811277125905992`, 
        0.00836786114767801}, {0.01317210935984767, 0.00866287228730914}, {
        0.013159122225614722`, 0.008665101795157615}}]}, 
      {Arrowheads[{{0.01420424588643641, 1.}}], 
       ArrowBox[{{0.012852513851021966`, 0.008717737408627179}, {
        0.011694728785777072`, 0.00891649495155472}, {0.010379135403694192`, 
        0.009128729140414743}, {0.009225329213599032, 0.009299574853889214}, {
        0.007278820650620398, 0.009561555383915623}, {0.005730945338089695, 
        0.009746891070868069}, {0.004098130238153276, 
        0.009910561710571761}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.02454247260672951, 0.09}, {0.023825499839196643`, 
        0.08910725744699623}, {0.02286521734404656, 0.0879115564592515}, {
        0.021600091635652456`, 0.08601012648262556}, {0.020506607732061897`, 
        0.08452725250653986}, {0.01944612911200127, 0.08307076218783693}, {
        0.01841865577547057, 0.08164065552651677}, {0.0174241877224698, 
        0.08023693252257938}, {0.017220432378414703`, 0.0799450436826274}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.01704236455879729, 0.07968995339509684}, {
        0.01646272495299896, 0.07885959317602476}, {0.015534267467058051`, 
        0.0775086374868529}, {0.014638815264647073`, 0.0761840654550638}, {
        0.013776368345766022`, 0.07488587708065748}, {0.013547923016710374`, 
        0.07453886668450944}, {0.01332161224938896, 0.07419364188591043}, {
        0.012194934518678136`, 0.07230805932280819}, {0.011068256787967313`, 
        0.07042247675970595}, {0.010343441244280598`, 0.06920944173346213}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.010183871709262745`, 0.06894238974101513}, {
        0.009941579057256488, 0.06853689419660372}, {0.008814901326545665, 
        0.06665131163350148}, {0.008168995699368475, 0.06522280601021815}, {
        0.007127160104575351, 0.06341788408355456}, {0.006141885933727362, 
        0.061666735914516706`}, {0.005213173186824505, 0.05996936150310461}, {
        0.004336770318839304, 0.058322994668781825`}, {0.004192357571587911, 
        0.05804437909830205}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.004049198513682631, 0.05776818227117436}, {
        0.00350842578474428, 0.056724869231011894`}, {0.0027281395845394334`, 
        0.05517498518979482}, {0.001995911718224765, 0.05367334254513061}, {
        0.0013117421858002752`, 0.05221994129701926}, {0.0006756309872659612, 
        0.05081478144546076}, {0.00008757812262182474, 
        0.04945786299045512}, {-0.0004524164081321329, 
        0.04814918593200234}, {-0.0011121637344261575`, 
        0.046453676822932825`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.00122497526811685, 
        0.04616375828085233}, {-0.001423149255339976, 
        0.045654463605260584`}, {-0.002271486341728029, 
        0.04330852206574074}, {-0.002997427667296291, 
        0.04111136131344281}, {-0.0036009732320447605`, 
        0.03906298134836679}, {-0.004105062983395645, 
        0.037146530893173595`}, {-0.00453263686877115, 
        0.035345158670524124`}, {-0.0047609377322298954`, 
        0.034248524061110355`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.00482434275316952, 
        0.033943960428193726`}, {-0.004883694888171276, 
        0.0336588646804184}, {-0.005158237041596022, 
        0.032087648922856406`}, {-0.005472916002506376, 
        0.02982527378996557}, {-0.005678421913066061, 
        0.027769302589306457`}, {-0.0057747547732750785`, 
        0.02591973532087906}, {-0.0057619145831334295`, 
        0.02427657198468337}, {-0.005675199632227007, 
        0.02280401713732985}, {-0.005559871902737149, 0.02157265810181767}}]}, 
      {Arrowheads[{{0.0016229741474641307`, 1.}}], 
       ArrowBox[{{-0.005522339706711427, 
        0.021263899233021466`}, {-0.005386040316877533, 
        0.02026334657898067}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{-0.01777231777468427, 0.09}, {-0.017926820031536582`, 
        0.08857089002125561}, {-0.018186621633376265`, 
        0.08697171268109027}, {-0.018429512183206837`, 
        0.08540232586518581}, {-0.018655491681028296`, 
        0.08386272957354221}, {-0.018864560126840648`, 
        0.08235292380615948}, {-0.019056717520643886`, 
        0.08087290856303761}, {-0.019231963862438015`, 
        0.0794226838441766}, {-0.019390299152223033`, 
        0.07800224964957644}, {-0.019424227360052556`, 
        0.07766862899016129}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.019455702287836333`, 
        0.07735913176546172}, {-0.01953172338999894, 
        0.07661160597923716}, {-0.019567631011130838`, 
        0.07624009111715652}, {-0.019602484084152914`, 
        0.07587058260203074}, {-0.019692605183070613`, 
        0.07397802867186641}, {-0.01978272628198831, 
        0.07208547474170209}, {-0.019872847380906014`, 
        0.07019292081153777}, {-0.019962968479823713`, 
        0.06830036688137345}, {-0.019863796559827212`, 
        0.06685842589940272}, {-0.019920513008348288`, 
        0.06504539190127255}, {-0.019922663616177817`, 
        0.06493550862240285}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0199287510950995, 
        0.06462447462783617}, {-0.019954959689938285`, 
        0.06328537119116517}, {-0.019967136604597195`, 
        0.06157836376908056}, {-0.01995917992613988, 
        0.059921673949478456`}, {-0.019933225828381206`, 
        0.058312606046818594`}, {-0.01988927431132117, 
        0.05675116006110098}, {-0.019827325374959764`, 
        0.0552373359923256}, {-0.019747379019297, 
        0.053771133840492466`}, {-0.01964943524433287, 
        0.05235255360560157}, {-0.019635627616813395`, 
        0.052189283924631964`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.01960941218403807, 
        0.051879296901903384`}, {-0.01953349405006738, 
        0.05098159528765292}, {-0.019399555436500522`, 
        0.04965825888664651}, {-0.01909532575450829, 
        0.0471328926546348}, {-0.01875438600140174, 
        0.044754895728740834`}, {-0.018376736177180875`, 
        0.04252426810896462}, {-0.017962376281845698`, 
        0.04044100979530615}, {-0.01776878577985282, 0.0395821952449514}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.017700376804031144`, 
        0.039278716390329274`}, {-0.01752228844277439, 
        0.03848867310658513}, {-0.01706745478734514, 
        0.036650810361621294`}, {-0.016597875315557946`, 
        0.034927421560414625`}, {-0.01611355002741281, 
        0.03331850670296512}, {-0.01532750177612893, 
        0.030951011908564103`}, {-0.014537817492394644`, 
        0.028798200808825794`}, {-0.013974718100509166`, 
        0.02742251643401575}}]}, 
      {Arrowheads[{{0.008884032164777506, 1.}}], 
       ArrowBox[{{-0.0138568705971316, 
        0.027134608168897498`}, {-0.013744497176209949`, 
        0.026860073403750198`}, {-0.012947540827574846`, 
        0.02513662969333732}, {-0.012161663487345127`, 
        0.023590714552999815`}, {-0.011401580196376594`, 
        0.02218517285815036}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.025714172029242012`}, {-0.09870511655553978, 
        0.025407956619119633`}, {-0.09669293291627917, 
        0.024935485842751494`}, {-0.09472033505769424, 
        0.024475748898268004`}, {-0.09278732297978497, 
        0.02402874578566916}, {-0.09089389668255138, 
        0.023594476504954963`}, {-0.08904005616599345, 
        0.023172941056125416`}, {-0.08854480235358665, 
        0.02306083175440161}, {-0.08805221511342812, 
        0.022949557465626085`}, {-0.08787614464834634, 
        0.022911130215382984`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.08757220560708416, 
        0.022844795741899286`}, {-0.08608659888011602, 
        0.022520563160168313`}, {-0.08412098264680394, 
        0.022091568854710544`}, {-0.08215536641349186, 
        0.021662574549252772`}, {-0.08018975018017978, 
        0.021233580243795003`}, {-0.07858725321872542, 
        0.020911993442233615`}, {-0.07668571685691765, 
        0.020501953402169322`}, {-0.07540679964762685, 
        0.02022852853534413}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07510258100167796, 
        0.020163488404403646`}, {-0.07482690040944608, 
        0.020104549539034015`}, {-0.0730108038763107, 
        0.019719781852827696`}, {-0.07123571236890514, 
        0.019347002172124032`}, {-0.06949991099862295, 
        0.018985562325496697`}, {-0.06780339976546416, 
        0.01863546231294569}, {-0.06614617866942878, 
        0.01829670213447101}, {-0.06452824771051678, 
        0.017969281790072657`}, {-0.06294960688872818, 
        0.017653201279750633`}, {-0.06291612928340198, 
        0.017646573817803317`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06261095822460669, 
        0.017586160011024702`}, {-0.06141025620406297, 
        0.017348460603504937`}, {-0.059910195656521156`, 
        0.01705505976133557}, {-0.05844601589015767, 
        0.016771702570246034`}, {-0.057014307549027435`, 
        0.01649709284723983}, {-0.05561507063313045, 
        0.01623123059231696}, {-0.05424830514246673, 
        0.015974115805477425`}, {-0.05161218843683906, 
        0.015486128636048356`}, {-0.05038587177786007, 
        0.015264473836127534`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05007973871087054, 
        0.015209140767612256`}, {-0.04910595743214442, 
        0.015033131338952626`}, {-0.04674352783412966, 
        0.014620080588172699`}, {-0.044446043976895964`, 
        0.014218888564474595`}, {-0.04226731325599781, 
        0.013848721073923851`}, {-0.04020176938913647, 
        0.013507595446927485`}, {-0.03872004178213367, 
        0.013269180880606224`}, {-0.03781178789310035, 
        0.013126425368861131`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.037504467232859405`, 
        0.013078122004953457`}, {-0.037296592488739407`, 
        0.01304544913029358}, {-0.035929036660402106`, 
        0.012835583657740346`}, {-0.0346149894485702, 
        0.01263876792469731}, {-0.032137881480216235`, 
        0.012281019524144988`}, {-0.029846189795264898`, 
        0.011965671622642933`}, {-0.027720835605303543`, 
        0.01168619191419746}, {-0.02574274012191956, 
        0.011436048092814883`}, {-0.025179525989898352`, 
        0.011366833454844957`}}]}, 
      {Arrowheads[{{0.00948332001407118, 1.}}], 
       ArrowBox[{{-0.02487075529686996, 
        0.011328887937290226`}, {-0.023892824556700314`, 
        0.01120870785250152}, {-0.022152010121233176`, 
        0.010997638887263688`}, {-0.02052213848485725, 
        0.010804556580836854`}, {-0.01901148838083523, 
        0.010633714067642384`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.06630578078232702}, {0.049578939649600376`, 
        0.06600265988371211}, {0.0480452770453185, 0.06496559304741134}, {
        0.04655032136351776, 0.06394585937741908}, {0.04509407260419818, 
        0.06294345887373533}, {0.04367653076735972, 0.06195839153636008}, {
        0.042297695853002415`, 0.060990657365293355`}, {0.04095756786112625, 
        0.06004025636053513}, {0.03978537686236785, 0.0591998414116899}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03953303273003628, 0.059017904803202764`}, {
        0.03839343264481734, 0.05819145384994421}, {0.03805766579945819, 
        0.05794650208793786}, {0.037724434985245636`, 0.05770273159095901}, {
        0.035991770114322606`, 0.056358345851798344`}, {0.03425910524339958, 
        0.05501396011263767}, {0.03252644037247655, 0.053669574373477}, {
        0.030793775501553527`, 0.05232518863431632}, {0.02973292990961169, 
        0.051358417716435505`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.02949362795863978, 0.05115988990207934}, {
        0.028031020637270875`, 0.05000065522007104}, {0.0264739994857387, 
        0.048747328996929386`}, {0.024987235821962866`, 
        0.04753042658019534}, {0.023565966859430236`, 0.04634818083701365}, {
        0.02220542981162767, 0.04519882463452908}, {0.02090562467855517, 
        0.044082357972741626`}, {0.019916366453188263`, 
        0.04321724559359425}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.019682187383471106`, 0.04301245456234011}, {
        0.019666551460212744`, 0.042998780851651285`}, {0.018488210156600383`,
         0.04194809327125806}, {0.01737060076771809, 0.04093029523156196}, {
        0.01631372329356586, 0.03994538673256297}, {0.015317577734143703`, 
        0.0389933677742611}, {0.013468613918539922`, 0.03717396471354457}, {
        0.011784840879957077`, 0.0354580522832082}, {0.010748213247718064`, 
        0.03435736710139922}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.010534925581476236`, 0.03413089949973214}, {
        0.010266258618395169`, 0.033845630483252}, {0.008912867133854202, 
        0.03233669931367598}, {0.007698191948387085, 0.030920255991286897`}, {
        0.006595758584046728, 0.029585297732891536`}, {0.0056055670408331325`,
         0.02833182453848989}, {0.004727617318746301, 
        0.027159836408081964`}, {0.0034270084142406054`, 
        0.025312544512878163`}, {0.0028224721491867675`, 
        0.02438557307596765}}]}, 
      {Arrowheads[{{0.006098756246809452, 1.}}], 
       ArrowBox[{{0.0026525337966956187`, 0.024124996485445166`}, {
        0.002336751103919393, 0.023640788087379613`}, {0.0014568453877826615`,
         0.02214456713158632}, {0.0007872912658304092, 
        0.02082388164549827}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.07536098944937719}, {0.04958717221834412, 
        0.07505236989123579}, {0.047974539386497386`, 0.07383332132330003}, {
        0.04641045647047165, 0.07263708219301372}, {0.045994646184507694`, 
        0.07231712908921706}, {0.045582014084916814`, 0.07199872922772596}, {
        0.04378957270028809, 0.07054216121010888}, {0.04199713131565936, 
        0.06908559319249181}, {0.04023349259448446, 0.06765243070365175}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.039992062330978795`, 0.06745624041072339}, {
        0.038412248546401906`, 0.06617245715725767}, {0.03714137440114232, 
        0.06499538242199304}, {0.03544097429404933, 0.06358813674832052}, {
        0.03380193503864682, 0.062213772637277696`}, {0.0322242566349348, 
        0.06087229008886458}, {0.030704361419202963`, 0.0595623457489693}, {
        0.030514345604620016`, 0.05939643570514221}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03028000774341284, 0.05919182639455109}, {
        0.02923867172774101, 0.05828259626347998}, {0.027827187560548937`, 
        0.05703304163239664}, {0.026469908917626746`, 0.05581368185571927}, {
        0.025166835798974437`, 0.054624516933447866`}, {0.023917968204592008`,
         0.05346554686558244}, {0.02272330613447946, 0.052336771652122985`}, {
        0.0215828495886368, 0.0512381912930695}, {0.021113753704795405`, 
        0.05077870507297088}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.020891512758783114`, 0.050561016843864916`}, {
        0.02048940059667404, 0.05016714215046502}, {0.019435761188201207`, 
        0.04912096058635256}, {0.018421931363218298`, 
        0.048099646600732134`}, {0.017447911121725314`, 
        0.047103200193603735`}, {0.015619299389209126`, 
        0.04518491011482303}, {0.013949925990652642`, 
        0.043366090350010426`}, {0.012418748091714078`, 
        0.041637998099783725`}, {0.012330323100095752`, 
        0.041535060018112954`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012127612013982379`, 0.041299078199443666`}, {
        0.011004722858051654`, 0.0399918905647607}, {0.00970785028966537, 
        0.03842776774494135}, {0.008528130386555229, 0.03694562964032569}, {
        0.007395113604184366, 0.03546795531948739}, {0.006348238097363478, 
        0.034058476224678905`}, {0.00538750386609257, 0.03271719235590024}, {
        0.004523038855274929, 0.0314588463103178}}]}, 
      {Arrowheads[{{0.0018430656156570742`, 1.}}], 
       ArrowBox[{{0.0043523626022113375`, 0.031198757543648932`}, {
        0.0037244592302006913`, 0.030239210296432374`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAKEvrKqkpc797FK5H4XqEv8jff7IY
7G6/FKQMRMK3gb+GrqzkJ6Nnv4wh632htn2/JSpozcJIYb+YYAi3gWZ4v0+l
ZNnSuVe/SgVxMyV/c7+nJa6mFeBTv+H79uEPpXG/CtUSuEE/UL9z9OF+/bFv
vw1gb4N1qUm//6j9Zhg1bL/fUHhUXwBJv3FARcNH3Wu/x2GY+FBYSL+B3XWr
uoVrv6fs/WonXke/R6ziQuUCa79gO7RBp7hGv8MfrDIArGq/7+uTlCoURr90
auUAXlVqv48iOru47Cg/OKArYU1nVL9aabjBFx8sP85JtmEjZlO/S0b1Q/hH
Lz9rmi/xU2ZSv23JZvomEjE/++QQpk98Ub8oUkrhsvQyP95WMA/tRVC/tDTC
s7/QND9viyB51yJOvzGG+OYzuD0/ge7MK9xQQr94wsLeZ/5CPywFWBkffiu/
Prfha37TRj/CD6H6c9AgP1hN2kCO508//46stGPZUD8IZ7o6
        "]]}, 
      {Arrowheads[{{0.011722382974010959`, 1.}}], 
       ArrowBox[{{0.0010651647844873474`, 0.0013257202487930398`}, {
        0.0011722556704273374`, 0.0016736488034979197`}, {
        0.001474478001090433, 0.002984366830766236}, {0.0017153217652415632`, 
        0.005030683085132693}, {0.001674707771310475, 
        0.0064919551419575445`}, {0.0014629306823953302`, 
        0.007694315806089874}, {0.001191103680597115, 
        0.008490410573037987}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.1, -0.0015624593846324745`}, {-0.09984789193118193, \
-0.0015583174183955667`}, {-0.09758672552768345, -0.0014928319397014256`}, \
{-0.0953760085746967, -0.0014248072473890794`}, {-0.09321574107222168, \
-0.0013542433414585272`}, {-0.0911059230202584, -0.0012811402219097697`}, \
{-0.09054303085609623, -0.0012610577317867012`}, {-0.08998350393880424, \
-0.0012408292079538702`}, {-0.0880109082851679, -0.0011555536384162271`}, \
{-0.08756371034274535, -0.001136221212550923}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08725290706847878, -0.0011227851461282949`}, \
{-0.08603831263153157, -0.001070278068878584}, {-0.08406571697789524, \
-0.0009850024993409412}, {-0.0820931213242589, -0.0008997269298032982}, \
{-0.08047787069086729, -0.0008036358459250225}, {-0.07856833592315648, \
-0.0007164516562096208}, {-0.07670084174606272, -0.00062799505304238}, \
{-0.07487538815958597, -0.0005382660364233}, {-0.07482319405284449, \
-0.0005356098812937349}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0745125025448502, -0.0005197988080865835}, \
{-0.07309031370933092, -0.00044742369896965854`}, {-0.07134395694090223, \
-0.0003556271332987334}, {-0.06963631785429993, -0.0002628763394105244}, \
{-0.06796739644952397, -0.00016917131730503177`}, {-0.0663371927265744, \
-0.00007451206698225535}, {-0.06474570668545118, 
        0.00002110141155780483}, {-0.06319293832615434, 
        0.00011766911831514872`}, {-0.06208905999241117, 
        0.0001887713295456583}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.061778609765542995`, 
        0.000208767824569245}, {-0.061678887648683865`, 
        0.0002151910532897764}, {-0.06020025009949148, 
        0.00031334751638020027`}, {-0.05875372112502891, 
        0.0004118188074849322}, {-0.05733930072529615, 
        0.0005106049266039726}, {-0.0559569889002932, 
        0.0006097058737373211}, {-0.05328869097447674, 
        0.0008088522520469434}, {-0.05074882734757954, 
        0.0010092579424137989`}, {-0.04936890943225523, 
        0.0011259414688308}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.049058922119507443`, 
        0.0011521534720190041`}, {-0.048350906542258286`, 
        0.0012120220724583172`}, {-0.046018380263458336`, 
        0.0014109162523313968`}, {-0.04380348146545227, 
        0.0016101904421653658`}, {-0.04170080673917742, 
        0.0018094049909120524`}, {-0.04017590551987828, 
        0.001960436552744556}, {-0.03871003996636574, 
        0.0021111788600138293`}, {-0.03730082551042023, 
        0.0022614607105526595`}, {-0.036671541798874996`, 
        0.002330963328462011}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.036362328503797475`, 
        0.0023651150681399573`}, {-0.035945877583822165`, 
        0.0024111109021938337`}, {-0.033389243045789954`, 
        0.0027078315001143726`}, {-0.03102105980651236, 
        0.002999971036437751}, {-0.02882225132023264, 
        0.0032861598938262746`}, {-0.026773741041194052`, 
        0.00356502845494225}, {-0.024856452423639847`, 
        0.003835207102447983}, {-0.024021241009543313`, 
        0.003955560113138793}}]}, 
      {Arrowheads[{{0.014930589374096246`, 1.}}], 
       ArrowBox[{{-0.02371332785276252, 
        0.003999930047294885}, {-0.02305130892181328, 
        0.0040953262190057795`}, {-0.021360020159733234`, 
        0.004346309883539167}, {-0.019790691505964915`, 
        0.004589787927667435}, {-0.0183338400315711, 
        0.004825449363096531}, {-0.01697998280761457, 
        0.0050529832015324}, {-0.014543319395264409`, 
        0.005482424134248248}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.08476477774143937}, {-0.09975176203235828, 
        0.08449626878023134}, {-0.09820782905506376, 
        0.08283990874811925}, {-0.09668351042229786, 
        0.0812184145312975}, {-0.09517880613406061, 
        0.07963178612976606}, {-0.09369371619035201, 
        0.07808002354352493}, {-0.09222824059117202, 
        0.07656312677257412}, {-0.09142901588848643, 0.07574390864490238}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.09121177357530547, 
        0.07552123179262646}, {-0.09078237933652067, 
        0.07508109581691363}, {-0.0903945824369532, 
        0.07468559080836351}, {-0.09000817556285412, 
        0.07429241496908325}, {-0.08807248931543862, 
        0.07240719142286746}, {-0.08613680306802314, 
        0.07052196787665167}, {-0.08420111682060764, 
        0.06863674433043589}, {-0.08232591945563085, 0.06681043274147039}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08209518886620192, 
        0.06660188395305289}, {-0.08064167169082276, 
        0.06532429041844796}, {-0.07876103144900365, 
        0.06351988919819282}, {-0.07691708854424877, 
        0.061769369528578116`}, {-0.07510984297655814, 
        0.060072731409603834`}, {-0.07333823506660507, 
        0.05842717891381828}, {-0.07299745293897404, 
        0.058113817235068636`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07276845668649433, 
        0.057903246772928345`}, {-0.07160120513506289, 
        0.05682991611376976}, {-0.0698987531819316, 
        0.05528094300945827}, {-0.06823087920721121, 
        0.0537802596008838}, {-0.0665975832109017, 
        0.05232786588804637}, {-0.06499886519300309, 
        0.050923761870945966`}, {-0.0634881232854349, 0.04961423365578974}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.06325197121675367, 
        0.04941172291586107}, {-0.061905163092438514`, 
        0.04826042292395624}, {-0.06040814391049469, 
        0.04699558590554192}, {-0.058941632508406, 
        0.0457678344058146}, {-0.057505628886172444`, 
        0.04457716842477428}, {-0.05610013304379403, 
        0.04342358796242096}, {-0.05472514498127075, 
        0.042307093018754655`}, {-0.053676653036499516`, 
        0.04146531638447411}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.053434066818841684`, 
        0.041270557225053565`}, {-0.053380664698602615`, 
        0.041227683593775356`}, {-0.05206669219578961, 
        0.04018535968748307}, {-0.050783227472831746`, 
        0.039180121299877774`}, {-0.049528278619284924`, 
        0.038207734710170076`}, {-0.04829985372470503, 
        0.03726396619757057}, {-0.04709795278909207, 
        0.03634881576207923}, {-0.04592257581244605, 
        0.03546228340369608}, {-0.044773722794766956`, 
        0.03460436912242111}, {-0.043651393736054804`, 
        0.03377507291825433}, {-0.043555375649637955`, 
        0.033704914838488254`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.04330419027629783, 
        0.03352137979715906}, {-0.04255558863630958, 
        0.032974394791195724`}, {-0.041486307495531304`, 
        0.03220233474124531}, {-0.04026028596349434, 
        0.03132623317204643}, {-0.03906245490184683, 
        0.030477630517331426`}, {-0.03789281431058876, 
        0.029656526777100282`}, {-0.03675136418972013, 
        0.028862921951353007`}, {-0.03455303535915121, 
        0.02735820904331005}, {-0.033107000105861144`, 
        0.026391176883070137`}}]}, 
      {Arrowheads[{{0.00805618257858365, 1.}}], 
       ArrowBox[{{-0.03284840321326722, 
        0.026218240911345062`}, {-0.03246746841014007, 
        0.02596349179320256}, {-0.030494663342686697`, 
        0.024678770201030535`}, {-0.028634620156791107`, 
        0.023504044266793974`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07243146172113951, 0.09}, {-0.07214515951234611, 
        0.08945006127156847}, {-0.07124094796886646, 
        0.08773939642828624}, {-0.07034204001945193, 
        0.08606509342495469}, {-0.06944843566410255, 
        0.08442715226157384}, {-0.0685601349028183, 
        0.08282557293814367}, {-0.06832097385025715, 
        0.08239799130695658}, {-0.06808225340896047, 
        0.0819728460194291}, {-0.0669284406395485, 
        0.08005346108363555}, {-0.06637500704668277, 0.07913281595882038}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0662147279329223, 
        0.07886618923685147}, {-0.06577462787013653, 
        0.07813407614784199}, {-0.06462081510072457, 
        0.07621469121204842}, {-0.0634670023313126, 
        0.07429530627625486}, {-0.06242427448022602, 
        0.07280048861830696}, {-0.061290064931695004`, 
        0.07095602731978028}, {-0.06016892419708462, 
        0.06916151511276485}, {-0.05962915809444354, 0.06831170020807806}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05946236513266767, 
        0.06804909915880795}, {-0.05906085227639487, 
        0.06741695199726068}, {-0.05796598310567709, 
        0.06571995820652528}, {-0.0568844506209826, 
        0.06406815397381617}, {-0.0558162548223114, 
        0.062461539299133347`}, {-0.0547613957096635, 
        0.06090011418247681}, {-0.05371987328303889, 
        0.059383878623846566`}, {-0.05269168754243758, 
        0.05791283262324261}, {-0.0525449611717376, 0.05770668300915482}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05236456802953962, 
        0.057453231796051246`}, {-0.05167683848785956, 
        0.05648697618066494}, {-0.05067532611930484, 
        0.055106309296113556`}, {-0.04968748156091286, 
        0.053766080438957115`}, {-0.0487136359368231, 
        0.05246153807856428}, {-0.04775378924703555, 
        0.051192682214935045`}, {-0.0468079414915502, 
        0.049959512848069404`}, {-0.04587609267036706, 
        0.04876202997796737}, {-0.044958242783486126`, 
        0.04760023360462893}, {-0.044885576830498694`, 
        0.04750969893503943}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04469084922594775, 
        0.04726708738708348}, {-0.044054391830907404`, 
        0.04647412372805408}, {-0.04316453981263089, 
        0.04538370034824284}, {-0.041427496271712994`, 
        0.04332838622760844}, {-0.03974335123527087, 
        0.04132961006677446}, {-0.038114670981854754`, 
        0.03945880137403704}, {-0.036620870749828005`, 0.0377972021614993}}]}, 
      {Arrowheads[{{0.019412072274130197`, 1.}}], 
       ArrowBox[{{-0.036411048920177276`, 
        0.03756752811542843}, {-0.0355853528588891, 
        0.03667266515003819}, {-0.034649873356184004`, 
        0.035678891567191375`}, {-0.03373457239154862, 
        0.034725417559011304`}, {-0.0328392708302736, 
        0.033810410543132476`}, {-0.031107949378967277`, 
        0.032088467158816546`}, {-0.029454475924590266`, 
        0.030498400755319524`}, {-0.02787741738946778, 
        0.029025550673717357`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAjI/ZTyV8jT97FK5H4XqEv4iPosdm
FI0/M69jClxDg78HxtIr8I2LPx/b7CyxXH6/N9IbsGQIij/daxwxlgN3v5GS
ZnSe4Yk/KYBKW1NSdr+uQbvk5bqJP9mK5VTtonW/Eqb+2juUiT9zt4dCX/V0
v6J3lYTsgIk/pJW22UefdL+HQkwfoW2JP//HrqCkSXS/eFf8xFlaiT/uQGv/
dPRzv2ODMY8WR4k/6SWnXrifc79oBzSX1zOJPxRixSduS3O/s0fsSMndhj80
KnOwi2hjv7onHXf4yYY/r4OnP7DQYr9XXs+EL7aGPycIBa2xOWK/slBup3ym
hj8ThB3zosJhv0C5tZSVkYY/KX0NEKskYb/+ZYQgt3yGP90mjRGXh2C/l5Il
iuwUhj/WeIKXZghbvzyyLSQUroU/WCKME30vVb/F9UOcN0iFP9JO+Ws9Bk+/
ZFD+6khbgz+QkNCchihFP8rERKEPmYI/rPqcBj/uUz8/cbUs
        "]]}, 
      {Arrowheads[{{0.011394345583163204`, 1.}}], 
       ArrowBox[{{0.008911637122003439, 0.0014774191397958587`}, {
        0.008564171400191776, 0.0020127726911708665`}, {0.006961286020173622, 
        0.004187307324649961}, {0.0055958304482273385`, 
        0.005781671176990643}, {0.004444757559175553, 
        0.00696464765517533}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.028481774113086014`, -0.01}, {-0.028062204329890886`, \
-0.009811972509321426}, {-0.026705682962462528`, -0.009194025138797805}, \
{-0.025409861005298393`, -0.008593966178810553}, {-0.024172110366373914`, \
-0.008011335302338005}, {-0.021861154358892455`, -0.006896585829714847}, \
{-0.02164172022491955, -0.006788740609079872}, {-0.02142430542754837, \
-0.00668153630666784}, {-0.021208892429169388`, -0.006574969538251154}, \
{-0.02110193170265228, -0.00652192428035329}, {-0.020995464909476482`, \
-0.006469037142553119}, {-0.020889489898035477`, -0.006416307705672446}, \
{-0.02078400452569377, -0.0063637355513934775`}, {-0.020679006657649608`, \
-0.006311320262151091}, {-0.018436224916635706`, -0.005172178011229274}, \
{-0.017288923907102342`, -0.004567431165080815}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01701372099098717, -0.004422370632414502}, \
{-0.01641648805249704, -0.004107566816356865}, {-0.016287654854944798`, \
-0.004038205519497993}, {-0.016159738903761274`, -0.0039691634118953914`}, \
{-0.01610216367276993, -0.00393798483120876}, {-0.016025665384739606`, \
-0.0038965075189204205`}, {-0.015949476135459585`, -0.003855138602610894}, \
{-0.015573415855088183`, -0.0036500155397792165`}, {-0.015205401378291464`, \
-0.0034477402617805446`}, {-0.014845270968415635`, -0.0032482770478671485`}, \
{-0.013151831547130352`, -0.002290570281728342}, {-0.011633797477173143`, \
-0.001398110645590232}, {-0.01027482313702995, -0.0005669377851649366}, \
{-0.009058562905186727, 0.0002069086538354272}, {-0.007000250135161277, 
        0.001596814975688874}, {-0.0063896039286012365`, 
        0.002037605848534886}}]}, 
      {Arrowheads[{{0.01072175662292158, 1.}}], 
       ArrowBox[{{-0.006137361482404671, 
        0.0022196853682851904`}, {-0.005748091608930859, 
        0.002500677218325132}, {-0.004672576067560134, 
        0.0033199290468668196`}, {-0.003773703511049103, 
        0.004054570461313938}, {-0.003051473939397766, 
        0.0047046014616664855`}, {-0.0012133366652040882`, 
        0.006690852081887529}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.053658564786938076`}, {-0.0997877523213601, 
        0.0535356208147656}, {-0.09798570194182335, 
        0.05249810256901205}, {-0.09621452767390973, 
        0.05148478446692337}, {-0.09447422951761925, 
        0.050495666508499536`}, {-0.09276480747295189, 
        0.049530748693740564`}, {-0.09230736806020103, 
        0.04927345205360093}, {-0.09185204289555228, 
        0.04901776370481454}, {-0.08986907990805694, 
        0.04793544579752838}, {-0.08916013284733357, 0.04754849651810286}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08888706582110828, 
        0.04739945423428983}, {-0.0878861169205616, 
        0.046853127890242215`}, {-0.08590315393306627, 
        0.04577080998295606}, {-0.08392019094557093, 
        0.0446884920756699}, {-0.08228308454695492, 
        0.04385282949662393}, {-0.08036115507514416, 
        0.04281403900020369}, {-0.07847991461378981, 
        0.04180426677769406}, {-0.07792627919697746, 0.04150925730058433}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07765173079594052, 
        0.0413629617823215}, {-0.07663936316289183, 
        0.04082351282909504}, {-0.07483800745174037, 
        0.03987036208435189}, {-0.07307435420962553, 
        0.03894339947340989}, {-0.07134840343654734, 
        0.038042624996269016`}, {-0.06966015513250579, 
        0.03716803865292928}, {-0.06800960929750086, 
        0.036319640443390686`}, {-0.06661784044753274, 
        0.03561013176096863}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06634058341165001, 
        0.03546903765772683}, {-0.0648216250346009, 
        0.034701408425716895`}, {-0.06328418660670587, 
        0.03393157461758171}, {-0.06178149725343081, 
        0.03318510072642612}, {-0.06031060358035905, 
        0.032459158535428585`}, {-0.05887150558749059, 
        0.031753748044589115`}, {-0.05746420327482544, 
        0.031068869253907703`}, {-0.05608869664236358, 
        0.03040452216338435}, {-0.05517881619888821, 
        0.029968569005514187`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05489826328851765, 
        0.029834147029415278`}, {-0.054744985690105025`, 
        0.029760706773019056`}, {-0.05343307041804977, 
        0.029137423082811822`}, {-0.052152950826197815`, 
        0.028534671092762646`}, {-0.049678093634058645`, 
        0.027382028447162466`}, {-0.04731040906464234, 
        0.026294045070242515`}, {-0.045049897117948885`, 
        0.025270720962002783`}, {-0.04359802932298297, 
        0.024624350651839058`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.043313828095451826`, 
        0.024497824506534944`}, {-0.0428965577939783, 
        0.024312056122443276`}, {-0.04157016931984117, 
        0.02372890901433722}, {-0.040276788128105916`, 
        0.023164338706542498`}, {-0.039016414218772555`, 
        0.02261834519905912}, {-0.03778904759184108, 
        0.022090928491887086`}, {-0.035433336185183795`, 
        0.021091825478477044`}, {-0.03320965390813406, 
        0.02016702966631237}, {-0.03186621535858032, 0.0196207731384255}}]}, 
      {Arrowheads[{{0.004185801941242829, 1.}}], 
       ArrowBox[{{-0.031578033835871475`, 
        0.019503595439416953`}, {-0.031118000760691884`, 
        0.019316541055393065`}, {-0.029158376742857258`, 
        0.01854035964571913}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.038300471367909567`, 0.09}, {0.03733108252766641, 
        0.08900693486866473}, {0.03586508139508092, 0.08748708321698213}, {
        0.034444437444018164`, 0.0859956515466162}, {0.03306915067447814, 
        0.08453263985756693}, {0.03173922108646085, 0.0830980481498343}, {
        0.031386204857234784`, 0.08271448156707725}, {0.03103614080892269, 
        0.08233284306885745}, {0.029811934692118656`, 0.08090441576764704}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.02960949295328284, 0.08066820284346028}, {
        0.029388349013903733`, 0.08041016783107935}, {0.02774055721888478, 
        0.07848749259330126}, {0.026092765423865828`, 0.07656481735552317}, {
        0.024444973628846876`, 0.07464214211774507}, {0.023375225885909796`, 
        0.07313967230450544}, {0.021829441864787646`, 0.07129115096517531}, {
        0.02166864139539901, 0.07109538839882959}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02147118134492391, 0.07085499552946342}, {
        0.020351663026263362`, 0.06949206555814381}, {0.018941889370336945`, 
        0.06774241608341097}, {0.017595589728551353`, 0.06603990078706874}, {
        0.016308232932449547`, 0.0643822179152091}, {0.015079818982031526`, 
        0.06276936746783204}, {0.013910347877297285`, 
        0.061201349444937575`}, {0.01380419799613967, 0.06105575569805655}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.013620924113833581`, 0.060804379710261015`}, {
        0.012799819618246827`, 0.059678163846525696`}, {0.011748234204880154`,
         0.05819981067259641}, {0.01075559163719726, 0.0567662899231497}, {
        0.009821891915198153, 0.05537760159818558}, {0.00893793724695717, 
        0.05402916718067245}, {0.008094529840548651, 0.0527164081535787}, {
        0.007291669695972603, 0.05143932451690433}, {0.006696406268871494, 
        0.050469952302653186`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.006533615582992482, 0.05020485157506692}, {
        0.006529356813229021, 0.050197916270649345`}, {0.005126372833239258, 
        0.04782212594939751}, {0.003885577900579362, 0.0455890371898232}, {
        0.0027814574247168908`, 0.04348419722783246}, {0.0017884968151193998`,
         0.04149315329933134}, {0.0009066960717868871, 0.03961590540431984}, {
        0.000728088810827928, 0.03920719972026903}}]}, 
      {Arrowheads[{{0.01895546345399484, 1.}}], 
       ArrowBox[{{0.0006035146118445898, 0.03892213749526651}, {
        0.00013605519471935733`, 
        0.03785245354279796}, {-0.00047783636562789963`, 
        0.036353689815186115`}, {-0.0010348908918840932`, 
        0.03492325404344766}, {-0.001535108384049223, 
        0.03356114622758262}, {-0.001978488842123289, 
        0.03226736636759097}, {-0.0026947386559982305`, 
        0.029884790515227886`}, {-0.003183640333508917, 
        0.027775526486358403`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.04786540885007602, 0.09}, {-0.04769729409395957, 
        0.08922745409616967}, {-0.04732136340351638, 
        0.08756187682301159}, {-0.04693946676204073, 
        0.08593083921226906}, {-0.046551604169532614`, 
        0.08433434126394208}, {-0.04615777562599204, 
        0.08277238297803066}, {-0.046050620044799255`, 
        0.08235525297757355}, {-0.04594315022940055, 
        0.08194044253978733}, {-0.04536773802311379, 
        0.08002118349979183}, {-0.04479232581682704, 
        0.07810192445979634}, {-0.044749188345648866`, 0.0779580415518276}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.044659848333936054`, 
        0.07766005234819283}, {-0.044216913610540275`, 
        0.07618266541980084}, {-0.04364150140425352, 
        0.07426340637980534}, {-0.04304549425225715, 
        0.07276883301271031}, {-0.04246644764378635, 
        0.07092451850322666}, {-0.041884978100526174`, 
        0.06913016701408425}, {-0.041301085622476634`, 
        0.06738577854528306}, {-0.04076952318193809, 0.06584500743141451}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04066686218677545, 
        0.06555134420898566}, {-0.04012971854814212, 
        0.06403737276410552}, {-0.0395431656233903, 
        0.06243097597557945}, {-0.03895603310691546, 
        0.06086978325509518}, {-0.03836832099871757, 
        0.05935379460265271}, {-0.037780029298796654`, 
        0.05788301001825204}, {-0.0371911580071527, 
        0.05645742950189316}, {-0.0366017071237857, 
        0.05507705305357609}, {-0.03611706675449566, 
        0.053972881607408985`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.035991645610764046`, 
        0.05368819253923051}, {-0.035428726740225784`, 
        0.05243291406346528}, {-0.034847112279618654`, 
        0.05116440194727102}, {-0.034268748306460074`, 
        0.049931594750317526`}, {-0.03312177182248858, 
        0.047573095114132845`}, {-0.03198779728831129, 
        0.045357415154911235`}, {-0.030861549206696617`, 
        0.04330303489851482}, {-0.030451801282737275`, 
        0.04255108351340051}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.030302947539466888`, 
        0.04227791366460654}, {-0.029772922061956936`, 
        0.04130523419839152}, {-0.028701517264796743`, 
        0.03943546915454158}, {-0.027649445014108674`, 
        0.03768634775662015}, {-0.026358803498302493`, 
        0.035651820981964705`}, {-0.02510134240985103, 
        0.0337796150371823}, {-0.023880283329968867`, 
        0.03205492598743923}, {-0.023664519148361138`, 
        0.03176418525637356}}]}, 
      {Arrowheads[{{0.002104380238632045, 1.}}], 
       ArrowBox[{{-0.023479125461570268`, 
        0.031514368555423014`}, {-0.022698847839870574`, 
        0.030462949897901832`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAASKucEKXDnj97FK5H4XqEvytiPhET
Yp4/SWduP8jEg7/CY1QoYjWdP245Q7c0noG/dwPcZdgSnD9OefHcWSh/v4ll
lc82+po/e0tP4W9Ke7/2j+5uRcOaP6kpxwjkinq/Z80qcraMmj8SdcStYM15
v0eCuFaJVpo/ElwFdOAReb+oRsRYlzuaP2+viwTgtHi/G78sor0gmj8sUnRg
Xlh4v0ydnyL8BZo/fOsH4Fr8d78R5MrJUuuZP3dzZtzUoHe/f+lch8HQmT+z
0muvy0V3v0sxkHfUJZg/AgBzfXWjcb/cUsuDh5OWP07Crson92i/8gra/zJ5
lj+PfXbiMk1ov4KJWuf5XpY/y3/4VEOkZ792idZ111SWP5xgDh4jY2e/+v4h
H7lKlj+rBzPDKSJnv5SybUaSO5Y/f3qQuvLAZr/W2Z4nfTGWP0Aj/4JQgGa/
dICwH2wnlj/ssyfk1D9mv/70BS+hw5U/dYXrWDHDY7+MYlqRaWGVP6qqDe5C
VWG/S6+gUuMYlT9dvNef1hpfvzyOycc=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.020357001405976387`, -0.0017077439771299651`}, {
        0.018750395019809643`, -0.00046989049973654223`}, {0.0171274165410682,
         0.0007357289364005534}, {0.01563298773445883, 
        0.0018061831930152187`}, {0.01425835536344573, 
        0.0027569442057457406`}, {0.012995482418768401`, 
        0.0036004588836127923`}, {0.011836331891166346`, 
        0.004349174135637045}, {0.010469704688974946`, 
        0.005201036132701323}, {0.010148008187863553`, 
        0.005394056405761935}}]}, 
      {Arrowheads[{{0.003242553729088524, 1.}}], 
       ArrowBox[{{0.009881248528698304, 0.005554114168515789}, {
        0.009236751957338432, 0.005940816864257683}, {0.008137473696256807, 
        0.006568516330306122}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.011076438687622309`}, {0.049571267752165735`, 
        0.011101200127822152`}, {0.0474268587550343, 0.011218693247143181`}, {
        0.045372239370810925`, 0.011324643296983197`}, {0.04340740959949561, 
        0.0114190502773422}, {0.04314816677146156, 0.011431018445018055`}, {
        0.042890425848095694`, 0.011442803833048463`}, {0.04114403021906787, 
        0.011503451446579856`}, {0.03939763459004006, 
        0.011564099060111249`}, {0.037651238961012246`, 
        0.01162474667364264}, {0.0375689383395737, 0.011627604752418969`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0372580321971027, 0.011638401684832052`}, {
        0.03590484333198443, 0.011685394287174033`}, {0.034748571430125226`, 
        0.01168725816581927}, {0.03310631528236246, 0.011737532179076636`}, {
        0.03153348545544306, 0.011780890458817982`}, {0.030030081949367023`, 
        0.01181733300504331}, {0.02859130582508237, 0.011847584583850223`}, {
        0.027212358143537105`, 0.011872369961336322`}, {0.02589323890473123, 
        0.011891689137501608`}, {0.024817662747005507`, 
        0.011903521138102922`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0245065817906377, 0.011906157809533947`}, {
        0.022294851844749945`, 0.011916849458072585`}, {0.02019506935179271, 
        0.011906291998515835`}, {0.018295132964779973`, 
        0.011880221797709013`}, {0.01655557501869867, 
        0.011844990919685298`}, {0.0149763955135488, 0.011800599364444692`}, {
        0.01355759444933036, 0.01174704713198719}, {0.012066857803388306`, 
        0.011673841987442904`}}]}, 
      {Arrowheads[{{0.0010619580512048776`, 1.}}], 
       ArrowBox[{{0.011756138662135799`, 0.011658583598437721`}, {
        0.011096197274702669`, 0.011626176060332779`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.00800915561699783, 0.09}, {-0.008358124032199613, 
        0.08886244800130046}, {-0.008831596793028626, 
        0.08727006610802232}, {-0.009280164475507205, 
        0.08570989263500012}, {-0.009703827079635345, 
        0.08418192758223382}, {-0.009814871241969912, 
        0.08377366101692875}, {-0.009924334349628578, 
        0.08336756677278172}, {-0.010355212688066186`, 
        0.08144182494763638}, {-0.010786091026503795`, 
        0.07951608312249106}, {-0.011133961666920336`, 
        0.07796133092859021}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.011201888290707233`, 
        0.07765774374678465}, {-0.011216969364941404`, 
        0.07759034129734574}, {-0.011647847703379012`, 
        0.07566459947220042}, {-0.011818779785288325`, 
        0.0741571157328525}, {-0.012203785254926823`, 
        0.07230518415814201}, {-0.01255820881203258, 
        0.07050245941705474}, {-0.012882050456605596`, 
        0.06874894150959071}, {-0.01317769329711935, 
        0.0670423345138862}, {-0.013440543000593086`, 0.06542331984425712}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.013487434183069363`, 
        0.06511578292481959}, {-0.01369153189138952, 
        0.06376296549216473}, {-0.013909727645145932`, 
        0.06219020346614776}, {-0.014102107703316562`, 
        0.06066205643002664}, {-0.014268672065901412`, 
        0.05917852438380135}, {-0.01440942073290048, 
        0.05773960732747191}, {-0.014524353704313769`, 
        0.05634530526103831}, {-0.014696173543050032`, 
        0.053672240918479344`}, {-0.01473563959321962, 
        0.052741745778153645`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.014748822472929145`, 
        0.05243093166190682}, {-0.014803532564777231`, 
        0.051141026176745166`}, {-0.014846430769495371`, 
        0.04875166103583578}, {-0.014824868157204447`, 
        0.04650414549575117}, {-0.014751871077467575`, 
        0.04438411541247841}, {-0.014640465879847867`, 
        0.04237720664200451}, {-0.014490652564345324`, 
        0.0404834191843295}, {-0.014439742282396664`, 0.04000178319919456}}]}, 
      {Arrowheads[{{0.013822455748581057`, 1.}}], 
       ArrowBox[{{-0.014407040995420093`, 
        0.03969241314730556}, {-0.014302431130959945`, 
        0.03870275303945338}, {-0.013933361689777072`, 
        0.03597137491421448}, {-0.013511387981718954`, 
        0.03347286043655776}, {-0.01303651000678559, 0.03120720960648323}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.01289898020268381, 0.09}, {0.011956861116387888`, 
        0.08842365347138105}, {0.0110466803047405, 0.08687378214360253}, {
        0.010170870387280671`, 0.08535445625727582}, {0.009329431364008406, 
        0.08386567581240094}, {0.009106847120534516, 0.08346776476716986}, {
        0.008886478303461946, 0.0830719190680257}, {0.007913227454742513, 
        0.08114694150236365}, {0.0069399766060230786`, 0.07922196393670158}, {
        0.006884424952928206, 0.07911208919466178}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0067440593548236845`, 0.0788344622830619}, {
        0.005966725757303645, 0.07729698637103953}, {0.004993474908584211, 
        0.07537200880537746}, {0.004417235866443421, 0.07386566095604129}, {
        0.003514045924767277, 0.07201455922267203}, {0.002657563254453326, 
        0.07021270804416463}, {0.0018477878555015694`, 0.06846010742051911}, {
        0.001451999378716196, 0.06757921108531717}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.0013245023086918572`, 0.0672954441028986}, {
        0.0010814386198723307`, 0.06675446343958866}, {0.000355234439525932, 
        0.06509348218922645}, {-0.00033082468553762446`, 
        0.06347716366943251}, {-0.0009767387553183391, 
        0.06190550788020682}, {-0.0015825077698162129`, 
        0.06037851482154939}, {-0.0021481317290312453`, 
        0.058896184493460214`}, {-0.002673610632963434, 
        0.0574585168959393}, {-0.0031589444816127834`, 
        0.056065512028986644`}, {-0.0032690603500762122`, 
        0.05573580955297688}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0033676099647408212`, 
        0.05544073807583077}, {-0.0036107972136864134`, 
        0.054712601075867}, {-0.004035832767891443, 
        0.05339521521984514}, {-0.004434051144227876, 
        0.052113354460921045`}, {-0.00480545234269571, 
        0.05086701879909473}, {-0.005467803206025584, 
        0.04848092276673543}, {-0.0060228853578810655`, 
        0.046236927122767224`}, {-0.006488998046444591, 
        0.04412065717360822}, {-0.006623437767510511, 0.04343971902772415}}]}, 
      {Arrowheads[{{0.016502213279178946`, 1.}}], 
       ArrowBox[{{-0.006683694753223484, 
        0.04313451696539738}, {-0.0068844405198986, 
        0.042117738225676514`}, {-0.007209212778243091, 
        0.04022817027897211}, {-0.007463314821478066, 
        0.038451953333495}, {-0.00763842252206625, 
        0.03698094705403976}, {-0.007781200841894606, 
        0.03557478848461837}, {-0.007891649780963135, 
        0.034233477625230845`}, {-0.007969769339271836, 
        0.03295701447587718}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.027272964191524376`, 0.09}, {-0.027276912480346888`, 
        0.08992497299740682}, {-0.027349575797889002`, 
        0.08827936678738038}, {-0.02740654672949227, 
        0.08666712566152274}, {-0.027447825275156688`, 
        0.08508824961983388}, {-0.027473411434882255`, 
        0.08354273866231382}, {-0.02747820197020444, 
        0.08312989084662278}, {-0.0274820277360095, 
        0.08271928849567767}, {-0.027417881130661084`, 
        0.08079656345942685}, {-0.02735373452531267, 
        0.07887383842317604}, {-0.027309989779864, 0.07756263704592878}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.027299616742132878`, 
        0.07725171647204541}, {-0.027289587919964255`, 
        0.07695111338692523}, {-0.02722544131461584, 
        0.07502838835067442}, {-0.02702032731673571, 
        0.07352696113705856}, {-0.02693130411270523, 
        0.07167858277539038}, {-0.02682569650955337, 
        0.06987976886344396}, {-0.026703504507280134`, 
        0.06813051940121931}, {-0.026566377466170372`, 
        0.0664284982754444}, {-0.026422619423504577`, 0.06484468536375383}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.026391975948174932`, 
        0.06453510792501733}, {-0.026252266348295812`, 
        0.06315913269342786}, {-0.026075282271531018`, 
        0.061591788237186224`}, {-0.025885012516214546`, 
        0.06006933600412234}, {-0.0256814570823464, 
        0.05859177599423621}, {-0.025464615969926573`, 
        0.057159108207527835`}, {-0.025234489178955072`, 
        0.055771332643997217`}, {-0.024747881541740673`, 
        0.0531118185860867}, {-0.02456860463682357, 0.05223169156463535}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.024506511704455048`, 
        0.05192685772313214}, {-0.024235137151086838`, 
        0.0505945942201221}, {-0.023696256006993568`, 
        0.04821965954610343}, {-0.02313123810946086, 
        0.04598701456403069}, {-0.02254870250867104, 
        0.04388209502187917}, {-0.02195726825480644, 
        0.04189033666762414}, {-0.02135693534786705, 
        0.04001173950126561}, {-0.021320450892307455`, 0.0399060145606568}}]}, 
      {Arrowheads[{{0.007685631348015542, 1.}}], 
       ArrowBox[{{-0.02121896873224225, 
        0.039611938763685635`}, {-0.020747703787852883`, 
        0.03824630352280358}, {-0.020160151928593217`, 
        0.03664582837093475}, {-0.01957459430772247, 0.03512214909553918}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.045450421187606234`, -0.01}, {
        0.04525446368991769, -0.00988095630551021}, {
        0.04402142966243168, -0.009131891187844444}, {
        0.04236717965998954, -0.008282186036967617}, {
        0.040848475714490635`, -0.007421399839317466}, {
        0.03937933671301918, -0.0065978973668506125`}, {
        0.03795976265557519, -0.0058116786195670555`}, {
        0.036589753542158654`, -0.005062743597466797}, {
        0.03640810885639764, -0.004964132800304746}, {
        0.03622731185157199, -0.004866141307200668}, {
        0.03455288148764037, -0.003998897446342777}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.034276640778214684`, -0.0038558230823507516`}, {
        0.03283380990982114, -0.00310853239781461}, {
        0.03113705893894572, -0.0022297279431215808`}, {
        0.029440307968070293`, -0.001350923488428552}, {
        0.02839238463872329, -0.0008971269715379172}, {
        0.0268101326634117, -0.00009332391763354616}, {0.02530421335180934, 
        0.0006604782024117199}, {0.023874626703916206`, 
        0.0013642793885978808`}, {0.023151874964761152`, 
        0.0017143123621052717`}}]}, 
      {Arrowheads[{{0.014210915475527813`, 1.}}], 
       ArrowBox[{{0.02287188898710078, 0.0018499112392735338`}, {
        0.022515506510025932`, 0.002022509396286997}, {0.021220986560432153`, 
        0.002639597980841131}, {0.019991066855134867`, 
        0.003215545142260281}, {0.018825747394134076`, 
        0.003750350880544448}, {0.016688909205021977`, 
        0.004696538087707833}, {0.014810471993095858`, 
        0.005478159602331285}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05327694501323778, -0.01}, {-0.052025343090157335`, \
-0.009705202320220615}, {-0.04955496810216892, -0.009116448764185497}, \
{-0.0470845931141805, -0.008527695208150379}, {-0.04461421812619208, \
-0.00793894165211526}, {-0.04296192412285589, -0.00746414387313376}, \
{-0.04120059188310578, -0.007005603862596678}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04089953325979289, -0.0069272271536540446`}, \
{-0.04083978430562643, -0.006911672288163729}, {-0.03881294582793042, \
-0.006373940801740026}, {-0.03688140868976785, -0.005850949413862649}, \
{-0.03504517289113874, -0.0053426981245316}, {-0.034803664881952995`, \
-0.005275065430301494}, {-0.03456373475663412, -0.00520769138681185}, \
{-0.03287892178810459, -0.004700669924568041}, {-0.03119410881957505, \
-0.004193648462324232}, {-0.02950929585104551, -0.003686627000080423}, \
{-0.0289344435407215, -0.00351363304502493}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02863654683263815, -0.003423985097536811}, \
{-0.027824482882515975`, -0.003179605537836614}, {-0.025241124773331812`, \
-0.0023199441970179944`}, {-0.023752878761771005`, -0.001851518130691435}, \
{-0.02234325953299769, -0.0013985302227317756`}, {-0.01973544300449368, \
-0.0005357001022406828}, {-0.017393216768499947`, 
        0.00027171494412775703`}, {-0.01682164959844825, 
        0.0004786932049848228}}]}, 
      {Arrowheads[{{0.014663085157740301`, 1.}}], 
       ArrowBox[{{-0.016529144112674667`, 
        0.0005846164978343605}, {-0.015316580825016485`, 
        0.0010237149163735435`}, {-0.013505535174043298`, 
        0.0017202998144966767`}, {-0.01190852103168833, 
        0.002367390550122375}, {-0.010473979614059539`, 
        0.002970908034875858}, {-0.009201910921156915, 
        0.003530852268757126}, {-0.008092314952980463, 
        0.004047223251766178}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.03342419335838609}, {-0.09899993536034518, 
        0.03310141647241826}, {-0.09704708253573255, 
        0.032475387160928924`}, {-0.0951333948403761, 
        0.03186626433074432}, {-0.09462192658628653, 
        0.031704064555632246`}, {-0.09411310689483236, 
        0.031542979838980204`}, {-0.0921259368839357, 
        0.030930938082731185`}, {-0.09013876687303903, 
        0.030318896326482162`}, {-0.08815159686214237, 
        0.029706854570233143`}, {-0.08812703558607506, 
        0.029699289778867773`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08782972433856223, 
        0.02960771890315884}, {-0.0861644268512457, 
        0.02909481281398412}, {-0.08452309475965547, 
        0.02862111596951427}, {-0.0825969549698129, 
        0.02803348802122628}, {-0.08071150199400635, 
        0.027462135944912307`}, {-0.07886673583223587, 
        0.026907059740572357`}, {-0.0770611212471158, 
        0.02636748355534528}, {-0.07591261540125087, 
        0.026026535472721147`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07561438550104649, 
        0.02593800225974538}, {-0.07529312300126051, 
        0.025842631536369936`}, {-0.07356274109466998, 
        0.025332503683646323`}, {-0.07186997552734424, 
        0.024837099997174438`}, {-0.07021482629928327, 
        0.024356420476954282`}, {-0.06859729341048708, 
        0.023890465122985857`}, {-0.06701737686095566, 
        0.02343923393526916}, {-0.06547507665068901, 
        0.023002726913804197`}, {-0.06396734436837252, 
        0.0225793953512975}, {-0.06365718647112462, 0.022492894610085804`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0633575285631316, 
        0.022409322238138026`}, {-0.0624911316026916, 
        0.022167690540455608`}, {-0.06104643835364624, 
        0.02176761248127852}, {-0.05963326462123643, 
        0.021379161173766238`}, {-0.05825161040546217, 
        0.021002336617918758`}, {-0.05690147570632348, 
        0.020637138813736085`}, {-0.05558286052382034, 
        0.02028356776121822}, {-0.05429576485795276, 
        0.019941623460365154`}, {-0.0518287824791672, 
        0.01929865375790686}, {-0.051342466592265816`, 
        0.01917207813859188}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.051041403378560654`, 
        0.01909371906426574}, {-0.049428842952723526`, 
        0.018674010722258497`}, {-0.04714486117038774, 
        0.018091043777866616`}, {-0.044971776970942665`, 
        0.017547337467029852`}, {-0.04333179862810884, 
        0.017144548500710444`}, {-0.0417550374457185, 
        0.016763812402715482`}, {-0.040238984105353606`, 
        0.01640397499712918}, {-0.03896205628385393, 
        0.016106089318126172`}}]}, 
      {Arrowheads[{{0.0021106889553604213`, 1.}}], 
       ArrowBox[{{-0.03865899016083831, 
        0.01603587682782938}, {-0.037378963677028115`, 
        0.015742379559519418`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.09657595528223646, -0.01}, {-0.09567466138822005, \
-0.009905471654621382}, {-0.09418235747564879, -0.00974698214582525}, \
{-0.09271299736993183, -0.009588923387991688}, {-0.09126658107106912, \
-0.009431295381120695}, {-0.0898431085790607, -0.009274098125212269}, \
{-0.08844257989390653, -0.009117331620266414}, {-0.08571035394416103, \
-0.008805090863262404}, {-0.08420803956171778, -0.008629157167199834}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08389905753615604, -0.008592972763715944}, \
{-0.08306232601144277, -0.008494984438851834}, {-0.0804909188853619, \
-0.008187423675777863}, {-0.07799613256591845, -0.007882408574040496}, \
{-0.0755779670531124, -0.007579939133639729}, {-0.07319811194362483, \
-0.007278742523907233}, {-0.07154892093924853, -0.00707001942251371}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07124028933787446, -0.0070309587286002066`}, \
{-0.07081825683413726, -0.006977545914174738}, {-0.06843840172464968, \
-0.006676349304442242}, {-0.06660214167799261, -0.00639847812456558}, \
{-0.06502670973125221, -0.0061806505615740635`}, {-0.06348487455319149, \
-0.005964640466575477}, {-0.06197663614381042, -0.005750447839569821}, \
{-0.060501994503109, -0.005538072680557097}, {-0.05906094963108725, \
-0.005327514989537303}, {-0.05891707173761948, -0.005306176296124891}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.05860934418548988, -0.00526053687417355}, \
{-0.05765350152774516, -0.005118774766510439}, {-0.05493939562709996, \
-0.004706746724435504}, {-0.05458200117438308, -0.004651604199632432}, \
{-0.0542268397241866, -0.004596599740774836}, {-0.0524069181362936, \
-0.004292826942937203}, {-0.05058699654840059, -0.00398905414509957}, \
{-0.048767074960507584`, -0.003685281347261936}, {-0.046947153372614576`, \
-0.003381508549424303}, {-0.046328472793605247`, -0.0032583263974085607`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.046023368036848485`, -0.0031975786354734464`}, \
{-0.04562953810275644, -0.0031191652821928938`}, {-0.04389825880628135, \
-0.0028227035779916526`}, {-0.042226074370751536`, -0.0025311159362146735`}, \
{-0.040612984796167005`, -0.002244402356861956}, {-0.03905556566786868, \
-0.001962505756493255}, {-0.037550392571197494`, -0.0016853690516683256`}, \
{-0.03609746550615345, -0.0014129922423871675`}, {-0.03469678447273654, \
-0.0011453753286497811`}, {-0.03378190594319447, -0.0009651569825301029}}]}, 
      {Arrowheads[{{0.0196667454475509, 1.}}], 
       ArrowBox[{{-0.0334766779827838, -0.0009050313194628695}, \
{-0.03205216050078414, -0.0006244211878063237}, {-0.029616520655340293`, \
-0.00012250662913795233`}, {-0.027362241084440936`, 
        0.00036070994243366937`}, {-0.025261697936122, 
        0.0008255701219868807}, {-0.023314891210383482`, 
        0.00127207390952168}, {-0.02152182090722539, 
        0.0017002213050380673`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.018370927466193877`}, {-0.09844661998930587, 
        0.018123500171866914`}, {-0.09638429806013056, 
        0.01779881516652589}, {-0.09583355166320832, 
        0.0177126329965884}, {-0.09528585786322989, 
        0.017627169850029954`}, {-0.09329565283554306, 
        0.017329846994156295`}, {-0.09130544780785621, 
        0.01703252413828264}, {-0.08931524278016936, 
        0.01673520128240898}, {-0.0876987701330542, 0.016493711457393045`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.08739109106228157, 
        0.01644774633382937}, {-0.08732503775248251, 
        0.01643787842653532}, {-0.08567922631617504, 
        0.016216761297688186`}, {-0.08374979662814339, 
        0.015932886511289795`}, {-0.08186088383321517, 
        0.015657977104541584`}, {-0.08001248793139043, 
        0.015392033077443553`}, {-0.07820307631442283, 
        0.015134603156391964`}, {-0.07643111637406606, 
        0.014885236067783084`}, {-0.07507135123735713, 
        0.014696065960189807`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07476322516805327, 
        0.014653199556199203`}, {-0.07469660811032014, 
        0.014643931811616911`}, {-0.07299955152318505, 
        0.014410690387893449`}, {-0.07133994661266078, 
        0.014185511796612694`}, {-0.06971779337874737, 
        0.013968396037774647`}, {-0.06813309182144477, 
        0.013759343111379307`}, {-0.06658584194075302, 
        0.013558353017426677`}, {-0.06507299796327179, 
        0.01336452493040037}, {-0.06359151411560073, 
        0.013176958024784005`}, {-0.06242574801316715, 
        0.013031204897065496`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06211705290078771, 
        0.012992649583237866`}, {-0.06072262680968912, 
        0.012820607757781101`}, {-0.05797918002301825, 
        0.01248930221641796}, {-0.05536117375558809, 
        0.012183041400694587`}, {-0.0528811972209668, 
        0.011905313872042562`}, {-0.05046791154226818, 
        0.011636351115682914`}, {-0.049756202919016494`, 
        0.011559940665208929`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.049446886931371295`, 
        0.011526731886809152`}, {-0.048169995011955756`, 
        0.011389642235817765`}, {-0.045982411944602265`, 
        0.011163791807874482`}, {-0.044337625211358346`, 
        0.011000151904387743`}, {-0.04275521416111259, 
        0.010848046838363155`}, {-0.04123271533162757, 
        0.010706821535752966`}, {-0.039767665260665844`, 
        0.010575820922509424`}, {-0.03835760048598997, 
        0.010454389924584775`}, {-0.037059574906598426`, 
        0.010346806411409677`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.05768296844496328}, {0.04914330693322274, 
        0.05718046421430395}, {0.047688278864185835`, 
        0.056318153400363336`}, {0.04627483751049885, 0.05547139023776747}, {
        0.04589876079071003, 0.055244825909472356`}, {0.045525416106770876`, 
        0.05501932443757595}, {0.043743414398672326`, 
        0.053886481278361396`}, {0.04196141269057377, 0.05275363811914684}, {
        0.04017941098247521, 0.05162079495993228}, {0.039418625139698474`, 
        0.05113715286593197}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.039156090243545036`, 0.05097025579742137}, {
        0.03839740927437666, 0.05048795180071772}, {0.03715426244767448, 
        0.04958654907842995}, {0.03546735277746941, 0.04849454834926129}, {
        0.03384383779919332, 0.04742977590678991}, {0.03228371751284621, 
        0.0463922317510158}, {0.030783113484259585`, 0.04538074532976513}, {
        0.02933814727926491, 0.04439414609086409}, {0.028824107922920814`, 
        0.04403832103671891}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.028568317968470164`, 0.04386125974118015}, {
        0.0279488188978622, 0.04343243403431267}, {0.026615128340051454`, 
        0.04249560916011087}, {0.025337075605832662`, 0.0415836714682587}, {
        0.024114660695205837`, 0.040696620958756154`}, {0.02294788360817097, 
        0.039834457631603225`}, {0.021836744344728064`, 
        0.038997181486799926`}, {0.019750027108046533`, 
        0.03738802371223221}, {0.018572468890870764`, 0.03645413756949706}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.018328723844026316`, 0.036260830675376526`}, {
        0.017823156804589645`, 0.035859880603043015`}, {0.016056133434357397`,
         0.03441275215923235}, {0.014448956997349797`, 0.0330466383808002}, {
        0.012979254694235625`, 0.03175398757375377}, {0.011624653725683678`, 
        0.030527248044100258`}, {0.010385154091693955`, 
        0.02936641979183966}, {0.009260755792266451, 0.02827150281697197}, {
        0.009014019362020047, 0.02801942488516842}}]}, 
      {Arrowheads[{{0.003376777944875858, 1.}}], 
       ArrowBox[{{0.00879641106619584, 0.027797105671504344`}, {
        0.007326781278273426, 0.02629566043665836}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAlZt3KT/Jdj97FK5H4XqEv2yHYWIa
ynY/rmtdhhx3hL+07QiUuNV2P8aHpLEHQ4S/eH8+URHhdj9EA/ACMw+Ev1ix
zzkl7HY/+zMWLp7bg7+iAYjs9PZ2P6k4OedIqIO/xW+2/lKIdz/p4hvKbXeA
v8x6SdUP23c/aG/jFQELe7+fJqaeiN53P9a24CBzqXq/1VQwgsPhdz85/7u9
bEh6v962K4OP43c/Kdj+HKEMer+7WhJt0+V3PxmWSFkxvXm/fOLLC/Hndz9z
t0glF255v8Mo2Zkw8Hc/2YYGvtvnd78bPRiGqPR3P0o8My9Qana/9ObNk4T1
dz9DWManRPV0v8jFv15Qznc/rjmO2ck9bL+DKV0Lu2F3PzY3IVteCGC/qyaO
p1nzdT/+04zSukRCPznfwFqiPnQ/yr8W5ghPYz+qXaHf
        "]]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.09570766941431641, 0.09}, {-0.09495411149002272, 
        0.08905590261323965}, {-0.09355231868732979, 
        0.08731977152765714}, {-0.09317595606498676, 
        0.0868563898581564}, {-0.09280076202883004, 
        0.08639570164715989}, {-0.09114850970815833, 
        0.08445787154467793}, {-0.08949625738748661, 
        0.08252004144219596}, {-0.08784400506681489, 
        0.08058221133971401}, {-0.08773144074147271, 0.0804501912266934}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08752960025936601, 
        0.0802134643313928}, {-0.08619175274614317, 
        0.07864438123723205}, {-0.08474675449657443, 
        0.07711389913227337}, {-0.08313107642374441, 
        0.07524795397053083}, {-0.08153978118280887, 
        0.07342993210261455}, {-0.07997286877376779, 
        0.07165983352852452}, {-0.0792869846718621, 0.07089331161362626}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07907954090416541, 
        0.07066147916029081}, {-0.078429916530455, 
        0.06993547994625805}, {-0.07691050178670433, 
        0.06825469305381239}, {-0.07541462454251578, 
        0.06661747285118755}, {-0.07394228479788935, 
        0.06502381933838353}, {-0.07249348255282503, 
        0.06347373251540031}, {-0.07106821780732284, 
        0.061967212382237916`}, {-0.07063874090191392, 
        0.061518976308191795`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07042351519446165, 
        0.0612943497335676}, {-0.06966649056138276, 
        0.06050425893889634}, {-0.06828830081500481, 
        0.05908487218537558}, {-0.06693284925056606, 
        0.05770470813571676}, {-0.06559933655044359, 
        0.05635942280396098}, {-0.06428776271463739, 
        0.055049016190108255`}, {-0.06299812774314748, 
        0.05377348829415859}, {-0.06173043163597384, 
        0.05253283911611197}, {-0.061658010761436295`, 
        0.05246274283393837}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.06143447610209081, 
        0.052246383273837536`}, {-0.060484674393116486`, 
        0.051327068655968415`}, {-0.05926085601457542, 
        0.0501561769137279}, {-0.05805897650035063, 
        0.04902016388939045}, {-0.0568917019236001, 
        0.04796454593608484}, {-0.05572579873186857, 
        0.04686989613353271}, {-0.05458135793775145, 
        0.04580841283497282}, {-0.053458141307897805`, 
        0.04477923993344979}, {-0.052355910608956696`, 
        0.04378152132200821}, {-0.05233335974278761, 0.04376135512122603}}]}, 
      {Arrowheads[{{0.001783210614865795, 1.}}], 
       ArrowBox[{{-0.05210146433017964, 
        0.043553981736272444`}, {-0.05127442760757721, 
        0.04281440089369268}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.035267636722781964`}, {0.04812722462117538, 
        0.03465478920223906}, {0.04566190601006123, 0.03383375594195599}, {
        0.043315191482793156`, 0.03303725298164704}, {0.041087081039371136`, 
        0.03226528032131219}, {0.04079423622430228, 0.03216270030307709}, {
        0.04050335134216347, 0.03206054590839201}, {0.03876758425545556, 
        0.0314139456288122}, {0.03823563102687705, 0.031215784764398874`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037944107626404405`, 0.03110718775637104}, {
        0.03703181716874764, 0.03076734534923239}, {0.03529605008203973, 
        0.03012074506965258}, {0.03356028299533182, 0.029474144790072772`}, {
        0.03242511482912483, 0.02897736909098579}, {0.030795335787211192`, 
        0.028357208443257655`}, {0.029236215441827078`, 
        0.02775467421676397}, {0.027747753792972486`, 
        0.027169766411504738`}, {0.026343582693123226`, 
        0.026609070139989487`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.026055240925752697`, 0.02649228800024315}, {
        0.024963109886505047`, 0.026049532259990262`}, {0.0236620034543055, 
        0.02551338146256018}, {0.02242170736946207, 0.024993208184014862`}, {
        0.020123546241843548`, 0.024000794183578544`}, {0.018068626503649488`,
         0.0230722902586813}, {0.016216448472774696`, 0.0222012971016035}, {
        0.014679675448906818`, 0.021455723263033084`}}]}, 
      {Arrowheads[{{0.019269753379811017`, 1.}}], 
       ArrowBox[{{0.014400688933686812`, 0.021318098150754156`}, {
        0.012998818486667372`, 0.020612645167747308`}, {0.011633366531434836`,
         0.019894986390968917`}, {0.009281531381687354, 
        0.018591872548076066`}, {0.007363349702946878, 0.01745094320631148}, {
        0.006088774036439653, 0.01663929354122442}, {0.004993990505620636, 
        0.015904304639191978`}, {0.0040789991104898254`, 
        0.01524597650021416}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.04226712179430375}, {0.0495218744032061, 
        0.04206927814825914}, {0.04818222218015196, 0.04150959944998542}, {
        0.046877774428723214`, 0.04095914416428124}, {0.045608531148919856`, 
        0.04041791229114659}, {0.045270528250818017`, 0.04027299920089122}, {
        0.04493484763682781, 0.0401287217165645}, {0.043164605618131326`, 
        0.03932657767733081}, {0.04139436359943484, 0.03852443363809712}, {
        0.03962412158073835, 0.03772228959886343}, {0.03860838433637843, 
        0.0372620318672167}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03832502394530244, 0.037133633689873755`}, {
        0.037853879562041864`, 0.03692014555962974}, {0.03664027766714696, 
        0.03628890528513027}, {0.03496826625853311, 0.035516920733790855`}, {
        0.033361741923307674`, 0.03476504250771428}, {0.03182070466147066, 
        0.03403327060690057}, {0.0303409601189119, 0.03332072363435919}, {
        0.02891831394152122, 0.032626520193099626`}, {0.027552766129298613`, 
        0.03195066028312187}, {0.02711655778596786, 0.03173145874582944}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.026838587524158047`, 0.03159177432749613}, {
        0.02624431668224409, 0.031293143904425946`}, {0.02379871288363928, 
        0.030033141740879538`}, {0.02158150254570678, 
        0.028846513702460403`}, {0.019558592370237722`, 0.0277263318488137}, {
        0.017695889059023223`, 0.026665668239584585`}, {0.015993392612063277`,
         0.02566452287477306}, {0.015923523174332748`, 
        0.025621864895239585`}}]}, 
      {Arrowheads[{{0.009707257486163008, 1.}}], 
       ArrowBox[{{0.015658005061640758`, 0.02545975587325681}, {
        0.014451103029357898`, 0.024722895754379134`}, {0.013045292400904018`,
         0.02383507879407947}, {0.011752232816698573`, 
        0.022995363909550755`}, {0.01057192427674157, 
        0.022203751100792986`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.028571415663610603`}, {0.049477485136896794`, 
        0.02845101449944538}, {0.04705965068706955, 0.02788058157407133}, {
        0.04674152777362303, 0.027804583887293007`}, {0.04642545357070713, 
        0.02772885562861918}, {0.0446509868421218, 0.027275972754701148`}, {
        0.042876520113536466`, 0.026823089880783118`}, {0.04110205338495113, 
        0.026370207006865088`}, {0.0393275866563658, 0.025917324132947058`}, {
        0.03810727648609625, 0.025551387521652758`}, {0.037941005065550204`, 
        0.025507997880564168`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037639991970656296`, 0.02542944649688368}, {
        0.03643060209133135, 0.025113848105844796`}, {0.03481912258578007, 
        0.024686537662110215`}, {0.033272837969442415`, 
        0.024269456190449016`}, {0.031787556805424014`, 
        0.023862244335899313`}, {0.030359087656830496`, 
        0.02346454274349923}, {0.02898743052366187, 0.02307635141324876}, {
        0.027672585405918132`, 0.02269767034514791}, {0.025651069113530742`, 
        0.02209856820499879}}]}, 
      {Arrowheads[{{0.018648052059656174`, 1.}}], 
       ArrowBox[{{0.025352798595190858`, 0.022010171932085366`}, {
        0.025213331216705322`, 0.02196883899539506}, {0.02298132508919206, 
        0.021278048694240673`}, {0.020942441603230964`, 
        0.020622595736694855`}, {0.019062555338674635`, 0.0199997764177677}, {
        0.01734166629552308, 0.01940959073745921}, {0.015779774473776303`, 
        0.018852038695769385`}, {0.014353256289836257`, 
        0.01832452542396273}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.1, 0.004644973431636315}, {-0.09784168167731709, 
        0.004588225402877709}, {-0.09725238476638431, 
        0.0045733000349151695`}, {-0.09666652938063583, 
        0.004558723255170472}, {-0.09467163452272637, 
        0.004521883144531726}, {-0.09267673966481689, 
        0.0044850430338929815`}, {-0.09068184480690741, 
        0.004448202923254236}, {-0.08868694994899795, 
        0.004411362812615491}, {-0.08755874322247655, 
        0.004406886184868435}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08724765211126544, 
        0.004405651801960079}, {-0.0870328496570994, 
        0.004404799484203191}, {-0.08509809501672128, 
        0.004373302335133818}, {-0.08320343385469736, 
        0.004345367160444027}, {-0.08134886617102768, 
        0.0043209939601338175`}, {-0.07953289181292404, 
        0.004299951027522732}, {-0.07775401062759822, 
        0.004282006655930314}, {-0.07601222261505022, 
        0.004267160845356562}, {-0.07480483819522177, 
        0.004258840619496925}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0744937520213185, 
        0.0042566968886468505`}, {-0.07430752777528007, 
        0.004255413595801477}, {-0.07263992610828775, 
        0.004246764907265059}, {-0.07100941761407326, 
        0.004241214779747308}, {-0.0694160022926366, 
        0.004238763213248223}, {-0.06785968014397777, 
        0.0042394102077678054`}, {-0.06633746950999714, 
        0.00424269268175251}, {-0.06484638873259506, 
        0.004248147553648791}, {-0.06338643781177154, 
        0.00425577482345665}, {-0.06205011280057975, 0.004264940100622948}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06173903117156977, 
        0.0042676396774968236`}, {-0.059193364188772385`, 
        0.0042916910203496875`}, {-0.05655363105633242, 
        0.004326497141169599}, {-0.05405075973213749, 
        0.004371725300412954}, {-0.051614810051913096`, 
        0.004417558299675989}, {-0.04929707874990777, 
        0.004470613147407106}}]}, 
      {Arrowheads[{{0.019945184919583612`, 1.}}], 
       ArrowBox[{{-0.048986098283724376`, 
        0.004478999693451263}, {-0.04708191030100082, 
        0.0045304422221650095`}, {-0.04540581594227937, 
        0.004582047535810825}, {-0.04379272784446941, 
        0.004637197833339348}, {-0.042240177049207225`, 
        0.004695569589841388}, {-0.040745694598129115`, 
        0.004756839280407749}, {-0.03930681153287138, 
        0.004820683380129241}, {-0.037921058895070324`, 
        0.004886778364096671}, {-0.03658596772636223, 
        0.004954800707400845}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.1, 0.07556703343984189}, {-0.0997972929490473, 
        0.07538114302959505}, {-0.09817727674695609, 
        0.07390811982265563}, {-0.09658084641619881, 
        0.07246932173721725}, {-0.09615292964244682, 
        0.07208540861936504}, {-0.09572666579971112, 
        0.0717037797431245}, {-0.09372237209279835, 
        0.06997624003640614}, {-0.0917180783858856, 
        0.06824870032968777}, {-0.09066454035922597, 0.06734063542517055}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.0904288975734469, 
        0.06713753032753388}, {-0.08971378467897283, 
        0.06652116062296941}, {-0.08770949097206007, 
        0.06479362091625104}, {-0.08602734918402176, 
        0.06346637226159656}, {-0.0840799058157339, 
        0.06180947215230123}, {-0.08217036267319597, 
        0.0601996651079546}, {-0.08089887928078972, 0.059138049746358015`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.08066007966510806, 
        0.05893866582843578}, {-0.08029871975640798, 
        0.05863695112855666}, {-0.0784638159715619, 
        0.05711899032898698}, {-0.07666449022484974, 
        0.05564344282412513}, {-0.07490074251627146, 
        0.05421030861397111}, {-0.07317257284582708, 
        0.05281958769852493}, {-0.0714799812135166, 
        0.05147128007778657}, {-0.07100105833362111, 
        0.051093840403386964`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0707567233468774, 
        0.05090127971833241}, {-0.06982296761934002, 
        0.050165385751756046`}, {-0.06820153206329733, 
        0.048901904720433355`}, {-0.06661567454538855, 
        0.04768083698381849}, {-0.06506313315544787, 
        0.04649750262072551}, {-0.06354164598330951, 
        0.04534722170996847}, {-0.06205121302897345, 
        0.044229994251547375`}, {-0.06086667781496473, 
        0.04335000178888408}}]}, 
      {Arrowheads[{{0.016102800001280795`, 1.}}], 
       ArrowBox[{{-0.060616954623072775`, 
        0.043164482165644315`}, {-0.060591834292439695`, 
        0.043145820245462214`}, {-0.059163509773708246`, 
        0.04209469969171299}, {-0.05776623947277911, 
        0.0410766325902997}, {-0.05640002338965229, 
        0.04009161894122235}, {-0.055064861524327775`, 
        0.03913965874448095}, {-0.05375865728633129, 
        0.038217162756662384`}, {-0.05247931408518855, 
        0.037320541734353535`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07945326419882273, 0.09}, {-0.07921318452302256, 
        0.08960313646316534}, {-0.07815636705691012, 
        0.0878820353000245}, {-0.07787208182213108, 
        0.08742257667167613}, {-0.07758843101855925, 
        0.08696574837494256}, {-0.07631062422242005, 
        0.08502573838559165}, {-0.07503281742628086, 
        0.08308572839624073}, {-0.07375501063014166, 
        0.08114571840688982}, {-0.07270265452983223, 0.07954799537620696}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07253153365877882, 
        0.0792881938160391}, {-0.07247720383400247, 
        0.0792057084175389}, {-0.0713280967009152, 
        0.07767116764897455}, {-0.07007300161002046, 
        0.07580271105152715}, {-0.06883304765595535, 
        0.07398195671534875}, {-0.0676082348387199, 
        0.07220890464043937}, {-0.06639856956795336, 
        0.07048139808595266}, {-0.06540913719627321, 0.06908641703908434}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06522915977643186, 
        0.06883267044989944}, {-0.06520405825329498, 
        0.06879728031104233}, {-0.0640247008947448, 
        0.06715655131570837}, {-0.06286049749230278, 
        0.06555921109995076}, {-0.06171144804596896, 
        0.06400525966376953}, {-0.06057755255574331, 
        0.06249469700716466}, {-0.05945881102162585, 
        0.06102752313013616}, {-0.058355223443616565`, 
        0.05960373803268402}, {-0.05777725061171378, 0.05886840609829644}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05758500670408847, 
        0.0586238217914477}, {-0.05726684848514886, 
        0.05821904169511694}, {-0.05619374480965616, 
        0.05686913409774362}, {-0.055135912417138444`, 
        0.05555401524056405}, {-0.054093351307595725`, 
        0.05427368512357823}, {-0.05306606148102799, 
        0.053028143746786174`}, {-0.052054042937435256`, 
        0.05181739111018786}, {-0.051057295676817514`, 
        0.050641427213783306`}, {-0.05007581969917476, 
        0.049500252057572504`}, {-0.049655114269048006`, 
        0.049036334358681315`}}]}, 
      {Arrowheads[{{0.0054183833024499806`, 1.}}], 
       ArrowBox[{{-0.049446132540085515`, 
        0.04880588731457882}, {-0.049113418793544375`, 
        0.04843899926267436}, {-0.04816011248524209, 
        0.04733924613041639}, {-0.04722193437067201, 0.04627258392188374}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAATnoawTr4ir97FK5H4XqEvx1zXkcG
54q/Ugb5Fn5shL+CrBmdUruKv69cOBbgR4S/1AbIMdqPir9uhZJRYSOEvzHj
TLycZIq/P24bsAH/g78CzOr4X+uGv0tHSXixA4G/mv1jbzLUg7/JdzkDOXx8
v746NTUXooO/tEY5/gggfL/vCqVoYnCDv81wgdNNxHu/HxfpwWZcg7/b/Vlh
R597v9s2C7J7SIO//gWK/FN6e78uGHz6tSqDv96sdcsFQ3u/yqlDFPAWg78Y
OZklPR57vwm4zp86A4O/bGV9cYf5er+5ZsgnnkGCvxoqI5l1jnm/ZG6QSTqG
gb+ANLlIoyp4vwIhKvDg0IC/7D9eoe3Ndr/Gnxr/ESp7v0msg6SjX3C/gP2L
aHeydb+sPWmuSiFlvyHfWi/DU3G/F+2T56pVVr95ZKLV
        "]]}, 
      {Arrowheads[{{0.005964094210087843, 1.}}], 
       ArrowBox[{{-0.004031273092698627, -0.001124128828155404}, \
{-0.0032324102174013606`, -0.00014536360523991583`}, {-0.0017914473652382251`,
         0.0018328525720128289`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.1, 0.06037353297024523}, {-0.09977021909631256, 
        0.060218500387388185`}, {-0.0980264341104038, 
        0.059050587900988494`}, {-0.09755955859643264, 
        0.05873907764348295}, {-0.09709472999946023, 
        0.05842947509983312}, {-0.09509210686894753, 
        0.05713489616961247}, {-0.09308948373843487, 
        0.05584031723939181}, {-0.09108686060792219, 
        0.054545738309171164`}, {-0.08958011362428764, 
        0.053571714356053506`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08931885523364774, 
        0.05340282606014174}, {-0.08908423747740951, 
        0.05325115937895051}, {-0.08741079845599412, 
        0.052241890111868965`}, {-0.08546626663885155, 
        0.05099765994573169}, {-0.08356046236395571, 
        0.04978699562231666}, {-0.08169338563130663, 
        0.04860989714162387}, {-0.07986372500907178, 
        0.04746477436387238}, {-0.0787781553113838, 0.046790067257396206`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07851393649554696, 
        0.04662584904728081}, {-0.07807016906541872, 
        0.0463500371492812}, {-0.07631271780034742, 
        0.04526568549785035}, {-0.07459137121385788, 
        0.044211719409579825`}, {-0.07290612930595011, 
        0.043188138884469617`}, {-0.07125699207662411, 
        0.04219494392251973}, {-0.06964395952587989, 
        0.04123213452373017}, {-0.06806703165371743, 
        0.040299710688100926`}, {-0.06786825271539534, 
        0.040183126395285415`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06759990751633142, 
        0.04002574133463773}, {-0.06652362163635836, 
        0.039394497253936046`}, {-0.06501114265002433, 
        0.03851331905953957}, {-0.06352959469471534, 
        0.03765617610491151}, {-0.06207897777043136, 
        0.036823068390051845`}, {-0.06065929187717242, 
        0.036013995914960586`}, {-0.05927053701493851, 
        0.03522895867963773}, {-0.057912713183729626`, 
        0.034467956684083284`}, {-0.05679789395433291, 
        0.033848777266829264`}}]}, 
      {Arrowheads[{{0.004602636320315998, 1.}}], 
       ArrowBox[{{-0.05652582203543028, 
        0.03369792670933435}, {-0.05528760826782994, 
        0.033015585708174984`}, {-0.054015826490025086`, 
        0.0323192713196119}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.0658936487593563, 0.09}, {-0.06538849553299429, 
        0.08886398787290255}, {-0.06462459805088981, 
        0.08718045770875096}, {-0.06441852854738507, 
        0.08673095601130248}, {-0.06421265475975738, 
        0.08628399496294534}, {-0.06324632135104676, 
        0.08434675954670362}, {-0.062279987942336135`, 
        0.08240952413046192}, {-0.06131365453362552, 
        0.0804722887142202}, {-0.06047870237251683, 0.07879843693305749}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06033880151447058, 
        0.07852061967770663}, {-0.05944468001903004, 
        0.07700583091753355}, {-0.05848958642846514, 
        0.07514059780172656}, {-0.0575419860499974, 
        0.07332336621954273}, {-0.0566018788836268, 
        0.07155413617098204}, {-0.05566964055163681, 
        0.0698307223606414}, {-0.05474564667631088, 
        0.06815093949311773}, {-0.05442343454249343, 0.06757524925279018}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.05427149579040427, 
        0.06730378319821002}, {-0.05382989725764901, 
        0.06651478756841103}, {-0.052922392295651204`, 
        0.06492226658652128}, {-0.052023131790317464`, 
        0.0633733765474485}, {-0.051132115741647784`, 
        0.06186811745119269}, {-0.05024934414964217, 
        0.06040648929775383}, {-0.04937481701430061, 
        0.05898849208713194}, {-0.04850933510940195, 
        0.057609768548433665`}, {-0.047883603962767446`, 
        0.05662703514460686}}]}, 
      {Arrowheads[{{0.014383803611253871`, 1.}}], 
       ArrowBox[{{-0.047716517923640324`, 
        0.05636462047522929}, {-0.047653699208725045`, 
        0.05626596141076566}, {-0.04680790931226987, 
        0.05495707067412794}, {-0.04597196542003644, 
        0.05368309633852048}, {-0.04514586753202475, 
        0.0524440384039433}, {-0.044329615648234795`, 
        0.05123989687039639}, {-0.04352320976866658, 
        0.05007067173787975}, {-0.04272664989332011, 0.04893636300639338}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.046111684783003634`, 0.09}, {0.04563635834512085, 
        0.08956747781352123}, {0.04399308667391546, 0.08805301791978687}, {
        0.04355656754922513, 0.08764804395767506}, {0.043123541583462655`, 
        0.08724507669682416}, {0.04133523033757311, 0.08548742858008414}, {
        0.03954691909168356, 0.08372978046334412}, {0.037758607845794025`, 
        0.08197213234660408}, {0.03714738991864913, 0.08137139461650633}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.036925519636636005`, 0.08115332861471984}, {
        0.03597029659990448, 0.08021448422986406}, {0.03470280983690351, 
        0.07878456619658492}, {0.03300640879387666, 0.07708475280045564}, {
        0.03137128121942493, 0.07542349588473352}, {0.029797427113548332`, 
        0.07380079544941856}, {0.02828132515517936, 0.07221511132922713}, {
        0.028276725328165483`, 0.07221023354736017}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.028063292093189245`, 0.0719839031309701}, {
        0.026819454023250512`, 0.07066490335887554}, {0.025411813717761793`, 
        0.06915017153836382}, {0.0240584042387132, 0.06767091586769196}, {
        0.02275922558610473, 0.06622713634685996}, {0.021514277759936393`, 
        0.06481883297586782}, {0.02032356076020818, 0.06344600575471555}, {
        0.01972860376240301, 0.06274589483642999}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.01952715149726235, 0.06250883748462367}, {
        0.019187074586920094`, 0.06210865468340314}, {0.018097746238511743`, 
        0.06080372377253286}, {0.01704850271342273, 0.059528157032707}, {
        0.016039344011653054`, 0.05828195446392555}, {0.015070270133202716`, 
        0.0570651160661885}, {0.014141281078071718`, 0.05587764183949587}, {
        0.013252376846260058`, 0.05471953178384764}, {0.012403557437767738`, 
        0.05359078589924383}, {0.011794379321476115`, 
        0.052762678268347435`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01161003636950828, 0.05251208521330498}, {
        0.011594822852594755`, 0.052491404185684425`}, {0.010076744898946575`,
         0.050370675830453175`}, {0.00867727973205529, 0.04834728927690822}, {
        0.007396427351920897, 0.04642124452504955}, {0.006234187758543397, 
        0.04459254157487718}, {0.005089323448394855, 0.04271351917860865}, {
        0.004750278875515395, 0.04213607249049644}}]}, 
      {Arrowheads[{{0.0017652933195863722`, 1.}}], 
       ArrowBox[{{0.0045927656584901335`, 0.041867802496575984`}, {
        0.0040366515989676294`, 0.04092065204034947}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.053605998144226855`, 0.09}, {-0.05354410736358446, 
        0.0897851849521474}, {-0.05304399048013753, 
        0.08810278587835102}, {-0.05290831373475501, 
        0.08765351667388938}, {-0.05277241806732478, 
        0.08720675491753033}, {-0.05210729885848943, 
        0.08526579779457304}, {-0.05144217964965407, 
        0.08332484067161575}, {-0.05077706044081872, 
        0.08138388354865846}, {-0.05011194123198337, 
        0.07944292642570117}, {-0.04958528711579942, 0.0782306549247122}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.049461329223177725`, 
        0.07794532416220575}, {-0.049444510279026604`, 
        0.07790660970798509}, {-0.0487789831153463, 
        0.07603705971536448}, {-0.04811318398176936, 
        0.07421511447630166}, {-0.047447112878295776`, 
        0.07244077399079664}, {-0.046781513503549386`, 
        0.07071189244701023}, {-0.04611712955615402, 
        0.06902632403310327}, {-0.04545396103610967, 
        0.06738406874907574}, {-0.04501538604433838, 0.06632469452779213}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04489638946539274, 
        0.0660372592874771}, {-0.04479200794341634, 
        0.06578512659492766}, {-0.04413127027807403, 
        0.06422949757065903}, {-0.04347174804008274, 
        0.06271718167626983}, {-0.04281344122944247, 
        0.06124817891176009}, {-0.04215634984615322, 
        0.059822489277129784`}, {-0.04150200989034069, 
        0.0584358358320344}, {-0.040851957362130584`, 
        0.05708394163612941}, {-0.040206192261522895`, 
        0.055766806689414826`}, {-0.03969126690840453, 
        0.05473742127716114}}]}, 
      {Arrowheads[{{0.008644843092306773, 1.}}], 
       ArrowBox[{{-0.03955177202903357, 
        0.05445935816261221}, {-0.038294621525314355`, 
        0.05202395734441344}, {-0.03704167817252078, 0.04970252069369783}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.020964059736796842`, -0.01}, {
        0.020732356747099615`, -0.009643514540879996}, {
        0.019602954451875088`, -0.007987648182516892}, {
        0.01952813666332207, -0.00788081871386405}, {
        0.019453517821858047`, -0.007774604833480265}, {
        0.01942664362507935, -0.007736502080997622}, {
        0.019399795481118212`, -0.007698478584231751}, {
        0.019359565616733538`, -0.007641571859692891}, {
        0.019332776122927695`, -0.007603726148723387}, {
        0.019306012709524045`, -0.0075659592143791435`}, {
        0.019039815491424687`, -0.007192574876266313}, {
        0.018776234953302454`, -0.006826895631697037}, {
        0.018515277787654195`, -0.006468767096951754}, {
        0.017249786070780208`, -0.004780852801752165}, {
        0.01604975073719789, -0.003261023896914851}, {
        0.014914550471508924`, -0.0018937124212056286`}, {
        0.013843563958314986`, -0.000663350413390312}, {
        0.013377700867190642`, -0.00015222858007109404`}}]}, 
      {Arrowheads[{{0.0007941616841193409, 1.}}], 
       ArrowBox[{{0.013168139625813683`, 0.00007769160018343782}, {
        0.012835288609057551`, 0.0004428791953113604}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, -0.006174636964379212}, {
        0.049711693853217914`, -0.006050246864432056}, {
        0.0478421836570975, -0.005253827402413474}, {
        0.047594605910184745`, -0.005149072182074649}, {
        0.04734825077956444, -0.005044999625462758}, {
        0.04556964224946935, -0.0043235410312579756`}, {
        0.04379103371937426, -0.003602082437053193}, {
        0.04201242518927917, -0.0028806238428484105`}, {
        0.040233816659184074`, -0.0021591652486436285`}, {
        0.03900453124963063, -0.0017194768958723983`}, {
        0.038467396768188854`, -0.0015049211816373493`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03817849839859091, -0.0013895221555609585`}, {
        0.03732286209374877, -0.0010477424619205961`}, {
        0.035705819187342405`, -0.00040915746813744737`}, {
        0.03415340253041152, 0.00019627808547704887`}, {0.032661493096013135`,
         0.0007711130465960919}, {0.031225971857204257`, 
        0.0013178962628928844`}, {0.029846838813984894`, 
        0.0018366277343674253`}, {0.028524093966355038`, 
        0.002327307461019714}, {0.026551317342271313`, 
        0.003042069631739294}}]}, 
      {Arrowheads[{{0.00036080249362804194`, 1.}}], 
       ArrowBox[{{0.02625882952530116, 0.0031480417040025267`}, {
        0.026047768857863855`, 0.0032245116798575377`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04227744793920881, 0.09}, {-0.04211050302517107, 
        0.08887875607140483}, {-0.041850209354059115`, 
        0.08723332628110643}, {-0.04177857922937289, 
        0.08679386742769742}, {-0.04170637469760865, 
        0.08635683356498171}, {-0.041309365114890736`, 
        0.08441923232953852}, {-0.04091235553217283, 
        0.08248163109409534}, {-0.040515345949454926`, 
        0.08054402985865215}, {-0.04011833636673702, 
        0.07860642862320896}, {-0.03987586473210425, 0.07779737562528542}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0397865552000806, 
        0.07749937728524735}, {-0.03965980850422449, 
        0.07707646268571247}, {-0.03925194275448401, 
        0.0752107970910834}, {-0.0388368395600618, 
        0.07339308859033042}, {-0.03841449892095787, 
        0.07162333718345351}, {-0.03798602083167702, 
        0.06989936407712022}, {-0.03755250528672404, 
        0.06821899047799806}, {-0.03711395228609893, 
        0.06658221638608705}, {-0.03679147739894732, 0.06542403368147623}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.036708033168055286`, 
        0.06512434006541715}, {-0.036670361829801684`, 
        0.06498904180138719}, {-0.03622173391783231, 
        0.06343946672389847}, {-0.0357680685501908, 
        0.06193349115362087}, {-0.03530936572687717, 
        0.06047111509055443}, {-0.03484562544789141, 
        0.059052338534699135`}, {-0.034379101817945644`, 
        0.057672818583410085`}, {-0.033912048941751996`, 
        0.05632821233404238}, {-0.03344446681931047, 
        0.05501851978659604}, {-0.03297635545062107, 
        0.05374374094107105}, {-0.032810303762214464`, 
        0.05331085398558541}}]}, 
      {Arrowheads[{{0.006964468755084863, 1.}}], 
       ArrowBox[{{-0.032698886837463643`, 
        0.053020396635782036`}, {-0.03203854497449862, 
        0.05129892435578514}, {-0.031098617513384667`, 
        0.04899376257818465}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.005552325839209739}, {0.04868504555069893, 
        0.005768957196389571}, {0.04666823160985543, 0.006094066850029587}, {
        0.04640183618377472, 0.006136506018758786}, {0.04613691572316731, 
        0.006178593265308841}, {0.04436833063103239, 0.006440445126829607}, {
        0.04259974553889748, 0.006702296988350373}, {0.040831160446762556`, 
        0.0069641488498711395`}, {0.039062575354627635`, 
        0.007226000711391905}, {0.037856905919812854`, 
        0.007366811648759523}, {0.03769369765254001, 0.007390325384337905}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03738578332685692, 0.007434687205928744}, {
        0.03618765888485208, 0.007607303347194438}, {0.03458463722134073, 
        0.007833554936905454}, {0.03304784092927881, 0.00804556641789257}, {
        0.03157291345674058, 0.00824452575954817}, {0.030155498251800302`, 
        0.008431620931264637}, {0.028795595314457984`, 0.00860685193304197}, {
        0.027493204644713623`, 0.00877021876488017}, {0.025060960108018764`, 
        0.009061359918739171}, {0.025049391147349987`, 
        0.009062640084891369}}]}, 
      {Arrowheads[{{0.006286126684147653, 1.}}], 
       ArrowBox[{{0.02474018487836643, 0.00909685537967305}, {
        0.022858764641715726`, 0.00930504439284164}, {0.02085109205392724, 
        0.00951133705109265}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.047489733297032224`}, {-0.09893518623945069, 
        0.0469630083334705}, {-0.09710014213802651, 
        0.04606131322188608}, {-0.09660926962865521, 
        0.045820940788160874`}, {-0.09612074691202237, 
        0.04558209965708621}, {-0.09412473726203624, 
        0.04463159819343779}, {-0.0921287276120501, 
        0.043681096729789363`}, {-0.09013271796206397, 
        0.042730595266140946`}, {-0.08878881494779606, 
        0.04209062752747192}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08850794198414828, 
        0.04195687558742076}, {-0.08813670831207783, 
        0.04178009380249252}, {-0.08647795445611979, 
        0.04103724746133017}, {-0.08454146053449156, 
        0.04012339101929693}, {-0.08264464376510193, 
        0.03923396459167383}, {-0.0807875041479509, 
        0.03836896817846085}, {-0.07896861326298352, 
        0.03752725836078348}, {-0.07721890439680058, 
        0.036722574730364894`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07693598452087547, 
        0.03659320901899968}, {-0.07544129242943502, 
        0.035910268255412055`}, {-0.07373286248085388, 
        0.035134987967717995`}, {-0.07206125284440149, 
        0.03438185085668504}, {-0.07042646352007784, 
        0.03365085692231319}, {-0.0688284945078829, 
        0.03294200616460244}, {-0.06726734580781674, 
        0.03225529858355279}, {-0.06574018759632275, 
        0.03158845207023587}, {-0.06557502396270729, 0.03151677054325452}}]}, 
      {Arrowheads[{{0.01635801412253641, 1.}}], 
       ArrowBox[{{-0.06528964809195438, 
        0.03139291653416419}, {-0.06424419004984436, 
        0.03093918451572329}, {-0.0627793531683816, 
        0.030307495920015054`}, {-0.06134567695193447, 
        0.02969338628311116}, {-0.05994316140050295, 
        0.02909685560501162}, {-0.05857180651408706, 
        0.028517903885716418`}, {-0.057231612292686786`, 
        0.02795653112522556}, {-0.05592257873630213, 
        0.027412737323539046`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.031169007877470872`, 0.09}, {0.030779754936250042`, 
        0.0895534498254251}, {0.029457935181614953`, 0.08801476703227996}, {
        0.02910722360153911, 0.08760340099174549}, {0.028759513645453896`, 
        0.08719411541151348}, {0.027217811419504176`, 0.08525163734488622}, {
        0.025676109193554453`, 0.08330915927825895}, {0.024134406967604733`, 
        0.0813666812116317}, {0.023322846209530988`, 0.08034414978775538}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.0231294483762217, 0.0801004768896994}, {
        0.022592704741655013`, 0.07942420314500442}, {0.021573776315525334`, 
        0.07788381138991651}, {0.020124328289543858`, 0.07601228973120797}, {
        0.01873638306354121, 0.07418807234444522}, {0.01740994063751739, 
        0.07241115922962828}, {0.016141057421715115`, 0.07067945523367876}, {
        0.01572639607772261, 0.07010329158540511}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.01554467358079021, 0.06985079180860446}, {
        0.0149257898263771, 0.06899086520351827}, {0.013764137851503348`, 
        0.06734538913914682}, {0.012656101497093859`, 0.06574302704056441}, {
        0.011601680763148629`, 0.06418377890777101}, {0.010600875649667663`, 
        0.06266764474076666}, {0.009653686156650956, 0.06119462453955134}, {
        0.008760112284098513, 0.059764718304125046`}, {0.008611499333905582, 
        0.059520931322681846`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0084495716210724, 0.059255302598722366`}, {
        0.007912182394993292, 0.058373761002812684`}, {0.007101924852318265, 
        0.05701758760393913}, {0.0063293396560734246`, 0.0556961981075044}, {
        0.005594426806258773, 0.054409592513508465`}, {0.00489718630287431, 
        0.053157770821951354`}, {0.004237618145920036, 0.05194073303283306}, {
        0.0036157223353959515`, 0.05075847914615357}, {0.0030314988713020553`,
         0.0496110091619129}, {0.002425807462129314, 0.04837270224352412}}]}, 
      {Arrowheads[{{0.008407071779689166, 1.}}], 
       ArrowBox[{{0.002289117940475012, 0.048093247098920114`}, {
        0.0019535016982780602`, 0.04740709585367833}, {0.0009810593427212761, 
        0.04531566806105969}, {0.00011417180463170527`, 
        0.04333672578405697}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.01650051552480703}, {0.049545588845954676`, 
        0.01648258856277242}, {0.04731445352312342, 0.016386711412556185`}, {
        0.045184511473908125`, 0.016286969743918796`}, {0.044903745470903804`,
         0.016273241105010952`}, {0.04462466660478802, 0.01625945982660611}, {
        0.04286540810694297, 0.016152112093547003`}, {0.04110614960909792, 
        0.016044764360487896`}, {0.03934689111125287, 
        0.015937416627428785`}, {0.03758763261340782, 
        0.015830068894369678`}, {0.03757482589235829, 0.01582885010954634}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03726513160168269, 0.0157993772491717}, {
        0.03640236318241227, 0.0157172696549331}, {0.03474439687283478, 
        0.01560895989133679}, {0.033153958688769, 0.015500008774049013`}, {
        0.03163104863021492, 0.01539041630306977}, {0.030171137404908892`, 
        0.015280473205279256`}, {0.028769695720587275`, 
        0.015170470207557673`}, {0.027426723577250067`, 
        0.015060407309905016`}, {0.02614222097489726, 
        0.014950284512321289`}, {0.024859573192703904`, 
        0.014832166021563073`}}]}, 
      {Arrowheads[{{0.007956686451064945, 1.}}], 
       ArrowBox[{{0.024549790414274766`, 0.014803638256763632`}, {
        0.02374862439314487, 0.014729859217360622`}, {0.0215889059753301, 
        0.014509194322675669`}, {0.019625970022868, 0.01429096338557867}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.0028867027938277025`, 0.09}, {-0.0033030923402870764`, 
        0.08889098805102871}, {-0.0034625685658892123`, 
        0.08845999131430304}, {-0.0036201265403607795`, 
        0.08803126865762116}, {-0.0042465457185662265`, 
        0.0860864234624971}, {-0.004872964896771674, 
        0.08414157826737304}, {-0.005499384074977121, 
        0.08219673307224898}, {-0.006125803253182569, 
        0.08025188787712491}, {-0.0064571213819737145`, 
        0.0787077421349278}, {-0.006630165795769888, 0.07814308198025476}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.006721318471033699, 
        0.07784564225027912}, {-0.007031463904400168, 
        0.07683360860796731}, {-0.0075710886563072925`, 
        0.07500661619311588}, {-0.008075995637695087, 
        0.07322676489037351}, {-0.008548656537487742, 
        0.07149196269528885}, {-0.008991543044609447, 
        0.06980011760341057}, {-0.009404655159060206, 
        0.06815122961473864}, {-0.009787992880840014, 
        0.06654529872927309}, {-0.009949578447387076, 0.06583098821313131}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.010018217247543407`, 
        0.06552756125604142}, {-0.010141556209948874`, 
        0.06498232494701392}, {-0.010465345146386784`, 
        0.06346230826796112}, {-0.010759359690153746`, 
        0.061985248692114685`}, {-0.01102359984124976, 
        0.06055114621947462}, {-0.011263068704483563`, 
        0.05915583654900888}, {-0.0114827693846639, 
        0.05779515537968545}, {-0.01168270188179077, 
        0.05646910271150431}, {-0.011862866195864174`, 
        0.05517767854446545}, {-0.012095199712712536`, 
        0.05326438923378711}}]}, 
      {Arrowheads[{{0.004194372746831746, 1.}}], 
       ArrowBox[{{-0.012132700782235651`, 
        0.05295556424619648}, {-0.012163890274850576`, 
        0.052698715713814626`}, {-0.01238584162162311, 
        0.05035826688773297}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.018586381029883223`, 0.09}, {0.017800308438313817`, 
        0.08884398376959822}, {0.017516472516794113`, 0.08842281574587862}, {
        0.0172352660185111, 0.0880038118802707}, {0.016029440239412766`, 
        0.08605852170597786}, {0.014823614460314428`, 0.084113231531685}, {
        0.013617788681216091`, 0.08216794135739215}, {0.012411962902117754`, 
        0.0802226511830993}, {0.012019890982595517`, 0.07943653607354917}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.011881045020567612`, 0.07915814605576069}, {
        0.011641194114121171`, 0.07867723831356226}, {0.01051214309815844, 
        0.0768025147224616}, {0.009434275257619442, 0.07497483552015577}, {
        0.00840759059250418, 0.07319420070664472}, {0.007428740920585354, 
        0.07145853470015434}, {0.006494378059635661, 0.06976576191891048}, {
        0.005727983128449443, 0.06834482320636535}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.005580769075004181, 0.06807076882253117}, {
        0.004759112770643682, 0.06650889603216235}, {0.003958210342601395, 
        0.06494480292665808}, {0.0032017947255282408`, 0.06342360304640034}, {
        0.0024898659194242207`, 0.06194529639138911}, {0.0018224239242893348`,
         0.06050988296162442}, {0.001192701812556405, 
        0.059113234600222817`}, {0.0005939326566582522, 
        0.05775122315030086}, {0.00020883304974313595`, 
        0.05685098216928233}}]}, 
      {Arrowheads[{{0.006785169633446405, 1.}}], 
       ArrowBox[{{0.00008648003211638418, 0.056564959543860226`}, {
        0.000026116456594876564`, 
        0.056423848611858556`}, {-0.0005107467876337205, 
        0.0551311109848959}, {-0.0014916144085865852`, 
        0.052649546465409536`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, -0.006060598250332016}, {-0.09996253066220036, \
-0.006058120269803848}, {-0.09933658813323012, -0.006016051405523142}, \
{-0.09871443245955334, -0.0059739275975261835`}, {-0.09671229620733926, \
-0.005824677246190567}, {-0.09471015995512518, -0.005675426894854951}, \
{-0.09270802370291108, -0.005526176543519335}, {-0.09070588745069699, \
-0.005376926192183719}, {-0.08903873180742214, -0.00522696659089071}, \
{-0.08759239559447886, -0.005115775255486879}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.08728221729437632, -0.005091929389571992}, \
{-0.08709570978031497, -0.005077591077797906}, {-0.08519209723661242, \
-0.004928132123533645}, {-0.08332789417631448, -0.004778589728097926}, \
{-0.08150165688772879, -0.004629064347744185}, {-0.07971194165916297, \
-0.0044796564387258545`}, {-0.07795874849061704, -0.004330366001042937}, \
{-0.076242077382091, -0.004181193034695432}, {-0.07488136662284578, \
-0.004060476711362149}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07457149010873959, -0.004032985818667964}, \
{-0.07456192833358484, -0.0040321375396833396`}, {-0.07291830134509857, \
-0.0038831995160066588`}, {-0.07131119641663217, -0.003734378963665391}, \
{-0.06974061354818566, -0.003585675882659535}, {-0.06820368371926164, \
-0.0034372917846967888`}, {-0.06669753790936273, -0.00328942818148485}, \
{-0.06522217611848893, -0.003142085073023719}, {-0.06377759834664024, \
-0.002995262459313395}, {-0.06236380459381664, -0.0028489603403538777`}, \
{-0.06218612172408876, -0.002830230973011067}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.061876742181699834`, -0.0027976195957487167`}, \
{-0.06098079486001816, -0.002703178716145169}, {-0.05962856914524479, \
-0.002557917586687267}, {-0.058307127449496524`, -0.0024131769519801726`}, \
{-0.05576852640089972, -0.002124586596887437}, {-0.0532973867612228, \
-0.0018412075471424512`}, {-0.050939838968986795`, -0.0015604469323454704`}, \
{-0.04951369873563841, -0.0013842196553465168`}}]}, 
      {Arrowheads[{{0.0008321462547187443, 1.}}], 
       ArrowBox[{{-0.049204953422253075`, -0.0013460681856720792`}, \
{-0.04869111090986193, -0.001282572980468881}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.03201321012690179, 0.09}, {-0.031985814095368846`, 
        0.08847917555288815}, {-0.031941212887704504`, 
        0.08685842929562965}, {-0.031927174207736934`, 
        0.08642550598466471}, {-0.031912236277495794`, 
        0.08599494596096598}, {-0.03176579010016286, 
        0.08405872117373887}, {-0.031619343922829925`, 
        0.08212249638651178}, {-0.031472897745497, 
        0.08018627159928468}, {-0.03132645156816406, 
        0.07825004681205759}, {-0.031211864088909146`, 
        0.07758959245401835}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03115868445315666, 
        0.07728307796901485}, {-0.03106145074606487, 
        0.07672264653257299}, {-0.03089408316083201, 
        0.07485856724671222}, {-0.03071276797033253, 
        0.07304258496176234}, {-0.030517505174566435`, 
        0.07127469967772333}, {-0.030309740345220708`, 
        0.06955272042407513}, {-0.030090919053982344`, 
        0.06787445623029766}, {-0.02986104130085134, 
        0.0662399070963909}, {-0.02966305876888214, 0.06493267326125614}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.029616207200458614`, 
        0.06462512933173338}, {-0.029368116408911422`, 
        0.06310195400818955}, {-0.029105069270102504`, 
        0.06159855005389496}, {-0.028830965669400948`, 
        0.06013886115947109}, {-0.02854580560680675, 
        0.05872288732491794}, {-0.028252538816126833`, 
        0.057346261793841745`}, {-0.027954115031168104`, 
        0.056004617809848736`}, {-0.02765053425193057, 
        0.05469795537293891}, {-0.027341796478414226`, 
        0.05342627448311226}, {-0.02708738135361647, 
        0.052446143980296706`}}]}, 
      {Arrowheads[{{0.00576213667513115, 1.}}], 
       ArrowBox[{{-0.02700922020717884, 
        0.052145029320468786`}, {-0.02670884994854511, 
        0.050987857344708516`}, {-0.02605527544156076, 
        0.048689366394637494`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{-0.0225364607125842, 0.09}, {-0.022553934768255984`, 
        0.08984809124152976}, {-0.02272665159866473, 
        0.08821362586336245}, {-0.02288012760829096, 
        0.0866134575866172}, {-0.0229189744601155, 
        0.08618597799555776}, {-0.02295662249570405, 
        0.08576080806623351}, {-0.023046012588901998`, 
        0.08382542114136655}, {-0.023135402682099945`, 
        0.08189003421649961}, {-0.02322479277529789, 
        0.07995464729163265}, {-0.023314182868495837`, 
        0.07801926036676571}, {-0.023290319303592724`, 
        0.07758603764381444}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.023273209018779585`, 
        0.07727541497669348}, {-0.023230131542118358`, 
        0.07649338002873768}, {-0.023288914325979466`, 
        0.07463025897213643}, {-0.023327292236949345`, 
        0.07281531516104564}, {-0.023345265275027997`, 
        0.0710485485954653}, {-0.023344616138330807`, 
        0.06932776215645078}, {-0.02332712752497316, 
        0.0676507587250574}, {-0.02329279943495505, 
        0.06601753830128516}, {-0.023254742029949694`, 
        0.06483534678029441}}]}, 
      {Arrowheads[{{0.018243026704388283`, 1.}}], 
       ArrowBox[{{-0.023244732413628476`, 
        0.06452441429444446}, {-0.023241631868276484`, 
        0.06442810088513407}, {-0.02317362482493746, 
        0.06288244647660411}, {-0.02308877830493797, 
        0.06138057507569531}, {-0.02298709230827803, 
        0.05992248668240765}, {-0.022868566834957627`, 
        0.05850818129674113}, {-0.02259551130474833, 
        0.055793406182350846`}, {-0.02228412556072296, 
        0.05321873636660376}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.0075727827312991785`, 0.09}, {0.007145295983323975, 
        0.08918627113834743}, {0.006337695754188694, 0.08761594119062467}, {
        0.006124250830965275, 0.08719625833046288}, {0.005913016803663897, 
        0.0867787634789826}, {0.005025335993992986, 0.08483867497055546}, {
        0.004137655184322075, 0.08289858646212833}, {0.003249974374651163, 
        0.08095849795370119}, {0.002362293564980252, 0.07901840944527407}, {
        0.002269643985729069, 0.07874793436852542}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0021688312813616206`, 0.07845362840220152}, {
        0.0018363877096768304`, 0.07748311454458046}, {0.0010125495390119464`,
         0.07561446020222394}, {0.00023127312768441517`, 
        0.07379342863724786}, {-0.0005074415243057654, 
        0.07202001984965217}, {-0.001206519662032416, 
        0.07029209864946266}, {-0.001868886530569356, 
        0.06860752984670505}, {-0.002494542129916588, 
        0.06696631344137935}, {-0.0025092353015034765`, 
        0.06692644941885922}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.002616823443961818, 
        0.06663455218561079}, {-0.003083486460074111, 
        0.06536844943348555}, {-0.0036357195210419244`, 
        0.06381393782302366}, {-0.0041512413128200285`, 
        0.06230277860999369}, {-0.004630051835408424, 
        0.06083497179439563}, {-0.005072151088807111, 
        0.05941051737622946}, {-0.005483461312324394, 
        0.058025165546776725`}, {-0.005869904745268575, 
        0.056674666497318935`}, {-0.006231481387639655, 
        0.05535902022785609}, {-0.00638361406924522, 
        0.054780330453573486`}}]}, 
      {Arrowheads[{{0.0006667877352075069, 1.}}], 
       ArrowBox[{{-0.0064627103626938255`, 
        0.054479460083582655`}, {-0.006568191239437634, 
        0.05407822673838819}}]}}}}, 
   {PointSize[0.025], PointBox[{0, 0.08}]}, 
   {PointSize[0.025], PointBox[{0, 0.01}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.08}, {0.05, 0.08}}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.01}, {0.05, 0.01}}]}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0.09}, {0, -0.01}}]}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwVy3k8lAkcx3FF16s1M+TIoBy5jxR2ifph1IZSq9IhuUtExcikw9FjNGbm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      "]]}}},
  AspectRatio->1,
  BaseStyle->{FontWeight -> "Bold", FontSize -> 12},
  Frame->True,
  ImageMargins->10,
  ImageSize->{454.5, Automatic},
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{-0.1027733900410869, 0.0527733900410869}, {-0.0127733900410869,
    0.0927733900410869}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.703994782950015*^9, 3.703994808105215*^9}, {
   3.703994889992215*^9, 3.703994935892415*^9}, 3.703995123631215*^9, 
   3.703995236068815*^9, 3.7039973979171467`*^9, 3.703997511583747*^9, 
   3.703997601445747*^9, 3.704148828548354*^9, 3.7044972409250135`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{{}, {
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.036785746414043155`, 0.09}, {-0.036739933790758524`, 
        0.08934491541648468}, {-0.036609109144105735`, 
        0.08765810161394799}, {-0.03646777840468362, 
        0.08600493496720509}, {-0.036315941572492176`, 
        0.08438541547625594}, {-0.03615359864753141, 
        0.08279954314110058}, {-0.03598074962980132, 
        0.08124731796173898}, {-0.03579739451930191, 
        0.07972873993817116}, {-0.035603533316033165`, 
        0.0782438090703971}, {-0.03551620864078092, 0.07762368598170122}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.03547282897002875, 
        0.07731563175377834}, {-0.0353991660199951, 
        0.07679252535841682}, {-0.03518429263118771, 
        0.07537488880223031}, {-0.03495891314961099, 
        0.07399089940183758}, {-0.03448733877361775, 
        0.07130901733007086}, {-0.03399514575748356, 
        0.06873203440475416}, {-0.033482334101208405`, 
        0.06625995062588745}, {-0.03321675112104059, 0.06508138249147787}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.033148362994586955`, 
        0.0647778989378281}, {-0.0329489038047923, 
        0.06389276599347074}, {-0.032405164188305705`, 
        0.061578030934279035`}, {-0.03186142457181912, 
        0.05926329587508733}, {-0.03131768495533253, 
        0.056948560815895624`}, {-0.030681104592480916`, 
        0.05535166799660556}, {-0.02990571980627977, 0.05278201163278158}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.029815850635978376`, 
        0.052484181588284606`}, {-0.029125812246149373`, 
        0.05019736661427121}, {-0.0283481660729836, 
        0.04762021592310403}, {-0.027530484977698628`, 
        0.04606244175090883}, {-0.02693461689241114, 
        0.04454572108020045}, {-0.026340703572994312`, 
        0.043088522625542754`}, {-0.025748745019448148`, 
        0.04169084638693575}, {-0.025392587537077495`, 
        0.04088306586475385}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.025267081468008247`, 
        0.04059841269016675}, {-0.02515874123177265, 
        0.040352692364379446`}, {-0.025079205468728955`, 
        0.04017602111843744}, {-0.02499973803881323, 
        0.04000034785238884}, {-0.024152659715359116`, 
        0.03835061457152353}, {-0.023305581391904997`, 
        0.03670088129065822}, {-0.02245850306845088, 
        0.03505114800979291}, {-0.021611424744996763`, 
        0.033401414728927596`}, {-0.020919671713067294`, 
        0.03250252261029406}, {-0.020100003735176352`, 
        0.030985290710999057`}, {-0.019360428519558506`, 
        0.0296666175768568}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.019205435922526836`, 
        0.029396896805856332`}, {-0.01851548847052081, 
        0.028215829675549683`}, {-0.017750310623539663`, 
        0.026956007519731845`}, {-0.017002745219834196`, 
        0.02576933357896728}, {-0.016272792259404412`, 
        0.02465580785325599}, {-0.01556045174225031, 
        0.02361543034259797}, {-0.014188608037769147`, 
        0.021754119966441766`}, {-0.012887214106390713`, 
        0.02018540245049866}, {-0.012040856588833146`, 
        0.019256596375403275`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.011831323040149002`, 
        0.019026650957637323`}, {-0.01166347719570642, 
        0.018842454283343375`}, {-0.010524604553307679`, 
        0.017658451953550626`}, {-0.009470596179194496, 
        0.01663339546112042}, {-0.008501452073366864, 
        0.015767284806052745`}, {-0.006808806022165904, 
        0.014360426837382981`}, {-0.005437715755302435, 
        0.013286403876919302`}, {-0.0032506552473375245`, 
        0.011727935569477436`}, {-0.0022692587584729803`, 
        0.011121762943206251`}}]}, 
      {Arrowheads[{{0.0015839870050487392`, 1.}}], 
       ArrowBox[{{-0.002004582906287722, 
        0.010958282374190434`}, {-0.001935008050949549, 
        0.010915308537151773`}, {-0.0011405670109927812`, 
        0.010484443052274188`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, 0.04166482525099589}, {-0.09890083428720697, 
        0.04120185270289407}, {-0.0973236447721784, 
        0.040541544581361715`}, {-0.09577305861155921, 
        0.0398964516581652}, {-0.09424691474188278, 
        0.03926494425946741}, {-0.09274305209968248, 
        0.03864539271143121}, {-0.0912614706849583, 
        0.038037797014056615`}, {-0.08980217049771023, 
        0.03744215716734362}, {-0.0884993753624347, 0.03691299179661348}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08821104011642662, 
        0.036796193191623285`}, {-0.08695041380564252, 
        0.03628674502590243}, {-0.08555795730082286, 
        0.035726972731174235`}, {-0.08418778202347932, 
        0.035179156287107646`}, {-0.08282874735987375, 
        0.03463731776837182}, {-0.08146971269626818, 
        0.034095479249635983`}, {-0.08011067803266261, 
        0.033553640730900156`}, {-0.07875164336905704, 
        0.03301180221216432}, {-0.07739260870545148, 
        0.03246996369342849}, {-0.07665660446671965, 0.03217652346178662}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07636763136039335, 
        0.032061311713271735`}, {-0.07603357404184591, 
        0.03192812517469266}, {-0.07394843546343237, 
        0.0311702468606349}, {-0.0725237288911372, 
        0.03062544674190017}, {-0.07112400924435223, 
        0.030092996846251364`}, {-0.06974927652307747, 
        0.02957289717368848}, {-0.06839953072731292, 
        0.02906514772421152}, {-0.06707477185705857, 
        0.028569748497820478`}, {-0.06577499991231443, 
        0.028086699494515362`}, {-0.06471479018816642, 
        0.027696542000313896`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06442283785912424, 
        0.027589103456287224`}, {-0.06325041679935678, 
        0.027157652157162898`}, {-0.06291628454490748, 
        0.02703554339833693}, {-0.06258384601755619, 
        0.026914251037065025`}, {-0.06072121500946996, 
        0.02625814529058758}, {-0.05885858400138373, 
        0.025602039544110135`}, {-0.0569959529932975, 
        0.024945933797632693`}, {-0.05513332198521127, 
        0.024289828051155246`}, {-0.053727378418023, 
        0.023839193467083398`}, {-0.052679741617837714`, 
        0.023474794272170838`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.052385915076277545`, 
        0.02337259267408882}, {-0.051945339311271696`, 
        0.02321934733750106}, {-0.050217028138743694`, 
        0.02262367428584879}, {-0.04854244490043897, 
        0.02205217431212659}, {-0.046918802204351136`, 
        0.021503297453372053`}, {-0.045343312658473786`, 
        0.020975493746622775`}, {-0.04381597626280692, 
        0.02046876319187875}, {-0.042336793017350535`, 
        0.019983105789139984`}, {-0.04090576292210464, 
        0.019518521538406476`}, {-0.04058801470470004, 
        0.019416614523812024`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04029178333736179, 
        0.019321608312538034`}, {-0.039522885977069225`, 
        0.019075010439678224`}, {-0.038188162182244294`, 
        0.018652572492955228`}, {-0.03690159153762985, 
        0.018251207698237487`}, {-0.034450659812832594`, 
        0.017499090210587518`}, {-0.03214784091647765, 
        0.016806050622498046`}, {-0.029993134848565008`, 
        0.016172088933969077`}, {-0.02838392376272373, 0.0157110541073379}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02808486179880362, 
        0.015625373625826795`}, {-0.02798654160909468, 
        0.01559720514500061}, {-0.026111111962652235`, 
        0.015072643884984959`}, {-0.024349896673823243`, 
        0.014589649783314437`}, {-0.022702895742607712`, 
        0.014148222839989046`}, {-0.021170109169005635`, 
        0.013748363055008785`}, {-0.01948304248011406, 
        0.013319609479574354`}, {-0.017906010230796725`, 
        0.012928370477677724`}, {-0.016439012421053636`, 
        0.012574646049318896`}, {-0.01604552898783709, 
        0.012482953567394053`}}]}, 
      {Arrowheads[{{0.016573577136268666`, 1.}}], 
       ArrowBox[{{-0.015742552770844215`, 
        0.01241235176067202}, {-0.015082049050884786`, 
        0.012258436194497874`}, {-0.01269822562926982, 
        0.011738560205469236`}, {-0.010754539965951822`, 
        0.01136874251059181}, {-0.009139432360254886, 
        0.011099953721304406`}, {-0.007741343111503107, 
        0.010883164449045838`}, {-0.006560272219696479, 
        0.010718374693816106`}, {-0.005596219684835006, 
        0.010605584455615208`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.08576508954823489}, {0.049096241846110736`, 
        0.08501315528260978}, {0.04793271776916072, 0.08403786340113932}, {
        0.04679226858285984, 0.08307469890645183}, {0.045674552941541935`, 
        0.08212353690030533}, {0.04457922949954082, 0.08118425248445785}, {
        0.04350595691119036, 0.0802567207606674}, {0.042454393830824354`, 
        0.079340816830692}, {0.04055374380780476, 0.0776656495994284}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.04032102800451664, 0.07745920087697092}, {
        0.038458409675881704`, 0.07579098108410143}, {0.03658179965899686, 
        0.07408258261940504}, {0.034782469995397206`, 0.07241719817919348}, {
        0.033057689919753414`, 0.07079382857753094}, {0.03137904968359062, 
        0.06918776671382465}, {0.03119121900233015, 0.06900515433954178}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03096816603268719, 0.06878829822155295}, {
        0.029768857504677757`, 0.06762230885108488}, {0.02822459221209269, 
        0.06609648421211439}, {0.0267438437930469, 0.06460934961830485}, {
        0.025324261813368082`, 0.06315997629085468}, {0.023963598997918768`, 
        0.06174746184852653}, {0.022659700767136946`, 0.06037093278544914}, {
        0.02224026683157229, 0.05992055841783621}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.02202824946066489, 0.05969290113679902}, {
        0.021410433468379387`, 0.05902951064014751}, {0.021166950018256248`, 
        0.058765361481414646`}, {0.020925554166709045`, 
        0.05850257593445551}, {0.020686230109113, 0.05824114734614614}, {
        0.02056734058122753, 0.058110940046527504`}, {0.020448963120954646`, 
        0.05798106950396156}, {0.020331095783667878`, 0.05785153489513188}, {
        0.020213736631595213`, 0.0577223353985736}, {0.02009688373295219, 
        0.05759347019444037}, {0.01846675332376584, 0.05577425355283211}, {
        0.01693052360151838, 0.05401947242197111}, {0.015488194566209805`, 
        0.052329126801857376`}, {0.014139766217840126`, 0.0507032166924909}, {
        0.013964029898928351`, 0.05048802317656974}, {0.013835350425070208`, 
        0.05032987938688722}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.013648340237187214`, 0.050081355060809275`}, {
        0.01250989835757083, 0.04853181605013676}, {0.011229978429311978`, 
        0.046789710550607384`}, {0.009950058501053126, 0.04504760505107801}, {
        0.008670138572794273, 0.04330549955154863}, {0.008130284001526834, 
        0.0421853904749576}, {0.006980963842148821, 0.0405530490500644}, {
        0.006532813261507779, 0.03989525806926289}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.006357654403217154, 0.039638161633001996`}, {
        0.005918710195358032, 0.03899388367492865}, {0.004943523061154467, 
        0.037507894349550354`}, {0.004067725016793127, 0.03612280251972643}, {
        0.0032594692431566334`, 0.03479761400406398}, {0.0025187557402449874`,
         0.03353232880256301}, {0.001845584508058188, 0.03232694691522351}, {
        0.0007018688558591286, 0.030095893083028943`}, {
        0.00016283329810045722`, 0.028867043564170754`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0000378660697100333, 
        0.028582153418668765`}, {-0.00017167771344054434`, 
        0.02810445250748028}, {-0.000845944262940813, 
        0.02631193659261765}, {-0.0013918198557416601`, 
        0.024677656742481187`}, {-0.001809304491843085, 
        0.023201612957070888`}, {-0.002098398171245089, 
        0.021883805236386753`}, {-0.00244351366278895, 
        0.01961610562681974}, {-0.002579267333211362, 
        0.0177677655514029}, {-0.0025664507943616863`, 
        0.016514122107370754`}}]}, 
      {Arrowheads[{{0.0019820993310611457`, 1.}}], 
       ArrowBox[{{-0.0025618065428875494`, 
        0.016203117775649343`}, {-0.0024517203394034933`, 
        0.014974804409946805`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08723360662812876, 0.09}, {-0.0864474054667097, 
        0.08888100468232914}, {-0.08550843297536606, 
        0.08755551279849866}, {-0.08457670068791098, 
        0.08625126778860612}, {-0.0836522086043445, 
        0.08496826965265153}, {-0.08273495672466658, 
        0.08370651839063488}, {-0.08182494504887726, 
        0.08246601400255617}, {-0.08092217357697651, 
        0.0812467564884154}, {-0.08002302220701998, 
        0.0800381224112435}, {-0.07993610822404403, 0.07992129313742216}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.07975042152683781, 
        0.07967169415173438}, {-0.07912387083706346, 
        0.0788294883340716}, {-0.07822471946710693, 
        0.07762085425689971}, {-0.07732556809715041, 
        0.07641222017972782}, {-0.07642641672719389, 
        0.07520358610255592}, {-0.07552726535723736, 
        0.07399495202538403}, {-0.0739629318486086, 
        0.07217408000347}, {-0.07287581077245524, 
        0.07081011260113773}, {-0.07210896662463759, 0.06985657637569105}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07191400621387455, 
        0.06961415186906922}, {-0.07180085859160042, 
        0.06947345788715831}, {-0.07073807530604415, 
        0.06816411586153173}, {-0.06968746091578641, 
        0.066882086524258}, {-0.06864901542082723, 
        0.06562736987533714}, {-0.06762273882116657, 
        0.06439996591476911}, {-0.06660863111680447, 
        0.06319987464255394}, {-0.0656066923077409, 
        0.06202709605869162}, {-0.06533776162290468, 
        0.06171407484815546}, {-0.06506970702748593, 
        0.06140287985911655}, {-0.06388833147072227, 0.06010698534465449}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06367874796933153, 
        0.05987708545531019}, {-0.06341352133982173, 
        0.059586148562039296`}, {-0.06175733565215754, 
        0.05776941726496204}, {-0.06010114996449334, 
        0.05595268596788479}, {-0.058444964276829145`, 
        0.054135954670807535`}, {-0.05709682219542833, 
        0.052851841982639036`}, {-0.05549499714416355, 
        0.05112910220478097}, {-0.0551788390986679, 0.05079386177850534}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05496539839058796, 
        0.05056753840960574}, {-0.05392941251716506, 
        0.0494690234397357}, {-0.052400068314432835`, 
        0.047871605687503226`}, {-0.05090581832369254, 
        0.04633300663659828}, {-0.04944551633266982, 
        0.044849383975535596`}, {-0.04801916234136466, 
        0.04342073770431518}, {-0.04662675634977708, 
        0.04204706782293703}, {-0.046252895672409, 0.04168415071770669}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.046029676556212436`, 
        0.04146746562514111}, {-0.04526829835790708, 
        0.04072837433140114}, {-0.04394378836575464, 
        0.03946465722970752}, {-0.04265322637331977, 
        0.03825591651785616}, {-0.04139661238060247, 
        0.03710215219584707}, {-0.04017186074514705, 
        0.03599557962872119}, {-0.03897688582449781, 
        0.0349284141815195}, {-0.037811687618654756`, 
        0.03390065585424198}, {-0.03685273146263356, 0.03306591256103819}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.036617731593023964`, 
        0.03286206608771714}, {-0.03557062135138718, 
        0.03196336055945946}, {-0.03449475328996267, 
        0.031053823591954473`}, {-0.03344866194334433, 
        0.030183693744373657`}, {-0.032432347311532175`, 
        0.029352971016717022`}, {-0.030480254657221137`, 
        0.027787740540362895`}, {-0.028629681791924287`, 
        0.02633612578207871}, {-0.026939808177499146`, 
        0.025043398131417746`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.026690740212198777`, 
        0.02485700891530581}, {-0.02523309542837313, 
        0.02377374341972015}, {-0.02375468687075238, 
        0.02270191966583806}, {-0.022345063277985647`, 
        0.021698796609557928`}, {-0.02100422465007292, 
        0.02076437425087976}, {-0.01973217098701421, 
        0.019898652589803553`}, {-0.01852890228880951, 
        0.019101631626329312`}, {-0.01739441855545882, 
        0.01837331136045703}, {-0.01645312226308785, 
        0.017790691325281372`}}]}, 
      {Arrowheads[{{0.00801011823347622, 1.}}], 
       ArrowBox[{{-0.016186962527959283`, 
        0.01762966543093769}, {-0.015331805983319478`, 
        0.017122772921518356`}, {-0.013499668070143267`, 
        0.016077766230647626`}, {-0.011853339615477274`, 
        0.015169020245504945`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.022012997778176283`}, {0.0486744286908332, 
        0.021837608558287636`}, {0.04686770960786241, 
        0.021592307550852008`}, {0.04512690808297565, 0.02134985247235683}, {
        0.043449714954445995`, 0.021110312106453158`}, {0.041833821060546506`,
         0.020873755236792055`}, {0.040157910688245646`, 
        0.02062259764698413}, {0.038547331747905166`, 
        0.020375272722061015`}, {0.037683630146190424`, 
        0.020239523752806035`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAADgDm0/wioz8IMdL0Aa2UP2gyNOt4
8aI/euDQYXGdlD8Jf/8PTy6iP6QBa4KpXpQ/q8k3mLJyoT8ul4W26yCUPwDX
SdtZvqA/O8fj6jnkkz9Fykm5JZugP1csb4w22JM/Y0Fzmjh4oD9rHZf2PcyT
P4qEbPSRVaA/UIAdK1DAkz9yeAToWESgP6mVuVFdupM/Ko9aRjEzoD9tIYQr
bbSTP2JTbP4aIqA/yl+puH+ukz9xaUf/FRGgP/7rUvmUqJM/oYUHOCIAoD99
FqjtrKKTP0QQMhCPep4/6wGf2fFdkz89Z+iq3QWdP3Gi0rmsGpM/EwsP0IZP
mj+/AvBWhJiSP4nU+zXyIpo/T4FcOO2Pkj9HqovppfaZP0xLWeVch5I/xnof
+wK5mT9DExcHVXqSP6SvjpI=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024815459880080805`, 0.01798043819965419}, {
        0.023765484131298684`, 0.017758459877177304`}, {0.022176017949515466`,
         0.017422426366807908`}, {0.020586551767732247`, 
        0.017086392856438516`}, {0.01899708558594903, 
        0.016750359346069124`}, {0.01677312412755659, 
        0.016200101483076573`}, {0.014167174307094556`, 
        0.015601119956985529`}, {0.012679302080777763`, 
        0.015236758323478771`}}]}, 
      {Arrowheads[{{0.019663784462818926`, 1.}}], 
       ArrowBox[{{0.01237713702714311, 0.015162761813171213`}, {
        0.011963943141902113`, 0.015061575705709483`}, {0.010058974422151562`,
         0.014562395197484493`}, {0.008452268147842905, 
        0.014103578432310557`}, {0.0071438243189761415`, 
        0.013685125410187678`}, {0.005118903131145259, 0.01295284757664908}, {
        0.0036813899922358857`, 0.012349098678422689`}, {
        0.0019193577094871878`, 0.011467844135397153`}, {
        0.0009578345098178169, 0.010907926041324857`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.00247466884086246, 0.09}, {0.002052619692786359, 
        0.08907120810157503}, {0.0009811037668291693, 
        0.08662835775730468}, {-0.00005358882640635267, 
        0.08422414607720902}, {-0.0010882814196418746`, 
        0.08181993439711337}, {-0.0021229740128773968`, 
        0.07941572271701772}, {-0.0023807798985707685`, 
        0.07854945811107814}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0024695169890152015`, 
        0.07825128881025194}, {-0.0026750994070148986`, 
        0.07756050251637954}, {-0.0031739921382296496`, 
        0.07620642088347292}, {-0.0036528983230445073`, 
        0.07487715820579466}, {-0.004550751053474542, 
        0.07229308971612315}, {-0.0053686575983050025`, 
        0.06980829704736505}, {-0.006106617957535889, 
        0.06742278019952032}, {-0.0062008637327578865`, 
        0.06710737799683472}, {-0.006293838151358367, 
        0.06679365020555891}, {-0.006378892254344865, 0.06644173575401216}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0064519761042498855`, 
        0.06613934866093643}, {-0.006740368116050408, 
        0.06494611619948354}, {-0.007186898080742449, 
        0.06309858219340816}, {-0.007633428045434489, 
        0.06125104818733279}, {-0.00807995801012653, 
        0.059403514181257416`}, {-0.008212228836726596, 
        0.05805373874074753}, {-0.00860330130646123, 
        0.05629404448153665}, {-0.008957402112890925, 
        0.054592910053568776`}, {-0.009074460431031729, 
        0.05398660494449282}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.00913343367770124, 
        0.05368115223235396}, {-0.009274531256015683, 
        0.0529503354568439}, {-0.00955806183422991, 
        0.05136299496984822}, {-0.009811366945928018, 
        0.04982756287106793}, {-0.010034446591110009`, 
        0.048344039160503054`}, {-0.010227300769775877`, 
        0.046912423838153576`}, {-0.010522332727559256`, 
        0.044204918358100816`}, {-0.010696462819278156`, 
        0.04170504643090966}, {-0.010708990395526443`, 
        0.04134869774860954}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01071992025835923, 
        0.04103779625090619}, {-0.010777986815719875`, 
        0.03938608479522853}, {-0.01079520048767171, 
        0.037221310189705856`}, {-0.01074810383513366, 
        0.03521072261434163}, {-0.010636696858105726`, 
        0.033354322069135876`}, {-0.010478017312063477`, 
        0.031632513723198856`}, {-0.01028910295248248, 
        0.030025702745640852`}, {-0.010084418051899382`, 
        0.028632351742137546`}}]}, 
      {Arrowheads[{{0.018212891224959796`, 1.}}], 
       ArrowBox[{{-0.010032244742474786`, 
        0.028325702495820212`}, {-0.009820569792704245, 
        0.02715707289566191}, {-0.00946588419316262, 
        0.025506758808396233`}, {-0.009092024332943588, 
        0.023998478706358097`}, {-0.008698990212047147, 
        0.02263223258954751}, {-0.008286781830473296, 
        0.02140802045796446}, {-0.007453308685599289, 
        0.019292489969487743`}, {-0.006640071298627482, 
        0.01755867905993468}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.01112152126705709}, {-0.09860779342713426, 
        0.010991386469566178`}, {-0.09613753041958938, 
        0.010808261955044847`}, {-0.09406517349982116, 
        0.010633667263978673`}, {-0.092033656466364, 
        0.010465381059296917`}, {-0.09004297931921787, 
        0.010303403340999578`}, {-0.08809314205838281, 
        0.010147734109086658`}, {-0.08759770223537358, 
        0.010108970692061205`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08728755651505246, 
        0.01008470476240209}, {-0.08618414468385882, 
        0.009998373363558155}, {-0.08431598719564587, 
        0.00985532110441407}, {-0.08248866959374399, 
        0.009718577331654403}, {-0.08070219187815314, 
        0.009588142045279155}, {-0.08022529450057103, 
        0.009553771711161372}, {-0.07975113179027707, 
        0.009519804848686303}, {-0.07781640152997206, 
        0.009395342997962982}, {-0.07588167126966706, 
        0.009270881147239661}, {-0.07487505115720318, 
        0.009206124935615193}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07456459931955131, 
        0.009186153464104473}, {-0.07394694100936205, 
        0.009146419296516339}, {-0.07201221074905705, 
        0.009021957445793018}, {-0.07046658358202705, 
        0.00894918466358506}, {-0.06860051857347645, 
        0.008833844413187979}, {-0.06678023039942879, 
        0.008724585229675058}, {-0.06500571905988409, 
        0.008621407113046299}, {-0.06327498760475272, 
        0.008523915904952108}, {-0.062142109780059865`, 
        0.0084620729374789}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06183147871399233, 
        0.008445115815981539}, {-0.061586039083945096`, 
        0.008431717447042892}, {-0.05993887349746122, 
        0.008344811739318655}, {-0.058333490845301095`, 
        0.008263198781779394}, {-0.05676989112746471, 
        0.008186878574425108}, {-0.05524807434395207, 
        0.0081158511172558}, {-0.053768040494763185`, 
        0.008050116410271467}, {-0.052329789579898034`, 
        0.007989674453472113}, {-0.04956272391469554, 
        0.007881498720442958}, {-0.04940092799878211, 
        0.007875760042270724}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04909002993563127, 
        0.007864732916408362}, {-0.04693096470990115, 
        0.007788153848182958}, {-0.044434511965514865`, 
        0.007709639836692115}, {-0.04207336568153669, 
        0.007645956685970429}, {-0.03986339001974559, 
        0.007599968062198303}, {-0.03771468806339405, 
        0.007555446523686779}, {-0.03665081034741485, 
        0.0075386533031274695`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0363397555366018, 
        0.007533743329015257}, {-0.03568860123802744, 
        0.007523464913000088}, {-0.03377878387893416, 
        0.007502877763666068}, {-0.03130695799055331, 
        0.007491385703057225}, {-0.029029306524914762`, 
        0.007497390028980394}, {-0.026928658555402406`, 
        0.007517981288360199}, {-0.024987843155400133`, 
        0.007550250028121265}, {-0.023896893050524913`, 
        0.007575147267947643}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.023585880471531238`, 
        0.007582245076301685}, {-0.023189689398291823`, 
        0.007591286795188215}, {-0.02151702635746137, 
        0.007638182136485672}, {-0.019952683106292658`, 
        0.0076880265989382615`}, {-0.018479488718169568`, 
        0.007737910729470606}, {-0.015821617522265827`, 
        0.007843612424897848}, {-0.013537659881731296`, 
        0.0079594365505462}, {-0.01156203812449708, 
        0.008077066546748184}, {-0.011153909701328594`, 
        0.008103237648154333}}]}, 
      {Arrowheads[{{0.004070402225464734, 1.}}], 
       ArrowBox[{{-0.01084345377962589, 
        0.008123145532407882}, {-0.009829174578494294, 
        0.008188185853836329}, {-0.008316705085683624, 
        0.008294329291708244}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.04978612550042228}, {0.04957745440913568, 
        0.049573593947880565`}, {0.04710954124688883, 0.04832651200422817}, {
        0.04464162808464198, 0.04707943006057578}, {0.04217371492239512, 
        0.04583234811692338}, {0.04052857773945201, 0.044863145579740964`}, {
        0.03897677268082012, 0.0440200664707131}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03870341658732091, 0.04387155502562357}, {
        0.03822932484650582, 0.0436139860479865}, {0.03604297952534185, 
        0.042405569758409624`}, {0.03396954177596009, 
        0.041237896711010344`}, {0.032009011598360546`, 
        0.04011096690578866}, {0.031751910101063534`, 0.03996155180499453}, {
        0.03149666397978937, 0.039812833539575286`}, {0.029828874590843008`, 
        0.038776413145845554`}, {0.028161085201896644`, 
        0.037739992752115814`}, {0.02795281588170502, 0.03761056719498885}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02768858641556586, 0.037446366121912135`}, {
        0.026493295812950284`, 0.03670357235838608}, {0.02482550642400392, 
        0.03566715196465635}, {0.023844893135528778`, 0.0349240131117296}, {
        0.022298370117253805`, 0.033939348284023924`}, {0.020832691346093096`,
         0.03298918716700095}, {0.019447856822046646`, 
        0.032073529760660684`}, {0.018137481667889074`, 
        0.03119035800257465}, {0.017294892164021934`, 
        0.030612012029075666`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.017038405327301578`, 0.030435961735792997`}, {
        0.016895181006395005`, 0.030337653830314386`}, {0.01572095483756443, 
        0.029515417243879887`}, {0.014614803161397356`, 
        0.028723648243271158`}, {0.0126067232870537, 0.027231512999531002`}, {
        0.01087094138336404, 0.025861248099093914`}, {0.009353682036467708, 
        0.024596839081752506`}, {0.008001169832504037, 
        0.023422271487299393`}, {0.007265268840001423, 
        0.02275021007344099}}]}, 
      {Arrowheads[{{0.015787692365694384`, 1.}}], 
       ArrowBox[{{0.007035554356677931, 0.02254042337384554}, {
        0.006813404771473028, 0.022337545315734574`}, {0.005790386853374682, 
        0.02134266056705805}, {0.00410586980431692, 0.019575119081524508`}, {
        0.0028148960436716946`, 0.0180723507738534}, {0.001555250710421856, 
        0.016395021481009436`}, {0.0007256194776443242, 
        0.015056750946768848`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, 0.0675096353363349}, {-0.09872296704716596, 
        0.06647455799161318}, {-0.0978020567702959, 
        0.0659154397525051}, {-0.09614782776045122, 
        0.06463721072746206}, {-0.09451791478964644, 
        0.06338550197266152}, {-0.09291231785788155, 
        0.06216031348810344}, {-0.09133103696515656, 
        0.06096164527378785}, {-0.09007434078327163, 0.06001555208328681}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0898258053424651, 
        0.05982844425918842}, {-0.08977407211147145, 
        0.059789497329714746`}, {-0.08824142329682624, 
        0.05864386965588412}, {-0.08673309052122094, 
        0.05752476225229598}, {-0.08524907378465552, 
        0.05643217511895032}, {-0.08485160801614582, 
        0.05614070996006355}, {-0.08445582530783126, 
        0.05585101193777249}, {-0.08249503141464568, 
        0.05446523875211879}, {-0.08053423752146008, 
        0.05307946556646509}, {-0.07975106525847088, 0.05252596571848518}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07949701461628274, 
        0.05234641774612259}, {-0.07857344362827448, 
        0.05169369238081138}, {-0.0766126497350889, 
        0.05030791919515768}, {-0.07501196852284417, 
        0.049268142530736005`}, {-0.0731147239262952, 
        0.04794342755471148}, {-0.07125984552750399, 
        0.04665941805177309}, {-0.06944733332647052, 
        0.045416114021920806`}, {-0.06925288773059549, 0.0452838922369532}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0689956354704125, 
        0.04510896231439426}, {-0.06767560999668731, 
        0.044211353275972906`}, {-0.0659430982116469, 
        0.04304297362474761}, {-0.06424979797134926, 
        0.04191097506824494}, {-0.06259570927579441, 
        0.040815357606464896`}, {-0.060980832124982357`, 
        0.039756121239407465`}, {-0.059405166518913075`, 
        0.038733265967072654`}, {-0.0586250319403094, 
        0.038232383684793106`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05836325018732867, 
        0.03806430775855123}, {-0.05786871245758658, 
        0.037746791789460464`}, {-0.05637146994100287, 
        0.036796698706570895`}, {-0.054910343686237734`, 
        0.035878649210393444`}, {-0.05348223841036693, 
        0.0349883057929176}, {-0.05208715411339047, 
        0.03412566845414336}, {-0.050725090795308354`, 
        0.03329073719407074}, {-0.04939604845612059, 
        0.03248351201269973}, {-0.04810002709582716, 
        0.03170399291003032}, {-0.04778289224579865, 0.03151521536560758}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04751557428255076, 
        0.03135609179821191}, {-0.04683702671442808, 
        0.03095217988606253}, {-0.045607047311923346`, 
        0.03022807294079635}, {-0.043235456522704566`, 
        0.028849972777556604`}, {-0.040974559807278474`, 
        0.027556687911498873`}, {-0.038824357165645085`, 
        0.026348218342623162`}, {-0.03678484859780439, 
        0.025224564070929465`}, {-0.036710867992952284`, 
        0.02518454247770612}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.03643724660562488, 
        0.025036520386203676`}, {-0.03457560241576071, 
        0.024029419043327498`}, {-0.032474722834474806`, 
        0.02291084509690869}, {-0.030482209853946677`, 
        0.021868842231673045`}, {-0.028598063474176327`, 
        0.02090341044762056}, {-0.026822283695163755`, 
        0.020014549744751236`}, {-0.025387834040933158`, 
        0.019315749602016145`}}]}, 
      {Arrowheads[{{0.007641449859704441, 1.}}], 
       ArrowBox[{{-0.025107882866827507`, 
        0.01918008651655545}, {-0.023595823939411946`, 
        0.01846654158256207}, {-0.0221451439626727, 
        0.01780739412324223}, {-0.020783078381110168`, 
        0.01720571869668313}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05977884952128519, 0.09}, {-0.059041873859079275`, 
        0.08831483010473425}, {-0.05841043577021545, 
        0.08665300465631304}, {-0.05777974069950362, 
        0.0850234481198379}, {-0.05714978864694377, 
        0.08342616049530885}, {-0.056520579612535905`, 
        0.08186114178272587}, {-0.05589211359628003, 
        0.08032839198208898}, {-0.05526439059817615, 
        0.07882791109339816}, {-0.05511024601974472, 0.07846694754840482}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05498807138498783, 
        0.07818084868123168}, {-0.054637410618224254`, 
        0.07735969911665344}, {-0.05401117365642434, 
        0.07592375605185478}, {-0.05384216210733914, 
        0.07554034448737597}, {-0.05367327763375204, 
        0.0751590970008381}, {-0.052755796609612354`, 
        0.0732701307357154}, {-0.051838315585472666`, 
        0.0713811644705927}, {-0.05092083456133298, 
        0.06949219820547}, {-0.05000335353719328, 
        0.06760323194034729}, {-0.04962173462729061, 0.06695950866065643}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04946309123503503, 
        0.06669190545202587}, {-0.04915290672699341, 
        0.0661686793129523}, {-0.04824725527001957, 
        0.06435990368978153}, {-0.0473494901911563, 
        0.06260458849457876}, {-0.0464596114904036, 
        0.06090273372734393}, {-0.04557808143525169, 
        0.05925158951757209}, {-0.04470536229319082, 
        0.057648405994758276`}, {-0.043841454064220985`, 
        0.05609318315890247}, {-0.043622129600846854`, 
        0.055706584515879724`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04346862313077188, 
        0.05543600187264323}, {-0.042986356748342176`, 
        0.05458592101000468}, {-0.042140070345554406`, 
        0.0531266195480649}, {-0.041302594855857674`, 
        0.051715278773083136`}, {-0.04047393027925197, 
        0.05035189868505938}, {-0.0396540766157373, 
        0.04903647928399365}, {-0.03884406348496055, 
        0.047763515019991015`}, {-0.038044920506568616`, 
        0.046527500343156586`}, {-0.03725664768056149, 
        0.045328435253490354`}, {-0.03693569686102509, 
        0.04484865568033196}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.03676272382689212, 
        0.044590083576967025`}, {-0.03647924500693919, 
        0.044166319750992326`}, {-0.03495705011684901, 
        0.04195293750750087}, {-0.03347833583629809, 
        0.03988735361268221}, {-0.03204423153962874, 
        0.037952863748897454`}, {-0.030655866601183263`, 
        0.036132763598507686`}, {-0.02941264035942906, 
        0.03455333296099822}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02921823484352155, 
        0.03431047755413422}, {-0.02801635479896395, 
        0.03283573243791314}, {-0.02652780100832713, 
        0.03106627416447614}, {-0.02509486622006528, 
        0.02940980192360803}, {-0.023717550434178388`, 
        0.027866315715308825`}, {-0.022395853650666465`, 
        0.02643581553957852}, {-0.02112977586952951, 
        0.025118301396417114`}, {-0.0209914108866161, 
        0.024980614335638956`}}]}, 
      {Arrowheads[{{0.006850212763907399, 1.}}], 
       ArrowBox[{{-0.02077089497278641, 
        0.024761178844153225`}, {-0.01991931709076752, 
        0.02391377328582461}, {-0.018764477314380495`, 
        0.022822231207801}, {-0.01766525654036844, 0.0218436751623463}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, -0.00038641644801165717`}, {
        0.04952683157891378, -0.0002466450023889988}, {0.04704928247305371, 
        0.0004852098820350879}, {0.044571733367193646`, 
        0.0012170647664591747`}, {0.04292675250973709, 
        0.001630167332309434}, {0.04122381736111482, 0.002100337659282115}, {
        0.03958380446045906, 0.0025475515569368364`}, {0.03801845980426412, 
        0.0029686492026424283`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037717759870082974`, 0.003048390675676961}, {
        0.03649254540304705, 0.0033731100642923977`}, {0.03629233751953194, 
        0.003425747293248362}, {0.036093191097405976`, 
        0.0034780071017010495`}, {0.034399944995526247`, 
        0.0038994582327849057`}, {0.03270669889364652, 
        0.004320909363868761}, {0.031013452791766788`, 
        0.004742360494952617}, {0.02932020668988706, 
        0.0051638116260364735`}, {0.02670782760336545, 
        0.005757035675180082}, {0.025633380355088924`, 
        0.006014257723912132}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.025330835742799276`, 0.0060866867288081996`}, {
        0.025208109780795185`, 0.006116067253007913}, {0.023785803269948703`, 
        0.006450131009533332}, {0.021149494103469155`, 
        0.007052358911978697}, {0.01877497002396885, 0.007572723235817931}, {
        0.016662231031447795`, 0.008011223981051035}, {0.014811277125905992`, 
        0.00836786114767801}, {0.01317210935984767, 0.00866287228730914}, {
        0.013159122225614722`, 0.008665101795157615}}]}, 
      {Arrowheads[{{0.01420424588643641, 1.}}], 
       ArrowBox[{{0.012852513851021966`, 0.008717737408627179}, {
        0.011694728785777072`, 0.00891649495155472}, {0.010379135403694192`, 
        0.009128729140414743}, {0.009225329213599032, 0.009299574853889214}, {
        0.007278820650620398, 0.009561555383915623}, {0.005730945338089695, 
        0.009746891070868069}, {0.004098130238153276, 
        0.009910561710571761}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.02454247260672951, 0.09}, {0.023825499839196643`, 
        0.08910725744699623}, {0.02286521734404656, 0.0879115564592515}, {
        0.021600091635652456`, 0.08601012648262556}, {0.020506607732061897`, 
        0.08452725250653986}, {0.01944612911200127, 0.08307076218783693}, {
        0.01841865577547057, 0.08164065552651677}, {0.0174241877224698, 
        0.08023693252257938}, {0.017220432378414703`, 0.0799450436826274}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.01704236455879729, 0.07968995339509684}, {
        0.01646272495299896, 0.07885959317602476}, {0.015534267467058051`, 
        0.0775086374868529}, {0.014638815264647073`, 0.0761840654550638}, {
        0.013776368345766022`, 0.07488587708065748}, {0.013547923016710374`, 
        0.07453886668450944}, {0.01332161224938896, 0.07419364188591043}, {
        0.012194934518678136`, 0.07230805932280819}, {0.011068256787967313`, 
        0.07042247675970595}, {0.010343441244280598`, 0.06920944173346213}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.010183871709262745`, 0.06894238974101513}, {
        0.009941579057256488, 0.06853689419660372}, {0.008814901326545665, 
        0.06665131163350148}, {0.008168995699368475, 0.06522280601021815}, {
        0.007127160104575351, 0.06341788408355456}, {0.006141885933727362, 
        0.061666735914516706`}, {0.005213173186824505, 0.05996936150310461}, {
        0.004336770318839304, 0.058322994668781825`}, {0.004192357571587911, 
        0.05804437909830205}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.004049198513682631, 0.05776818227117436}, {
        0.00350842578474428, 0.056724869231011894`}, {0.0027281395845394334`, 
        0.05517498518979482}, {0.001995911718224765, 0.05367334254513061}, {
        0.0013117421858002752`, 0.05221994129701926}, {0.0006756309872659612, 
        0.05081478144546076}, {0.00008757812262182474, 
        0.04945786299045512}, {-0.0004524164081321329, 
        0.04814918593200234}, {-0.0011121637344261575`, 
        0.046453676822932825`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.00122497526811685, 
        0.04616375828085233}, {-0.001423149255339976, 
        0.045654463605260584`}, {-0.002271486341728029, 
        0.04330852206574074}, {-0.002997427667296291, 
        0.04111136131344281}, {-0.0036009732320447605`, 
        0.03906298134836679}, {-0.004105062983395645, 
        0.037146530893173595`}, {-0.00453263686877115, 
        0.035345158670524124`}, {-0.0047609377322298954`, 
        0.034248524061110355`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.00482434275316952, 
        0.033943960428193726`}, {-0.004883694888171276, 
        0.0336588646804184}, {-0.005158237041596022, 
        0.032087648922856406`}, {-0.005472916002506376, 
        0.02982527378996557}, {-0.005678421913066061, 
        0.027769302589306457`}, {-0.0057747547732750785`, 
        0.02591973532087906}, {-0.0057619145831334295`, 
        0.02427657198468337}, {-0.005675199632227007, 
        0.02280401713732985}, {-0.005559871902737149, 0.02157265810181767}}]}, 
      {Arrowheads[{{0.0016229741474641307`, 1.}}], 
       ArrowBox[{{-0.005522339706711427, 
        0.021263899233021466`}, {-0.005386040316877533, 
        0.02026334657898067}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{-0.01777231777468427, 0.09}, {-0.017926820031536582`, 
        0.08857089002125561}, {-0.018186621633376265`, 
        0.08697171268109027}, {-0.018429512183206837`, 
        0.08540232586518581}, {-0.018655491681028296`, 
        0.08386272957354221}, {-0.018864560126840648`, 
        0.08235292380615948}, {-0.019056717520643886`, 
        0.08087290856303761}, {-0.019231963862438015`, 
        0.0794226838441766}, {-0.019390299152223033`, 
        0.07800224964957644}, {-0.019424227360052556`, 
        0.07766862899016129}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.019455702287836333`, 
        0.07735913176546172}, {-0.01953172338999894, 
        0.07661160597923716}, {-0.019567631011130838`, 
        0.07624009111715652}, {-0.019602484084152914`, 
        0.07587058260203074}, {-0.019692605183070613`, 
        0.07397802867186641}, {-0.01978272628198831, 
        0.07208547474170209}, {-0.019872847380906014`, 
        0.07019292081153777}, {-0.019962968479823713`, 
        0.06830036688137345}, {-0.019863796559827212`, 
        0.06685842589940272}, {-0.019920513008348288`, 
        0.06504539190127255}, {-0.019922663616177817`, 
        0.06493550862240285}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0199287510950995, 
        0.06462447462783617}, {-0.019954959689938285`, 
        0.06328537119116517}, {-0.019967136604597195`, 
        0.06157836376908056}, {-0.01995917992613988, 
        0.059921673949478456`}, {-0.019933225828381206`, 
        0.058312606046818594`}, {-0.01988927431132117, 
        0.05675116006110098}, {-0.019827325374959764`, 
        0.0552373359923256}, {-0.019747379019297, 
        0.053771133840492466`}, {-0.01964943524433287, 
        0.05235255360560157}, {-0.019635627616813395`, 
        0.052189283924631964`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.01960941218403807, 
        0.051879296901903384`}, {-0.01953349405006738, 
        0.05098159528765292}, {-0.019399555436500522`, 
        0.04965825888664651}, {-0.01909532575450829, 
        0.0471328926546348}, {-0.01875438600140174, 
        0.044754895728740834`}, {-0.018376736177180875`, 
        0.04252426810896462}, {-0.017962376281845698`, 
        0.04044100979530615}, {-0.01776878577985282, 0.0395821952449514}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.017700376804031144`, 
        0.039278716390329274`}, {-0.01752228844277439, 
        0.03848867310658513}, {-0.01706745478734514, 
        0.036650810361621294`}, {-0.016597875315557946`, 
        0.034927421560414625`}, {-0.01611355002741281, 
        0.03331850670296512}, {-0.01532750177612893, 
        0.030951011908564103`}, {-0.014537817492394644`, 
        0.028798200808825794`}, {-0.013974718100509166`, 
        0.02742251643401575}}]}, 
      {Arrowheads[{{0.008884032164777506, 1.}}], 
       ArrowBox[{{-0.0138568705971316, 
        0.027134608168897498`}, {-0.013744497176209949`, 
        0.026860073403750198`}, {-0.012947540827574846`, 
        0.02513662969333732}, {-0.012161663487345127`, 
        0.023590714552999815`}, {-0.011401580196376594`, 
        0.02218517285815036}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.025714172029242012`}, {-0.09870511655553978, 
        0.025407956619119633`}, {-0.09669293291627917, 
        0.024935485842751494`}, {-0.09472033505769424, 
        0.024475748898268004`}, {-0.09278732297978497, 
        0.02402874578566916}, {-0.09089389668255138, 
        0.023594476504954963`}, {-0.08904005616599345, 
        0.023172941056125416`}, {-0.08854480235358665, 
        0.02306083175440161}, {-0.08805221511342812, 
        0.022949557465626085`}, {-0.08787614464834634, 
        0.022911130215382984`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.08757220560708416, 
        0.022844795741899286`}, {-0.08608659888011602, 
        0.022520563160168313`}, {-0.08412098264680394, 
        0.022091568854710544`}, {-0.08215536641349186, 
        0.021662574549252772`}, {-0.08018975018017978, 
        0.021233580243795003`}, {-0.07858725321872542, 
        0.020911993442233615`}, {-0.07668571685691765, 
        0.020501953402169322`}, {-0.07540679964762685, 
        0.02022852853534413}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07510258100167796, 
        0.020163488404403646`}, {-0.07482690040944608, 
        0.020104549539034015`}, {-0.0730108038763107, 
        0.019719781852827696`}, {-0.07123571236890514, 
        0.019347002172124032`}, {-0.06949991099862295, 
        0.018985562325496697`}, {-0.06780339976546416, 
        0.01863546231294569}, {-0.06614617866942878, 
        0.01829670213447101}, {-0.06452824771051678, 
        0.017969281790072657`}, {-0.06294960688872818, 
        0.017653201279750633`}, {-0.06291612928340198, 
        0.017646573817803317`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06261095822460669, 
        0.017586160011024702`}, {-0.06141025620406297, 
        0.017348460603504937`}, {-0.059910195656521156`, 
        0.01705505976133557}, {-0.05844601589015767, 
        0.016771702570246034`}, {-0.057014307549027435`, 
        0.01649709284723983}, {-0.05561507063313045, 
        0.01623123059231696}, {-0.05424830514246673, 
        0.015974115805477425`}, {-0.05161218843683906, 
        0.015486128636048356`}, {-0.05038587177786007, 
        0.015264473836127534`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05007973871087054, 
        0.015209140767612256`}, {-0.04910595743214442, 
        0.015033131338952626`}, {-0.04674352783412966, 
        0.014620080588172699`}, {-0.044446043976895964`, 
        0.014218888564474595`}, {-0.04226731325599781, 
        0.013848721073923851`}, {-0.04020176938913647, 
        0.013507595446927485`}, {-0.03872004178213367, 
        0.013269180880606224`}, {-0.03781178789310035, 
        0.013126425368861131`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.037504467232859405`, 
        0.013078122004953457`}, {-0.037296592488739407`, 
        0.01304544913029358}, {-0.035929036660402106`, 
        0.012835583657740346`}, {-0.0346149894485702, 
        0.01263876792469731}, {-0.032137881480216235`, 
        0.012281019524144988`}, {-0.029846189795264898`, 
        0.011965671622642933`}, {-0.027720835605303543`, 
        0.01168619191419746}, {-0.02574274012191956, 
        0.011436048092814883`}, {-0.025179525989898352`, 
        0.011366833454844957`}}]}, 
      {Arrowheads[{{0.00948332001407118, 1.}}], 
       ArrowBox[{{-0.02487075529686996, 
        0.011328887937290226`}, {-0.023892824556700314`, 
        0.01120870785250152}, {-0.022152010121233176`, 
        0.010997638887263688`}, {-0.02052213848485725, 
        0.010804556580836854`}, {-0.01901148838083523, 
        0.010633714067642384`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.06630578078232702}, {0.049578939649600376`, 
        0.06600265988371211}, {0.0480452770453185, 0.06496559304741134}, {
        0.04655032136351776, 0.06394585937741908}, {0.04509407260419818, 
        0.06294345887373533}, {0.04367653076735972, 0.06195839153636008}, {
        0.042297695853002415`, 0.060990657365293355`}, {0.04095756786112625, 
        0.06004025636053513}, {0.03978537686236785, 0.0591998414116899}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03953303273003628, 0.059017904803202764`}, {
        0.03839343264481734, 0.05819145384994421}, {0.03805766579945819, 
        0.05794650208793786}, {0.037724434985245636`, 0.05770273159095901}, {
        0.035991770114322606`, 0.056358345851798344`}, {0.03425910524339958, 
        0.05501396011263767}, {0.03252644037247655, 0.053669574373477}, {
        0.030793775501553527`, 0.05232518863431632}, {0.02973292990961169, 
        0.051358417716435505`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.02949362795863978, 0.05115988990207934}, {
        0.028031020637270875`, 0.05000065522007104}, {0.0264739994857387, 
        0.048747328996929386`}, {0.024987235821962866`, 
        0.04753042658019534}, {0.023565966859430236`, 0.04634818083701365}, {
        0.02220542981162767, 0.04519882463452908}, {0.02090562467855517, 
        0.044082357972741626`}, {0.019916366453188263`, 
        0.04321724559359425}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.019682187383471106`, 0.04301245456234011}, {
        0.019666551460212744`, 0.042998780851651285`}, {0.018488210156600383`,
         0.04194809327125806}, {0.01737060076771809, 0.04093029523156196}, {
        0.01631372329356586, 0.03994538673256297}, {0.015317577734143703`, 
        0.0389933677742611}, {0.013468613918539922`, 0.03717396471354457}, {
        0.011784840879957077`, 0.0354580522832082}, {0.010748213247718064`, 
        0.03435736710139922}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.010534925581476236`, 0.03413089949973214}, {
        0.010266258618395169`, 0.033845630483252}, {0.008912867133854202, 
        0.03233669931367598}, {0.007698191948387085, 0.030920255991286897`}, {
        0.006595758584046728, 0.029585297732891536`}, {0.0056055670408331325`,
         0.02833182453848989}, {0.004727617318746301, 
        0.027159836408081964`}, {0.0034270084142406054`, 
        0.025312544512878163`}, {0.0028224721491867675`, 
        0.02438557307596765}}]}, 
      {Arrowheads[{{0.006098756246809452, 1.}}], 
       ArrowBox[{{0.0026525337966956187`, 0.024124996485445166`}, {
        0.002336751103919393, 0.023640788087379613`}, {0.0014568453877826615`,
         0.02214456713158632}, {0.0007872912658304092, 
        0.02082388164549827}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.07536098944937719}, {0.04958717221834412, 
        0.07505236989123579}, {0.047974539386497386`, 0.07383332132330003}, {
        0.04641045647047165, 0.07263708219301372}, {0.045994646184507694`, 
        0.07231712908921706}, {0.045582014084916814`, 0.07199872922772596}, {
        0.04378957270028809, 0.07054216121010888}, {0.04199713131565936, 
        0.06908559319249181}, {0.04023349259448446, 0.06765243070365175}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.039992062330978795`, 0.06745624041072339}, {
        0.038412248546401906`, 0.06617245715725767}, {0.03714137440114232, 
        0.06499538242199304}, {0.03544097429404933, 0.06358813674832052}, {
        0.03380193503864682, 0.062213772637277696`}, {0.0322242566349348, 
        0.06087229008886458}, {0.030704361419202963`, 0.0595623457489693}, {
        0.030514345604620016`, 0.05939643570514221}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03028000774341284, 0.05919182639455109}, {
        0.02923867172774101, 0.05828259626347998}, {0.027827187560548937`, 
        0.05703304163239664}, {0.026469908917626746`, 0.05581368185571927}, {
        0.025166835798974437`, 0.054624516933447866`}, {0.023917968204592008`,
         0.05346554686558244}, {0.02272330613447946, 0.052336771652122985`}, {
        0.0215828495886368, 0.0512381912930695}, {0.021113753704795405`, 
        0.05077870507297088}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.020891512758783114`, 0.050561016843864916`}, {
        0.02048940059667404, 0.05016714215046502}, {0.019435761188201207`, 
        0.04912096058635256}, {0.018421931363218298`, 
        0.048099646600732134`}, {0.017447911121725314`, 
        0.047103200193603735`}, {0.015619299389209126`, 
        0.04518491011482303}, {0.013949925990652642`, 
        0.043366090350010426`}, {0.012418748091714078`, 
        0.041637998099783725`}, {0.012330323100095752`, 
        0.041535060018112954`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012127612013982379`, 0.041299078199443666`}, {
        0.011004722858051654`, 0.0399918905647607}, {0.00970785028966537, 
        0.03842776774494135}, {0.008528130386555229, 0.03694562964032569}, {
        0.007395113604184366, 0.03546795531948739}, {0.006348238097363478, 
        0.034058476224678905`}, {0.00538750386609257, 0.03271719235590024}, {
        0.004523038855274929, 0.0314588463103178}}]}, 
      {Arrowheads[{{0.0018430656156570742`, 1.}}], 
       ArrowBox[{{0.0043523626022113375`, 0.031198757543648932`}, {
        0.0037244592302006913`, 0.030239210296432374`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAKEvrKqkpc797FK5H4XqEv8jff7IY
7G6/FKQMRMK3gb+GrqzkJ6Nnv4wh632htn2/JSpozcJIYb+YYAi3gWZ4v0+l
ZNnSuVe/SgVxMyV/c7+nJa6mFeBTv+H79uEPpXG/CtUSuEE/UL9z9OF+/bFv
vw1gb4N1qUm//6j9Zhg1bL/fUHhUXwBJv3FARcNH3Wu/x2GY+FBYSL+B3XWr
uoVrv6fs/WonXke/R6ziQuUCa79gO7RBp7hGv8MfrDIArGq/7+uTlCoURr90
auUAXlVqv48iOru47Cg/OKArYU1nVL9aabjBFx8sP85JtmEjZlO/S0b1Q/hH
Lz9rmi/xU2ZSv23JZvomEjE/++QQpk98Ub8oUkrhsvQyP95WMA/tRVC/tDTC
s7/QND9viyB51yJOvzGG+OYzuD0/ge7MK9xQQr94wsLeZ/5CPywFWBkffiu/
Prfha37TRj/CD6H6c9AgP1hN2kCO508//46stGPZUD8IZ7o6
        "]]}, 
      {Arrowheads[{{0.011722382974010959`, 1.}}], 
       ArrowBox[{{0.0010651647844873474`, 0.0013257202487930398`}, {
        0.0011722556704273374`, 0.0016736488034979197`}, {
        0.001474478001090433, 0.002984366830766236}, {0.0017153217652415632`, 
        0.005030683085132693}, {0.001674707771310475, 
        0.0064919551419575445`}, {0.0014629306823953302`, 
        0.007694315806089874}, {0.001191103680597115, 
        0.008490410573037987}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.1, -0.0015624593846324745`}, {-0.09984789193118193, \
-0.0015583174183955667`}, {-0.09758672552768345, -0.0014928319397014256`}, \
{-0.0953760085746967, -0.0014248072473890794`}, {-0.09321574107222168, \
-0.0013542433414585272`}, {-0.0911059230202584, -0.0012811402219097697`}, \
{-0.09054303085609623, -0.0012610577317867012`}, {-0.08998350393880424, \
-0.0012408292079538702`}, {-0.0880109082851679, -0.0011555536384162271`}, \
{-0.08756371034274535, -0.001136221212550923}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08725290706847878, -0.0011227851461282949`}, \
{-0.08603831263153157, -0.001070278068878584}, {-0.08406571697789524, \
-0.0009850024993409412}, {-0.0820931213242589, -0.0008997269298032982}, \
{-0.08047787069086729, -0.0008036358459250225}, {-0.07856833592315648, \
-0.0007164516562096208}, {-0.07670084174606272, -0.00062799505304238}, \
{-0.07487538815958597, -0.0005382660364233}, {-0.07482319405284449, \
-0.0005356098812937349}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0745125025448502, -0.0005197988080865835}, \
{-0.07309031370933092, -0.00044742369896965854`}, {-0.07134395694090223, \
-0.0003556271332987334}, {-0.06963631785429993, -0.0002628763394105244}, \
{-0.06796739644952397, -0.00016917131730503177`}, {-0.0663371927265744, \
-0.00007451206698225535}, {-0.06474570668545118, 
        0.00002110141155780483}, {-0.06319293832615434, 
        0.00011766911831514872`}, {-0.06208905999241117, 
        0.0001887713295456583}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.061778609765542995`, 
        0.000208767824569245}, {-0.061678887648683865`, 
        0.0002151910532897764}, {-0.06020025009949148, 
        0.00031334751638020027`}, {-0.05875372112502891, 
        0.0004118188074849322}, {-0.05733930072529615, 
        0.0005106049266039726}, {-0.0559569889002932, 
        0.0006097058737373211}, {-0.05328869097447674, 
        0.0008088522520469434}, {-0.05074882734757954, 
        0.0010092579424137989`}, {-0.04936890943225523, 
        0.0011259414688308}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.049058922119507443`, 
        0.0011521534720190041`}, {-0.048350906542258286`, 
        0.0012120220724583172`}, {-0.046018380263458336`, 
        0.0014109162523313968`}, {-0.04380348146545227, 
        0.0016101904421653658`}, {-0.04170080673917742, 
        0.0018094049909120524`}, {-0.04017590551987828, 
        0.001960436552744556}, {-0.03871003996636574, 
        0.0021111788600138293`}, {-0.03730082551042023, 
        0.0022614607105526595`}, {-0.036671541798874996`, 
        0.002330963328462011}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.036362328503797475`, 
        0.0023651150681399573`}, {-0.035945877583822165`, 
        0.0024111109021938337`}, {-0.033389243045789954`, 
        0.0027078315001143726`}, {-0.03102105980651236, 
        0.002999971036437751}, {-0.02882225132023264, 
        0.0032861598938262746`}, {-0.026773741041194052`, 
        0.00356502845494225}, {-0.024856452423639847`, 
        0.003835207102447983}, {-0.024021241009543313`, 
        0.003955560113138793}}]}, 
      {Arrowheads[{{0.014930589374096246`, 1.}}], 
       ArrowBox[{{-0.02371332785276252, 
        0.003999930047294885}, {-0.02305130892181328, 
        0.0040953262190057795`}, {-0.021360020159733234`, 
        0.004346309883539167}, {-0.019790691505964915`, 
        0.004589787927667435}, {-0.0183338400315711, 
        0.004825449363096531}, {-0.01697998280761457, 
        0.0050529832015324}, {-0.014543319395264409`, 
        0.005482424134248248}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.08476477774143937}, {-0.09975176203235828, 
        0.08449626878023134}, {-0.09820782905506376, 
        0.08283990874811925}, {-0.09668351042229786, 
        0.0812184145312975}, {-0.09517880613406061, 
        0.07963178612976606}, {-0.09369371619035201, 
        0.07808002354352493}, {-0.09222824059117202, 
        0.07656312677257412}, {-0.09142901588848643, 0.07574390864490238}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.09121177357530547, 
        0.07552123179262646}, {-0.09078237933652067, 
        0.07508109581691363}, {-0.0903945824369532, 
        0.07468559080836351}, {-0.09000817556285412, 
        0.07429241496908325}, {-0.08807248931543862, 
        0.07240719142286746}, {-0.08613680306802314, 
        0.07052196787665167}, {-0.08420111682060764, 
        0.06863674433043589}, {-0.08232591945563085, 0.06681043274147039}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08209518886620192, 
        0.06660188395305289}, {-0.08064167169082276, 
        0.06532429041844796}, {-0.07876103144900365, 
        0.06351988919819282}, {-0.07691708854424877, 
        0.061769369528578116`}, {-0.07510984297655814, 
        0.060072731409603834`}, {-0.07333823506660507, 
        0.05842717891381828}, {-0.07299745293897404, 
        0.058113817235068636`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07276845668649433, 
        0.057903246772928345`}, {-0.07160120513506289, 
        0.05682991611376976}, {-0.0698987531819316, 
        0.05528094300945827}, {-0.06823087920721121, 
        0.0537802596008838}, {-0.0665975832109017, 
        0.05232786588804637}, {-0.06499886519300309, 
        0.050923761870945966`}, {-0.0634881232854349, 0.04961423365578974}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.06325197121675367, 
        0.04941172291586107}, {-0.061905163092438514`, 
        0.04826042292395624}, {-0.06040814391049469, 
        0.04699558590554192}, {-0.058941632508406, 
        0.0457678344058146}, {-0.057505628886172444`, 
        0.04457716842477428}, {-0.05610013304379403, 
        0.04342358796242096}, {-0.05472514498127075, 
        0.042307093018754655`}, {-0.053676653036499516`, 
        0.04146531638447411}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.053434066818841684`, 
        0.041270557225053565`}, {-0.053380664698602615`, 
        0.041227683593775356`}, {-0.05206669219578961, 
        0.04018535968748307}, {-0.050783227472831746`, 
        0.039180121299877774`}, {-0.049528278619284924`, 
        0.038207734710170076`}, {-0.04829985372470503, 
        0.03726396619757057}, {-0.04709795278909207, 
        0.03634881576207923}, {-0.04592257581244605, 
        0.03546228340369608}, {-0.044773722794766956`, 
        0.03460436912242111}, {-0.043651393736054804`, 
        0.03377507291825433}, {-0.043555375649637955`, 
        0.033704914838488254`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.04330419027629783, 
        0.03352137979715906}, {-0.04255558863630958, 
        0.032974394791195724`}, {-0.041486307495531304`, 
        0.03220233474124531}, {-0.04026028596349434, 
        0.03132623317204643}, {-0.03906245490184683, 
        0.030477630517331426`}, {-0.03789281431058876, 
        0.029656526777100282`}, {-0.03675136418972013, 
        0.028862921951353007`}, {-0.03455303535915121, 
        0.02735820904331005}, {-0.033107000105861144`, 
        0.026391176883070137`}}]}, 
      {Arrowheads[{{0.00805618257858365, 1.}}], 
       ArrowBox[{{-0.03284840321326722, 
        0.026218240911345062`}, {-0.03246746841014007, 
        0.02596349179320256}, {-0.030494663342686697`, 
        0.024678770201030535`}, {-0.028634620156791107`, 
        0.023504044266793974`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07243146172113951, 0.09}, {-0.07214515951234611, 
        0.08945006127156847}, {-0.07124094796886646, 
        0.08773939642828624}, {-0.07034204001945193, 
        0.08606509342495469}, {-0.06944843566410255, 
        0.08442715226157384}, {-0.0685601349028183, 
        0.08282557293814367}, {-0.06832097385025715, 
        0.08239799130695658}, {-0.06808225340896047, 
        0.0819728460194291}, {-0.0669284406395485, 
        0.08005346108363555}, {-0.06637500704668277, 0.07913281595882038}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0662147279329223, 
        0.07886618923685147}, {-0.06577462787013653, 
        0.07813407614784199}, {-0.06462081510072457, 
        0.07621469121204842}, {-0.0634670023313126, 
        0.07429530627625486}, {-0.06242427448022602, 
        0.07280048861830696}, {-0.061290064931695004`, 
        0.07095602731978028}, {-0.06016892419708462, 
        0.06916151511276485}, {-0.05962915809444354, 0.06831170020807806}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05946236513266767, 
        0.06804909915880795}, {-0.05906085227639487, 
        0.06741695199726068}, {-0.05796598310567709, 
        0.06571995820652528}, {-0.0568844506209826, 
        0.06406815397381617}, {-0.0558162548223114, 
        0.062461539299133347`}, {-0.0547613957096635, 
        0.06090011418247681}, {-0.05371987328303889, 
        0.059383878623846566`}, {-0.05269168754243758, 
        0.05791283262324261}, {-0.0525449611717376, 0.05770668300915482}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05236456802953962, 
        0.057453231796051246`}, {-0.05167683848785956, 
        0.05648697618066494}, {-0.05067532611930484, 
        0.055106309296113556`}, {-0.04968748156091286, 
        0.053766080438957115`}, {-0.0487136359368231, 
        0.05246153807856428}, {-0.04775378924703555, 
        0.051192682214935045`}, {-0.0468079414915502, 
        0.049959512848069404`}, {-0.04587609267036706, 
        0.04876202997796737}, {-0.044958242783486126`, 
        0.04760023360462893}, {-0.044885576830498694`, 
        0.04750969893503943}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04469084922594775, 
        0.04726708738708348}, {-0.044054391830907404`, 
        0.04647412372805408}, {-0.04316453981263089, 
        0.04538370034824284}, {-0.041427496271712994`, 
        0.04332838622760844}, {-0.03974335123527087, 
        0.04132961006677446}, {-0.038114670981854754`, 
        0.03945880137403704}, {-0.036620870749828005`, 0.0377972021614993}}]}, 
      {Arrowheads[{{0.019412072274130197`, 1.}}], 
       ArrowBox[{{-0.036411048920177276`, 
        0.03756752811542843}, {-0.0355853528588891, 
        0.03667266515003819}, {-0.034649873356184004`, 
        0.035678891567191375`}, {-0.03373457239154862, 
        0.034725417559011304`}, {-0.0328392708302736, 
        0.033810410543132476`}, {-0.031107949378967277`, 
        0.032088467158816546`}, {-0.029454475924590266`, 
        0.030498400755319524`}, {-0.02787741738946778, 
        0.029025550673717357`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAjI/ZTyV8jT97FK5H4XqEv4iPosdm
FI0/M69jClxDg78HxtIr8I2LPx/b7CyxXH6/N9IbsGQIij/daxwxlgN3v5GS
ZnSe4Yk/KYBKW1NSdr+uQbvk5bqJP9mK5VTtonW/Eqb+2juUiT9zt4dCX/V0
v6J3lYTsgIk/pJW22UefdL+HQkwfoW2JP//HrqCkSXS/eFf8xFlaiT/uQGv/
dPRzv2ODMY8WR4k/6SWnXrifc79oBzSX1zOJPxRixSduS3O/s0fsSMndhj80
KnOwi2hjv7onHXf4yYY/r4OnP7DQYr9XXs+EL7aGPycIBa2xOWK/slBup3ym
hj8ThB3zosJhv0C5tZSVkYY/KX0NEKskYb/+ZYQgt3yGP90mjRGXh2C/l5Il
iuwUhj/WeIKXZghbvzyyLSQUroU/WCKME30vVb/F9UOcN0iFP9JO+Ws9Bk+/
ZFD+6khbgz+QkNCchihFP8rERKEPmYI/rPqcBj/uUz8/cbUs
        "]]}, 
      {Arrowheads[{{0.011394345583163204`, 1.}}], 
       ArrowBox[{{0.008911637122003439, 0.0014774191397958587`}, {
        0.008564171400191776, 0.0020127726911708665`}, {0.006961286020173622, 
        0.004187307324649961}, {0.0055958304482273385`, 
        0.005781671176990643}, {0.004444757559175553, 
        0.00696464765517533}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.028481774113086014`, -0.01}, {-0.028062204329890886`, \
-0.009811972509321426}, {-0.026705682962462528`, -0.009194025138797805}, \
{-0.025409861005298393`, -0.008593966178810553}, {-0.024172110366373914`, \
-0.008011335302338005}, {-0.021861154358892455`, -0.006896585829714847}, \
{-0.02164172022491955, -0.006788740609079872}, {-0.02142430542754837, \
-0.00668153630666784}, {-0.021208892429169388`, -0.006574969538251154}, \
{-0.02110193170265228, -0.00652192428035329}, {-0.020995464909476482`, \
-0.006469037142553119}, {-0.020889489898035477`, -0.006416307705672446}, \
{-0.02078400452569377, -0.0063637355513934775`}, {-0.020679006657649608`, \
-0.006311320262151091}, {-0.018436224916635706`, -0.005172178011229274}, \
{-0.017288923907102342`, -0.004567431165080815}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01701372099098717, -0.004422370632414502}, \
{-0.01641648805249704, -0.004107566816356865}, {-0.016287654854944798`, \
-0.004038205519497993}, {-0.016159738903761274`, -0.0039691634118953914`}, \
{-0.01610216367276993, -0.00393798483120876}, {-0.016025665384739606`, \
-0.0038965075189204205`}, {-0.015949476135459585`, -0.003855138602610894}, \
{-0.015573415855088183`, -0.0036500155397792165`}, {-0.015205401378291464`, \
-0.0034477402617805446`}, {-0.014845270968415635`, -0.0032482770478671485`}, \
{-0.013151831547130352`, -0.002290570281728342}, {-0.011633797477173143`, \
-0.001398110645590232}, {-0.01027482313702995, -0.0005669377851649366}, \
{-0.009058562905186727, 0.0002069086538354272}, {-0.007000250135161277, 
        0.001596814975688874}, {-0.0063896039286012365`, 
        0.002037605848534886}}]}, 
      {Arrowheads[{{0.01072175662292158, 1.}}], 
       ArrowBox[{{-0.006137361482404671, 
        0.0022196853682851904`}, {-0.005748091608930859, 
        0.002500677218325132}, {-0.004672576067560134, 
        0.0033199290468668196`}, {-0.003773703511049103, 
        0.004054570461313938}, {-0.003051473939397766, 
        0.0047046014616664855`}, {-0.0012133366652040882`, 
        0.006690852081887529}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.053658564786938076`}, {-0.0997877523213601, 
        0.0535356208147656}, {-0.09798570194182335, 
        0.05249810256901205}, {-0.09621452767390973, 
        0.05148478446692337}, {-0.09447422951761925, 
        0.050495666508499536`}, {-0.09276480747295189, 
        0.049530748693740564`}, {-0.09230736806020103, 
        0.04927345205360093}, {-0.09185204289555228, 
        0.04901776370481454}, {-0.08986907990805694, 
        0.04793544579752838}, {-0.08916013284733357, 0.04754849651810286}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08888706582110828, 
        0.04739945423428983}, {-0.0878861169205616, 
        0.046853127890242215`}, {-0.08590315393306627, 
        0.04577080998295606}, {-0.08392019094557093, 
        0.0446884920756699}, {-0.08228308454695492, 
        0.04385282949662393}, {-0.08036115507514416, 
        0.04281403900020369}, {-0.07847991461378981, 
        0.04180426677769406}, {-0.07792627919697746, 0.04150925730058433}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07765173079594052, 
        0.0413629617823215}, {-0.07663936316289183, 
        0.04082351282909504}, {-0.07483800745174037, 
        0.03987036208435189}, {-0.07307435420962553, 
        0.03894339947340989}, {-0.07134840343654734, 
        0.038042624996269016`}, {-0.06966015513250579, 
        0.03716803865292928}, {-0.06800960929750086, 
        0.036319640443390686`}, {-0.06661784044753274, 
        0.03561013176096863}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06634058341165001, 
        0.03546903765772683}, {-0.0648216250346009, 
        0.034701408425716895`}, {-0.06328418660670587, 
        0.03393157461758171}, {-0.06178149725343081, 
        0.03318510072642612}, {-0.06031060358035905, 
        0.032459158535428585`}, {-0.05887150558749059, 
        0.031753748044589115`}, {-0.05746420327482544, 
        0.031068869253907703`}, {-0.05608869664236358, 
        0.03040452216338435}, {-0.05517881619888821, 
        0.029968569005514187`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05489826328851765, 
        0.029834147029415278`}, {-0.054744985690105025`, 
        0.029760706773019056`}, {-0.05343307041804977, 
        0.029137423082811822`}, {-0.052152950826197815`, 
        0.028534671092762646`}, {-0.049678093634058645`, 
        0.027382028447162466`}, {-0.04731040906464234, 
        0.026294045070242515`}, {-0.045049897117948885`, 
        0.025270720962002783`}, {-0.04359802932298297, 
        0.024624350651839058`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.043313828095451826`, 
        0.024497824506534944`}, {-0.0428965577939783, 
        0.024312056122443276`}, {-0.04157016931984117, 
        0.02372890901433722}, {-0.040276788128105916`, 
        0.023164338706542498`}, {-0.039016414218772555`, 
        0.02261834519905912}, {-0.03778904759184108, 
        0.022090928491887086`}, {-0.035433336185183795`, 
        0.021091825478477044`}, {-0.03320965390813406, 
        0.02016702966631237}, {-0.03186621535858032, 0.0196207731384255}}]}, 
      {Arrowheads[{{0.004185801941242829, 1.}}], 
       ArrowBox[{{-0.031578033835871475`, 
        0.019503595439416953`}, {-0.031118000760691884`, 
        0.019316541055393065`}, {-0.029158376742857258`, 
        0.01854035964571913}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.038300471367909567`, 0.09}, {0.03733108252766641, 
        0.08900693486866473}, {0.03586508139508092, 0.08748708321698213}, {
        0.034444437444018164`, 0.0859956515466162}, {0.03306915067447814, 
        0.08453263985756693}, {0.03173922108646085, 0.0830980481498343}, {
        0.031386204857234784`, 0.08271448156707725}, {0.03103614080892269, 
        0.08233284306885745}, {0.029811934692118656`, 0.08090441576764704}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.02960949295328284, 0.08066820284346028}, {
        0.029388349013903733`, 0.08041016783107935}, {0.02774055721888478, 
        0.07848749259330126}, {0.026092765423865828`, 0.07656481735552317}, {
        0.024444973628846876`, 0.07464214211774507}, {0.023375225885909796`, 
        0.07313967230450544}, {0.021829441864787646`, 0.07129115096517531}, {
        0.02166864139539901, 0.07109538839882959}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02147118134492391, 0.07085499552946342}, {
        0.020351663026263362`, 0.06949206555814381}, {0.018941889370336945`, 
        0.06774241608341097}, {0.017595589728551353`, 0.06603990078706874}, {
        0.016308232932449547`, 0.0643822179152091}, {0.015079818982031526`, 
        0.06276936746783204}, {0.013910347877297285`, 
        0.061201349444937575`}, {0.01380419799613967, 0.06105575569805655}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.013620924113833581`, 0.060804379710261015`}, {
        0.012799819618246827`, 0.059678163846525696`}, {0.011748234204880154`,
         0.05819981067259641}, {0.01075559163719726, 0.0567662899231497}, {
        0.009821891915198153, 0.05537760159818558}, {0.00893793724695717, 
        0.05402916718067245}, {0.008094529840548651, 0.0527164081535787}, {
        0.007291669695972603, 0.05143932451690433}, {0.006696406268871494, 
        0.050469952302653186`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.006533615582992482, 0.05020485157506692}, {
        0.006529356813229021, 0.050197916270649345`}, {0.005126372833239258, 
        0.04782212594939751}, {0.003885577900579362, 0.0455890371898232}, {
        0.0027814574247168908`, 0.04348419722783246}, {0.0017884968151193998`,
         0.04149315329933134}, {0.0009066960717868871, 0.03961590540431984}, {
        0.000728088810827928, 0.03920719972026903}}]}, 
      {Arrowheads[{{0.01895546345399484, 1.}}], 
       ArrowBox[{{0.0006035146118445898, 0.03892213749526651}, {
        0.00013605519471935733`, 
        0.03785245354279796}, {-0.00047783636562789963`, 
        0.036353689815186115`}, {-0.0010348908918840932`, 
        0.03492325404344766}, {-0.001535108384049223, 
        0.03356114622758262}, {-0.001978488842123289, 
        0.03226736636759097}, {-0.0026947386559982305`, 
        0.029884790515227886`}, {-0.003183640333508917, 
        0.027775526486358403`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.04786540885007602, 0.09}, {-0.04769729409395957, 
        0.08922745409616967}, {-0.04732136340351638, 
        0.08756187682301159}, {-0.04693946676204073, 
        0.08593083921226906}, {-0.046551604169532614`, 
        0.08433434126394208}, {-0.04615777562599204, 
        0.08277238297803066}, {-0.046050620044799255`, 
        0.08235525297757355}, {-0.04594315022940055, 
        0.08194044253978733}, {-0.04536773802311379, 
        0.08002118349979183}, {-0.04479232581682704, 
        0.07810192445979634}, {-0.044749188345648866`, 0.0779580415518276}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.044659848333936054`, 
        0.07766005234819283}, {-0.044216913610540275`, 
        0.07618266541980084}, {-0.04364150140425352, 
        0.07426340637980534}, {-0.04304549425225715, 
        0.07276883301271031}, {-0.04246644764378635, 
        0.07092451850322666}, {-0.041884978100526174`, 
        0.06913016701408425}, {-0.041301085622476634`, 
        0.06738577854528306}, {-0.04076952318193809, 0.06584500743141451}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04066686218677545, 
        0.06555134420898566}, {-0.04012971854814212, 
        0.06403737276410552}, {-0.0395431656233903, 
        0.06243097597557945}, {-0.03895603310691546, 
        0.06086978325509518}, {-0.03836832099871757, 
        0.05935379460265271}, {-0.037780029298796654`, 
        0.05788301001825204}, {-0.0371911580071527, 
        0.05645742950189316}, {-0.0366017071237857, 
        0.05507705305357609}, {-0.03611706675449566, 
        0.053972881607408985`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.035991645610764046`, 
        0.05368819253923051}, {-0.035428726740225784`, 
        0.05243291406346528}, {-0.034847112279618654`, 
        0.05116440194727102}, {-0.034268748306460074`, 
        0.049931594750317526`}, {-0.03312177182248858, 
        0.047573095114132845`}, {-0.03198779728831129, 
        0.045357415154911235`}, {-0.030861549206696617`, 
        0.04330303489851482}, {-0.030451801282737275`, 
        0.04255108351340051}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.030302947539466888`, 
        0.04227791366460654}, {-0.029772922061956936`, 
        0.04130523419839152}, {-0.028701517264796743`, 
        0.03943546915454158}, {-0.027649445014108674`, 
        0.03768634775662015}, {-0.026358803498302493`, 
        0.035651820981964705`}, {-0.02510134240985103, 
        0.0337796150371823}, {-0.023880283329968867`, 
        0.03205492598743923}, {-0.023664519148361138`, 
        0.03176418525637356}}]}, 
      {Arrowheads[{{0.002104380238632045, 1.}}], 
       ArrowBox[{{-0.023479125461570268`, 
        0.031514368555423014`}, {-0.022698847839870574`, 
        0.030462949897901832`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAASKucEKXDnj97FK5H4XqEvytiPhET
Yp4/SWduP8jEg7/CY1QoYjWdP245Q7c0noG/dwPcZdgSnD9OefHcWSh/v4ll
lc82+po/e0tP4W9Ke7/2j+5uRcOaP6kpxwjkinq/Z80qcraMmj8SdcStYM15
v0eCuFaJVpo/ElwFdOAReb+oRsRYlzuaP2+viwTgtHi/G78sor0gmj8sUnRg
Xlh4v0ydnyL8BZo/fOsH4Fr8d78R5MrJUuuZP3dzZtzUoHe/f+lch8HQmT+z
0muvy0V3v0sxkHfUJZg/AgBzfXWjcb/cUsuDh5OWP07Crson92i/8gra/zJ5
lj+PfXbiMk1ov4KJWuf5XpY/y3/4VEOkZ792idZ111SWP5xgDh4jY2e/+v4h
H7lKlj+rBzPDKSJnv5SybUaSO5Y/f3qQuvLAZr/W2Z4nfTGWP0Aj/4JQgGa/
dICwH2wnlj/ssyfk1D9mv/70BS+hw5U/dYXrWDHDY7+MYlqRaWGVP6qqDe5C
VWG/S6+gUuMYlT9dvNef1hpfvzyOycc=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.020357001405976387`, -0.0017077439771299651`}, {
        0.018750395019809643`, -0.00046989049973654223`}, {0.0171274165410682,
         0.0007357289364005534}, {0.01563298773445883, 
        0.0018061831930152187`}, {0.01425835536344573, 
        0.0027569442057457406`}, {0.012995482418768401`, 
        0.0036004588836127923`}, {0.011836331891166346`, 
        0.004349174135637045}, {0.010469704688974946`, 
        0.005201036132701323}, {0.010148008187863553`, 
        0.005394056405761935}}]}, 
      {Arrowheads[{{0.003242553729088524, 1.}}], 
       ArrowBox[{{0.009881248528698304, 0.005554114168515789}, {
        0.009236751957338432, 0.005940816864257683}, {0.008137473696256807, 
        0.006568516330306122}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.011076438687622309`}, {0.049571267752165735`, 
        0.011101200127822152`}, {0.0474268587550343, 0.011218693247143181`}, {
        0.045372239370810925`, 0.011324643296983197`}, {0.04340740959949561, 
        0.0114190502773422}, {0.04314816677146156, 0.011431018445018055`}, {
        0.042890425848095694`, 0.011442803833048463`}, {0.04114403021906787, 
        0.011503451446579856`}, {0.03939763459004006, 
        0.011564099060111249`}, {0.037651238961012246`, 
        0.01162474667364264}, {0.0375689383395737, 0.011627604752418969`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0372580321971027, 0.011638401684832052`}, {
        0.03590484333198443, 0.011685394287174033`}, {0.034748571430125226`, 
        0.01168725816581927}, {0.03310631528236246, 0.011737532179076636`}, {
        0.03153348545544306, 0.011780890458817982`}, {0.030030081949367023`, 
        0.01181733300504331}, {0.02859130582508237, 0.011847584583850223`}, {
        0.027212358143537105`, 0.011872369961336322`}, {0.02589323890473123, 
        0.011891689137501608`}, {0.024817662747005507`, 
        0.011903521138102922`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0245065817906377, 0.011906157809533947`}, {
        0.022294851844749945`, 0.011916849458072585`}, {0.02019506935179271, 
        0.011906291998515835`}, {0.018295132964779973`, 
        0.011880221797709013`}, {0.01655557501869867, 
        0.011844990919685298`}, {0.0149763955135488, 0.011800599364444692`}, {
        0.01355759444933036, 0.01174704713198719}, {0.012066857803388306`, 
        0.011673841987442904`}}]}, 
      {Arrowheads[{{0.0010619580512048776`, 1.}}], 
       ArrowBox[{{0.011756138662135799`, 0.011658583598437721`}, {
        0.011096197274702669`, 0.011626176060332779`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.00800915561699783, 0.09}, {-0.008358124032199613, 
        0.08886244800130046}, {-0.008831596793028626, 
        0.08727006610802232}, {-0.009280164475507205, 
        0.08570989263500012}, {-0.009703827079635345, 
        0.08418192758223382}, {-0.009814871241969912, 
        0.08377366101692875}, {-0.009924334349628578, 
        0.08336756677278172}, {-0.010355212688066186`, 
        0.08144182494763638}, {-0.010786091026503795`, 
        0.07951608312249106}, {-0.011133961666920336`, 
        0.07796133092859021}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.011201888290707233`, 
        0.07765774374678465}, {-0.011216969364941404`, 
        0.07759034129734574}, {-0.011647847703379012`, 
        0.07566459947220042}, {-0.011818779785288325`, 
        0.0741571157328525}, {-0.012203785254926823`, 
        0.07230518415814201}, {-0.01255820881203258, 
        0.07050245941705474}, {-0.012882050456605596`, 
        0.06874894150959071}, {-0.01317769329711935, 
        0.0670423345138862}, {-0.013440543000593086`, 0.06542331984425712}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.013487434183069363`, 
        0.06511578292481959}, {-0.01369153189138952, 
        0.06376296549216473}, {-0.013909727645145932`, 
        0.06219020346614776}, {-0.014102107703316562`, 
        0.06066205643002664}, {-0.014268672065901412`, 
        0.05917852438380135}, {-0.01440942073290048, 
        0.05773960732747191}, {-0.014524353704313769`, 
        0.05634530526103831}, {-0.014696173543050032`, 
        0.053672240918479344`}, {-0.01473563959321962, 
        0.052741745778153645`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.014748822472929145`, 
        0.05243093166190682}, {-0.014803532564777231`, 
        0.051141026176745166`}, {-0.014846430769495371`, 
        0.04875166103583578}, {-0.014824868157204447`, 
        0.04650414549575117}, {-0.014751871077467575`, 
        0.04438411541247841}, {-0.014640465879847867`, 
        0.04237720664200451}, {-0.014490652564345324`, 
        0.0404834191843295}, {-0.014439742282396664`, 0.04000178319919456}}]}, 
      {Arrowheads[{{0.013822455748581057`, 1.}}], 
       ArrowBox[{{-0.014407040995420093`, 
        0.03969241314730556}, {-0.014302431130959945`, 
        0.03870275303945338}, {-0.013933361689777072`, 
        0.03597137491421448}, {-0.013511387981718954`, 
        0.03347286043655776}, {-0.01303651000678559, 0.03120720960648323}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.01289898020268381, 0.09}, {0.011956861116387888`, 
        0.08842365347138105}, {0.0110466803047405, 0.08687378214360253}, {
        0.010170870387280671`, 0.08535445625727582}, {0.009329431364008406, 
        0.08386567581240094}, {0.009106847120534516, 0.08346776476716986}, {
        0.008886478303461946, 0.0830719190680257}, {0.007913227454742513, 
        0.08114694150236365}, {0.0069399766060230786`, 0.07922196393670158}, {
        0.006884424952928206, 0.07911208919466178}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0067440593548236845`, 0.0788344622830619}, {
        0.005966725757303645, 0.07729698637103953}, {0.004993474908584211, 
        0.07537200880537746}, {0.004417235866443421, 0.07386566095604129}, {
        0.003514045924767277, 0.07201455922267203}, {0.002657563254453326, 
        0.07021270804416463}, {0.0018477878555015694`, 0.06846010742051911}, {
        0.001451999378716196, 0.06757921108531717}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.0013245023086918572`, 0.0672954441028986}, {
        0.0010814386198723307`, 0.06675446343958866}, {0.000355234439525932, 
        0.06509348218922645}, {-0.00033082468553762446`, 
        0.06347716366943251}, {-0.0009767387553183391, 
        0.06190550788020682}, {-0.0015825077698162129`, 
        0.06037851482154939}, {-0.0021481317290312453`, 
        0.058896184493460214`}, {-0.002673610632963434, 
        0.0574585168959393}, {-0.0031589444816127834`, 
        0.056065512028986644`}, {-0.0032690603500762122`, 
        0.05573580955297688}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0033676099647408212`, 
        0.05544073807583077}, {-0.0036107972136864134`, 
        0.054712601075867}, {-0.004035832767891443, 
        0.05339521521984514}, {-0.004434051144227876, 
        0.052113354460921045`}, {-0.00480545234269571, 
        0.05086701879909473}, {-0.005467803206025584, 
        0.04848092276673543}, {-0.0060228853578810655`, 
        0.046236927122767224`}, {-0.006488998046444591, 
        0.04412065717360822}, {-0.006623437767510511, 0.04343971902772415}}]}, 
      {Arrowheads[{{0.016502213279178946`, 1.}}], 
       ArrowBox[{{-0.006683694753223484, 
        0.04313451696539738}, {-0.0068844405198986, 
        0.042117738225676514`}, {-0.007209212778243091, 
        0.04022817027897211}, {-0.007463314821478066, 
        0.038451953333495}, {-0.00763842252206625, 
        0.03698094705403976}, {-0.007781200841894606, 
        0.03557478848461837}, {-0.007891649780963135, 
        0.034233477625230845`}, {-0.007969769339271836, 
        0.03295701447587718}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.027272964191524376`, 0.09}, {-0.027276912480346888`, 
        0.08992497299740682}, {-0.027349575797889002`, 
        0.08827936678738038}, {-0.02740654672949227, 
        0.08666712566152274}, {-0.027447825275156688`, 
        0.08508824961983388}, {-0.027473411434882255`, 
        0.08354273866231382}, {-0.02747820197020444, 
        0.08312989084662278}, {-0.0274820277360095, 
        0.08271928849567767}, {-0.027417881130661084`, 
        0.08079656345942685}, {-0.02735373452531267, 
        0.07887383842317604}, {-0.027309989779864, 0.07756263704592878}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.027299616742132878`, 
        0.07725171647204541}, {-0.027289587919964255`, 
        0.07695111338692523}, {-0.02722544131461584, 
        0.07502838835067442}, {-0.02702032731673571, 
        0.07352696113705856}, {-0.02693130411270523, 
        0.07167858277539038}, {-0.02682569650955337, 
        0.06987976886344396}, {-0.026703504507280134`, 
        0.06813051940121931}, {-0.026566377466170372`, 
        0.0664284982754444}, {-0.026422619423504577`, 0.06484468536375383}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.026391975948174932`, 
        0.06453510792501733}, {-0.026252266348295812`, 
        0.06315913269342786}, {-0.026075282271531018`, 
        0.061591788237186224`}, {-0.025885012516214546`, 
        0.06006933600412234}, {-0.0256814570823464, 
        0.05859177599423621}, {-0.025464615969926573`, 
        0.057159108207527835`}, {-0.025234489178955072`, 
        0.055771332643997217`}, {-0.024747881541740673`, 
        0.0531118185860867}, {-0.02456860463682357, 0.05223169156463535}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.024506511704455048`, 
        0.05192685772313214}, {-0.024235137151086838`, 
        0.0505945942201221}, {-0.023696256006993568`, 
        0.04821965954610343}, {-0.02313123810946086, 
        0.04598701456403069}, {-0.02254870250867104, 
        0.04388209502187917}, {-0.02195726825480644, 
        0.04189033666762414}, {-0.02135693534786705, 
        0.04001173950126561}, {-0.021320450892307455`, 0.0399060145606568}}]}, 
      {Arrowheads[{{0.007685631348015542, 1.}}], 
       ArrowBox[{{-0.02121896873224225, 
        0.039611938763685635`}, {-0.020747703787852883`, 
        0.03824630352280358}, {-0.020160151928593217`, 
        0.03664582837093475}, {-0.01957459430772247, 0.03512214909553918}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.045450421187606234`, -0.01}, {
        0.04525446368991769, -0.00988095630551021}, {
        0.04402142966243168, -0.009131891187844444}, {
        0.04236717965998954, -0.008282186036967617}, {
        0.040848475714490635`, -0.007421399839317466}, {
        0.03937933671301918, -0.0065978973668506125`}, {
        0.03795976265557519, -0.0058116786195670555`}, {
        0.036589753542158654`, -0.005062743597466797}, {
        0.03640810885639764, -0.004964132800304746}, {
        0.03622731185157199, -0.004866141307200668}, {
        0.03455288148764037, -0.003998897446342777}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.034276640778214684`, -0.0038558230823507516`}, {
        0.03283380990982114, -0.00310853239781461}, {
        0.03113705893894572, -0.0022297279431215808`}, {
        0.029440307968070293`, -0.001350923488428552}, {
        0.02839238463872329, -0.0008971269715379172}, {
        0.0268101326634117, -0.00009332391763354616}, {0.02530421335180934, 
        0.0006604782024117199}, {0.023874626703916206`, 
        0.0013642793885978808`}, {0.023151874964761152`, 
        0.0017143123621052717`}}]}, 
      {Arrowheads[{{0.014210915475527813`, 1.}}], 
       ArrowBox[{{0.02287188898710078, 0.0018499112392735338`}, {
        0.022515506510025932`, 0.002022509396286997}, {0.021220986560432153`, 
        0.002639597980841131}, {0.019991066855134867`, 
        0.003215545142260281}, {0.018825747394134076`, 
        0.003750350880544448}, {0.016688909205021977`, 
        0.004696538087707833}, {0.014810471993095858`, 
        0.005478159602331285}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05327694501323778, -0.01}, {-0.052025343090157335`, \
-0.009705202320220615}, {-0.04955496810216892, -0.009116448764185497}, \
{-0.0470845931141805, -0.008527695208150379}, {-0.04461421812619208, \
-0.00793894165211526}, {-0.04296192412285589, -0.00746414387313376}, \
{-0.04120059188310578, -0.007005603862596678}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04089953325979289, -0.0069272271536540446`}, \
{-0.04083978430562643, -0.006911672288163729}, {-0.03881294582793042, \
-0.006373940801740026}, {-0.03688140868976785, -0.005850949413862649}, \
{-0.03504517289113874, -0.0053426981245316}, {-0.034803664881952995`, \
-0.005275065430301494}, {-0.03456373475663412, -0.00520769138681185}, \
{-0.03287892178810459, -0.004700669924568041}, {-0.03119410881957505, \
-0.004193648462324232}, {-0.02950929585104551, -0.003686627000080423}, \
{-0.0289344435407215, -0.00351363304502493}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02863654683263815, -0.003423985097536811}, \
{-0.027824482882515975`, -0.003179605537836614}, {-0.025241124773331812`, \
-0.0023199441970179944`}, {-0.023752878761771005`, -0.001851518130691435}, \
{-0.02234325953299769, -0.0013985302227317756`}, {-0.01973544300449368, \
-0.0005357001022406828}, {-0.017393216768499947`, 
        0.00027171494412775703`}, {-0.01682164959844825, 
        0.0004786932049848228}}]}, 
      {Arrowheads[{{0.014663085157740301`, 1.}}], 
       ArrowBox[{{-0.016529144112674667`, 
        0.0005846164978343605}, {-0.015316580825016485`, 
        0.0010237149163735435`}, {-0.013505535174043298`, 
        0.0017202998144966767`}, {-0.01190852103168833, 
        0.002367390550122375}, {-0.010473979614059539`, 
        0.002970908034875858}, {-0.009201910921156915, 
        0.003530852268757126}, {-0.008092314952980463, 
        0.004047223251766178}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.03342419335838609}, {-0.09899993536034518, 
        0.03310141647241826}, {-0.09704708253573255, 
        0.032475387160928924`}, {-0.0951333948403761, 
        0.03186626433074432}, {-0.09462192658628653, 
        0.031704064555632246`}, {-0.09411310689483236, 
        0.031542979838980204`}, {-0.0921259368839357, 
        0.030930938082731185`}, {-0.09013876687303903, 
        0.030318896326482162`}, {-0.08815159686214237, 
        0.029706854570233143`}, {-0.08812703558607506, 
        0.029699289778867773`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08782972433856223, 
        0.02960771890315884}, {-0.0861644268512457, 
        0.02909481281398412}, {-0.08452309475965547, 
        0.02862111596951427}, {-0.0825969549698129, 
        0.02803348802122628}, {-0.08071150199400635, 
        0.027462135944912307`}, {-0.07886673583223587, 
        0.026907059740572357`}, {-0.0770611212471158, 
        0.02636748355534528}, {-0.07591261540125087, 
        0.026026535472721147`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07561438550104649, 
        0.02593800225974538}, {-0.07529312300126051, 
        0.025842631536369936`}, {-0.07356274109466998, 
        0.025332503683646323`}, {-0.07186997552734424, 
        0.024837099997174438`}, {-0.07021482629928327, 
        0.024356420476954282`}, {-0.06859729341048708, 
        0.023890465122985857`}, {-0.06701737686095566, 
        0.02343923393526916}, {-0.06547507665068901, 
        0.023002726913804197`}, {-0.06396734436837252, 
        0.0225793953512975}, {-0.06365718647112462, 0.022492894610085804`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0633575285631316, 
        0.022409322238138026`}, {-0.0624911316026916, 
        0.022167690540455608`}, {-0.06104643835364624, 
        0.02176761248127852}, {-0.05963326462123643, 
        0.021379161173766238`}, {-0.05825161040546217, 
        0.021002336617918758`}, {-0.05690147570632348, 
        0.020637138813736085`}, {-0.05558286052382034, 
        0.02028356776121822}, {-0.05429576485795276, 
        0.019941623460365154`}, {-0.0518287824791672, 
        0.01929865375790686}, {-0.051342466592265816`, 
        0.01917207813859188}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.051041403378560654`, 
        0.01909371906426574}, {-0.049428842952723526`, 
        0.018674010722258497`}, {-0.04714486117038774, 
        0.018091043777866616`}, {-0.044971776970942665`, 
        0.017547337467029852`}, {-0.04333179862810884, 
        0.017144548500710444`}, {-0.0417550374457185, 
        0.016763812402715482`}, {-0.040238984105353606`, 
        0.01640397499712918}, {-0.03896205628385393, 
        0.016106089318126172`}}]}, 
      {Arrowheads[{{0.0021106889553604213`, 1.}}], 
       ArrowBox[{{-0.03865899016083831, 
        0.01603587682782938}, {-0.037378963677028115`, 
        0.015742379559519418`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.09657595528223646, -0.01}, {-0.09567466138822005, \
-0.009905471654621382}, {-0.09418235747564879, -0.00974698214582525}, \
{-0.09271299736993183, -0.009588923387991688}, {-0.09126658107106912, \
-0.009431295381120695}, {-0.0898431085790607, -0.009274098125212269}, \
{-0.08844257989390653, -0.009117331620266414}, {-0.08571035394416103, \
-0.008805090863262404}, {-0.08420803956171778, -0.008629157167199834}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08389905753615604, -0.008592972763715944}, \
{-0.08306232601144277, -0.008494984438851834}, {-0.0804909188853619, \
-0.008187423675777863}, {-0.07799613256591845, -0.007882408574040496}, \
{-0.0755779670531124, -0.007579939133639729}, {-0.07319811194362483, \
-0.007278742523907233}, {-0.07154892093924853, -0.00707001942251371}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07124028933787446, -0.0070309587286002066`}, \
{-0.07081825683413726, -0.006977545914174738}, {-0.06843840172464968, \
-0.006676349304442242}, {-0.06660214167799261, -0.00639847812456558}, \
{-0.06502670973125221, -0.0061806505615740635`}, {-0.06348487455319149, \
-0.005964640466575477}, {-0.06197663614381042, -0.005750447839569821}, \
{-0.060501994503109, -0.005538072680557097}, {-0.05906094963108725, \
-0.005327514989537303}, {-0.05891707173761948, -0.005306176296124891}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.05860934418548988, -0.00526053687417355}, \
{-0.05765350152774516, -0.005118774766510439}, {-0.05493939562709996, \
-0.004706746724435504}, {-0.05458200117438308, -0.004651604199632432}, \
{-0.0542268397241866, -0.004596599740774836}, {-0.0524069181362936, \
-0.004292826942937203}, {-0.05058699654840059, -0.00398905414509957}, \
{-0.048767074960507584`, -0.003685281347261936}, {-0.046947153372614576`, \
-0.003381508549424303}, {-0.046328472793605247`, -0.0032583263974085607`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.046023368036848485`, -0.0031975786354734464`}, \
{-0.04562953810275644, -0.0031191652821928938`}, {-0.04389825880628135, \
-0.0028227035779916526`}, {-0.042226074370751536`, -0.0025311159362146735`}, \
{-0.040612984796167005`, -0.002244402356861956}, {-0.03905556566786868, \
-0.001962505756493255}, {-0.037550392571197494`, -0.0016853690516683256`}, \
{-0.03609746550615345, -0.0014129922423871675`}, {-0.03469678447273654, \
-0.0011453753286497811`}, {-0.03378190594319447, -0.0009651569825301029}}]}, 
      {Arrowheads[{{0.0196667454475509, 1.}}], 
       ArrowBox[{{-0.0334766779827838, -0.0009050313194628695}, \
{-0.03205216050078414, -0.0006244211878063237}, {-0.029616520655340293`, \
-0.00012250662913795233`}, {-0.027362241084440936`, 
        0.00036070994243366937`}, {-0.025261697936122, 
        0.0008255701219868807}, {-0.023314891210383482`, 
        0.00127207390952168}, {-0.02152182090722539, 
        0.0017002213050380673`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.018370927466193877`}, {-0.09844661998930587, 
        0.018123500171866914`}, {-0.09638429806013056, 
        0.01779881516652589}, {-0.09583355166320832, 
        0.0177126329965884}, {-0.09528585786322989, 
        0.017627169850029954`}, {-0.09329565283554306, 
        0.017329846994156295`}, {-0.09130544780785621, 
        0.01703252413828264}, {-0.08931524278016936, 
        0.01673520128240898}, {-0.0876987701330542, 0.016493711457393045`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.08739109106228157, 
        0.01644774633382937}, {-0.08732503775248251, 
        0.01643787842653532}, {-0.08567922631617504, 
        0.016216761297688186`}, {-0.08374979662814339, 
        0.015932886511289795`}, {-0.08186088383321517, 
        0.015657977104541584`}, {-0.08001248793139043, 
        0.015392033077443553`}, {-0.07820307631442283, 
        0.015134603156391964`}, {-0.07643111637406606, 
        0.014885236067783084`}, {-0.07507135123735713, 
        0.014696065960189807`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07476322516805327, 
        0.014653199556199203`}, {-0.07469660811032014, 
        0.014643931811616911`}, {-0.07299955152318505, 
        0.014410690387893449`}, {-0.07133994661266078, 
        0.014185511796612694`}, {-0.06971779337874737, 
        0.013968396037774647`}, {-0.06813309182144477, 
        0.013759343111379307`}, {-0.06658584194075302, 
        0.013558353017426677`}, {-0.06507299796327179, 
        0.01336452493040037}, {-0.06359151411560073, 
        0.013176958024784005`}, {-0.06242574801316715, 
        0.013031204897065496`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06211705290078771, 
        0.012992649583237866`}, {-0.06072262680968912, 
        0.012820607757781101`}, {-0.05797918002301825, 
        0.01248930221641796}, {-0.05536117375558809, 
        0.012183041400694587`}, {-0.0528811972209668, 
        0.011905313872042562`}, {-0.05046791154226818, 
        0.011636351115682914`}, {-0.049756202919016494`, 
        0.011559940665208929`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.049446886931371295`, 
        0.011526731886809152`}, {-0.048169995011955756`, 
        0.011389642235817765`}, {-0.045982411944602265`, 
        0.011163791807874482`}, {-0.044337625211358346`, 
        0.011000151904387743`}, {-0.04275521416111259, 
        0.010848046838363155`}, {-0.04123271533162757, 
        0.010706821535752966`}, {-0.039767665260665844`, 
        0.010575820922509424`}, {-0.03835760048598997, 
        0.010454389924584775`}, {-0.037059574906598426`, 
        0.010346806411409677`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.05768296844496328}, {0.04914330693322274, 
        0.05718046421430395}, {0.047688278864185835`, 
        0.056318153400363336`}, {0.04627483751049885, 0.05547139023776747}, {
        0.04589876079071003, 0.055244825909472356`}, {0.045525416106770876`, 
        0.05501932443757595}, {0.043743414398672326`, 
        0.053886481278361396`}, {0.04196141269057377, 0.05275363811914684}, {
        0.04017941098247521, 0.05162079495993228}, {0.039418625139698474`, 
        0.05113715286593197}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.039156090243545036`, 0.05097025579742137}, {
        0.03839740927437666, 0.05048795180071772}, {0.03715426244767448, 
        0.04958654907842995}, {0.03546735277746941, 0.04849454834926129}, {
        0.03384383779919332, 0.04742977590678991}, {0.03228371751284621, 
        0.0463922317510158}, {0.030783113484259585`, 0.04538074532976513}, {
        0.02933814727926491, 0.04439414609086409}, {0.028824107922920814`, 
        0.04403832103671891}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.028568317968470164`, 0.04386125974118015}, {
        0.0279488188978622, 0.04343243403431267}, {0.026615128340051454`, 
        0.04249560916011087}, {0.025337075605832662`, 0.0415836714682587}, {
        0.024114660695205837`, 0.040696620958756154`}, {0.02294788360817097, 
        0.039834457631603225`}, {0.021836744344728064`, 
        0.038997181486799926`}, {0.019750027108046533`, 
        0.03738802371223221}, {0.018572468890870764`, 0.03645413756949706}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.018328723844026316`, 0.036260830675376526`}, {
        0.017823156804589645`, 0.035859880603043015`}, {0.016056133434357397`,
         0.03441275215923235}, {0.014448956997349797`, 0.0330466383808002}, {
        0.012979254694235625`, 0.03175398757375377}, {0.011624653725683678`, 
        0.030527248044100258`}, {0.010385154091693955`, 
        0.02936641979183966}, {0.009260755792266451, 0.02827150281697197}, {
        0.009014019362020047, 0.02801942488516842}}]}, 
      {Arrowheads[{{0.003376777944875858, 1.}}], 
       ArrowBox[{{0.00879641106619584, 0.027797105671504344`}, {
        0.007326781278273426, 0.02629566043665836}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAlZt3KT/Jdj97FK5H4XqEv2yHYWIa
ynY/rmtdhhx3hL+07QiUuNV2P8aHpLEHQ4S/eH8+URHhdj9EA/ACMw+Ev1ix
zzkl7HY/+zMWLp7bg7+iAYjs9PZ2P6k4OedIqIO/xW+2/lKIdz/p4hvKbXeA
v8x6SdUP23c/aG/jFQELe7+fJqaeiN53P9a24CBzqXq/1VQwgsPhdz85/7u9
bEh6v962K4OP43c/Kdj+HKEMer+7WhJt0+V3PxmWSFkxvXm/fOLLC/Hndz9z
t0glF255v8Mo2Zkw8Hc/2YYGvtvnd78bPRiGqPR3P0o8My9Qana/9ObNk4T1
dz9DWManRPV0v8jFv15Qznc/rjmO2ck9bL+DKV0Lu2F3PzY3IVteCGC/qyaO
p1nzdT/+04zSukRCPznfwFqiPnQ/yr8W5ghPYz+qXaHf
        "]]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.09570766941431641, 0.09}, {-0.09495411149002272, 
        0.08905590261323965}, {-0.09355231868732979, 
        0.08731977152765714}, {-0.09317595606498676, 
        0.0868563898581564}, {-0.09280076202883004, 
        0.08639570164715989}, {-0.09114850970815833, 
        0.08445787154467793}, {-0.08949625738748661, 
        0.08252004144219596}, {-0.08784400506681489, 
        0.08058221133971401}, {-0.08773144074147271, 0.0804501912266934}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08752960025936601, 
        0.0802134643313928}, {-0.08619175274614317, 
        0.07864438123723205}, {-0.08474675449657443, 
        0.07711389913227337}, {-0.08313107642374441, 
        0.07524795397053083}, {-0.08153978118280887, 
        0.07342993210261455}, {-0.07997286877376779, 
        0.07165983352852452}, {-0.0792869846718621, 0.07089331161362626}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07907954090416541, 
        0.07066147916029081}, {-0.078429916530455, 
        0.06993547994625805}, {-0.07691050178670433, 
        0.06825469305381239}, {-0.07541462454251578, 
        0.06661747285118755}, {-0.07394228479788935, 
        0.06502381933838353}, {-0.07249348255282503, 
        0.06347373251540031}, {-0.07106821780732284, 
        0.061967212382237916`}, {-0.07063874090191392, 
        0.061518976308191795`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07042351519446165, 
        0.0612943497335676}, {-0.06966649056138276, 
        0.06050425893889634}, {-0.06828830081500481, 
        0.05908487218537558}, {-0.06693284925056606, 
        0.05770470813571676}, {-0.06559933655044359, 
        0.05635942280396098}, {-0.06428776271463739, 
        0.055049016190108255`}, {-0.06299812774314748, 
        0.05377348829415859}, {-0.06173043163597384, 
        0.05253283911611197}, {-0.061658010761436295`, 
        0.05246274283393837}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.06143447610209081, 
        0.052246383273837536`}, {-0.060484674393116486`, 
        0.051327068655968415`}, {-0.05926085601457542, 
        0.0501561769137279}, {-0.05805897650035063, 
        0.04902016388939045}, {-0.0568917019236001, 
        0.04796454593608484}, {-0.05572579873186857, 
        0.04686989613353271}, {-0.05458135793775145, 
        0.04580841283497282}, {-0.053458141307897805`, 
        0.04477923993344979}, {-0.052355910608956696`, 
        0.04378152132200821}, {-0.05233335974278761, 0.04376135512122603}}]}, 
      {Arrowheads[{{0.001783210614865795, 1.}}], 
       ArrowBox[{{-0.05210146433017964, 
        0.043553981736272444`}, {-0.05127442760757721, 
        0.04281440089369268}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.035267636722781964`}, {0.04812722462117538, 
        0.03465478920223906}, {0.04566190601006123, 0.03383375594195599}, {
        0.043315191482793156`, 0.03303725298164704}, {0.041087081039371136`, 
        0.03226528032131219}, {0.04079423622430228, 0.03216270030307709}, {
        0.04050335134216347, 0.03206054590839201}, {0.03876758425545556, 
        0.0314139456288122}, {0.03823563102687705, 0.031215784764398874`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037944107626404405`, 0.03110718775637104}, {
        0.03703181716874764, 0.03076734534923239}, {0.03529605008203973, 
        0.03012074506965258}, {0.03356028299533182, 0.029474144790072772`}, {
        0.03242511482912483, 0.02897736909098579}, {0.030795335787211192`, 
        0.028357208443257655`}, {0.029236215441827078`, 
        0.02775467421676397}, {0.027747753792972486`, 
        0.027169766411504738`}, {0.026343582693123226`, 
        0.026609070139989487`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.026055240925752697`, 0.02649228800024315}, {
        0.024963109886505047`, 0.026049532259990262`}, {0.0236620034543055, 
        0.02551338146256018}, {0.02242170736946207, 0.024993208184014862`}, {
        0.020123546241843548`, 0.024000794183578544`}, {0.018068626503649488`,
         0.0230722902586813}, {0.016216448472774696`, 0.0222012971016035}, {
        0.014679675448906818`, 0.021455723263033084`}}]}, 
      {Arrowheads[{{0.019269753379811017`, 1.}}], 
       ArrowBox[{{0.014400688933686812`, 0.021318098150754156`}, {
        0.012998818486667372`, 0.020612645167747308`}, {0.011633366531434836`,
         0.019894986390968917`}, {0.009281531381687354, 
        0.018591872548076066`}, {0.007363349702946878, 0.01745094320631148}, {
        0.006088774036439653, 0.01663929354122442}, {0.004993990505620636, 
        0.015904304639191978`}, {0.0040789991104898254`, 
        0.01524597650021416}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.04226712179430375}, {0.0495218744032061, 
        0.04206927814825914}, {0.04818222218015196, 0.04150959944998542}, {
        0.046877774428723214`, 0.04095914416428124}, {0.045608531148919856`, 
        0.04041791229114659}, {0.045270528250818017`, 0.04027299920089122}, {
        0.04493484763682781, 0.0401287217165645}, {0.043164605618131326`, 
        0.03932657767733081}, {0.04139436359943484, 0.03852443363809712}, {
        0.03962412158073835, 0.03772228959886343}, {0.03860838433637843, 
        0.0372620318672167}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03832502394530244, 0.037133633689873755`}, {
        0.037853879562041864`, 0.03692014555962974}, {0.03664027766714696, 
        0.03628890528513027}, {0.03496826625853311, 0.035516920733790855`}, {
        0.033361741923307674`, 0.03476504250771428}, {0.03182070466147066, 
        0.03403327060690057}, {0.0303409601189119, 0.03332072363435919}, {
        0.02891831394152122, 0.032626520193099626`}, {0.027552766129298613`, 
        0.03195066028312187}, {0.02711655778596786, 0.03173145874582944}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.026838587524158047`, 0.03159177432749613}, {
        0.02624431668224409, 0.031293143904425946`}, {0.02379871288363928, 
        0.030033141740879538`}, {0.02158150254570678, 
        0.028846513702460403`}, {0.019558592370237722`, 0.0277263318488137}, {
        0.017695889059023223`, 0.026665668239584585`}, {0.015993392612063277`,
         0.02566452287477306}, {0.015923523174332748`, 
        0.025621864895239585`}}]}, 
      {Arrowheads[{{0.009707257486163008, 1.}}], 
       ArrowBox[{{0.015658005061640758`, 0.02545975587325681}, {
        0.014451103029357898`, 0.024722895754379134`}, {0.013045292400904018`,
         0.02383507879407947}, {0.011752232816698573`, 
        0.022995363909550755`}, {0.01057192427674157, 
        0.022203751100792986`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.028571415663610603`}, {0.049477485136896794`, 
        0.02845101449944538}, {0.04705965068706955, 0.02788058157407133}, {
        0.04674152777362303, 0.027804583887293007`}, {0.04642545357070713, 
        0.02772885562861918}, {0.0446509868421218, 0.027275972754701148`}, {
        0.042876520113536466`, 0.026823089880783118`}, {0.04110205338495113, 
        0.026370207006865088`}, {0.0393275866563658, 0.025917324132947058`}, {
        0.03810727648609625, 0.025551387521652758`}, {0.037941005065550204`, 
        0.025507997880564168`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037639991970656296`, 0.02542944649688368}, {
        0.03643060209133135, 0.025113848105844796`}, {0.03481912258578007, 
        0.024686537662110215`}, {0.033272837969442415`, 
        0.024269456190449016`}, {0.031787556805424014`, 
        0.023862244335899313`}, {0.030359087656830496`, 
        0.02346454274349923}, {0.02898743052366187, 0.02307635141324876}, {
        0.027672585405918132`, 0.02269767034514791}, {0.025651069113530742`, 
        0.02209856820499879}}]}, 
      {Arrowheads[{{0.018648052059656174`, 1.}}], 
       ArrowBox[{{0.025352798595190858`, 0.022010171932085366`}, {
        0.025213331216705322`, 0.02196883899539506}, {0.02298132508919206, 
        0.021278048694240673`}, {0.020942441603230964`, 
        0.020622595736694855`}, {0.019062555338674635`, 0.0199997764177677}, {
        0.01734166629552308, 0.01940959073745921}, {0.015779774473776303`, 
        0.018852038695769385`}, {0.014353256289836257`, 
        0.01832452542396273}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.1, 0.004644973431636315}, {-0.09784168167731709, 
        0.004588225402877709}, {-0.09725238476638431, 
        0.0045733000349151695`}, {-0.09666652938063583, 
        0.004558723255170472}, {-0.09467163452272637, 
        0.004521883144531726}, {-0.09267673966481689, 
        0.0044850430338929815`}, {-0.09068184480690741, 
        0.004448202923254236}, {-0.08868694994899795, 
        0.004411362812615491}, {-0.08755874322247655, 
        0.004406886184868435}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08724765211126544, 
        0.004405651801960079}, {-0.0870328496570994, 
        0.004404799484203191}, {-0.08509809501672128, 
        0.004373302335133818}, {-0.08320343385469736, 
        0.004345367160444027}, {-0.08134886617102768, 
        0.0043209939601338175`}, {-0.07953289181292404, 
        0.004299951027522732}, {-0.07775401062759822, 
        0.004282006655930314}, {-0.07601222261505022, 
        0.004267160845356562}, {-0.07480483819522177, 
        0.004258840619496925}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0744937520213185, 
        0.0042566968886468505`}, {-0.07430752777528007, 
        0.004255413595801477}, {-0.07263992610828775, 
        0.004246764907265059}, {-0.07100941761407326, 
        0.004241214779747308}, {-0.0694160022926366, 
        0.004238763213248223}, {-0.06785968014397777, 
        0.0042394102077678054`}, {-0.06633746950999714, 
        0.00424269268175251}, {-0.06484638873259506, 
        0.004248147553648791}, {-0.06338643781177154, 
        0.00425577482345665}, {-0.06205011280057975, 0.004264940100622948}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06173903117156977, 
        0.0042676396774968236`}, {-0.059193364188772385`, 
        0.0042916910203496875`}, {-0.05655363105633242, 
        0.004326497141169599}, {-0.05405075973213749, 
        0.004371725300412954}, {-0.051614810051913096`, 
        0.004417558299675989}, {-0.04929707874990777, 
        0.004470613147407106}}]}, 
      {Arrowheads[{{0.019945184919583612`, 1.}}], 
       ArrowBox[{{-0.048986098283724376`, 
        0.004478999693451263}, {-0.04708191030100082, 
        0.0045304422221650095`}, {-0.04540581594227937, 
        0.004582047535810825}, {-0.04379272784446941, 
        0.004637197833339348}, {-0.042240177049207225`, 
        0.004695569589841388}, {-0.040745694598129115`, 
        0.004756839280407749}, {-0.03930681153287138, 
        0.004820683380129241}, {-0.037921058895070324`, 
        0.004886778364096671}, {-0.03658596772636223, 
        0.004954800707400845}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.1, 0.07556703343984189}, {-0.0997972929490473, 
        0.07538114302959505}, {-0.09817727674695609, 
        0.07390811982265563}, {-0.09658084641619881, 
        0.07246932173721725}, {-0.09615292964244682, 
        0.07208540861936504}, {-0.09572666579971112, 
        0.0717037797431245}, {-0.09372237209279835, 
        0.06997624003640614}, {-0.0917180783858856, 
        0.06824870032968777}, {-0.09066454035922597, 0.06734063542517055}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.0904288975734469, 
        0.06713753032753388}, {-0.08971378467897283, 
        0.06652116062296941}, {-0.08770949097206007, 
        0.06479362091625104}, {-0.08602734918402176, 
        0.06346637226159656}, {-0.0840799058157339, 
        0.06180947215230123}, {-0.08217036267319597, 
        0.0601996651079546}, {-0.08089887928078972, 0.059138049746358015`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.08066007966510806, 
        0.05893866582843578}, {-0.08029871975640798, 
        0.05863695112855666}, {-0.0784638159715619, 
        0.05711899032898698}, {-0.07666449022484974, 
        0.05564344282412513}, {-0.07490074251627146, 
        0.05421030861397111}, {-0.07317257284582708, 
        0.05281958769852493}, {-0.0714799812135166, 
        0.05147128007778657}, {-0.07100105833362111, 
        0.051093840403386964`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0707567233468774, 
        0.05090127971833241}, {-0.06982296761934002, 
        0.050165385751756046`}, {-0.06820153206329733, 
        0.048901904720433355`}, {-0.06661567454538855, 
        0.04768083698381849}, {-0.06506313315544787, 
        0.04649750262072551}, {-0.06354164598330951, 
        0.04534722170996847}, {-0.06205121302897345, 
        0.044229994251547375`}, {-0.06086667781496473, 
        0.04335000178888408}}]}, 
      {Arrowheads[{{0.016102800001280795`, 1.}}], 
       ArrowBox[{{-0.060616954623072775`, 
        0.043164482165644315`}, {-0.060591834292439695`, 
        0.043145820245462214`}, {-0.059163509773708246`, 
        0.04209469969171299}, {-0.05776623947277911, 
        0.0410766325902997}, {-0.05640002338965229, 
        0.04009161894122235}, {-0.055064861524327775`, 
        0.03913965874448095}, {-0.05375865728633129, 
        0.038217162756662384`}, {-0.05247931408518855, 
        0.037320541734353535`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07945326419882273, 0.09}, {-0.07921318452302256, 
        0.08960313646316534}, {-0.07815636705691012, 
        0.0878820353000245}, {-0.07787208182213108, 
        0.08742257667167613}, {-0.07758843101855925, 
        0.08696574837494256}, {-0.07631062422242005, 
        0.08502573838559165}, {-0.07503281742628086, 
        0.08308572839624073}, {-0.07375501063014166, 
        0.08114571840688982}, {-0.07270265452983223, 0.07954799537620696}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07253153365877882, 
        0.0792881938160391}, {-0.07247720383400247, 
        0.0792057084175389}, {-0.0713280967009152, 
        0.07767116764897455}, {-0.07007300161002046, 
        0.07580271105152715}, {-0.06883304765595535, 
        0.07398195671534875}, {-0.0676082348387199, 
        0.07220890464043937}, {-0.06639856956795336, 
        0.07048139808595266}, {-0.06540913719627321, 0.06908641703908434}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06522915977643186, 
        0.06883267044989944}, {-0.06520405825329498, 
        0.06879728031104233}, {-0.0640247008947448, 
        0.06715655131570837}, {-0.06286049749230278, 
        0.06555921109995076}, {-0.06171144804596896, 
        0.06400525966376953}, {-0.06057755255574331, 
        0.06249469700716466}, {-0.05945881102162585, 
        0.06102752313013616}, {-0.058355223443616565`, 
        0.05960373803268402}, {-0.05777725061171378, 0.05886840609829644}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05758500670408847, 
        0.0586238217914477}, {-0.05726684848514886, 
        0.05821904169511694}, {-0.05619374480965616, 
        0.05686913409774362}, {-0.055135912417138444`, 
        0.05555401524056405}, {-0.054093351307595725`, 
        0.05427368512357823}, {-0.05306606148102799, 
        0.053028143746786174`}, {-0.052054042937435256`, 
        0.05181739111018786}, {-0.051057295676817514`, 
        0.050641427213783306`}, {-0.05007581969917476, 
        0.049500252057572504`}, {-0.049655114269048006`, 
        0.049036334358681315`}}]}, 
      {Arrowheads[{{0.0054183833024499806`, 1.}}], 
       ArrowBox[{{-0.049446132540085515`, 
        0.04880588731457882}, {-0.049113418793544375`, 
        0.04843899926267436}, {-0.04816011248524209, 
        0.04733924613041639}, {-0.04722193437067201, 0.04627258392188374}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAATnoawTr4ir97FK5H4XqEvx1zXkcG
54q/Ugb5Fn5shL+CrBmdUruKv69cOBbgR4S/1AbIMdqPir9uhZJRYSOEvzHj
TLycZIq/P24bsAH/g78CzOr4X+uGv0tHSXixA4G/mv1jbzLUg7/JdzkDOXx8
v746NTUXooO/tEY5/gggfL/vCqVoYnCDv81wgdNNxHu/HxfpwWZcg7/b/Vlh
R597v9s2C7J7SIO//gWK/FN6e78uGHz6tSqDv96sdcsFQ3u/yqlDFPAWg78Y
OZklPR57vwm4zp86A4O/bGV9cYf5er+5ZsgnnkGCvxoqI5l1jnm/ZG6QSTqG
gb+ANLlIoyp4vwIhKvDg0IC/7D9eoe3Ndr/Gnxr/ESp7v0msg6SjX3C/gP2L
aHeydb+sPWmuSiFlvyHfWi/DU3G/F+2T56pVVr95ZKLV
        "]]}, 
      {Arrowheads[{{0.005964094210087843, 1.}}], 
       ArrowBox[{{-0.004031273092698627, -0.001124128828155404}, \
{-0.0032324102174013606`, -0.00014536360523991583`}, {-0.0017914473652382251`,
         0.0018328525720128289`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.1, 0.06037353297024523}, {-0.09977021909631256, 
        0.060218500387388185`}, {-0.0980264341104038, 
        0.059050587900988494`}, {-0.09755955859643264, 
        0.05873907764348295}, {-0.09709472999946023, 
        0.05842947509983312}, {-0.09509210686894753, 
        0.05713489616961247}, {-0.09308948373843487, 
        0.05584031723939181}, {-0.09108686060792219, 
        0.054545738309171164`}, {-0.08958011362428764, 
        0.053571714356053506`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08931885523364774, 
        0.05340282606014174}, {-0.08908423747740951, 
        0.05325115937895051}, {-0.08741079845599412, 
        0.052241890111868965`}, {-0.08546626663885155, 
        0.05099765994573169}, {-0.08356046236395571, 
        0.04978699562231666}, {-0.08169338563130663, 
        0.04860989714162387}, {-0.07986372500907178, 
        0.04746477436387238}, {-0.0787781553113838, 0.046790067257396206`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07851393649554696, 
        0.04662584904728081}, {-0.07807016906541872, 
        0.0463500371492812}, {-0.07631271780034742, 
        0.04526568549785035}, {-0.07459137121385788, 
        0.044211719409579825`}, {-0.07290612930595011, 
        0.043188138884469617`}, {-0.07125699207662411, 
        0.04219494392251973}, {-0.06964395952587989, 
        0.04123213452373017}, {-0.06806703165371743, 
        0.040299710688100926`}, {-0.06786825271539534, 
        0.040183126395285415`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06759990751633142, 
        0.04002574133463773}, {-0.06652362163635836, 
        0.039394497253936046`}, {-0.06501114265002433, 
        0.03851331905953957}, {-0.06352959469471534, 
        0.03765617610491151}, {-0.06207897777043136, 
        0.036823068390051845`}, {-0.06065929187717242, 
        0.036013995914960586`}, {-0.05927053701493851, 
        0.03522895867963773}, {-0.057912713183729626`, 
        0.034467956684083284`}, {-0.05679789395433291, 
        0.033848777266829264`}}]}, 
      {Arrowheads[{{0.004602636320315998, 1.}}], 
       ArrowBox[{{-0.05652582203543028, 
        0.03369792670933435}, {-0.05528760826782994, 
        0.033015585708174984`}, {-0.054015826490025086`, 
        0.0323192713196119}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.0658936487593563, 0.09}, {-0.06538849553299429, 
        0.08886398787290255}, {-0.06462459805088981, 
        0.08718045770875096}, {-0.06441852854738507, 
        0.08673095601130248}, {-0.06421265475975738, 
        0.08628399496294534}, {-0.06324632135104676, 
        0.08434675954670362}, {-0.062279987942336135`, 
        0.08240952413046192}, {-0.06131365453362552, 
        0.0804722887142202}, {-0.06047870237251683, 0.07879843693305749}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06033880151447058, 
        0.07852061967770663}, {-0.05944468001903004, 
        0.07700583091753355}, {-0.05848958642846514, 
        0.07514059780172656}, {-0.0575419860499974, 
        0.07332336621954273}, {-0.0566018788836268, 
        0.07155413617098204}, {-0.05566964055163681, 
        0.0698307223606414}, {-0.05474564667631088, 
        0.06815093949311773}, {-0.05442343454249343, 0.06757524925279018}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.05427149579040427, 
        0.06730378319821002}, {-0.05382989725764901, 
        0.06651478756841103}, {-0.052922392295651204`, 
        0.06492226658652128}, {-0.052023131790317464`, 
        0.0633733765474485}, {-0.051132115741647784`, 
        0.06186811745119269}, {-0.05024934414964217, 
        0.06040648929775383}, {-0.04937481701430061, 
        0.05898849208713194}, {-0.04850933510940195, 
        0.057609768548433665`}, {-0.047883603962767446`, 
        0.05662703514460686}}]}, 
      {Arrowheads[{{0.014383803611253871`, 1.}}], 
       ArrowBox[{{-0.047716517923640324`, 
        0.05636462047522929}, {-0.047653699208725045`, 
        0.05626596141076566}, {-0.04680790931226987, 
        0.05495707067412794}, {-0.04597196542003644, 
        0.05368309633852048}, {-0.04514586753202475, 
        0.0524440384039433}, {-0.044329615648234795`, 
        0.05123989687039639}, {-0.04352320976866658, 
        0.05007067173787975}, {-0.04272664989332011, 0.04893636300639338}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.046111684783003634`, 0.09}, {0.04563635834512085, 
        0.08956747781352123}, {0.04399308667391546, 0.08805301791978687}, {
        0.04355656754922513, 0.08764804395767506}, {0.043123541583462655`, 
        0.08724507669682416}, {0.04133523033757311, 0.08548742858008414}, {
        0.03954691909168356, 0.08372978046334412}, {0.037758607845794025`, 
        0.08197213234660408}, {0.03714738991864913, 0.08137139461650633}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.036925519636636005`, 0.08115332861471984}, {
        0.03597029659990448, 0.08021448422986406}, {0.03470280983690351, 
        0.07878456619658492}, {0.03300640879387666, 0.07708475280045564}, {
        0.03137128121942493, 0.07542349588473352}, {0.029797427113548332`, 
        0.07380079544941856}, {0.02828132515517936, 0.07221511132922713}, {
        0.028276725328165483`, 0.07221023354736017}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.028063292093189245`, 0.0719839031309701}, {
        0.026819454023250512`, 0.07066490335887554}, {0.025411813717761793`, 
        0.06915017153836382}, {0.0240584042387132, 0.06767091586769196}, {
        0.02275922558610473, 0.06622713634685996}, {0.021514277759936393`, 
        0.06481883297586782}, {0.02032356076020818, 0.06344600575471555}, {
        0.01972860376240301, 0.06274589483642999}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.01952715149726235, 0.06250883748462367}, {
        0.019187074586920094`, 0.06210865468340314}, {0.018097746238511743`, 
        0.06080372377253286}, {0.01704850271342273, 0.059528157032707}, {
        0.016039344011653054`, 0.05828195446392555}, {0.015070270133202716`, 
        0.0570651160661885}, {0.014141281078071718`, 0.05587764183949587}, {
        0.013252376846260058`, 0.05471953178384764}, {0.012403557437767738`, 
        0.05359078589924383}, {0.011794379321476115`, 
        0.052762678268347435`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01161003636950828, 0.05251208521330498}, {
        0.011594822852594755`, 0.052491404185684425`}, {0.010076744898946575`,
         0.050370675830453175`}, {0.00867727973205529, 0.04834728927690822}, {
        0.007396427351920897, 0.04642124452504955}, {0.006234187758543397, 
        0.04459254157487718}, {0.005089323448394855, 0.04271351917860865}, {
        0.004750278875515395, 0.04213607249049644}}]}, 
      {Arrowheads[{{0.0017652933195863722`, 1.}}], 
       ArrowBox[{{0.0045927656584901335`, 0.041867802496575984`}, {
        0.0040366515989676294`, 0.04092065204034947}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.053605998144226855`, 0.09}, {-0.05354410736358446, 
        0.0897851849521474}, {-0.05304399048013753, 
        0.08810278587835102}, {-0.05290831373475501, 
        0.08765351667388938}, {-0.05277241806732478, 
        0.08720675491753033}, {-0.05210729885848943, 
        0.08526579779457304}, {-0.05144217964965407, 
        0.08332484067161575}, {-0.05077706044081872, 
        0.08138388354865846}, {-0.05011194123198337, 
        0.07944292642570117}, {-0.04958528711579942, 0.0782306549247122}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.049461329223177725`, 
        0.07794532416220575}, {-0.049444510279026604`, 
        0.07790660970798509}, {-0.0487789831153463, 
        0.07603705971536448}, {-0.04811318398176936, 
        0.07421511447630166}, {-0.047447112878295776`, 
        0.07244077399079664}, {-0.046781513503549386`, 
        0.07071189244701023}, {-0.04611712955615402, 
        0.06902632403310327}, {-0.04545396103610967, 
        0.06738406874907574}, {-0.04501538604433838, 0.06632469452779213}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04489638946539274, 
        0.0660372592874771}, {-0.04479200794341634, 
        0.06578512659492766}, {-0.04413127027807403, 
        0.06422949757065903}, {-0.04347174804008274, 
        0.06271718167626983}, {-0.04281344122944247, 
        0.06124817891176009}, {-0.04215634984615322, 
        0.059822489277129784`}, {-0.04150200989034069, 
        0.0584358358320344}, {-0.040851957362130584`, 
        0.05708394163612941}, {-0.040206192261522895`, 
        0.055766806689414826`}, {-0.03969126690840453, 
        0.05473742127716114}}]}, 
      {Arrowheads[{{0.008644843092306773, 1.}}], 
       ArrowBox[{{-0.03955177202903357, 
        0.05445935816261221}, {-0.038294621525314355`, 
        0.05202395734441344}, {-0.03704167817252078, 0.04970252069369783}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.020964059736796842`, -0.01}, {
        0.020732356747099615`, -0.009643514540879996}, {
        0.019602954451875088`, -0.007987648182516892}, {
        0.01952813666332207, -0.00788081871386405}, {
        0.019453517821858047`, -0.007774604833480265}, {
        0.01942664362507935, -0.007736502080997622}, {
        0.019399795481118212`, -0.007698478584231751}, {
        0.019359565616733538`, -0.007641571859692891}, {
        0.019332776122927695`, -0.007603726148723387}, {
        0.019306012709524045`, -0.0075659592143791435`}, {
        0.019039815491424687`, -0.007192574876266313}, {
        0.018776234953302454`, -0.006826895631697037}, {
        0.018515277787654195`, -0.006468767096951754}, {
        0.017249786070780208`, -0.004780852801752165}, {
        0.01604975073719789, -0.003261023896914851}, {
        0.014914550471508924`, -0.0018937124212056286`}, {
        0.013843563958314986`, -0.000663350413390312}, {
        0.013377700867190642`, -0.00015222858007109404`}}]}, 
      {Arrowheads[{{0.0007941616841193409, 1.}}], 
       ArrowBox[{{0.013168139625813683`, 0.00007769160018343782}, {
        0.012835288609057551`, 0.0004428791953113604}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, -0.006174636964379212}, {
        0.049711693853217914`, -0.006050246864432056}, {
        0.0478421836570975, -0.005253827402413474}, {
        0.047594605910184745`, -0.005149072182074649}, {
        0.04734825077956444, -0.005044999625462758}, {
        0.04556964224946935, -0.0043235410312579756`}, {
        0.04379103371937426, -0.003602082437053193}, {
        0.04201242518927917, -0.0028806238428484105`}, {
        0.040233816659184074`, -0.0021591652486436285`}, {
        0.03900453124963063, -0.0017194768958723983`}, {
        0.038467396768188854`, -0.0015049211816373493`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03817849839859091, -0.0013895221555609585`}, {
        0.03732286209374877, -0.0010477424619205961`}, {
        0.035705819187342405`, -0.00040915746813744737`}, {
        0.03415340253041152, 0.00019627808547704887`}, {0.032661493096013135`,
         0.0007711130465960919}, {0.031225971857204257`, 
        0.0013178962628928844`}, {0.029846838813984894`, 
        0.0018366277343674253`}, {0.028524093966355038`, 
        0.002327307461019714}, {0.026551317342271313`, 
        0.003042069631739294}}]}, 
      {Arrowheads[{{0.00036080249362804194`, 1.}}], 
       ArrowBox[{{0.02625882952530116, 0.0031480417040025267`}, {
        0.026047768857863855`, 0.0032245116798575377`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04227744793920881, 0.09}, {-0.04211050302517107, 
        0.08887875607140483}, {-0.041850209354059115`, 
        0.08723332628110643}, {-0.04177857922937289, 
        0.08679386742769742}, {-0.04170637469760865, 
        0.08635683356498171}, {-0.041309365114890736`, 
        0.08441923232953852}, {-0.04091235553217283, 
        0.08248163109409534}, {-0.040515345949454926`, 
        0.08054402985865215}, {-0.04011833636673702, 
        0.07860642862320896}, {-0.03987586473210425, 0.07779737562528542}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0397865552000806, 
        0.07749937728524735}, {-0.03965980850422449, 
        0.07707646268571247}, {-0.03925194275448401, 
        0.0752107970910834}, {-0.0388368395600618, 
        0.07339308859033042}, {-0.03841449892095787, 
        0.07162333718345351}, {-0.03798602083167702, 
        0.06989936407712022}, {-0.03755250528672404, 
        0.06821899047799806}, {-0.03711395228609893, 
        0.06658221638608705}, {-0.03679147739894732, 0.06542403368147623}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.036708033168055286`, 
        0.06512434006541715}, {-0.036670361829801684`, 
        0.06498904180138719}, {-0.03622173391783231, 
        0.06343946672389847}, {-0.0357680685501908, 
        0.06193349115362087}, {-0.03530936572687717, 
        0.06047111509055443}, {-0.03484562544789141, 
        0.059052338534699135`}, {-0.034379101817945644`, 
        0.057672818583410085`}, {-0.033912048941751996`, 
        0.05632821233404238}, {-0.03344446681931047, 
        0.05501851978659604}, {-0.03297635545062107, 
        0.05374374094107105}, {-0.032810303762214464`, 
        0.05331085398558541}}]}, 
      {Arrowheads[{{0.006964468755084863, 1.}}], 
       ArrowBox[{{-0.032698886837463643`, 
        0.053020396635782036`}, {-0.03203854497449862, 
        0.05129892435578514}, {-0.031098617513384667`, 
        0.04899376257818465}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.005552325839209739}, {0.04868504555069893, 
        0.005768957196389571}, {0.04666823160985543, 0.006094066850029587}, {
        0.04640183618377472, 0.006136506018758786}, {0.04613691572316731, 
        0.006178593265308841}, {0.04436833063103239, 0.006440445126829607}, {
        0.04259974553889748, 0.006702296988350373}, {0.040831160446762556`, 
        0.0069641488498711395`}, {0.039062575354627635`, 
        0.007226000711391905}, {0.037856905919812854`, 
        0.007366811648759523}, {0.03769369765254001, 0.007390325384337905}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03738578332685692, 0.007434687205928744}, {
        0.03618765888485208, 0.007607303347194438}, {0.03458463722134073, 
        0.007833554936905454}, {0.03304784092927881, 0.00804556641789257}, {
        0.03157291345674058, 0.00824452575954817}, {0.030155498251800302`, 
        0.008431620931264637}, {0.028795595314457984`, 0.00860685193304197}, {
        0.027493204644713623`, 0.00877021876488017}, {0.025060960108018764`, 
        0.009061359918739171}, {0.025049391147349987`, 
        0.009062640084891369}}]}, 
      {Arrowheads[{{0.006286126684147653, 1.}}], 
       ArrowBox[{{0.02474018487836643, 0.00909685537967305}, {
        0.022858764641715726`, 0.00930504439284164}, {0.02085109205392724, 
        0.00951133705109265}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.047489733297032224`}, {-0.09893518623945069, 
        0.0469630083334705}, {-0.09710014213802651, 
        0.04606131322188608}, {-0.09660926962865521, 
        0.045820940788160874`}, {-0.09612074691202237, 
        0.04558209965708621}, {-0.09412473726203624, 
        0.04463159819343779}, {-0.0921287276120501, 
        0.043681096729789363`}, {-0.09013271796206397, 
        0.042730595266140946`}, {-0.08878881494779606, 
        0.04209062752747192}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08850794198414828, 
        0.04195687558742076}, {-0.08813670831207783, 
        0.04178009380249252}, {-0.08647795445611979, 
        0.04103724746133017}, {-0.08454146053449156, 
        0.04012339101929693}, {-0.08264464376510193, 
        0.03923396459167383}, {-0.0807875041479509, 
        0.03836896817846085}, {-0.07896861326298352, 
        0.03752725836078348}, {-0.07721890439680058, 
        0.036722574730364894`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07693598452087547, 
        0.03659320901899968}, {-0.07544129242943502, 
        0.035910268255412055`}, {-0.07373286248085388, 
        0.035134987967717995`}, {-0.07206125284440149, 
        0.03438185085668504}, {-0.07042646352007784, 
        0.03365085692231319}, {-0.0688284945078829, 
        0.03294200616460244}, {-0.06726734580781674, 
        0.03225529858355279}, {-0.06574018759632275, 
        0.03158845207023587}, {-0.06557502396270729, 0.03151677054325452}}]}, 
      {Arrowheads[{{0.01635801412253641, 1.}}], 
       ArrowBox[{{-0.06528964809195438, 
        0.03139291653416419}, {-0.06424419004984436, 
        0.03093918451572329}, {-0.0627793531683816, 
        0.030307495920015054`}, {-0.06134567695193447, 
        0.02969338628311116}, {-0.05994316140050295, 
        0.02909685560501162}, {-0.05857180651408706, 
        0.028517903885716418`}, {-0.057231612292686786`, 
        0.02795653112522556}, {-0.05592257873630213, 
        0.027412737323539046`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.031169007877470872`, 0.09}, {0.030779754936250042`, 
        0.0895534498254251}, {0.029457935181614953`, 0.08801476703227996}, {
        0.02910722360153911, 0.08760340099174549}, {0.028759513645453896`, 
        0.08719411541151348}, {0.027217811419504176`, 0.08525163734488622}, {
        0.025676109193554453`, 0.08330915927825895}, {0.024134406967604733`, 
        0.0813666812116317}, {0.023322846209530988`, 0.08034414978775538}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.0231294483762217, 0.0801004768896994}, {
        0.022592704741655013`, 0.07942420314500442}, {0.021573776315525334`, 
        0.07788381138991651}, {0.020124328289543858`, 0.07601228973120797}, {
        0.01873638306354121, 0.07418807234444522}, {0.01740994063751739, 
        0.07241115922962828}, {0.016141057421715115`, 0.07067945523367876}, {
        0.01572639607772261, 0.07010329158540511}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.01554467358079021, 0.06985079180860446}, {
        0.0149257898263771, 0.06899086520351827}, {0.013764137851503348`, 
        0.06734538913914682}, {0.012656101497093859`, 0.06574302704056441}, {
        0.011601680763148629`, 0.06418377890777101}, {0.010600875649667663`, 
        0.06266764474076666}, {0.009653686156650956, 0.06119462453955134}, {
        0.008760112284098513, 0.059764718304125046`}, {0.008611499333905582, 
        0.059520931322681846`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0084495716210724, 0.059255302598722366`}, {
        0.007912182394993292, 0.058373761002812684`}, {0.007101924852318265, 
        0.05701758760393913}, {0.0063293396560734246`, 0.0556961981075044}, {
        0.005594426806258773, 0.054409592513508465`}, {0.00489718630287431, 
        0.053157770821951354`}, {0.004237618145920036, 0.05194073303283306}, {
        0.0036157223353959515`, 0.05075847914615357}, {0.0030314988713020553`,
         0.0496110091619129}, {0.002425807462129314, 0.04837270224352412}}]}, 
      {Arrowheads[{{0.008407071779689166, 1.}}], 
       ArrowBox[{{0.002289117940475012, 0.048093247098920114`}, {
        0.0019535016982780602`, 0.04740709585367833}, {0.0009810593427212761, 
        0.04531566806105969}, {0.00011417180463170527`, 
        0.04333672578405697}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.01650051552480703}, {0.049545588845954676`, 
        0.01648258856277242}, {0.04731445352312342, 0.016386711412556185`}, {
        0.045184511473908125`, 0.016286969743918796`}, {0.044903745470903804`,
         0.016273241105010952`}, {0.04462466660478802, 0.01625945982660611}, {
        0.04286540810694297, 0.016152112093547003`}, {0.04110614960909792, 
        0.016044764360487896`}, {0.03934689111125287, 
        0.015937416627428785`}, {0.03758763261340782, 
        0.015830068894369678`}, {0.03757482589235829, 0.01582885010954634}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03726513160168269, 0.0157993772491717}, {
        0.03640236318241227, 0.0157172696549331}, {0.03474439687283478, 
        0.01560895989133679}, {0.033153958688769, 0.015500008774049013`}, {
        0.03163104863021492, 0.01539041630306977}, {0.030171137404908892`, 
        0.015280473205279256`}, {0.028769695720587275`, 
        0.015170470207557673`}, {0.027426723577250067`, 
        0.015060407309905016`}, {0.02614222097489726, 
        0.014950284512321289`}, {0.024859573192703904`, 
        0.014832166021563073`}}]}, 
      {Arrowheads[{{0.007956686451064945, 1.}}], 
       ArrowBox[{{0.024549790414274766`, 0.014803638256763632`}, {
        0.02374862439314487, 0.014729859217360622`}, {0.0215889059753301, 
        0.014509194322675669`}, {0.019625970022868, 0.01429096338557867}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.0028867027938277025`, 0.09}, {-0.0033030923402870764`, 
        0.08889098805102871}, {-0.0034625685658892123`, 
        0.08845999131430304}, {-0.0036201265403607795`, 
        0.08803126865762116}, {-0.0042465457185662265`, 
        0.0860864234624971}, {-0.004872964896771674, 
        0.08414157826737304}, {-0.005499384074977121, 
        0.08219673307224898}, {-0.006125803253182569, 
        0.08025188787712491}, {-0.0064571213819737145`, 
        0.0787077421349278}, {-0.006630165795769888, 0.07814308198025476}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.006721318471033699, 
        0.07784564225027912}, {-0.007031463904400168, 
        0.07683360860796731}, {-0.0075710886563072925`, 
        0.07500661619311588}, {-0.008075995637695087, 
        0.07322676489037351}, {-0.008548656537487742, 
        0.07149196269528885}, {-0.008991543044609447, 
        0.06980011760341057}, {-0.009404655159060206, 
        0.06815122961473864}, {-0.009787992880840014, 
        0.06654529872927309}, {-0.009949578447387076, 0.06583098821313131}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.010018217247543407`, 
        0.06552756125604142}, {-0.010141556209948874`, 
        0.06498232494701392}, {-0.010465345146386784`, 
        0.06346230826796112}, {-0.010759359690153746`, 
        0.061985248692114685`}, {-0.01102359984124976, 
        0.06055114621947462}, {-0.011263068704483563`, 
        0.05915583654900888}, {-0.0114827693846639, 
        0.05779515537968545}, {-0.01168270188179077, 
        0.05646910271150431}, {-0.011862866195864174`, 
        0.05517767854446545}, {-0.012095199712712536`, 
        0.05326438923378711}}]}, 
      {Arrowheads[{{0.004194372746831746, 1.}}], 
       ArrowBox[{{-0.012132700782235651`, 
        0.05295556424619648}, {-0.012163890274850576`, 
        0.052698715713814626`}, {-0.01238584162162311, 
        0.05035826688773297}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.018586381029883223`, 0.09}, {0.017800308438313817`, 
        0.08884398376959822}, {0.017516472516794113`, 0.08842281574587862}, {
        0.0172352660185111, 0.0880038118802707}, {0.016029440239412766`, 
        0.08605852170597786}, {0.014823614460314428`, 0.084113231531685}, {
        0.013617788681216091`, 0.08216794135739215}, {0.012411962902117754`, 
        0.0802226511830993}, {0.012019890982595517`, 0.07943653607354917}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.011881045020567612`, 0.07915814605576069}, {
        0.011641194114121171`, 0.07867723831356226}, {0.01051214309815844, 
        0.0768025147224616}, {0.009434275257619442, 0.07497483552015577}, {
        0.00840759059250418, 0.07319420070664472}, {0.007428740920585354, 
        0.07145853470015434}, {0.006494378059635661, 0.06976576191891048}, {
        0.005727983128449443, 0.06834482320636535}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.005580769075004181, 0.06807076882253117}, {
        0.004759112770643682, 0.06650889603216235}, {0.003958210342601395, 
        0.06494480292665808}, {0.0032017947255282408`, 0.06342360304640034}, {
        0.0024898659194242207`, 0.06194529639138911}, {0.0018224239242893348`,
         0.06050988296162442}, {0.001192701812556405, 
        0.059113234600222817`}, {0.0005939326566582522, 
        0.05775122315030086}, {0.00020883304974313595`, 
        0.05685098216928233}}]}, 
      {Arrowheads[{{0.006785169633446405, 1.}}], 
       ArrowBox[{{0.00008648003211638418, 0.056564959543860226`}, {
        0.000026116456594876564`, 
        0.056423848611858556`}, {-0.0005107467876337205, 
        0.0551311109848959}, {-0.0014916144085865852`, 
        0.052649546465409536`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, -0.006060598250332016}, {-0.09996253066220036, \
-0.006058120269803848}, {-0.09933658813323012, -0.006016051405523142}, \
{-0.09871443245955334, -0.0059739275975261835`}, {-0.09671229620733926, \
-0.005824677246190567}, {-0.09471015995512518, -0.005675426894854951}, \
{-0.09270802370291108, -0.005526176543519335}, {-0.09070588745069699, \
-0.005376926192183719}, {-0.08903873180742214, -0.00522696659089071}, \
{-0.08759239559447886, -0.005115775255486879}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.08728221729437632, -0.005091929389571992}, \
{-0.08709570978031497, -0.005077591077797906}, {-0.08519209723661242, \
-0.004928132123533645}, {-0.08332789417631448, -0.004778589728097926}, \
{-0.08150165688772879, -0.004629064347744185}, {-0.07971194165916297, \
-0.0044796564387258545`}, {-0.07795874849061704, -0.004330366001042937}, \
{-0.076242077382091, -0.004181193034695432}, {-0.07488136662284578, \
-0.004060476711362149}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07457149010873959, -0.004032985818667964}, \
{-0.07456192833358484, -0.0040321375396833396`}, {-0.07291830134509857, \
-0.0038831995160066588`}, {-0.07131119641663217, -0.003734378963665391}, \
{-0.06974061354818566, -0.003585675882659535}, {-0.06820368371926164, \
-0.0034372917846967888`}, {-0.06669753790936273, -0.00328942818148485}, \
{-0.06522217611848893, -0.003142085073023719}, {-0.06377759834664024, \
-0.002995262459313395}, {-0.06236380459381664, -0.0028489603403538777`}, \
{-0.06218612172408876, -0.002830230973011067}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.061876742181699834`, -0.0027976195957487167`}, \
{-0.06098079486001816, -0.002703178716145169}, {-0.05962856914524479, \
-0.002557917586687267}, {-0.058307127449496524`, -0.0024131769519801726`}, \
{-0.05576852640089972, -0.002124586596887437}, {-0.0532973867612228, \
-0.0018412075471424512`}, {-0.050939838968986795`, -0.0015604469323454704`}, \
{-0.04951369873563841, -0.0013842196553465168`}}]}, 
      {Arrowheads[{{0.0008321462547187443, 1.}}], 
       ArrowBox[{{-0.049204953422253075`, -0.0013460681856720792`}, \
{-0.04869111090986193, -0.001282572980468881}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.03201321012690179, 0.09}, {-0.031985814095368846`, 
        0.08847917555288815}, {-0.031941212887704504`, 
        0.08685842929562965}, {-0.031927174207736934`, 
        0.08642550598466471}, {-0.031912236277495794`, 
        0.08599494596096598}, {-0.03176579010016286, 
        0.08405872117373887}, {-0.031619343922829925`, 
        0.08212249638651178}, {-0.031472897745497, 
        0.08018627159928468}, {-0.03132645156816406, 
        0.07825004681205759}, {-0.031211864088909146`, 
        0.07758959245401835}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03115868445315666, 
        0.07728307796901485}, {-0.03106145074606487, 
        0.07672264653257299}, {-0.03089408316083201, 
        0.07485856724671222}, {-0.03071276797033253, 
        0.07304258496176234}, {-0.030517505174566435`, 
        0.07127469967772333}, {-0.030309740345220708`, 
        0.06955272042407513}, {-0.030090919053982344`, 
        0.06787445623029766}, {-0.02986104130085134, 
        0.0662399070963909}, {-0.02966305876888214, 0.06493267326125614}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.029616207200458614`, 
        0.06462512933173338}, {-0.029368116408911422`, 
        0.06310195400818955}, {-0.029105069270102504`, 
        0.06159855005389496}, {-0.028830965669400948`, 
        0.06013886115947109}, {-0.02854580560680675, 
        0.05872288732491794}, {-0.028252538816126833`, 
        0.057346261793841745`}, {-0.027954115031168104`, 
        0.056004617809848736`}, {-0.02765053425193057, 
        0.05469795537293891}, {-0.027341796478414226`, 
        0.05342627448311226}, {-0.02708738135361647, 
        0.052446143980296706`}}]}, 
      {Arrowheads[{{0.00576213667513115, 1.}}], 
       ArrowBox[{{-0.02700922020717884, 
        0.052145029320468786`}, {-0.02670884994854511, 
        0.050987857344708516`}, {-0.02605527544156076, 
        0.048689366394637494`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{-0.0225364607125842, 0.09}, {-0.022553934768255984`, 
        0.08984809124152976}, {-0.02272665159866473, 
        0.08821362586336245}, {-0.02288012760829096, 
        0.0866134575866172}, {-0.0229189744601155, 
        0.08618597799555776}, {-0.02295662249570405, 
        0.08576080806623351}, {-0.023046012588901998`, 
        0.08382542114136655}, {-0.023135402682099945`, 
        0.08189003421649961}, {-0.02322479277529789, 
        0.07995464729163265}, {-0.023314182868495837`, 
        0.07801926036676571}, {-0.023290319303592724`, 
        0.07758603764381444}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.023273209018779585`, 
        0.07727541497669348}, {-0.023230131542118358`, 
        0.07649338002873768}, {-0.023288914325979466`, 
        0.07463025897213643}, {-0.023327292236949345`, 
        0.07281531516104564}, {-0.023345265275027997`, 
        0.0710485485954653}, {-0.023344616138330807`, 
        0.06932776215645078}, {-0.02332712752497316, 
        0.0676507587250574}, {-0.02329279943495505, 
        0.06601753830128516}, {-0.023254742029949694`, 
        0.06483534678029441}}]}, 
      {Arrowheads[{{0.018243026704388283`, 1.}}], 
       ArrowBox[{{-0.023244732413628476`, 
        0.06452441429444446}, {-0.023241631868276484`, 
        0.06442810088513407}, {-0.02317362482493746, 
        0.06288244647660411}, {-0.02308877830493797, 
        0.06138057507569531}, {-0.02298709230827803, 
        0.05992248668240765}, {-0.022868566834957627`, 
        0.05850818129674113}, {-0.02259551130474833, 
        0.055793406182350846`}, {-0.02228412556072296, 
        0.05321873636660376}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.0075727827312991785`, 0.09}, {0.007145295983323975, 
        0.08918627113834743}, {0.006337695754188694, 0.08761594119062467}, {
        0.006124250830965275, 0.08719625833046288}, {0.005913016803663897, 
        0.0867787634789826}, {0.005025335993992986, 0.08483867497055546}, {
        0.004137655184322075, 0.08289858646212833}, {0.003249974374651163, 
        0.08095849795370119}, {0.002362293564980252, 0.07901840944527407}, {
        0.002269643985729069, 0.07874793436852542}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0021688312813616206`, 0.07845362840220152}, {
        0.0018363877096768304`, 0.07748311454458046}, {0.0010125495390119464`,
         0.07561446020222394}, {0.00023127312768441517`, 
        0.07379342863724786}, {-0.0005074415243057654, 
        0.07202001984965217}, {-0.001206519662032416, 
        0.07029209864946266}, {-0.001868886530569356, 
        0.06860752984670505}, {-0.002494542129916588, 
        0.06696631344137935}, {-0.0025092353015034765`, 
        0.06692644941885922}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.002616823443961818, 
        0.06663455218561079}, {-0.003083486460074111, 
        0.06536844943348555}, {-0.0036357195210419244`, 
        0.06381393782302366}, {-0.0041512413128200285`, 
        0.06230277860999369}, {-0.004630051835408424, 
        0.06083497179439563}, {-0.005072151088807111, 
        0.05941051737622946}, {-0.005483461312324394, 
        0.058025165546776725`}, {-0.005869904745268575, 
        0.056674666497318935`}, {-0.006231481387639655, 
        0.05535902022785609}, {-0.00638361406924522, 
        0.054780330453573486`}}]}, 
      {Arrowheads[{{0.0006667877352075069, 1.}}], 
       ArrowBox[{{-0.0064627103626938255`, 
        0.054479460083582655`}, {-0.006568191239437634, 
        0.05407822673838819}}]}}}}, 
   {PointSize[0.025], PointBox[{0, 0.08}]}, 
   {PointSize[0.025], PointBox[{0, 0.01}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.08}, {0.05, 0.08}}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.01}, {0.05, 0.01}}]}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0.09}, {0, -0.01}}]}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwVy3k8lAkcx3FF16s1M+TIoBy5jxR2ifph1IZSq9IhuUtExcikw9FjNGbm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      "]]}}},
  AspectRatio->1,
  BaseStyle->{FontWeight -> "Bold", FontSize -> 12},
  Frame->True,
  ImageMargins->{{10., 11.}, {9.5, 10.}},
  ImageSize->{480., Automatic},
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{-0.1027733900410869, 0.0527733900410869}, {-0.0127733900410869,
    0.0927733900410869}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Input",
 CellChangeTimes->{{3.704148789221258*^9, 3.704148789283657*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.036785746414043155`, 0.09}, {-0.036739933790758524`, 
        0.08934491541648468}, {-0.036609109144105735`, 
        0.08765810161394799}, {-0.03646777840468362, 
        0.08600493496720509}, {-0.036315941572492176`, 
        0.08438541547625594}, {-0.03615359864753141, 
        0.08279954314110058}, {-0.03598074962980132, 
        0.08124731796173898}, {-0.03579739451930191, 
        0.07972873993817116}, {-0.035603533316033165`, 
        0.0782438090703971}, {-0.03551620864078092, 0.07762368598170122}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.03547282897002875, 
        0.07731563175377834}, {-0.0353991660199951, 
        0.07679252535841682}, {-0.03518429263118771, 
        0.07537488880223031}, {-0.03495891314961099, 
        0.07399089940183758}, {-0.03448733877361775, 
        0.07130901733007086}, {-0.03399514575748356, 
        0.06873203440475416}, {-0.033482334101208405`, 
        0.06625995062588745}, {-0.03321675112104059, 0.06508138249147787}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.033148362994586955`, 
        0.0647778989378281}, {-0.0329489038047923, 
        0.06389276599347074}, {-0.032405164188305705`, 
        0.061578030934279035`}, {-0.03186142457181912, 
        0.05926329587508733}, {-0.03131768495533253, 
        0.056948560815895624`}, {-0.030681104592480916`, 
        0.05535166799660556}, {-0.02990571980627977, 0.05278201163278158}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.029815850635978376`, 
        0.052484181588284606`}, {-0.029125812246149373`, 
        0.05019736661427121}, {-0.0283481660729836, 
        0.04762021592310403}, {-0.027530484977698628`, 
        0.04606244175090883}, {-0.02693461689241114, 
        0.04454572108020045}, {-0.026340703572994312`, 
        0.043088522625542754`}, {-0.025748745019448148`, 
        0.04169084638693575}, {-0.025392587537077495`, 
        0.04088306586475385}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.025267081468008247`, 
        0.04059841269016675}, {-0.02515874123177265, 
        0.040352692364379446`}, {-0.025079205468728955`, 
        0.04017602111843744}, {-0.02499973803881323, 
        0.04000034785238884}, {-0.024152659715359116`, 
        0.03835061457152353}, {-0.023305581391904997`, 
        0.03670088129065822}, {-0.02245850306845088, 
        0.03505114800979291}, {-0.021611424744996763`, 
        0.033401414728927596`}, {-0.020919671713067294`, 
        0.03250252261029406}, {-0.020100003735176352`, 
        0.030985290710999057`}, {-0.019360428519558506`, 
        0.0296666175768568}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.019205435922526836`, 
        0.029396896805856332`}, {-0.01851548847052081, 
        0.028215829675549683`}, {-0.017750310623539663`, 
        0.026956007519731845`}, {-0.017002745219834196`, 
        0.02576933357896728}, {-0.016272792259404412`, 
        0.02465580785325599}, {-0.01556045174225031, 
        0.02361543034259797}, {-0.014188608037769147`, 
        0.021754119966441766`}, {-0.012887214106390713`, 
        0.02018540245049866}, {-0.012040856588833146`, 
        0.019256596375403275`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.011831323040149002`, 
        0.019026650957637323`}, {-0.01166347719570642, 
        0.018842454283343375`}, {-0.010524604553307679`, 
        0.017658451953550626`}, {-0.009470596179194496, 
        0.01663339546112042}, {-0.008501452073366864, 
        0.015767284806052745`}, {-0.006808806022165904, 
        0.014360426837382981`}, {-0.005437715755302435, 
        0.013286403876919302`}, {-0.0032506552473375245`, 
        0.011727935569477436`}, {-0.0022692587584729803`, 
        0.011121762943206251`}}]}, 
      {Arrowheads[{{0.0015839870050487392`, 1.}}], 
       ArrowBox[{{-0.002004582906287722, 
        0.010958282374190434`}, {-0.001935008050949549, 
        0.010915308537151773`}, {-0.0011405670109927812`, 
        0.010484443052274188`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, 0.04166482525099589}, {-0.09890083428720697, 
        0.04120185270289407}, {-0.0973236447721784, 
        0.040541544581361715`}, {-0.09577305861155921, 
        0.0398964516581652}, {-0.09424691474188278, 
        0.03926494425946741}, {-0.09274305209968248, 
        0.03864539271143121}, {-0.0912614706849583, 
        0.038037797014056615`}, {-0.08980217049771023, 
        0.03744215716734362}, {-0.0884993753624347, 0.03691299179661348}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08821104011642662, 
        0.036796193191623285`}, {-0.08695041380564252, 
        0.03628674502590243}, {-0.08555795730082286, 
        0.035726972731174235`}, {-0.08418778202347932, 
        0.035179156287107646`}, {-0.08282874735987375, 
        0.03463731776837182}, {-0.08146971269626818, 
        0.034095479249635983`}, {-0.08011067803266261, 
        0.033553640730900156`}, {-0.07875164336905704, 
        0.03301180221216432}, {-0.07739260870545148, 
        0.03246996369342849}, {-0.07665660446671965, 0.03217652346178662}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07636763136039335, 
        0.032061311713271735`}, {-0.07603357404184591, 
        0.03192812517469266}, {-0.07394843546343237, 
        0.0311702468606349}, {-0.0725237288911372, 
        0.03062544674190017}, {-0.07112400924435223, 
        0.030092996846251364`}, {-0.06974927652307747, 
        0.02957289717368848}, {-0.06839953072731292, 
        0.02906514772421152}, {-0.06707477185705857, 
        0.028569748497820478`}, {-0.06577499991231443, 
        0.028086699494515362`}, {-0.06471479018816642, 
        0.027696542000313896`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06442283785912424, 
        0.027589103456287224`}, {-0.06325041679935678, 
        0.027157652157162898`}, {-0.06291628454490748, 
        0.02703554339833693}, {-0.06258384601755619, 
        0.026914251037065025`}, {-0.06072121500946996, 
        0.02625814529058758}, {-0.05885858400138373, 
        0.025602039544110135`}, {-0.0569959529932975, 
        0.024945933797632693`}, {-0.05513332198521127, 
        0.024289828051155246`}, {-0.053727378418023, 
        0.023839193467083398`}, {-0.052679741617837714`, 
        0.023474794272170838`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.052385915076277545`, 
        0.02337259267408882}, {-0.051945339311271696`, 
        0.02321934733750106}, {-0.050217028138743694`, 
        0.02262367428584879}, {-0.04854244490043897, 
        0.02205217431212659}, {-0.046918802204351136`, 
        0.021503297453372053`}, {-0.045343312658473786`, 
        0.020975493746622775`}, {-0.04381597626280692, 
        0.02046876319187875}, {-0.042336793017350535`, 
        0.019983105789139984`}, {-0.04090576292210464, 
        0.019518521538406476`}, {-0.04058801470470004, 
        0.019416614523812024`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04029178333736179, 
        0.019321608312538034`}, {-0.039522885977069225`, 
        0.019075010439678224`}, {-0.038188162182244294`, 
        0.018652572492955228`}, {-0.03690159153762985, 
        0.018251207698237487`}, {-0.034450659812832594`, 
        0.017499090210587518`}, {-0.03214784091647765, 
        0.016806050622498046`}, {-0.029993134848565008`, 
        0.016172088933969077`}, {-0.02838392376272373, 0.0157110541073379}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02808486179880362, 
        0.015625373625826795`}, {-0.02798654160909468, 
        0.01559720514500061}, {-0.026111111962652235`, 
        0.015072643884984959`}, {-0.024349896673823243`, 
        0.014589649783314437`}, {-0.022702895742607712`, 
        0.014148222839989046`}, {-0.021170109169005635`, 
        0.013748363055008785`}, {-0.01948304248011406, 
        0.013319609479574354`}, {-0.017906010230796725`, 
        0.012928370477677724`}, {-0.016439012421053636`, 
        0.012574646049318896`}, {-0.01604552898783709, 
        0.012482953567394053`}}]}, 
      {Arrowheads[{{0.016573577136268666`, 1.}}], 
       ArrowBox[{{-0.015742552770844215`, 
        0.01241235176067202}, {-0.015082049050884786`, 
        0.012258436194497874`}, {-0.01269822562926982, 
        0.011738560205469236`}, {-0.010754539965951822`, 
        0.01136874251059181}, {-0.009139432360254886, 
        0.011099953721304406`}, {-0.007741343111503107, 
        0.010883164449045838`}, {-0.006560272219696479, 
        0.010718374693816106`}, {-0.005596219684835006, 
        0.010605584455615208`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.08576508954823489}, {0.049096241846110736`, 
        0.08501315528260978}, {0.04793271776916072, 0.08403786340113932}, {
        0.04679226858285984, 0.08307469890645183}, {0.045674552941541935`, 
        0.08212353690030533}, {0.04457922949954082, 0.08118425248445785}, {
        0.04350595691119036, 0.0802567207606674}, {0.042454393830824354`, 
        0.079340816830692}, {0.04055374380780476, 0.0776656495994284}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.04032102800451664, 0.07745920087697092}, {
        0.038458409675881704`, 0.07579098108410143}, {0.03658179965899686, 
        0.07408258261940504}, {0.034782469995397206`, 0.07241719817919348}, {
        0.033057689919753414`, 0.07079382857753094}, {0.03137904968359062, 
        0.06918776671382465}, {0.03119121900233015, 0.06900515433954178}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03096816603268719, 0.06878829822155295}, {
        0.029768857504677757`, 0.06762230885108488}, {0.02822459221209269, 
        0.06609648421211439}, {0.0267438437930469, 0.06460934961830485}, {
        0.025324261813368082`, 0.06315997629085468}, {0.023963598997918768`, 
        0.06174746184852653}, {0.022659700767136946`, 0.06037093278544914}, {
        0.02224026683157229, 0.05992055841783621}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.02202824946066489, 0.05969290113679902}, {
        0.021410433468379387`, 0.05902951064014751}, {0.021166950018256248`, 
        0.058765361481414646`}, {0.020925554166709045`, 
        0.05850257593445551}, {0.020686230109113, 0.05824114734614614}, {
        0.02056734058122753, 0.058110940046527504`}, {0.020448963120954646`, 
        0.05798106950396156}, {0.020331095783667878`, 0.05785153489513188}, {
        0.020213736631595213`, 0.0577223353985736}, {0.02009688373295219, 
        0.05759347019444037}, {0.01846675332376584, 0.05577425355283211}, {
        0.01693052360151838, 0.05401947242197111}, {0.015488194566209805`, 
        0.052329126801857376`}, {0.014139766217840126`, 0.0507032166924909}, {
        0.013964029898928351`, 0.05048802317656974}, {0.013835350425070208`, 
        0.05032987938688722}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.013648340237187214`, 0.050081355060809275`}, {
        0.01250989835757083, 0.04853181605013676}, {0.011229978429311978`, 
        0.046789710550607384`}, {0.009950058501053126, 0.04504760505107801}, {
        0.008670138572794273, 0.04330549955154863}, {0.008130284001526834, 
        0.0421853904749576}, {0.006980963842148821, 0.0405530490500644}, {
        0.006532813261507779, 0.03989525806926289}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.006357654403217154, 0.039638161633001996`}, {
        0.005918710195358032, 0.03899388367492865}, {0.004943523061154467, 
        0.037507894349550354`}, {0.004067725016793127, 0.03612280251972643}, {
        0.0032594692431566334`, 0.03479761400406398}, {0.0025187557402449874`,
         0.03353232880256301}, {0.001845584508058188, 0.03232694691522351}, {
        0.0007018688558591286, 0.030095893083028943`}, {
        0.00016283329810045722`, 0.028867043564170754`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0000378660697100333, 
        0.028582153418668765`}, {-0.00017167771344054434`, 
        0.02810445250748028}, {-0.000845944262940813, 
        0.02631193659261765}, {-0.0013918198557416601`, 
        0.024677656742481187`}, {-0.001809304491843085, 
        0.023201612957070888`}, {-0.002098398171245089, 
        0.021883805236386753`}, {-0.00244351366278895, 
        0.01961610562681974}, {-0.002579267333211362, 
        0.0177677655514029}, {-0.0025664507943616863`, 
        0.016514122107370754`}}]}, 
      {Arrowheads[{{0.0019820993310611457`, 1.}}], 
       ArrowBox[{{-0.0025618065428875494`, 
        0.016203117775649343`}, {-0.0024517203394034933`, 
        0.014974804409946805`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08723360662812876, 0.09}, {-0.0864474054667097, 
        0.08888100468232914}, {-0.08550843297536606, 
        0.08755551279849866}, {-0.08457670068791098, 
        0.08625126778860612}, {-0.0836522086043445, 
        0.08496826965265153}, {-0.08273495672466658, 
        0.08370651839063488}, {-0.08182494504887726, 
        0.08246601400255617}, {-0.08092217357697651, 
        0.0812467564884154}, {-0.08002302220701998, 
        0.0800381224112435}, {-0.07993610822404403, 0.07992129313742216}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.07975042152683781, 
        0.07967169415173438}, {-0.07912387083706346, 
        0.0788294883340716}, {-0.07822471946710693, 
        0.07762085425689971}, {-0.07732556809715041, 
        0.07641222017972782}, {-0.07642641672719389, 
        0.07520358610255592}, {-0.07552726535723736, 
        0.07399495202538403}, {-0.0739629318486086, 
        0.07217408000347}, {-0.07287581077245524, 
        0.07081011260113773}, {-0.07210896662463759, 0.06985657637569105}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07191400621387455, 
        0.06961415186906922}, {-0.07180085859160042, 
        0.06947345788715831}, {-0.07073807530604415, 
        0.06816411586153173}, {-0.06968746091578641, 
        0.066882086524258}, {-0.06864901542082723, 
        0.06562736987533714}, {-0.06762273882116657, 
        0.06439996591476911}, {-0.06660863111680447, 
        0.06319987464255394}, {-0.0656066923077409, 
        0.06202709605869162}, {-0.06533776162290468, 
        0.06171407484815546}, {-0.06506970702748593, 
        0.06140287985911655}, {-0.06388833147072227, 0.06010698534465449}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06367874796933153, 
        0.05987708545531019}, {-0.06341352133982173, 
        0.059586148562039296`}, {-0.06175733565215754, 
        0.05776941726496204}, {-0.06010114996449334, 
        0.05595268596788479}, {-0.058444964276829145`, 
        0.054135954670807535`}, {-0.05709682219542833, 
        0.052851841982639036`}, {-0.05549499714416355, 
        0.05112910220478097}, {-0.0551788390986679, 0.05079386177850534}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05496539839058796, 
        0.05056753840960574}, {-0.05392941251716506, 
        0.0494690234397357}, {-0.052400068314432835`, 
        0.047871605687503226`}, {-0.05090581832369254, 
        0.04633300663659828}, {-0.04944551633266982, 
        0.044849383975535596`}, {-0.04801916234136466, 
        0.04342073770431518}, {-0.04662675634977708, 
        0.04204706782293703}, {-0.046252895672409, 0.04168415071770669}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.046029676556212436`, 
        0.04146746562514111}, {-0.04526829835790708, 
        0.04072837433140114}, {-0.04394378836575464, 
        0.03946465722970752}, {-0.04265322637331977, 
        0.03825591651785616}, {-0.04139661238060247, 
        0.03710215219584707}, {-0.04017186074514705, 
        0.03599557962872119}, {-0.03897688582449781, 
        0.0349284141815195}, {-0.037811687618654756`, 
        0.03390065585424198}, {-0.03685273146263356, 0.03306591256103819}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.036617731593023964`, 
        0.03286206608771714}, {-0.03557062135138718, 
        0.03196336055945946}, {-0.03449475328996267, 
        0.031053823591954473`}, {-0.03344866194334433, 
        0.030183693744373657`}, {-0.032432347311532175`, 
        0.029352971016717022`}, {-0.030480254657221137`, 
        0.027787740540362895`}, {-0.028629681791924287`, 
        0.02633612578207871}, {-0.026939808177499146`, 
        0.025043398131417746`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.026690740212198777`, 
        0.02485700891530581}, {-0.02523309542837313, 
        0.02377374341972015}, {-0.02375468687075238, 
        0.02270191966583806}, {-0.022345063277985647`, 
        0.021698796609557928`}, {-0.02100422465007292, 
        0.02076437425087976}, {-0.01973217098701421, 
        0.019898652589803553`}, {-0.01852890228880951, 
        0.019101631626329312`}, {-0.01739441855545882, 
        0.01837331136045703}, {-0.01645312226308785, 
        0.017790691325281372`}}]}, 
      {Arrowheads[{{0.00801011823347622, 1.}}], 
       ArrowBox[{{-0.016186962527959283`, 
        0.01762966543093769}, {-0.015331805983319478`, 
        0.017122772921518356`}, {-0.013499668070143267`, 
        0.016077766230647626`}, {-0.011853339615477274`, 
        0.015169020245504945`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.022012997778176283`}, {0.0486744286908332, 
        0.021837608558287636`}, {0.04686770960786241, 
        0.021592307550852008`}, {0.04512690808297565, 0.02134985247235683}, {
        0.043449714954445995`, 0.021110312106453158`}, {0.041833821060546506`,
         0.020873755236792055`}, {0.040157910688245646`, 
        0.02062259764698413}, {0.038547331747905166`, 
        0.020375272722061015`}, {0.037683630146190424`, 
        0.020239523752806035`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAADgDm0/wioz8IMdL0Aa2UP2gyNOt4
8aI/euDQYXGdlD8Jf/8PTy6iP6QBa4KpXpQ/q8k3mLJyoT8ul4W26yCUPwDX
SdtZvqA/O8fj6jnkkz9Fykm5JZugP1csb4w22JM/Y0Fzmjh4oD9rHZf2PcyT
P4qEbPSRVaA/UIAdK1DAkz9yeAToWESgP6mVuVFdupM/Ko9aRjEzoD9tIYQr
bbSTP2JTbP4aIqA/yl+puH+ukz9xaUf/FRGgP/7rUvmUqJM/oYUHOCIAoD99
FqjtrKKTP0QQMhCPep4/6wGf2fFdkz89Z+iq3QWdP3Gi0rmsGpM/EwsP0IZP
mj+/AvBWhJiSP4nU+zXyIpo/T4FcOO2Pkj9HqovppfaZP0xLWeVch5I/xnof
+wK5mT9DExcHVXqSP6SvjpI=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024815459880080805`, 0.01798043819965419}, {
        0.023765484131298684`, 0.017758459877177304`}, {0.022176017949515466`,
         0.017422426366807908`}, {0.020586551767732247`, 
        0.017086392856438516`}, {0.01899708558594903, 
        0.016750359346069124`}, {0.01677312412755659, 
        0.016200101483076573`}, {0.014167174307094556`, 
        0.015601119956985529`}, {0.012679302080777763`, 
        0.015236758323478771`}}]}, 
      {Arrowheads[{{0.019663784462818926`, 1.}}], 
       ArrowBox[{{0.01237713702714311, 0.015162761813171213`}, {
        0.011963943141902113`, 0.015061575705709483`}, {0.010058974422151562`,
         0.014562395197484493`}, {0.008452268147842905, 
        0.014103578432310557`}, {0.0071438243189761415`, 
        0.013685125410187678`}, {0.005118903131145259, 0.01295284757664908}, {
        0.0036813899922358857`, 0.012349098678422689`}, {
        0.0019193577094871878`, 0.011467844135397153`}, {
        0.0009578345098178169, 0.010907926041324857`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.00247466884086246, 0.09}, {0.002052619692786359, 
        0.08907120810157503}, {0.0009811037668291693, 
        0.08662835775730468}, {-0.00005358882640635267, 
        0.08422414607720902}, {-0.0010882814196418746`, 
        0.08181993439711337}, {-0.0021229740128773968`, 
        0.07941572271701772}, {-0.0023807798985707685`, 
        0.07854945811107814}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0024695169890152015`, 
        0.07825128881025194}, {-0.0026750994070148986`, 
        0.07756050251637954}, {-0.0031739921382296496`, 
        0.07620642088347292}, {-0.0036528983230445073`, 
        0.07487715820579466}, {-0.004550751053474542, 
        0.07229308971612315}, {-0.0053686575983050025`, 
        0.06980829704736505}, {-0.006106617957535889, 
        0.06742278019952032}, {-0.0062008637327578865`, 
        0.06710737799683472}, {-0.006293838151358367, 
        0.06679365020555891}, {-0.006378892254344865, 0.06644173575401216}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0064519761042498855`, 
        0.06613934866093643}, {-0.006740368116050408, 
        0.06494611619948354}, {-0.007186898080742449, 
        0.06309858219340816}, {-0.007633428045434489, 
        0.06125104818733279}, {-0.00807995801012653, 
        0.059403514181257416`}, {-0.008212228836726596, 
        0.05805373874074753}, {-0.00860330130646123, 
        0.05629404448153665}, {-0.008957402112890925, 
        0.054592910053568776`}, {-0.009074460431031729, 
        0.05398660494449282}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.00913343367770124, 
        0.05368115223235396}, {-0.009274531256015683, 
        0.0529503354568439}, {-0.00955806183422991, 
        0.05136299496984822}, {-0.009811366945928018, 
        0.04982756287106793}, {-0.010034446591110009`, 
        0.048344039160503054`}, {-0.010227300769775877`, 
        0.046912423838153576`}, {-0.010522332727559256`, 
        0.044204918358100816`}, {-0.010696462819278156`, 
        0.04170504643090966}, {-0.010708990395526443`, 
        0.04134869774860954}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01071992025835923, 
        0.04103779625090619}, {-0.010777986815719875`, 
        0.03938608479522853}, {-0.01079520048767171, 
        0.037221310189705856`}, {-0.01074810383513366, 
        0.03521072261434163}, {-0.010636696858105726`, 
        0.033354322069135876`}, {-0.010478017312063477`, 
        0.031632513723198856`}, {-0.01028910295248248, 
        0.030025702745640852`}, {-0.010084418051899382`, 
        0.028632351742137546`}}]}, 
      {Arrowheads[{{0.018212891224959796`, 1.}}], 
       ArrowBox[{{-0.010032244742474786`, 
        0.028325702495820212`}, {-0.009820569792704245, 
        0.02715707289566191}, {-0.00946588419316262, 
        0.025506758808396233`}, {-0.009092024332943588, 
        0.023998478706358097`}, {-0.008698990212047147, 
        0.02263223258954751}, {-0.008286781830473296, 
        0.02140802045796446}, {-0.007453308685599289, 
        0.019292489969487743`}, {-0.006640071298627482, 
        0.01755867905993468}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.01112152126705709}, {-0.09860779342713426, 
        0.010991386469566178`}, {-0.09613753041958938, 
        0.010808261955044847`}, {-0.09406517349982116, 
        0.010633667263978673`}, {-0.092033656466364, 
        0.010465381059296917`}, {-0.09004297931921787, 
        0.010303403340999578`}, {-0.08809314205838281, 
        0.010147734109086658`}, {-0.08759770223537358, 
        0.010108970692061205`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08728755651505246, 
        0.01008470476240209}, {-0.08618414468385882, 
        0.009998373363558155}, {-0.08431598719564587, 
        0.00985532110441407}, {-0.08248866959374399, 
        0.009718577331654403}, {-0.08070219187815314, 
        0.009588142045279155}, {-0.08022529450057103, 
        0.009553771711161372}, {-0.07975113179027707, 
        0.009519804848686303}, {-0.07781640152997206, 
        0.009395342997962982}, {-0.07588167126966706, 
        0.009270881147239661}, {-0.07487505115720318, 
        0.009206124935615193}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07456459931955131, 
        0.009186153464104473}, {-0.07394694100936205, 
        0.009146419296516339}, {-0.07201221074905705, 
        0.009021957445793018}, {-0.07046658358202705, 
        0.00894918466358506}, {-0.06860051857347645, 
        0.008833844413187979}, {-0.06678023039942879, 
        0.008724585229675058}, {-0.06500571905988409, 
        0.008621407113046299}, {-0.06327498760475272, 
        0.008523915904952108}, {-0.062142109780059865`, 
        0.0084620729374789}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06183147871399233, 
        0.008445115815981539}, {-0.061586039083945096`, 
        0.008431717447042892}, {-0.05993887349746122, 
        0.008344811739318655}, {-0.058333490845301095`, 
        0.008263198781779394}, {-0.05676989112746471, 
        0.008186878574425108}, {-0.05524807434395207, 
        0.0081158511172558}, {-0.053768040494763185`, 
        0.008050116410271467}, {-0.052329789579898034`, 
        0.007989674453472113}, {-0.04956272391469554, 
        0.007881498720442958}, {-0.04940092799878211, 
        0.007875760042270724}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04909002993563127, 
        0.007864732916408362}, {-0.04693096470990115, 
        0.007788153848182958}, {-0.044434511965514865`, 
        0.007709639836692115}, {-0.04207336568153669, 
        0.007645956685970429}, {-0.03986339001974559, 
        0.007599968062198303}, {-0.03771468806339405, 
        0.007555446523686779}, {-0.03665081034741485, 
        0.0075386533031274695`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0363397555366018, 
        0.007533743329015257}, {-0.03568860123802744, 
        0.007523464913000088}, {-0.03377878387893416, 
        0.007502877763666068}, {-0.03130695799055331, 
        0.007491385703057225}, {-0.029029306524914762`, 
        0.007497390028980394}, {-0.026928658555402406`, 
        0.007517981288360199}, {-0.024987843155400133`, 
        0.007550250028121265}, {-0.023896893050524913`, 
        0.007575147267947643}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.023585880471531238`, 
        0.007582245076301685}, {-0.023189689398291823`, 
        0.007591286795188215}, {-0.02151702635746137, 
        0.007638182136485672}, {-0.019952683106292658`, 
        0.0076880265989382615`}, {-0.018479488718169568`, 
        0.007737910729470606}, {-0.015821617522265827`, 
        0.007843612424897848}, {-0.013537659881731296`, 
        0.0079594365505462}, {-0.01156203812449708, 
        0.008077066546748184}, {-0.011153909701328594`, 
        0.008103237648154333}}]}, 
      {Arrowheads[{{0.004070402225464734, 1.}}], 
       ArrowBox[{{-0.01084345377962589, 
        0.008123145532407882}, {-0.009829174578494294, 
        0.008188185853836329}, {-0.008316705085683624, 
        0.008294329291708244}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.04978612550042228}, {0.04957745440913568, 
        0.049573593947880565`}, {0.04710954124688883, 0.04832651200422817}, {
        0.04464162808464198, 0.04707943006057578}, {0.04217371492239512, 
        0.04583234811692338}, {0.04052857773945201, 0.044863145579740964`}, {
        0.03897677268082012, 0.0440200664707131}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03870341658732091, 0.04387155502562357}, {
        0.03822932484650582, 0.0436139860479865}, {0.03604297952534185, 
        0.042405569758409624`}, {0.03396954177596009, 
        0.041237896711010344`}, {0.032009011598360546`, 
        0.04011096690578866}, {0.031751910101063534`, 0.03996155180499453}, {
        0.03149666397978937, 0.039812833539575286`}, {0.029828874590843008`, 
        0.038776413145845554`}, {0.028161085201896644`, 
        0.037739992752115814`}, {0.02795281588170502, 0.03761056719498885}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02768858641556586, 0.037446366121912135`}, {
        0.026493295812950284`, 0.03670357235838608}, {0.02482550642400392, 
        0.03566715196465635}, {0.023844893135528778`, 0.0349240131117296}, {
        0.022298370117253805`, 0.033939348284023924`}, {0.020832691346093096`,
         0.03298918716700095}, {0.019447856822046646`, 
        0.032073529760660684`}, {0.018137481667889074`, 
        0.03119035800257465}, {0.017294892164021934`, 
        0.030612012029075666`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.017038405327301578`, 0.030435961735792997`}, {
        0.016895181006395005`, 0.030337653830314386`}, {0.01572095483756443, 
        0.029515417243879887`}, {0.014614803161397356`, 
        0.028723648243271158`}, {0.0126067232870537, 0.027231512999531002`}, {
        0.01087094138336404, 0.025861248099093914`}, {0.009353682036467708, 
        0.024596839081752506`}, {0.008001169832504037, 
        0.023422271487299393`}, {0.007265268840001423, 
        0.02275021007344099}}]}, 
      {Arrowheads[{{0.015787692365694384`, 1.}}], 
       ArrowBox[{{0.007035554356677931, 0.02254042337384554}, {
        0.006813404771473028, 0.022337545315734574`}, {0.005790386853374682, 
        0.02134266056705805}, {0.00410586980431692, 0.019575119081524508`}, {
        0.0028148960436716946`, 0.0180723507738534}, {0.001555250710421856, 
        0.016395021481009436`}, {0.0007256194776443242, 
        0.015056750946768848`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, 0.0675096353363349}, {-0.09872296704716596, 
        0.06647455799161318}, {-0.0978020567702959, 
        0.0659154397525051}, {-0.09614782776045122, 
        0.06463721072746206}, {-0.09451791478964644, 
        0.06338550197266152}, {-0.09291231785788155, 
        0.06216031348810344}, {-0.09133103696515656, 
        0.06096164527378785}, {-0.09007434078327163, 0.06001555208328681}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0898258053424651, 
        0.05982844425918842}, {-0.08977407211147145, 
        0.059789497329714746`}, {-0.08824142329682624, 
        0.05864386965588412}, {-0.08673309052122094, 
        0.05752476225229598}, {-0.08524907378465552, 
        0.05643217511895032}, {-0.08485160801614582, 
        0.05614070996006355}, {-0.08445582530783126, 
        0.05585101193777249}, {-0.08249503141464568, 
        0.05446523875211879}, {-0.08053423752146008, 
        0.05307946556646509}, {-0.07975106525847088, 0.05252596571848518}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07949701461628274, 
        0.05234641774612259}, {-0.07857344362827448, 
        0.05169369238081138}, {-0.0766126497350889, 
        0.05030791919515768}, {-0.07501196852284417, 
        0.049268142530736005`}, {-0.0731147239262952, 
        0.04794342755471148}, {-0.07125984552750399, 
        0.04665941805177309}, {-0.06944733332647052, 
        0.045416114021920806`}, {-0.06925288773059549, 0.0452838922369532}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0689956354704125, 
        0.04510896231439426}, {-0.06767560999668731, 
        0.044211353275972906`}, {-0.0659430982116469, 
        0.04304297362474761}, {-0.06424979797134926, 
        0.04191097506824494}, {-0.06259570927579441, 
        0.040815357606464896`}, {-0.060980832124982357`, 
        0.039756121239407465`}, {-0.059405166518913075`, 
        0.038733265967072654`}, {-0.0586250319403094, 
        0.038232383684793106`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05836325018732867, 
        0.03806430775855123}, {-0.05786871245758658, 
        0.037746791789460464`}, {-0.05637146994100287, 
        0.036796698706570895`}, {-0.054910343686237734`, 
        0.035878649210393444`}, {-0.05348223841036693, 
        0.0349883057929176}, {-0.05208715411339047, 
        0.03412566845414336}, {-0.050725090795308354`, 
        0.03329073719407074}, {-0.04939604845612059, 
        0.03248351201269973}, {-0.04810002709582716, 
        0.03170399291003032}, {-0.04778289224579865, 0.03151521536560758}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04751557428255076, 
        0.03135609179821191}, {-0.04683702671442808, 
        0.03095217988606253}, {-0.045607047311923346`, 
        0.03022807294079635}, {-0.043235456522704566`, 
        0.028849972777556604`}, {-0.040974559807278474`, 
        0.027556687911498873`}, {-0.038824357165645085`, 
        0.026348218342623162`}, {-0.03678484859780439, 
        0.025224564070929465`}, {-0.036710867992952284`, 
        0.02518454247770612}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.03643724660562488, 
        0.025036520386203676`}, {-0.03457560241576071, 
        0.024029419043327498`}, {-0.032474722834474806`, 
        0.02291084509690869}, {-0.030482209853946677`, 
        0.021868842231673045`}, {-0.028598063474176327`, 
        0.02090341044762056}, {-0.026822283695163755`, 
        0.020014549744751236`}, {-0.025387834040933158`, 
        0.019315749602016145`}}]}, 
      {Arrowheads[{{0.007641449859704441, 1.}}], 
       ArrowBox[{{-0.025107882866827507`, 
        0.01918008651655545}, {-0.023595823939411946`, 
        0.01846654158256207}, {-0.0221451439626727, 
        0.01780739412324223}, {-0.020783078381110168`, 
        0.01720571869668313}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05977884952128519, 0.09}, {-0.059041873859079275`, 
        0.08831483010473425}, {-0.05841043577021545, 
        0.08665300465631304}, {-0.05777974069950362, 
        0.0850234481198379}, {-0.05714978864694377, 
        0.08342616049530885}, {-0.056520579612535905`, 
        0.08186114178272587}, {-0.05589211359628003, 
        0.08032839198208898}, {-0.05526439059817615, 
        0.07882791109339816}, {-0.05511024601974472, 0.07846694754840482}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05498807138498783, 
        0.07818084868123168}, {-0.054637410618224254`, 
        0.07735969911665344}, {-0.05401117365642434, 
        0.07592375605185478}, {-0.05384216210733914, 
        0.07554034448737597}, {-0.05367327763375204, 
        0.0751590970008381}, {-0.052755796609612354`, 
        0.0732701307357154}, {-0.051838315585472666`, 
        0.0713811644705927}, {-0.05092083456133298, 
        0.06949219820547}, {-0.05000335353719328, 
        0.06760323194034729}, {-0.04962173462729061, 0.06695950866065643}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04946309123503503, 
        0.06669190545202587}, {-0.04915290672699341, 
        0.0661686793129523}, {-0.04824725527001957, 
        0.06435990368978153}, {-0.0473494901911563, 
        0.06260458849457876}, {-0.0464596114904036, 
        0.06090273372734393}, {-0.04557808143525169, 
        0.05925158951757209}, {-0.04470536229319082, 
        0.057648405994758276`}, {-0.043841454064220985`, 
        0.05609318315890247}, {-0.043622129600846854`, 
        0.055706584515879724`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04346862313077188, 
        0.05543600187264323}, {-0.042986356748342176`, 
        0.05458592101000468}, {-0.042140070345554406`, 
        0.0531266195480649}, {-0.041302594855857674`, 
        0.051715278773083136`}, {-0.04047393027925197, 
        0.05035189868505938}, {-0.0396540766157373, 
        0.04903647928399365}, {-0.03884406348496055, 
        0.047763515019991015`}, {-0.038044920506568616`, 
        0.046527500343156586`}, {-0.03725664768056149, 
        0.045328435253490354`}, {-0.03693569686102509, 
        0.04484865568033196}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.03676272382689212, 
        0.044590083576967025`}, {-0.03647924500693919, 
        0.044166319750992326`}, {-0.03495705011684901, 
        0.04195293750750087}, {-0.03347833583629809, 
        0.03988735361268221}, {-0.03204423153962874, 
        0.037952863748897454`}, {-0.030655866601183263`, 
        0.036132763598507686`}, {-0.02941264035942906, 
        0.03455333296099822}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02921823484352155, 
        0.03431047755413422}, {-0.02801635479896395, 
        0.03283573243791314}, {-0.02652780100832713, 
        0.03106627416447614}, {-0.02509486622006528, 
        0.02940980192360803}, {-0.023717550434178388`, 
        0.027866315715308825`}, {-0.022395853650666465`, 
        0.02643581553957852}, {-0.02112977586952951, 
        0.025118301396417114`}, {-0.0209914108866161, 
        0.024980614335638956`}}]}, 
      {Arrowheads[{{0.006850212763907399, 1.}}], 
       ArrowBox[{{-0.02077089497278641, 
        0.024761178844153225`}, {-0.01991931709076752, 
        0.02391377328582461}, {-0.018764477314380495`, 
        0.022822231207801}, {-0.01766525654036844, 0.0218436751623463}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, -0.00038641644801165717`}, {
        0.04952683157891378, -0.0002466450023889988}, {0.04704928247305371, 
        0.0004852098820350879}, {0.044571733367193646`, 
        0.0012170647664591747`}, {0.04292675250973709, 
        0.001630167332309434}, {0.04122381736111482, 0.002100337659282115}, {
        0.03958380446045906, 0.0025475515569368364`}, {0.03801845980426412, 
        0.0029686492026424283`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037717759870082974`, 0.003048390675676961}, {
        0.03649254540304705, 0.0033731100642923977`}, {0.03629233751953194, 
        0.003425747293248362}, {0.036093191097405976`, 
        0.0034780071017010495`}, {0.034399944995526247`, 
        0.0038994582327849057`}, {0.03270669889364652, 
        0.004320909363868761}, {0.031013452791766788`, 
        0.004742360494952617}, {0.02932020668988706, 
        0.0051638116260364735`}, {0.02670782760336545, 
        0.005757035675180082}, {0.025633380355088924`, 
        0.006014257723912132}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.025330835742799276`, 0.0060866867288081996`}, {
        0.025208109780795185`, 0.006116067253007913}, {0.023785803269948703`, 
        0.006450131009533332}, {0.021149494103469155`, 
        0.007052358911978697}, {0.01877497002396885, 0.007572723235817931}, {
        0.016662231031447795`, 0.008011223981051035}, {0.014811277125905992`, 
        0.00836786114767801}, {0.01317210935984767, 0.00866287228730914}, {
        0.013159122225614722`, 0.008665101795157615}}]}, 
      {Arrowheads[{{0.01420424588643641, 1.}}], 
       ArrowBox[{{0.012852513851021966`, 0.008717737408627179}, {
        0.011694728785777072`, 0.00891649495155472}, {0.010379135403694192`, 
        0.009128729140414743}, {0.009225329213599032, 0.009299574853889214}, {
        0.007278820650620398, 0.009561555383915623}, {0.005730945338089695, 
        0.009746891070868069}, {0.004098130238153276, 
        0.009910561710571761}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.02454247260672951, 0.09}, {0.023825499839196643`, 
        0.08910725744699623}, {0.02286521734404656, 0.0879115564592515}, {
        0.021600091635652456`, 0.08601012648262556}, {0.020506607732061897`, 
        0.08452725250653986}, {0.01944612911200127, 0.08307076218783693}, {
        0.01841865577547057, 0.08164065552651677}, {0.0174241877224698, 
        0.08023693252257938}, {0.017220432378414703`, 0.0799450436826274}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.01704236455879729, 0.07968995339509684}, {
        0.01646272495299896, 0.07885959317602476}, {0.015534267467058051`, 
        0.0775086374868529}, {0.014638815264647073`, 0.0761840654550638}, {
        0.013776368345766022`, 0.07488587708065748}, {0.013547923016710374`, 
        0.07453886668450944}, {0.01332161224938896, 0.07419364188591043}, {
        0.012194934518678136`, 0.07230805932280819}, {0.011068256787967313`, 
        0.07042247675970595}, {0.010343441244280598`, 0.06920944173346213}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.010183871709262745`, 0.06894238974101513}, {
        0.009941579057256488, 0.06853689419660372}, {0.008814901326545665, 
        0.06665131163350148}, {0.008168995699368475, 0.06522280601021815}, {
        0.007127160104575351, 0.06341788408355456}, {0.006141885933727362, 
        0.061666735914516706`}, {0.005213173186824505, 0.05996936150310461}, {
        0.004336770318839304, 0.058322994668781825`}, {0.004192357571587911, 
        0.05804437909830205}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.004049198513682631, 0.05776818227117436}, {
        0.00350842578474428, 0.056724869231011894`}, {0.0027281395845394334`, 
        0.05517498518979482}, {0.001995911718224765, 0.05367334254513061}, {
        0.0013117421858002752`, 0.05221994129701926}, {0.0006756309872659612, 
        0.05081478144546076}, {0.00008757812262182474, 
        0.04945786299045512}, {-0.0004524164081321329, 
        0.04814918593200234}, {-0.0011121637344261575`, 
        0.046453676822932825`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.00122497526811685, 
        0.04616375828085233}, {-0.001423149255339976, 
        0.045654463605260584`}, {-0.002271486341728029, 
        0.04330852206574074}, {-0.002997427667296291, 
        0.04111136131344281}, {-0.0036009732320447605`, 
        0.03906298134836679}, {-0.004105062983395645, 
        0.037146530893173595`}, {-0.00453263686877115, 
        0.035345158670524124`}, {-0.0047609377322298954`, 
        0.034248524061110355`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.00482434275316952, 
        0.033943960428193726`}, {-0.004883694888171276, 
        0.0336588646804184}, {-0.005158237041596022, 
        0.032087648922856406`}, {-0.005472916002506376, 
        0.02982527378996557}, {-0.005678421913066061, 
        0.027769302589306457`}, {-0.0057747547732750785`, 
        0.02591973532087906}, {-0.0057619145831334295`, 
        0.02427657198468337}, {-0.005675199632227007, 
        0.02280401713732985}, {-0.005559871902737149, 0.02157265810181767}}]}, 
      {Arrowheads[{{0.0016229741474641307`, 1.}}], 
       ArrowBox[{{-0.005522339706711427, 
        0.021263899233021466`}, {-0.005386040316877533, 
        0.02026334657898067}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{-0.01777231777468427, 0.09}, {-0.017926820031536582`, 
        0.08857089002125561}, {-0.018186621633376265`, 
        0.08697171268109027}, {-0.018429512183206837`, 
        0.08540232586518581}, {-0.018655491681028296`, 
        0.08386272957354221}, {-0.018864560126840648`, 
        0.08235292380615948}, {-0.019056717520643886`, 
        0.08087290856303761}, {-0.019231963862438015`, 
        0.0794226838441766}, {-0.019390299152223033`, 
        0.07800224964957644}, {-0.019424227360052556`, 
        0.07766862899016129}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.019455702287836333`, 
        0.07735913176546172}, {-0.01953172338999894, 
        0.07661160597923716}, {-0.019567631011130838`, 
        0.07624009111715652}, {-0.019602484084152914`, 
        0.07587058260203074}, {-0.019692605183070613`, 
        0.07397802867186641}, {-0.01978272628198831, 
        0.07208547474170209}, {-0.019872847380906014`, 
        0.07019292081153777}, {-0.019962968479823713`, 
        0.06830036688137345}, {-0.019863796559827212`, 
        0.06685842589940272}, {-0.019920513008348288`, 
        0.06504539190127255}, {-0.019922663616177817`, 
        0.06493550862240285}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0199287510950995, 
        0.06462447462783617}, {-0.019954959689938285`, 
        0.06328537119116517}, {-0.019967136604597195`, 
        0.06157836376908056}, {-0.01995917992613988, 
        0.059921673949478456`}, {-0.019933225828381206`, 
        0.058312606046818594`}, {-0.01988927431132117, 
        0.05675116006110098}, {-0.019827325374959764`, 
        0.0552373359923256}, {-0.019747379019297, 
        0.053771133840492466`}, {-0.01964943524433287, 
        0.05235255360560157}, {-0.019635627616813395`, 
        0.052189283924631964`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.01960941218403807, 
        0.051879296901903384`}, {-0.01953349405006738, 
        0.05098159528765292}, {-0.019399555436500522`, 
        0.04965825888664651}, {-0.01909532575450829, 
        0.0471328926546348}, {-0.01875438600140174, 
        0.044754895728740834`}, {-0.018376736177180875`, 
        0.04252426810896462}, {-0.017962376281845698`, 
        0.04044100979530615}, {-0.01776878577985282, 0.0395821952449514}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.017700376804031144`, 
        0.039278716390329274`}, {-0.01752228844277439, 
        0.03848867310658513}, {-0.01706745478734514, 
        0.036650810361621294`}, {-0.016597875315557946`, 
        0.034927421560414625`}, {-0.01611355002741281, 
        0.03331850670296512}, {-0.01532750177612893, 
        0.030951011908564103`}, {-0.014537817492394644`, 
        0.028798200808825794`}, {-0.013974718100509166`, 
        0.02742251643401575}}]}, 
      {Arrowheads[{{0.008884032164777506, 1.}}], 
       ArrowBox[{{-0.0138568705971316, 
        0.027134608168897498`}, {-0.013744497176209949`, 
        0.026860073403750198`}, {-0.012947540827574846`, 
        0.02513662969333732}, {-0.012161663487345127`, 
        0.023590714552999815`}, {-0.011401580196376594`, 
        0.02218517285815036}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.025714172029242012`}, {-0.09870511655553978, 
        0.025407956619119633`}, {-0.09669293291627917, 
        0.024935485842751494`}, {-0.09472033505769424, 
        0.024475748898268004`}, {-0.09278732297978497, 
        0.02402874578566916}, {-0.09089389668255138, 
        0.023594476504954963`}, {-0.08904005616599345, 
        0.023172941056125416`}, {-0.08854480235358665, 
        0.02306083175440161}, {-0.08805221511342812, 
        0.022949557465626085`}, {-0.08787614464834634, 
        0.022911130215382984`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.08757220560708416, 
        0.022844795741899286`}, {-0.08608659888011602, 
        0.022520563160168313`}, {-0.08412098264680394, 
        0.022091568854710544`}, {-0.08215536641349186, 
        0.021662574549252772`}, {-0.08018975018017978, 
        0.021233580243795003`}, {-0.07858725321872542, 
        0.020911993442233615`}, {-0.07668571685691765, 
        0.020501953402169322`}, {-0.07540679964762685, 
        0.02022852853534413}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07510258100167796, 
        0.020163488404403646`}, {-0.07482690040944608, 
        0.020104549539034015`}, {-0.0730108038763107, 
        0.019719781852827696`}, {-0.07123571236890514, 
        0.019347002172124032`}, {-0.06949991099862295, 
        0.018985562325496697`}, {-0.06780339976546416, 
        0.01863546231294569}, {-0.06614617866942878, 
        0.01829670213447101}, {-0.06452824771051678, 
        0.017969281790072657`}, {-0.06294960688872818, 
        0.017653201279750633`}, {-0.06291612928340198, 
        0.017646573817803317`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06261095822460669, 
        0.017586160011024702`}, {-0.06141025620406297, 
        0.017348460603504937`}, {-0.059910195656521156`, 
        0.01705505976133557}, {-0.05844601589015767, 
        0.016771702570246034`}, {-0.057014307549027435`, 
        0.01649709284723983}, {-0.05561507063313045, 
        0.01623123059231696}, {-0.05424830514246673, 
        0.015974115805477425`}, {-0.05161218843683906, 
        0.015486128636048356`}, {-0.05038587177786007, 
        0.015264473836127534`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05007973871087054, 
        0.015209140767612256`}, {-0.04910595743214442, 
        0.015033131338952626`}, {-0.04674352783412966, 
        0.014620080588172699`}, {-0.044446043976895964`, 
        0.014218888564474595`}, {-0.04226731325599781, 
        0.013848721073923851`}, {-0.04020176938913647, 
        0.013507595446927485`}, {-0.03872004178213367, 
        0.013269180880606224`}, {-0.03781178789310035, 
        0.013126425368861131`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.037504467232859405`, 
        0.013078122004953457`}, {-0.037296592488739407`, 
        0.01304544913029358}, {-0.035929036660402106`, 
        0.012835583657740346`}, {-0.0346149894485702, 
        0.01263876792469731}, {-0.032137881480216235`, 
        0.012281019524144988`}, {-0.029846189795264898`, 
        0.011965671622642933`}, {-0.027720835605303543`, 
        0.01168619191419746}, {-0.02574274012191956, 
        0.011436048092814883`}, {-0.025179525989898352`, 
        0.011366833454844957`}}]}, 
      {Arrowheads[{{0.00948332001407118, 1.}}], 
       ArrowBox[{{-0.02487075529686996, 
        0.011328887937290226`}, {-0.023892824556700314`, 
        0.01120870785250152}, {-0.022152010121233176`, 
        0.010997638887263688`}, {-0.02052213848485725, 
        0.010804556580836854`}, {-0.01901148838083523, 
        0.010633714067642384`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.06630578078232702}, {0.049578939649600376`, 
        0.06600265988371211}, {0.0480452770453185, 0.06496559304741134}, {
        0.04655032136351776, 0.06394585937741908}, {0.04509407260419818, 
        0.06294345887373533}, {0.04367653076735972, 0.06195839153636008}, {
        0.042297695853002415`, 0.060990657365293355`}, {0.04095756786112625, 
        0.06004025636053513}, {0.03978537686236785, 0.0591998414116899}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03953303273003628, 0.059017904803202764`}, {
        0.03839343264481734, 0.05819145384994421}, {0.03805766579945819, 
        0.05794650208793786}, {0.037724434985245636`, 0.05770273159095901}, {
        0.035991770114322606`, 0.056358345851798344`}, {0.03425910524339958, 
        0.05501396011263767}, {0.03252644037247655, 0.053669574373477}, {
        0.030793775501553527`, 0.05232518863431632}, {0.02973292990961169, 
        0.051358417716435505`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.02949362795863978, 0.05115988990207934}, {
        0.028031020637270875`, 0.05000065522007104}, {0.0264739994857387, 
        0.048747328996929386`}, {0.024987235821962866`, 
        0.04753042658019534}, {0.023565966859430236`, 0.04634818083701365}, {
        0.02220542981162767, 0.04519882463452908}, {0.02090562467855517, 
        0.044082357972741626`}, {0.019916366453188263`, 
        0.04321724559359425}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.019682187383471106`, 0.04301245456234011}, {
        0.019666551460212744`, 0.042998780851651285`}, {0.018488210156600383`,
         0.04194809327125806}, {0.01737060076771809, 0.04093029523156196}, {
        0.01631372329356586, 0.03994538673256297}, {0.015317577734143703`, 
        0.0389933677742611}, {0.013468613918539922`, 0.03717396471354457}, {
        0.011784840879957077`, 0.0354580522832082}, {0.010748213247718064`, 
        0.03435736710139922}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.010534925581476236`, 0.03413089949973214}, {
        0.010266258618395169`, 0.033845630483252}, {0.008912867133854202, 
        0.03233669931367598}, {0.007698191948387085, 0.030920255991286897`}, {
        0.006595758584046728, 0.029585297732891536`}, {0.0056055670408331325`,
         0.02833182453848989}, {0.004727617318746301, 
        0.027159836408081964`}, {0.0034270084142406054`, 
        0.025312544512878163`}, {0.0028224721491867675`, 
        0.02438557307596765}}]}, 
      {Arrowheads[{{0.006098756246809452, 1.}}], 
       ArrowBox[{{0.0026525337966956187`, 0.024124996485445166`}, {
        0.002336751103919393, 0.023640788087379613`}, {0.0014568453877826615`,
         0.02214456713158632}, {0.0007872912658304092, 
        0.02082388164549827}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.07536098944937719}, {0.04958717221834412, 
        0.07505236989123579}, {0.047974539386497386`, 0.07383332132330003}, {
        0.04641045647047165, 0.07263708219301372}, {0.045994646184507694`, 
        0.07231712908921706}, {0.045582014084916814`, 0.07199872922772596}, {
        0.04378957270028809, 0.07054216121010888}, {0.04199713131565936, 
        0.06908559319249181}, {0.04023349259448446, 0.06765243070365175}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.039992062330978795`, 0.06745624041072339}, {
        0.038412248546401906`, 0.06617245715725767}, {0.03714137440114232, 
        0.06499538242199304}, {0.03544097429404933, 0.06358813674832052}, {
        0.03380193503864682, 0.062213772637277696`}, {0.0322242566349348, 
        0.06087229008886458}, {0.030704361419202963`, 0.0595623457489693}, {
        0.030514345604620016`, 0.05939643570514221}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03028000774341284, 0.05919182639455109}, {
        0.02923867172774101, 0.05828259626347998}, {0.027827187560548937`, 
        0.05703304163239664}, {0.026469908917626746`, 0.05581368185571927}, {
        0.025166835798974437`, 0.054624516933447866`}, {0.023917968204592008`,
         0.05346554686558244}, {0.02272330613447946, 0.052336771652122985`}, {
        0.0215828495886368, 0.0512381912930695}, {0.021113753704795405`, 
        0.05077870507297088}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.020891512758783114`, 0.050561016843864916`}, {
        0.02048940059667404, 0.05016714215046502}, {0.019435761188201207`, 
        0.04912096058635256}, {0.018421931363218298`, 
        0.048099646600732134`}, {0.017447911121725314`, 
        0.047103200193603735`}, {0.015619299389209126`, 
        0.04518491011482303}, {0.013949925990652642`, 
        0.043366090350010426`}, {0.012418748091714078`, 
        0.041637998099783725`}, {0.012330323100095752`, 
        0.041535060018112954`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012127612013982379`, 0.041299078199443666`}, {
        0.011004722858051654`, 0.0399918905647607}, {0.00970785028966537, 
        0.03842776774494135}, {0.008528130386555229, 0.03694562964032569}, {
        0.007395113604184366, 0.03546795531948739}, {0.006348238097363478, 
        0.034058476224678905`}, {0.00538750386609257, 0.03271719235590024}, {
        0.004523038855274929, 0.0314588463103178}}]}, 
      {Arrowheads[{{0.0018430656156570742`, 1.}}], 
       ArrowBox[{{0.0043523626022113375`, 0.031198757543648932`}, {
        0.0037244592302006913`, 0.030239210296432374`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAKEvrKqkpc797FK5H4XqEv8jff7IY
7G6/FKQMRMK3gb+GrqzkJ6Nnv4wh632htn2/JSpozcJIYb+YYAi3gWZ4v0+l
ZNnSuVe/SgVxMyV/c7+nJa6mFeBTv+H79uEPpXG/CtUSuEE/UL9z9OF+/bFv
vw1gb4N1qUm//6j9Zhg1bL/fUHhUXwBJv3FARcNH3Wu/x2GY+FBYSL+B3XWr
uoVrv6fs/WonXke/R6ziQuUCa79gO7RBp7hGv8MfrDIArGq/7+uTlCoURr90
auUAXlVqv48iOru47Cg/OKArYU1nVL9aabjBFx8sP85JtmEjZlO/S0b1Q/hH
Lz9rmi/xU2ZSv23JZvomEjE/++QQpk98Ub8oUkrhsvQyP95WMA/tRVC/tDTC
s7/QND9viyB51yJOvzGG+OYzuD0/ge7MK9xQQr94wsLeZ/5CPywFWBkffiu/
Prfha37TRj/CD6H6c9AgP1hN2kCO508//46stGPZUD8IZ7o6
        "]]}, 
      {Arrowheads[{{0.011722382974010959`, 1.}}], 
       ArrowBox[{{0.0010651647844873474`, 0.0013257202487930398`}, {
        0.0011722556704273374`, 0.0016736488034979197`}, {
        0.001474478001090433, 0.002984366830766236}, {0.0017153217652415632`, 
        0.005030683085132693}, {0.001674707771310475, 
        0.0064919551419575445`}, {0.0014629306823953302`, 
        0.007694315806089874}, {0.001191103680597115, 
        0.008490410573037987}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.1, -0.0015624593846324745`}, {-0.09984789193118193, \
-0.0015583174183955667`}, {-0.09758672552768345, -0.0014928319397014256`}, \
{-0.0953760085746967, -0.0014248072473890794`}, {-0.09321574107222168, \
-0.0013542433414585272`}, {-0.0911059230202584, -0.0012811402219097697`}, \
{-0.09054303085609623, -0.0012610577317867012`}, {-0.08998350393880424, \
-0.0012408292079538702`}, {-0.0880109082851679, -0.0011555536384162271`}, \
{-0.08756371034274535, -0.001136221212550923}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08725290706847878, -0.0011227851461282949`}, \
{-0.08603831263153157, -0.001070278068878584}, {-0.08406571697789524, \
-0.0009850024993409412}, {-0.0820931213242589, -0.0008997269298032982}, \
{-0.08047787069086729, -0.0008036358459250225}, {-0.07856833592315648, \
-0.0007164516562096208}, {-0.07670084174606272, -0.00062799505304238}, \
{-0.07487538815958597, -0.0005382660364233}, {-0.07482319405284449, \
-0.0005356098812937349}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0745125025448502, -0.0005197988080865835}, \
{-0.07309031370933092, -0.00044742369896965854`}, {-0.07134395694090223, \
-0.0003556271332987334}, {-0.06963631785429993, -0.0002628763394105244}, \
{-0.06796739644952397, -0.00016917131730503177`}, {-0.0663371927265744, \
-0.00007451206698225535}, {-0.06474570668545118, 
        0.00002110141155780483}, {-0.06319293832615434, 
        0.00011766911831514872`}, {-0.06208905999241117, 
        0.0001887713295456583}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.061778609765542995`, 
        0.000208767824569245}, {-0.061678887648683865`, 
        0.0002151910532897764}, {-0.06020025009949148, 
        0.00031334751638020027`}, {-0.05875372112502891, 
        0.0004118188074849322}, {-0.05733930072529615, 
        0.0005106049266039726}, {-0.0559569889002932, 
        0.0006097058737373211}, {-0.05328869097447674, 
        0.0008088522520469434}, {-0.05074882734757954, 
        0.0010092579424137989`}, {-0.04936890943225523, 
        0.0011259414688308}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.049058922119507443`, 
        0.0011521534720190041`}, {-0.048350906542258286`, 
        0.0012120220724583172`}, {-0.046018380263458336`, 
        0.0014109162523313968`}, {-0.04380348146545227, 
        0.0016101904421653658`}, {-0.04170080673917742, 
        0.0018094049909120524`}, {-0.04017590551987828, 
        0.001960436552744556}, {-0.03871003996636574, 
        0.0021111788600138293`}, {-0.03730082551042023, 
        0.0022614607105526595`}, {-0.036671541798874996`, 
        0.002330963328462011}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.036362328503797475`, 
        0.0023651150681399573`}, {-0.035945877583822165`, 
        0.0024111109021938337`}, {-0.033389243045789954`, 
        0.0027078315001143726`}, {-0.03102105980651236, 
        0.002999971036437751}, {-0.02882225132023264, 
        0.0032861598938262746`}, {-0.026773741041194052`, 
        0.00356502845494225}, {-0.024856452423639847`, 
        0.003835207102447983}, {-0.024021241009543313`, 
        0.003955560113138793}}]}, 
      {Arrowheads[{{0.014930589374096246`, 1.}}], 
       ArrowBox[{{-0.02371332785276252, 
        0.003999930047294885}, {-0.02305130892181328, 
        0.0040953262190057795`}, {-0.021360020159733234`, 
        0.004346309883539167}, {-0.019790691505964915`, 
        0.004589787927667435}, {-0.0183338400315711, 
        0.004825449363096531}, {-0.01697998280761457, 
        0.0050529832015324}, {-0.014543319395264409`, 
        0.005482424134248248}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.08476477774143937}, {-0.09975176203235828, 
        0.08449626878023134}, {-0.09820782905506376, 
        0.08283990874811925}, {-0.09668351042229786, 
        0.0812184145312975}, {-0.09517880613406061, 
        0.07963178612976606}, {-0.09369371619035201, 
        0.07808002354352493}, {-0.09222824059117202, 
        0.07656312677257412}, {-0.09142901588848643, 0.07574390864490238}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.09121177357530547, 
        0.07552123179262646}, {-0.09078237933652067, 
        0.07508109581691363}, {-0.0903945824369532, 
        0.07468559080836351}, {-0.09000817556285412, 
        0.07429241496908325}, {-0.08807248931543862, 
        0.07240719142286746}, {-0.08613680306802314, 
        0.07052196787665167}, {-0.08420111682060764, 
        0.06863674433043589}, {-0.08232591945563085, 0.06681043274147039}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08209518886620192, 
        0.06660188395305289}, {-0.08064167169082276, 
        0.06532429041844796}, {-0.07876103144900365, 
        0.06351988919819282}, {-0.07691708854424877, 
        0.061769369528578116`}, {-0.07510984297655814, 
        0.060072731409603834`}, {-0.07333823506660507, 
        0.05842717891381828}, {-0.07299745293897404, 
        0.058113817235068636`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07276845668649433, 
        0.057903246772928345`}, {-0.07160120513506289, 
        0.05682991611376976}, {-0.0698987531819316, 
        0.05528094300945827}, {-0.06823087920721121, 
        0.0537802596008838}, {-0.0665975832109017, 
        0.05232786588804637}, {-0.06499886519300309, 
        0.050923761870945966`}, {-0.0634881232854349, 0.04961423365578974}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.06325197121675367, 
        0.04941172291586107}, {-0.061905163092438514`, 
        0.04826042292395624}, {-0.06040814391049469, 
        0.04699558590554192}, {-0.058941632508406, 
        0.0457678344058146}, {-0.057505628886172444`, 
        0.04457716842477428}, {-0.05610013304379403, 
        0.04342358796242096}, {-0.05472514498127075, 
        0.042307093018754655`}, {-0.053676653036499516`, 
        0.04146531638447411}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.053434066818841684`, 
        0.041270557225053565`}, {-0.053380664698602615`, 
        0.041227683593775356`}, {-0.05206669219578961, 
        0.04018535968748307}, {-0.050783227472831746`, 
        0.039180121299877774`}, {-0.049528278619284924`, 
        0.038207734710170076`}, {-0.04829985372470503, 
        0.03726396619757057}, {-0.04709795278909207, 
        0.03634881576207923}, {-0.04592257581244605, 
        0.03546228340369608}, {-0.044773722794766956`, 
        0.03460436912242111}, {-0.043651393736054804`, 
        0.03377507291825433}, {-0.043555375649637955`, 
        0.033704914838488254`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.04330419027629783, 
        0.03352137979715906}, {-0.04255558863630958, 
        0.032974394791195724`}, {-0.041486307495531304`, 
        0.03220233474124531}, {-0.04026028596349434, 
        0.03132623317204643}, {-0.03906245490184683, 
        0.030477630517331426`}, {-0.03789281431058876, 
        0.029656526777100282`}, {-0.03675136418972013, 
        0.028862921951353007`}, {-0.03455303535915121, 
        0.02735820904331005}, {-0.033107000105861144`, 
        0.026391176883070137`}}]}, 
      {Arrowheads[{{0.00805618257858365, 1.}}], 
       ArrowBox[{{-0.03284840321326722, 
        0.026218240911345062`}, {-0.03246746841014007, 
        0.02596349179320256}, {-0.030494663342686697`, 
        0.024678770201030535`}, {-0.028634620156791107`, 
        0.023504044266793974`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07243146172113951, 0.09}, {-0.07214515951234611, 
        0.08945006127156847}, {-0.07124094796886646, 
        0.08773939642828624}, {-0.07034204001945193, 
        0.08606509342495469}, {-0.06944843566410255, 
        0.08442715226157384}, {-0.0685601349028183, 
        0.08282557293814367}, {-0.06832097385025715, 
        0.08239799130695658}, {-0.06808225340896047, 
        0.0819728460194291}, {-0.0669284406395485, 
        0.08005346108363555}, {-0.06637500704668277, 0.07913281595882038}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0662147279329223, 
        0.07886618923685147}, {-0.06577462787013653, 
        0.07813407614784199}, {-0.06462081510072457, 
        0.07621469121204842}, {-0.0634670023313126, 
        0.07429530627625486}, {-0.06242427448022602, 
        0.07280048861830696}, {-0.061290064931695004`, 
        0.07095602731978028}, {-0.06016892419708462, 
        0.06916151511276485}, {-0.05962915809444354, 0.06831170020807806}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05946236513266767, 
        0.06804909915880795}, {-0.05906085227639487, 
        0.06741695199726068}, {-0.05796598310567709, 
        0.06571995820652528}, {-0.0568844506209826, 
        0.06406815397381617}, {-0.0558162548223114, 
        0.062461539299133347`}, {-0.0547613957096635, 
        0.06090011418247681}, {-0.05371987328303889, 
        0.059383878623846566`}, {-0.05269168754243758, 
        0.05791283262324261}, {-0.0525449611717376, 0.05770668300915482}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05236456802953962, 
        0.057453231796051246`}, {-0.05167683848785956, 
        0.05648697618066494}, {-0.05067532611930484, 
        0.055106309296113556`}, {-0.04968748156091286, 
        0.053766080438957115`}, {-0.0487136359368231, 
        0.05246153807856428}, {-0.04775378924703555, 
        0.051192682214935045`}, {-0.0468079414915502, 
        0.049959512848069404`}, {-0.04587609267036706, 
        0.04876202997796737}, {-0.044958242783486126`, 
        0.04760023360462893}, {-0.044885576830498694`, 
        0.04750969893503943}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04469084922594775, 
        0.04726708738708348}, {-0.044054391830907404`, 
        0.04647412372805408}, {-0.04316453981263089, 
        0.04538370034824284}, {-0.041427496271712994`, 
        0.04332838622760844}, {-0.03974335123527087, 
        0.04132961006677446}, {-0.038114670981854754`, 
        0.03945880137403704}, {-0.036620870749828005`, 0.0377972021614993}}]}, 
      {Arrowheads[{{0.019412072274130197`, 1.}}], 
       ArrowBox[{{-0.036411048920177276`, 
        0.03756752811542843}, {-0.0355853528588891, 
        0.03667266515003819}, {-0.034649873356184004`, 
        0.035678891567191375`}, {-0.03373457239154862, 
        0.034725417559011304`}, {-0.0328392708302736, 
        0.033810410543132476`}, {-0.031107949378967277`, 
        0.032088467158816546`}, {-0.029454475924590266`, 
        0.030498400755319524`}, {-0.02787741738946778, 
        0.029025550673717357`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAjI/ZTyV8jT97FK5H4XqEv4iPosdm
FI0/M69jClxDg78HxtIr8I2LPx/b7CyxXH6/N9IbsGQIij/daxwxlgN3v5GS
ZnSe4Yk/KYBKW1NSdr+uQbvk5bqJP9mK5VTtonW/Eqb+2juUiT9zt4dCX/V0
v6J3lYTsgIk/pJW22UefdL+HQkwfoW2JP//HrqCkSXS/eFf8xFlaiT/uQGv/
dPRzv2ODMY8WR4k/6SWnXrifc79oBzSX1zOJPxRixSduS3O/s0fsSMndhj80
KnOwi2hjv7onHXf4yYY/r4OnP7DQYr9XXs+EL7aGPycIBa2xOWK/slBup3ym
hj8ThB3zosJhv0C5tZSVkYY/KX0NEKskYb/+ZYQgt3yGP90mjRGXh2C/l5Il
iuwUhj/WeIKXZghbvzyyLSQUroU/WCKME30vVb/F9UOcN0iFP9JO+Ws9Bk+/
ZFD+6khbgz+QkNCchihFP8rERKEPmYI/rPqcBj/uUz8/cbUs
        "]]}, 
      {Arrowheads[{{0.011394345583163204`, 1.}}], 
       ArrowBox[{{0.008911637122003439, 0.0014774191397958587`}, {
        0.008564171400191776, 0.0020127726911708665`}, {0.006961286020173622, 
        0.004187307324649961}, {0.0055958304482273385`, 
        0.005781671176990643}, {0.004444757559175553, 
        0.00696464765517533}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.028481774113086014`, -0.01}, {-0.028062204329890886`, \
-0.009811972509321426}, {-0.026705682962462528`, -0.009194025138797805}, \
{-0.025409861005298393`, -0.008593966178810553}, {-0.024172110366373914`, \
-0.008011335302338005}, {-0.021861154358892455`, -0.006896585829714847}, \
{-0.02164172022491955, -0.006788740609079872}, {-0.02142430542754837, \
-0.00668153630666784}, {-0.021208892429169388`, -0.006574969538251154}, \
{-0.02110193170265228, -0.00652192428035329}, {-0.020995464909476482`, \
-0.006469037142553119}, {-0.020889489898035477`, -0.006416307705672446}, \
{-0.02078400452569377, -0.0063637355513934775`}, {-0.020679006657649608`, \
-0.006311320262151091}, {-0.018436224916635706`, -0.005172178011229274}, \
{-0.017288923907102342`, -0.004567431165080815}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01701372099098717, -0.004422370632414502}, \
{-0.01641648805249704, -0.004107566816356865}, {-0.016287654854944798`, \
-0.004038205519497993}, {-0.016159738903761274`, -0.0039691634118953914`}, \
{-0.01610216367276993, -0.00393798483120876}, {-0.016025665384739606`, \
-0.0038965075189204205`}, {-0.015949476135459585`, -0.003855138602610894}, \
{-0.015573415855088183`, -0.0036500155397792165`}, {-0.015205401378291464`, \
-0.0034477402617805446`}, {-0.014845270968415635`, -0.0032482770478671485`}, \
{-0.013151831547130352`, -0.002290570281728342}, {-0.011633797477173143`, \
-0.001398110645590232}, {-0.01027482313702995, -0.0005669377851649366}, \
{-0.009058562905186727, 0.0002069086538354272}, {-0.007000250135161277, 
        0.001596814975688874}, {-0.0063896039286012365`, 
        0.002037605848534886}}]}, 
      {Arrowheads[{{0.01072175662292158, 1.}}], 
       ArrowBox[{{-0.006137361482404671, 
        0.0022196853682851904`}, {-0.005748091608930859, 
        0.002500677218325132}, {-0.004672576067560134, 
        0.0033199290468668196`}, {-0.003773703511049103, 
        0.004054570461313938}, {-0.003051473939397766, 
        0.0047046014616664855`}, {-0.0012133366652040882`, 
        0.006690852081887529}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.053658564786938076`}, {-0.0997877523213601, 
        0.0535356208147656}, {-0.09798570194182335, 
        0.05249810256901205}, {-0.09621452767390973, 
        0.05148478446692337}, {-0.09447422951761925, 
        0.050495666508499536`}, {-0.09276480747295189, 
        0.049530748693740564`}, {-0.09230736806020103, 
        0.04927345205360093}, {-0.09185204289555228, 
        0.04901776370481454}, {-0.08986907990805694, 
        0.04793544579752838}, {-0.08916013284733357, 0.04754849651810286}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08888706582110828, 
        0.04739945423428983}, {-0.0878861169205616, 
        0.046853127890242215`}, {-0.08590315393306627, 
        0.04577080998295606}, {-0.08392019094557093, 
        0.0446884920756699}, {-0.08228308454695492, 
        0.04385282949662393}, {-0.08036115507514416, 
        0.04281403900020369}, {-0.07847991461378981, 
        0.04180426677769406}, {-0.07792627919697746, 0.04150925730058433}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07765173079594052, 
        0.0413629617823215}, {-0.07663936316289183, 
        0.04082351282909504}, {-0.07483800745174037, 
        0.03987036208435189}, {-0.07307435420962553, 
        0.03894339947340989}, {-0.07134840343654734, 
        0.038042624996269016`}, {-0.06966015513250579, 
        0.03716803865292928}, {-0.06800960929750086, 
        0.036319640443390686`}, {-0.06661784044753274, 
        0.03561013176096863}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06634058341165001, 
        0.03546903765772683}, {-0.0648216250346009, 
        0.034701408425716895`}, {-0.06328418660670587, 
        0.03393157461758171}, {-0.06178149725343081, 
        0.03318510072642612}, {-0.06031060358035905, 
        0.032459158535428585`}, {-0.05887150558749059, 
        0.031753748044589115`}, {-0.05746420327482544, 
        0.031068869253907703`}, {-0.05608869664236358, 
        0.03040452216338435}, {-0.05517881619888821, 
        0.029968569005514187`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05489826328851765, 
        0.029834147029415278`}, {-0.054744985690105025`, 
        0.029760706773019056`}, {-0.05343307041804977, 
        0.029137423082811822`}, {-0.052152950826197815`, 
        0.028534671092762646`}, {-0.049678093634058645`, 
        0.027382028447162466`}, {-0.04731040906464234, 
        0.026294045070242515`}, {-0.045049897117948885`, 
        0.025270720962002783`}, {-0.04359802932298297, 
        0.024624350651839058`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.043313828095451826`, 
        0.024497824506534944`}, {-0.0428965577939783, 
        0.024312056122443276`}, {-0.04157016931984117, 
        0.02372890901433722}, {-0.040276788128105916`, 
        0.023164338706542498`}, {-0.039016414218772555`, 
        0.02261834519905912}, {-0.03778904759184108, 
        0.022090928491887086`}, {-0.035433336185183795`, 
        0.021091825478477044`}, {-0.03320965390813406, 
        0.02016702966631237}, {-0.03186621535858032, 0.0196207731384255}}]}, 
      {Arrowheads[{{0.004185801941242829, 1.}}], 
       ArrowBox[{{-0.031578033835871475`, 
        0.019503595439416953`}, {-0.031118000760691884`, 
        0.019316541055393065`}, {-0.029158376742857258`, 
        0.01854035964571913}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.038300471367909567`, 0.09}, {0.03733108252766641, 
        0.08900693486866473}, {0.03586508139508092, 0.08748708321698213}, {
        0.034444437444018164`, 0.0859956515466162}, {0.03306915067447814, 
        0.08453263985756693}, {0.03173922108646085, 0.0830980481498343}, {
        0.031386204857234784`, 0.08271448156707725}, {0.03103614080892269, 
        0.08233284306885745}, {0.029811934692118656`, 0.08090441576764704}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.02960949295328284, 0.08066820284346028}, {
        0.029388349013903733`, 0.08041016783107935}, {0.02774055721888478, 
        0.07848749259330126}, {0.026092765423865828`, 0.07656481735552317}, {
        0.024444973628846876`, 0.07464214211774507}, {0.023375225885909796`, 
        0.07313967230450544}, {0.021829441864787646`, 0.07129115096517531}, {
        0.02166864139539901, 0.07109538839882959}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02147118134492391, 0.07085499552946342}, {
        0.020351663026263362`, 0.06949206555814381}, {0.018941889370336945`, 
        0.06774241608341097}, {0.017595589728551353`, 0.06603990078706874}, {
        0.016308232932449547`, 0.0643822179152091}, {0.015079818982031526`, 
        0.06276936746783204}, {0.013910347877297285`, 
        0.061201349444937575`}, {0.01380419799613967, 0.06105575569805655}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.013620924113833581`, 0.060804379710261015`}, {
        0.012799819618246827`, 0.059678163846525696`}, {0.011748234204880154`,
         0.05819981067259641}, {0.01075559163719726, 0.0567662899231497}, {
        0.009821891915198153, 0.05537760159818558}, {0.00893793724695717, 
        0.05402916718067245}, {0.008094529840548651, 0.0527164081535787}, {
        0.007291669695972603, 0.05143932451690433}, {0.006696406268871494, 
        0.050469952302653186`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.006533615582992482, 0.05020485157506692}, {
        0.006529356813229021, 0.050197916270649345`}, {0.005126372833239258, 
        0.04782212594939751}, {0.003885577900579362, 0.0455890371898232}, {
        0.0027814574247168908`, 0.04348419722783246}, {0.0017884968151193998`,
         0.04149315329933134}, {0.0009066960717868871, 0.03961590540431984}, {
        0.000728088810827928, 0.03920719972026903}}]}, 
      {Arrowheads[{{0.01895546345399484, 1.}}], 
       ArrowBox[{{0.0006035146118445898, 0.03892213749526651}, {
        0.00013605519471935733`, 
        0.03785245354279796}, {-0.00047783636562789963`, 
        0.036353689815186115`}, {-0.0010348908918840932`, 
        0.03492325404344766}, {-0.001535108384049223, 
        0.03356114622758262}, {-0.001978488842123289, 
        0.03226736636759097}, {-0.0026947386559982305`, 
        0.029884790515227886`}, {-0.003183640333508917, 
        0.027775526486358403`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.04786540885007602, 0.09}, {-0.04769729409395957, 
        0.08922745409616967}, {-0.04732136340351638, 
        0.08756187682301159}, {-0.04693946676204073, 
        0.08593083921226906}, {-0.046551604169532614`, 
        0.08433434126394208}, {-0.04615777562599204, 
        0.08277238297803066}, {-0.046050620044799255`, 
        0.08235525297757355}, {-0.04594315022940055, 
        0.08194044253978733}, {-0.04536773802311379, 
        0.08002118349979183}, {-0.04479232581682704, 
        0.07810192445979634}, {-0.044749188345648866`, 0.0779580415518276}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.044659848333936054`, 
        0.07766005234819283}, {-0.044216913610540275`, 
        0.07618266541980084}, {-0.04364150140425352, 
        0.07426340637980534}, {-0.04304549425225715, 
        0.07276883301271031}, {-0.04246644764378635, 
        0.07092451850322666}, {-0.041884978100526174`, 
        0.06913016701408425}, {-0.041301085622476634`, 
        0.06738577854528306}, {-0.04076952318193809, 0.06584500743141451}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04066686218677545, 
        0.06555134420898566}, {-0.04012971854814212, 
        0.06403737276410552}, {-0.0395431656233903, 
        0.06243097597557945}, {-0.03895603310691546, 
        0.06086978325509518}, {-0.03836832099871757, 
        0.05935379460265271}, {-0.037780029298796654`, 
        0.05788301001825204}, {-0.0371911580071527, 
        0.05645742950189316}, {-0.0366017071237857, 
        0.05507705305357609}, {-0.03611706675449566, 
        0.053972881607408985`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.035991645610764046`, 
        0.05368819253923051}, {-0.035428726740225784`, 
        0.05243291406346528}, {-0.034847112279618654`, 
        0.05116440194727102}, {-0.034268748306460074`, 
        0.049931594750317526`}, {-0.03312177182248858, 
        0.047573095114132845`}, {-0.03198779728831129, 
        0.045357415154911235`}, {-0.030861549206696617`, 
        0.04330303489851482}, {-0.030451801282737275`, 
        0.04255108351340051}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.030302947539466888`, 
        0.04227791366460654}, {-0.029772922061956936`, 
        0.04130523419839152}, {-0.028701517264796743`, 
        0.03943546915454158}, {-0.027649445014108674`, 
        0.03768634775662015}, {-0.026358803498302493`, 
        0.035651820981964705`}, {-0.02510134240985103, 
        0.0337796150371823}, {-0.023880283329968867`, 
        0.03205492598743923}, {-0.023664519148361138`, 
        0.03176418525637356}}]}, 
      {Arrowheads[{{0.002104380238632045, 1.}}], 
       ArrowBox[{{-0.023479125461570268`, 
        0.031514368555423014`}, {-0.022698847839870574`, 
        0.030462949897901832`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAASKucEKXDnj97FK5H4XqEvytiPhET
Yp4/SWduP8jEg7/CY1QoYjWdP245Q7c0noG/dwPcZdgSnD9OefHcWSh/v4ll
lc82+po/e0tP4W9Ke7/2j+5uRcOaP6kpxwjkinq/Z80qcraMmj8SdcStYM15
v0eCuFaJVpo/ElwFdOAReb+oRsRYlzuaP2+viwTgtHi/G78sor0gmj8sUnRg
Xlh4v0ydnyL8BZo/fOsH4Fr8d78R5MrJUuuZP3dzZtzUoHe/f+lch8HQmT+z
0muvy0V3v0sxkHfUJZg/AgBzfXWjcb/cUsuDh5OWP07Crson92i/8gra/zJ5
lj+PfXbiMk1ov4KJWuf5XpY/y3/4VEOkZ792idZ111SWP5xgDh4jY2e/+v4h
H7lKlj+rBzPDKSJnv5SybUaSO5Y/f3qQuvLAZr/W2Z4nfTGWP0Aj/4JQgGa/
dICwH2wnlj/ssyfk1D9mv/70BS+hw5U/dYXrWDHDY7+MYlqRaWGVP6qqDe5C
VWG/S6+gUuMYlT9dvNef1hpfvzyOycc=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.020357001405976387`, -0.0017077439771299651`}, {
        0.018750395019809643`, -0.00046989049973654223`}, {0.0171274165410682,
         0.0007357289364005534}, {0.01563298773445883, 
        0.0018061831930152187`}, {0.01425835536344573, 
        0.0027569442057457406`}, {0.012995482418768401`, 
        0.0036004588836127923`}, {0.011836331891166346`, 
        0.004349174135637045}, {0.010469704688974946`, 
        0.005201036132701323}, {0.010148008187863553`, 
        0.005394056405761935}}]}, 
      {Arrowheads[{{0.003242553729088524, 1.}}], 
       ArrowBox[{{0.009881248528698304, 0.005554114168515789}, {
        0.009236751957338432, 0.005940816864257683}, {0.008137473696256807, 
        0.006568516330306122}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.011076438687622309`}, {0.049571267752165735`, 
        0.011101200127822152`}, {0.0474268587550343, 0.011218693247143181`}, {
        0.045372239370810925`, 0.011324643296983197`}, {0.04340740959949561, 
        0.0114190502773422}, {0.04314816677146156, 0.011431018445018055`}, {
        0.042890425848095694`, 0.011442803833048463`}, {0.04114403021906787, 
        0.011503451446579856`}, {0.03939763459004006, 
        0.011564099060111249`}, {0.037651238961012246`, 
        0.01162474667364264}, {0.0375689383395737, 0.011627604752418969`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0372580321971027, 0.011638401684832052`}, {
        0.03590484333198443, 0.011685394287174033`}, {0.034748571430125226`, 
        0.01168725816581927}, {0.03310631528236246, 0.011737532179076636`}, {
        0.03153348545544306, 0.011780890458817982`}, {0.030030081949367023`, 
        0.01181733300504331}, {0.02859130582508237, 0.011847584583850223`}, {
        0.027212358143537105`, 0.011872369961336322`}, {0.02589323890473123, 
        0.011891689137501608`}, {0.024817662747005507`, 
        0.011903521138102922`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0245065817906377, 0.011906157809533947`}, {
        0.022294851844749945`, 0.011916849458072585`}, {0.02019506935179271, 
        0.011906291998515835`}, {0.018295132964779973`, 
        0.011880221797709013`}, {0.01655557501869867, 
        0.011844990919685298`}, {0.0149763955135488, 0.011800599364444692`}, {
        0.01355759444933036, 0.01174704713198719}, {0.012066857803388306`, 
        0.011673841987442904`}}]}, 
      {Arrowheads[{{0.0010619580512048776`, 1.}}], 
       ArrowBox[{{0.011756138662135799`, 0.011658583598437721`}, {
        0.011096197274702669`, 0.011626176060332779`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.00800915561699783, 0.09}, {-0.008358124032199613, 
        0.08886244800130046}, {-0.008831596793028626, 
        0.08727006610802232}, {-0.009280164475507205, 
        0.08570989263500012}, {-0.009703827079635345, 
        0.08418192758223382}, {-0.009814871241969912, 
        0.08377366101692875}, {-0.009924334349628578, 
        0.08336756677278172}, {-0.010355212688066186`, 
        0.08144182494763638}, {-0.010786091026503795`, 
        0.07951608312249106}, {-0.011133961666920336`, 
        0.07796133092859021}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.011201888290707233`, 
        0.07765774374678465}, {-0.011216969364941404`, 
        0.07759034129734574}, {-0.011647847703379012`, 
        0.07566459947220042}, {-0.011818779785288325`, 
        0.0741571157328525}, {-0.012203785254926823`, 
        0.07230518415814201}, {-0.01255820881203258, 
        0.07050245941705474}, {-0.012882050456605596`, 
        0.06874894150959071}, {-0.01317769329711935, 
        0.0670423345138862}, {-0.013440543000593086`, 0.06542331984425712}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.013487434183069363`, 
        0.06511578292481959}, {-0.01369153189138952, 
        0.06376296549216473}, {-0.013909727645145932`, 
        0.06219020346614776}, {-0.014102107703316562`, 
        0.06066205643002664}, {-0.014268672065901412`, 
        0.05917852438380135}, {-0.01440942073290048, 
        0.05773960732747191}, {-0.014524353704313769`, 
        0.05634530526103831}, {-0.014696173543050032`, 
        0.053672240918479344`}, {-0.01473563959321962, 
        0.052741745778153645`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.014748822472929145`, 
        0.05243093166190682}, {-0.014803532564777231`, 
        0.051141026176745166`}, {-0.014846430769495371`, 
        0.04875166103583578}, {-0.014824868157204447`, 
        0.04650414549575117}, {-0.014751871077467575`, 
        0.04438411541247841}, {-0.014640465879847867`, 
        0.04237720664200451}, {-0.014490652564345324`, 
        0.0404834191843295}, {-0.014439742282396664`, 0.04000178319919456}}]}, 
      {Arrowheads[{{0.013822455748581057`, 1.}}], 
       ArrowBox[{{-0.014407040995420093`, 
        0.03969241314730556}, {-0.014302431130959945`, 
        0.03870275303945338}, {-0.013933361689777072`, 
        0.03597137491421448}, {-0.013511387981718954`, 
        0.03347286043655776}, {-0.01303651000678559, 0.03120720960648323}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.01289898020268381, 0.09}, {0.011956861116387888`, 
        0.08842365347138105}, {0.0110466803047405, 0.08687378214360253}, {
        0.010170870387280671`, 0.08535445625727582}, {0.009329431364008406, 
        0.08386567581240094}, {0.009106847120534516, 0.08346776476716986}, {
        0.008886478303461946, 0.0830719190680257}, {0.007913227454742513, 
        0.08114694150236365}, {0.0069399766060230786`, 0.07922196393670158}, {
        0.006884424952928206, 0.07911208919466178}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0067440593548236845`, 0.0788344622830619}, {
        0.005966725757303645, 0.07729698637103953}, {0.004993474908584211, 
        0.07537200880537746}, {0.004417235866443421, 0.07386566095604129}, {
        0.003514045924767277, 0.07201455922267203}, {0.002657563254453326, 
        0.07021270804416463}, {0.0018477878555015694`, 0.06846010742051911}, {
        0.001451999378716196, 0.06757921108531717}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.0013245023086918572`, 0.0672954441028986}, {
        0.0010814386198723307`, 0.06675446343958866}, {0.000355234439525932, 
        0.06509348218922645}, {-0.00033082468553762446`, 
        0.06347716366943251}, {-0.0009767387553183391, 
        0.06190550788020682}, {-0.0015825077698162129`, 
        0.06037851482154939}, {-0.0021481317290312453`, 
        0.058896184493460214`}, {-0.002673610632963434, 
        0.0574585168959393}, {-0.0031589444816127834`, 
        0.056065512028986644`}, {-0.0032690603500762122`, 
        0.05573580955297688}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0033676099647408212`, 
        0.05544073807583077}, {-0.0036107972136864134`, 
        0.054712601075867}, {-0.004035832767891443, 
        0.05339521521984514}, {-0.004434051144227876, 
        0.052113354460921045`}, {-0.00480545234269571, 
        0.05086701879909473}, {-0.005467803206025584, 
        0.04848092276673543}, {-0.0060228853578810655`, 
        0.046236927122767224`}, {-0.006488998046444591, 
        0.04412065717360822}, {-0.006623437767510511, 0.04343971902772415}}]}, 
      {Arrowheads[{{0.016502213279178946`, 1.}}], 
       ArrowBox[{{-0.006683694753223484, 
        0.04313451696539738}, {-0.0068844405198986, 
        0.042117738225676514`}, {-0.007209212778243091, 
        0.04022817027897211}, {-0.007463314821478066, 
        0.038451953333495}, {-0.00763842252206625, 
        0.03698094705403976}, {-0.007781200841894606, 
        0.03557478848461837}, {-0.007891649780963135, 
        0.034233477625230845`}, {-0.007969769339271836, 
        0.03295701447587718}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.027272964191524376`, 0.09}, {-0.027276912480346888`, 
        0.08992497299740682}, {-0.027349575797889002`, 
        0.08827936678738038}, {-0.02740654672949227, 
        0.08666712566152274}, {-0.027447825275156688`, 
        0.08508824961983388}, {-0.027473411434882255`, 
        0.08354273866231382}, {-0.02747820197020444, 
        0.08312989084662278}, {-0.0274820277360095, 
        0.08271928849567767}, {-0.027417881130661084`, 
        0.08079656345942685}, {-0.02735373452531267, 
        0.07887383842317604}, {-0.027309989779864, 0.07756263704592878}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.027299616742132878`, 
        0.07725171647204541}, {-0.027289587919964255`, 
        0.07695111338692523}, {-0.02722544131461584, 
        0.07502838835067442}, {-0.02702032731673571, 
        0.07352696113705856}, {-0.02693130411270523, 
        0.07167858277539038}, {-0.02682569650955337, 
        0.06987976886344396}, {-0.026703504507280134`, 
        0.06813051940121931}, {-0.026566377466170372`, 
        0.0664284982754444}, {-0.026422619423504577`, 0.06484468536375383}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.026391975948174932`, 
        0.06453510792501733}, {-0.026252266348295812`, 
        0.06315913269342786}, {-0.026075282271531018`, 
        0.061591788237186224`}, {-0.025885012516214546`, 
        0.06006933600412234}, {-0.0256814570823464, 
        0.05859177599423621}, {-0.025464615969926573`, 
        0.057159108207527835`}, {-0.025234489178955072`, 
        0.055771332643997217`}, {-0.024747881541740673`, 
        0.0531118185860867}, {-0.02456860463682357, 0.05223169156463535}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.024506511704455048`, 
        0.05192685772313214}, {-0.024235137151086838`, 
        0.0505945942201221}, {-0.023696256006993568`, 
        0.04821965954610343}, {-0.02313123810946086, 
        0.04598701456403069}, {-0.02254870250867104, 
        0.04388209502187917}, {-0.02195726825480644, 
        0.04189033666762414}, {-0.02135693534786705, 
        0.04001173950126561}, {-0.021320450892307455`, 0.0399060145606568}}]}, 
      {Arrowheads[{{0.007685631348015542, 1.}}], 
       ArrowBox[{{-0.02121896873224225, 
        0.039611938763685635`}, {-0.020747703787852883`, 
        0.03824630352280358}, {-0.020160151928593217`, 
        0.03664582837093475}, {-0.01957459430772247, 0.03512214909553918}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.045450421187606234`, -0.01}, {
        0.04525446368991769, -0.00988095630551021}, {
        0.04402142966243168, -0.009131891187844444}, {
        0.04236717965998954, -0.008282186036967617}, {
        0.040848475714490635`, -0.007421399839317466}, {
        0.03937933671301918, -0.0065978973668506125`}, {
        0.03795976265557519, -0.0058116786195670555`}, {
        0.036589753542158654`, -0.005062743597466797}, {
        0.03640810885639764, -0.004964132800304746}, {
        0.03622731185157199, -0.004866141307200668}, {
        0.03455288148764037, -0.003998897446342777}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.034276640778214684`, -0.0038558230823507516`}, {
        0.03283380990982114, -0.00310853239781461}, {
        0.03113705893894572, -0.0022297279431215808`}, {
        0.029440307968070293`, -0.001350923488428552}, {
        0.02839238463872329, -0.0008971269715379172}, {
        0.0268101326634117, -0.00009332391763354616}, {0.02530421335180934, 
        0.0006604782024117199}, {0.023874626703916206`, 
        0.0013642793885978808`}, {0.023151874964761152`, 
        0.0017143123621052717`}}]}, 
      {Arrowheads[{{0.014210915475527813`, 1.}}], 
       ArrowBox[{{0.02287188898710078, 0.0018499112392735338`}, {
        0.022515506510025932`, 0.002022509396286997}, {0.021220986560432153`, 
        0.002639597980841131}, {0.019991066855134867`, 
        0.003215545142260281}, {0.018825747394134076`, 
        0.003750350880544448}, {0.016688909205021977`, 
        0.004696538087707833}, {0.014810471993095858`, 
        0.005478159602331285}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05327694501323778, -0.01}, {-0.052025343090157335`, \
-0.009705202320220615}, {-0.04955496810216892, -0.009116448764185497}, \
{-0.0470845931141805, -0.008527695208150379}, {-0.04461421812619208, \
-0.00793894165211526}, {-0.04296192412285589, -0.00746414387313376}, \
{-0.04120059188310578, -0.007005603862596678}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04089953325979289, -0.0069272271536540446`}, \
{-0.04083978430562643, -0.006911672288163729}, {-0.03881294582793042, \
-0.006373940801740026}, {-0.03688140868976785, -0.005850949413862649}, \
{-0.03504517289113874, -0.0053426981245316}, {-0.034803664881952995`, \
-0.005275065430301494}, {-0.03456373475663412, -0.00520769138681185}, \
{-0.03287892178810459, -0.004700669924568041}, {-0.03119410881957505, \
-0.004193648462324232}, {-0.02950929585104551, -0.003686627000080423}, \
{-0.0289344435407215, -0.00351363304502493}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02863654683263815, -0.003423985097536811}, \
{-0.027824482882515975`, -0.003179605537836614}, {-0.025241124773331812`, \
-0.0023199441970179944`}, {-0.023752878761771005`, -0.001851518130691435}, \
{-0.02234325953299769, -0.0013985302227317756`}, {-0.01973544300449368, \
-0.0005357001022406828}, {-0.017393216768499947`, 
        0.00027171494412775703`}, {-0.01682164959844825, 
        0.0004786932049848228}}]}, 
      {Arrowheads[{{0.014663085157740301`, 1.}}], 
       ArrowBox[{{-0.016529144112674667`, 
        0.0005846164978343605}, {-0.015316580825016485`, 
        0.0010237149163735435`}, {-0.013505535174043298`, 
        0.0017202998144966767`}, {-0.01190852103168833, 
        0.002367390550122375}, {-0.010473979614059539`, 
        0.002970908034875858}, {-0.009201910921156915, 
        0.003530852268757126}, {-0.008092314952980463, 
        0.004047223251766178}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.1, 0.03342419335838609}, {-0.09899993536034518, 
        0.03310141647241826}, {-0.09704708253573255, 
        0.032475387160928924`}, {-0.0951333948403761, 
        0.03186626433074432}, {-0.09462192658628653, 
        0.031704064555632246`}, {-0.09411310689483236, 
        0.031542979838980204`}, {-0.0921259368839357, 
        0.030930938082731185`}, {-0.09013876687303903, 
        0.030318896326482162`}, {-0.08815159686214237, 
        0.029706854570233143`}, {-0.08812703558607506, 
        0.029699289778867773`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08782972433856223, 
        0.02960771890315884}, {-0.0861644268512457, 
        0.02909481281398412}, {-0.08452309475965547, 
        0.02862111596951427}, {-0.0825969549698129, 
        0.02803348802122628}, {-0.08071150199400635, 
        0.027462135944912307`}, {-0.07886673583223587, 
        0.026907059740572357`}, {-0.0770611212471158, 
        0.02636748355534528}, {-0.07591261540125087, 
        0.026026535472721147`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07561438550104649, 
        0.02593800225974538}, {-0.07529312300126051, 
        0.025842631536369936`}, {-0.07356274109466998, 
        0.025332503683646323`}, {-0.07186997552734424, 
        0.024837099997174438`}, {-0.07021482629928327, 
        0.024356420476954282`}, {-0.06859729341048708, 
        0.023890465122985857`}, {-0.06701737686095566, 
        0.02343923393526916}, {-0.06547507665068901, 
        0.023002726913804197`}, {-0.06396734436837252, 
        0.0225793953512975}, {-0.06365718647112462, 0.022492894610085804`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0633575285631316, 
        0.022409322238138026`}, {-0.0624911316026916, 
        0.022167690540455608`}, {-0.06104643835364624, 
        0.02176761248127852}, {-0.05963326462123643, 
        0.021379161173766238`}, {-0.05825161040546217, 
        0.021002336617918758`}, {-0.05690147570632348, 
        0.020637138813736085`}, {-0.05558286052382034, 
        0.02028356776121822}, {-0.05429576485795276, 
        0.019941623460365154`}, {-0.0518287824791672, 
        0.01929865375790686}, {-0.051342466592265816`, 
        0.01917207813859188}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.051041403378560654`, 
        0.01909371906426574}, {-0.049428842952723526`, 
        0.018674010722258497`}, {-0.04714486117038774, 
        0.018091043777866616`}, {-0.044971776970942665`, 
        0.017547337467029852`}, {-0.04333179862810884, 
        0.017144548500710444`}, {-0.0417550374457185, 
        0.016763812402715482`}, {-0.040238984105353606`, 
        0.01640397499712918}, {-0.03896205628385393, 
        0.016106089318126172`}}]}, 
      {Arrowheads[{{0.0021106889553604213`, 1.}}], 
       ArrowBox[{{-0.03865899016083831, 
        0.01603587682782938}, {-0.037378963677028115`, 
        0.015742379559519418`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.09657595528223646, -0.01}, {-0.09567466138822005, \
-0.009905471654621382}, {-0.09418235747564879, -0.00974698214582525}, \
{-0.09271299736993183, -0.009588923387991688}, {-0.09126658107106912, \
-0.009431295381120695}, {-0.0898431085790607, -0.009274098125212269}, \
{-0.08844257989390653, -0.009117331620266414}, {-0.08571035394416103, \
-0.008805090863262404}, {-0.08420803956171778, -0.008629157167199834}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08389905753615604, -0.008592972763715944}, \
{-0.08306232601144277, -0.008494984438851834}, {-0.0804909188853619, \
-0.008187423675777863}, {-0.07799613256591845, -0.007882408574040496}, \
{-0.0755779670531124, -0.007579939133639729}, {-0.07319811194362483, \
-0.007278742523907233}, {-0.07154892093924853, -0.00707001942251371}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07124028933787446, -0.0070309587286002066`}, \
{-0.07081825683413726, -0.006977545914174738}, {-0.06843840172464968, \
-0.006676349304442242}, {-0.06660214167799261, -0.00639847812456558}, \
{-0.06502670973125221, -0.0061806505615740635`}, {-0.06348487455319149, \
-0.005964640466575477}, {-0.06197663614381042, -0.005750447839569821}, \
{-0.060501994503109, -0.005538072680557097}, {-0.05906094963108725, \
-0.005327514989537303}, {-0.05891707173761948, -0.005306176296124891}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.05860934418548988, -0.00526053687417355}, \
{-0.05765350152774516, -0.005118774766510439}, {-0.05493939562709996, \
-0.004706746724435504}, {-0.05458200117438308, -0.004651604199632432}, \
{-0.0542268397241866, -0.004596599740774836}, {-0.0524069181362936, \
-0.004292826942937203}, {-0.05058699654840059, -0.00398905414509957}, \
{-0.048767074960507584`, -0.003685281347261936}, {-0.046947153372614576`, \
-0.003381508549424303}, {-0.046328472793605247`, -0.0032583263974085607`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.046023368036848485`, -0.0031975786354734464`}, \
{-0.04562953810275644, -0.0031191652821928938`}, {-0.04389825880628135, \
-0.0028227035779916526`}, {-0.042226074370751536`, -0.0025311159362146735`}, \
{-0.040612984796167005`, -0.002244402356861956}, {-0.03905556566786868, \
-0.001962505756493255}, {-0.037550392571197494`, -0.0016853690516683256`}, \
{-0.03609746550615345, -0.0014129922423871675`}, {-0.03469678447273654, \
-0.0011453753286497811`}, {-0.03378190594319447, -0.0009651569825301029}}]}, 
      {Arrowheads[{{0.0196667454475509, 1.}}], 
       ArrowBox[{{-0.0334766779827838, -0.0009050313194628695}, \
{-0.03205216050078414, -0.0006244211878063237}, {-0.029616520655340293`, \
-0.00012250662913795233`}, {-0.027362241084440936`, 
        0.00036070994243366937`}, {-0.025261697936122, 
        0.0008255701219868807}, {-0.023314891210383482`, 
        0.00127207390952168}, {-0.02152182090722539, 
        0.0017002213050380673`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.018370927466193877`}, {-0.09844661998930587, 
        0.018123500171866914`}, {-0.09638429806013056, 
        0.01779881516652589}, {-0.09583355166320832, 
        0.0177126329965884}, {-0.09528585786322989, 
        0.017627169850029954`}, {-0.09329565283554306, 
        0.017329846994156295`}, {-0.09130544780785621, 
        0.01703252413828264}, {-0.08931524278016936, 
        0.01673520128240898}, {-0.0876987701330542, 0.016493711457393045`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.08739109106228157, 
        0.01644774633382937}, {-0.08732503775248251, 
        0.01643787842653532}, {-0.08567922631617504, 
        0.016216761297688186`}, {-0.08374979662814339, 
        0.015932886511289795`}, {-0.08186088383321517, 
        0.015657977104541584`}, {-0.08001248793139043, 
        0.015392033077443553`}, {-0.07820307631442283, 
        0.015134603156391964`}, {-0.07643111637406606, 
        0.014885236067783084`}, {-0.07507135123735713, 
        0.014696065960189807`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07476322516805327, 
        0.014653199556199203`}, {-0.07469660811032014, 
        0.014643931811616911`}, {-0.07299955152318505, 
        0.014410690387893449`}, {-0.07133994661266078, 
        0.014185511796612694`}, {-0.06971779337874737, 
        0.013968396037774647`}, {-0.06813309182144477, 
        0.013759343111379307`}, {-0.06658584194075302, 
        0.013558353017426677`}, {-0.06507299796327179, 
        0.01336452493040037}, {-0.06359151411560073, 
        0.013176958024784005`}, {-0.06242574801316715, 
        0.013031204897065496`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06211705290078771, 
        0.012992649583237866`}, {-0.06072262680968912, 
        0.012820607757781101`}, {-0.05797918002301825, 
        0.01248930221641796}, {-0.05536117375558809, 
        0.012183041400694587`}, {-0.0528811972209668, 
        0.011905313872042562`}, {-0.05046791154226818, 
        0.011636351115682914`}, {-0.049756202919016494`, 
        0.011559940665208929`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.049446886931371295`, 
        0.011526731886809152`}, {-0.048169995011955756`, 
        0.011389642235817765`}, {-0.045982411944602265`, 
        0.011163791807874482`}, {-0.044337625211358346`, 
        0.011000151904387743`}, {-0.04275521416111259, 
        0.010848046838363155`}, {-0.04123271533162757, 
        0.010706821535752966`}, {-0.039767665260665844`, 
        0.010575820922509424`}, {-0.03835760048598997, 
        0.010454389924584775`}, {-0.037059574906598426`, 
        0.010346806411409677`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.05768296844496328}, {0.04914330693322274, 
        0.05718046421430395}, {0.047688278864185835`, 
        0.056318153400363336`}, {0.04627483751049885, 0.05547139023776747}, {
        0.04589876079071003, 0.055244825909472356`}, {0.045525416106770876`, 
        0.05501932443757595}, {0.043743414398672326`, 
        0.053886481278361396`}, {0.04196141269057377, 0.05275363811914684}, {
        0.04017941098247521, 0.05162079495993228}, {0.039418625139698474`, 
        0.05113715286593197}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.039156090243545036`, 0.05097025579742137}, {
        0.03839740927437666, 0.05048795180071772}, {0.03715426244767448, 
        0.04958654907842995}, {0.03546735277746941, 0.04849454834926129}, {
        0.03384383779919332, 0.04742977590678991}, {0.03228371751284621, 
        0.0463922317510158}, {0.030783113484259585`, 0.04538074532976513}, {
        0.02933814727926491, 0.04439414609086409}, {0.028824107922920814`, 
        0.04403832103671891}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.028568317968470164`, 0.04386125974118015}, {
        0.0279488188978622, 0.04343243403431267}, {0.026615128340051454`, 
        0.04249560916011087}, {0.025337075605832662`, 0.0415836714682587}, {
        0.024114660695205837`, 0.040696620958756154`}, {0.02294788360817097, 
        0.039834457631603225`}, {0.021836744344728064`, 
        0.038997181486799926`}, {0.019750027108046533`, 
        0.03738802371223221}, {0.018572468890870764`, 0.03645413756949706}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.018328723844026316`, 0.036260830675376526`}, {
        0.017823156804589645`, 0.035859880603043015`}, {0.016056133434357397`,
         0.03441275215923235}, {0.014448956997349797`, 0.0330466383808002}, {
        0.012979254694235625`, 0.03175398757375377}, {0.011624653725683678`, 
        0.030527248044100258`}, {0.010385154091693955`, 
        0.02936641979183966}, {0.009260755792266451, 0.02827150281697197}, {
        0.009014019362020047, 0.02801942488516842}}]}, 
      {Arrowheads[{{0.003376777944875858, 1.}}], 
       ArrowBox[{{0.00879641106619584, 0.027797105671504344`}, {
        0.007326781278273426, 0.02629566043665836}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAlZt3KT/Jdj97FK5H4XqEv2yHYWIa
ynY/rmtdhhx3hL+07QiUuNV2P8aHpLEHQ4S/eH8+URHhdj9EA/ACMw+Ev1ix
zzkl7HY/+zMWLp7bg7+iAYjs9PZ2P6k4OedIqIO/xW+2/lKIdz/p4hvKbXeA
v8x6SdUP23c/aG/jFQELe7+fJqaeiN53P9a24CBzqXq/1VQwgsPhdz85/7u9
bEh6v962K4OP43c/Kdj+HKEMer+7WhJt0+V3PxmWSFkxvXm/fOLLC/Hndz9z
t0glF255v8Mo2Zkw8Hc/2YYGvtvnd78bPRiGqPR3P0o8My9Qana/9ObNk4T1
dz9DWManRPV0v8jFv15Qznc/rjmO2ck9bL+DKV0Lu2F3PzY3IVteCGC/qyaO
p1nzdT/+04zSukRCPznfwFqiPnQ/yr8W5ghPYz+qXaHf
        "]]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.09570766941431641, 0.09}, {-0.09495411149002272, 
        0.08905590261323965}, {-0.09355231868732979, 
        0.08731977152765714}, {-0.09317595606498676, 
        0.0868563898581564}, {-0.09280076202883004, 
        0.08639570164715989}, {-0.09114850970815833, 
        0.08445787154467793}, {-0.08949625738748661, 
        0.08252004144219596}, {-0.08784400506681489, 
        0.08058221133971401}, {-0.08773144074147271, 0.0804501912266934}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08752960025936601, 
        0.0802134643313928}, {-0.08619175274614317, 
        0.07864438123723205}, {-0.08474675449657443, 
        0.07711389913227337}, {-0.08313107642374441, 
        0.07524795397053083}, {-0.08153978118280887, 
        0.07342993210261455}, {-0.07997286877376779, 
        0.07165983352852452}, {-0.0792869846718621, 0.07089331161362626}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07907954090416541, 
        0.07066147916029081}, {-0.078429916530455, 
        0.06993547994625805}, {-0.07691050178670433, 
        0.06825469305381239}, {-0.07541462454251578, 
        0.06661747285118755}, {-0.07394228479788935, 
        0.06502381933838353}, {-0.07249348255282503, 
        0.06347373251540031}, {-0.07106821780732284, 
        0.061967212382237916`}, {-0.07063874090191392, 
        0.061518976308191795`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07042351519446165, 
        0.0612943497335676}, {-0.06966649056138276, 
        0.06050425893889634}, {-0.06828830081500481, 
        0.05908487218537558}, {-0.06693284925056606, 
        0.05770470813571676}, {-0.06559933655044359, 
        0.05635942280396098}, {-0.06428776271463739, 
        0.055049016190108255`}, {-0.06299812774314748, 
        0.05377348829415859}, {-0.06173043163597384, 
        0.05253283911611197}, {-0.061658010761436295`, 
        0.05246274283393837}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.06143447610209081, 
        0.052246383273837536`}, {-0.060484674393116486`, 
        0.051327068655968415`}, {-0.05926085601457542, 
        0.0501561769137279}, {-0.05805897650035063, 
        0.04902016388939045}, {-0.0568917019236001, 
        0.04796454593608484}, {-0.05572579873186857, 
        0.04686989613353271}, {-0.05458135793775145, 
        0.04580841283497282}, {-0.053458141307897805`, 
        0.04477923993344979}, {-0.052355910608956696`, 
        0.04378152132200821}, {-0.05233335974278761, 0.04376135512122603}}]}, 
      {Arrowheads[{{0.001783210614865795, 1.}}], 
       ArrowBox[{{-0.05210146433017964, 
        0.043553981736272444`}, {-0.05127442760757721, 
        0.04281440089369268}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.035267636722781964`}, {0.04812722462117538, 
        0.03465478920223906}, {0.04566190601006123, 0.03383375594195599}, {
        0.043315191482793156`, 0.03303725298164704}, {0.041087081039371136`, 
        0.03226528032131219}, {0.04079423622430228, 0.03216270030307709}, {
        0.04050335134216347, 0.03206054590839201}, {0.03876758425545556, 
        0.0314139456288122}, {0.03823563102687705, 0.031215784764398874`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037944107626404405`, 0.03110718775637104}, {
        0.03703181716874764, 0.03076734534923239}, {0.03529605008203973, 
        0.03012074506965258}, {0.03356028299533182, 0.029474144790072772`}, {
        0.03242511482912483, 0.02897736909098579}, {0.030795335787211192`, 
        0.028357208443257655`}, {0.029236215441827078`, 
        0.02775467421676397}, {0.027747753792972486`, 
        0.027169766411504738`}, {0.026343582693123226`, 
        0.026609070139989487`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.026055240925752697`, 0.02649228800024315}, {
        0.024963109886505047`, 0.026049532259990262`}, {0.0236620034543055, 
        0.02551338146256018}, {0.02242170736946207, 0.024993208184014862`}, {
        0.020123546241843548`, 0.024000794183578544`}, {0.018068626503649488`,
         0.0230722902586813}, {0.016216448472774696`, 0.0222012971016035}, {
        0.014679675448906818`, 0.021455723263033084`}}]}, 
      {Arrowheads[{{0.019269753379811017`, 1.}}], 
       ArrowBox[{{0.014400688933686812`, 0.021318098150754156`}, {
        0.012998818486667372`, 0.020612645167747308`}, {0.011633366531434836`,
         0.019894986390968917`}, {0.009281531381687354, 
        0.018591872548076066`}, {0.007363349702946878, 0.01745094320631148}, {
        0.006088774036439653, 0.01663929354122442}, {0.004993990505620636, 
        0.015904304639191978`}, {0.0040789991104898254`, 
        0.01524597650021416}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.04226712179430375}, {0.0495218744032061, 
        0.04206927814825914}, {0.04818222218015196, 0.04150959944998542}, {
        0.046877774428723214`, 0.04095914416428124}, {0.045608531148919856`, 
        0.04041791229114659}, {0.045270528250818017`, 0.04027299920089122}, {
        0.04493484763682781, 0.0401287217165645}, {0.043164605618131326`, 
        0.03932657767733081}, {0.04139436359943484, 0.03852443363809712}, {
        0.03962412158073835, 0.03772228959886343}, {0.03860838433637843, 
        0.0372620318672167}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03832502394530244, 0.037133633689873755`}, {
        0.037853879562041864`, 0.03692014555962974}, {0.03664027766714696, 
        0.03628890528513027}, {0.03496826625853311, 0.035516920733790855`}, {
        0.033361741923307674`, 0.03476504250771428}, {0.03182070466147066, 
        0.03403327060690057}, {0.0303409601189119, 0.03332072363435919}, {
        0.02891831394152122, 0.032626520193099626`}, {0.027552766129298613`, 
        0.03195066028312187}, {0.02711655778596786, 0.03173145874582944}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.026838587524158047`, 0.03159177432749613}, {
        0.02624431668224409, 0.031293143904425946`}, {0.02379871288363928, 
        0.030033141740879538`}, {0.02158150254570678, 
        0.028846513702460403`}, {0.019558592370237722`, 0.0277263318488137}, {
        0.017695889059023223`, 0.026665668239584585`}, {0.015993392612063277`,
         0.02566452287477306}, {0.015923523174332748`, 
        0.025621864895239585`}}]}, 
      {Arrowheads[{{0.009707257486163008, 1.}}], 
       ArrowBox[{{0.015658005061640758`, 0.02545975587325681}, {
        0.014451103029357898`, 0.024722895754379134`}, {0.013045292400904018`,
         0.02383507879407947}, {0.011752232816698573`, 
        0.022995363909550755`}, {0.01057192427674157, 
        0.022203751100792986`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.028571415663610603`}, {0.049477485136896794`, 
        0.02845101449944538}, {0.04705965068706955, 0.02788058157407133}, {
        0.04674152777362303, 0.027804583887293007`}, {0.04642545357070713, 
        0.02772885562861918}, {0.0446509868421218, 0.027275972754701148`}, {
        0.042876520113536466`, 0.026823089880783118`}, {0.04110205338495113, 
        0.026370207006865088`}, {0.0393275866563658, 0.025917324132947058`}, {
        0.03810727648609625, 0.025551387521652758`}, {0.037941005065550204`, 
        0.025507997880564168`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037639991970656296`, 0.02542944649688368}, {
        0.03643060209133135, 0.025113848105844796`}, {0.03481912258578007, 
        0.024686537662110215`}, {0.033272837969442415`, 
        0.024269456190449016`}, {0.031787556805424014`, 
        0.023862244335899313`}, {0.030359087656830496`, 
        0.02346454274349923}, {0.02898743052366187, 0.02307635141324876}, {
        0.027672585405918132`, 0.02269767034514791}, {0.025651069113530742`, 
        0.02209856820499879}}]}, 
      {Arrowheads[{{0.018648052059656174`, 1.}}], 
       ArrowBox[{{0.025352798595190858`, 0.022010171932085366`}, {
        0.025213331216705322`, 0.02196883899539506}, {0.02298132508919206, 
        0.021278048694240673`}, {0.020942441603230964`, 
        0.020622595736694855`}, {0.019062555338674635`, 0.0199997764177677}, {
        0.01734166629552308, 0.01940959073745921}, {0.015779774473776303`, 
        0.018852038695769385`}, {0.014353256289836257`, 
        0.01832452542396273}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.1, 0.004644973431636315}, {-0.09784168167731709, 
        0.004588225402877709}, {-0.09725238476638431, 
        0.0045733000349151695`}, {-0.09666652938063583, 
        0.004558723255170472}, {-0.09467163452272637, 
        0.004521883144531726}, {-0.09267673966481689, 
        0.0044850430338929815`}, {-0.09068184480690741, 
        0.004448202923254236}, {-0.08868694994899795, 
        0.004411362812615491}, {-0.08755874322247655, 
        0.004406886184868435}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08724765211126544, 
        0.004405651801960079}, {-0.0870328496570994, 
        0.004404799484203191}, {-0.08509809501672128, 
        0.004373302335133818}, {-0.08320343385469736, 
        0.004345367160444027}, {-0.08134886617102768, 
        0.0043209939601338175`}, {-0.07953289181292404, 
        0.004299951027522732}, {-0.07775401062759822, 
        0.004282006655930314}, {-0.07601222261505022, 
        0.004267160845356562}, {-0.07480483819522177, 
        0.004258840619496925}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0744937520213185, 
        0.0042566968886468505`}, {-0.07430752777528007, 
        0.004255413595801477}, {-0.07263992610828775, 
        0.004246764907265059}, {-0.07100941761407326, 
        0.004241214779747308}, {-0.0694160022926366, 
        0.004238763213248223}, {-0.06785968014397777, 
        0.0042394102077678054`}, {-0.06633746950999714, 
        0.00424269268175251}, {-0.06484638873259506, 
        0.004248147553648791}, {-0.06338643781177154, 
        0.00425577482345665}, {-0.06205011280057975, 0.004264940100622948}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06173903117156977, 
        0.0042676396774968236`}, {-0.059193364188772385`, 
        0.0042916910203496875`}, {-0.05655363105633242, 
        0.004326497141169599}, {-0.05405075973213749, 
        0.004371725300412954}, {-0.051614810051913096`, 
        0.004417558299675989}, {-0.04929707874990777, 
        0.004470613147407106}}]}, 
      {Arrowheads[{{0.019945184919583612`, 1.}}], 
       ArrowBox[{{-0.048986098283724376`, 
        0.004478999693451263}, {-0.04708191030100082, 
        0.0045304422221650095`}, {-0.04540581594227937, 
        0.004582047535810825}, {-0.04379272784446941, 
        0.004637197833339348}, {-0.042240177049207225`, 
        0.004695569589841388}, {-0.040745694598129115`, 
        0.004756839280407749}, {-0.03930681153287138, 
        0.004820683380129241}, {-0.037921058895070324`, 
        0.004886778364096671}, {-0.03658596772636223, 
        0.004954800707400845}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.1, 0.07556703343984189}, {-0.0997972929490473, 
        0.07538114302959505}, {-0.09817727674695609, 
        0.07390811982265563}, {-0.09658084641619881, 
        0.07246932173721725}, {-0.09615292964244682, 
        0.07208540861936504}, {-0.09572666579971112, 
        0.0717037797431245}, {-0.09372237209279835, 
        0.06997624003640614}, {-0.0917180783858856, 
        0.06824870032968777}, {-0.09066454035922597, 0.06734063542517055}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.0904288975734469, 
        0.06713753032753388}, {-0.08971378467897283, 
        0.06652116062296941}, {-0.08770949097206007, 
        0.06479362091625104}, {-0.08602734918402176, 
        0.06346637226159656}, {-0.0840799058157339, 
        0.06180947215230123}, {-0.08217036267319597, 
        0.0601996651079546}, {-0.08089887928078972, 0.059138049746358015`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.08066007966510806, 
        0.05893866582843578}, {-0.08029871975640798, 
        0.05863695112855666}, {-0.0784638159715619, 
        0.05711899032898698}, {-0.07666449022484974, 
        0.05564344282412513}, {-0.07490074251627146, 
        0.05421030861397111}, {-0.07317257284582708, 
        0.05281958769852493}, {-0.0714799812135166, 
        0.05147128007778657}, {-0.07100105833362111, 
        0.051093840403386964`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0707567233468774, 
        0.05090127971833241}, {-0.06982296761934002, 
        0.050165385751756046`}, {-0.06820153206329733, 
        0.048901904720433355`}, {-0.06661567454538855, 
        0.04768083698381849}, {-0.06506313315544787, 
        0.04649750262072551}, {-0.06354164598330951, 
        0.04534722170996847}, {-0.06205121302897345, 
        0.044229994251547375`}, {-0.06086667781496473, 
        0.04335000178888408}}]}, 
      {Arrowheads[{{0.016102800001280795`, 1.}}], 
       ArrowBox[{{-0.060616954623072775`, 
        0.043164482165644315`}, {-0.060591834292439695`, 
        0.043145820245462214`}, {-0.059163509773708246`, 
        0.04209469969171299}, {-0.05776623947277911, 
        0.0410766325902997}, {-0.05640002338965229, 
        0.04009161894122235}, {-0.055064861524327775`, 
        0.03913965874448095}, {-0.05375865728633129, 
        0.038217162756662384`}, {-0.05247931408518855, 
        0.037320541734353535`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07945326419882273, 0.09}, {-0.07921318452302256, 
        0.08960313646316534}, {-0.07815636705691012, 
        0.0878820353000245}, {-0.07787208182213108, 
        0.08742257667167613}, {-0.07758843101855925, 
        0.08696574837494256}, {-0.07631062422242005, 
        0.08502573838559165}, {-0.07503281742628086, 
        0.08308572839624073}, {-0.07375501063014166, 
        0.08114571840688982}, {-0.07270265452983223, 0.07954799537620696}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07253153365877882, 
        0.0792881938160391}, {-0.07247720383400247, 
        0.0792057084175389}, {-0.0713280967009152, 
        0.07767116764897455}, {-0.07007300161002046, 
        0.07580271105152715}, {-0.06883304765595535, 
        0.07398195671534875}, {-0.0676082348387199, 
        0.07220890464043937}, {-0.06639856956795336, 
        0.07048139808595266}, {-0.06540913719627321, 0.06908641703908434}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06522915977643186, 
        0.06883267044989944}, {-0.06520405825329498, 
        0.06879728031104233}, {-0.0640247008947448, 
        0.06715655131570837}, {-0.06286049749230278, 
        0.06555921109995076}, {-0.06171144804596896, 
        0.06400525966376953}, {-0.06057755255574331, 
        0.06249469700716466}, {-0.05945881102162585, 
        0.06102752313013616}, {-0.058355223443616565`, 
        0.05960373803268402}, {-0.05777725061171378, 0.05886840609829644}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05758500670408847, 
        0.0586238217914477}, {-0.05726684848514886, 
        0.05821904169511694}, {-0.05619374480965616, 
        0.05686913409774362}, {-0.055135912417138444`, 
        0.05555401524056405}, {-0.054093351307595725`, 
        0.05427368512357823}, {-0.05306606148102799, 
        0.053028143746786174`}, {-0.052054042937435256`, 
        0.05181739111018786}, {-0.051057295676817514`, 
        0.050641427213783306`}, {-0.05007581969917476, 
        0.049500252057572504`}, {-0.049655114269048006`, 
        0.049036334358681315`}}]}, 
      {Arrowheads[{{0.0054183833024499806`, 1.}}], 
       ArrowBox[{{-0.049446132540085515`, 
        0.04880588731457882}, {-0.049113418793544375`, 
        0.04843899926267436}, {-0.04816011248524209, 
        0.04733924613041639}, {-0.04722193437067201, 0.04627258392188374}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAATnoawTr4ir97FK5H4XqEvx1zXkcG
54q/Ugb5Fn5shL+CrBmdUruKv69cOBbgR4S/1AbIMdqPir9uhZJRYSOEvzHj
TLycZIq/P24bsAH/g78CzOr4X+uGv0tHSXixA4G/mv1jbzLUg7/JdzkDOXx8
v746NTUXooO/tEY5/gggfL/vCqVoYnCDv81wgdNNxHu/HxfpwWZcg7/b/Vlh
R597v9s2C7J7SIO//gWK/FN6e78uGHz6tSqDv96sdcsFQ3u/yqlDFPAWg78Y
OZklPR57vwm4zp86A4O/bGV9cYf5er+5ZsgnnkGCvxoqI5l1jnm/ZG6QSTqG
gb+ANLlIoyp4vwIhKvDg0IC/7D9eoe3Ndr/Gnxr/ESp7v0msg6SjX3C/gP2L
aHeydb+sPWmuSiFlvyHfWi/DU3G/F+2T56pVVr95ZKLV
        "]]}, 
      {Arrowheads[{{0.005964094210087843, 1.}}], 
       ArrowBox[{{-0.004031273092698627, -0.001124128828155404}, \
{-0.0032324102174013606`, -0.00014536360523991583`}, {-0.0017914473652382251`,
         0.0018328525720128289`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.1, 0.06037353297024523}, {-0.09977021909631256, 
        0.060218500387388185`}, {-0.0980264341104038, 
        0.059050587900988494`}, {-0.09755955859643264, 
        0.05873907764348295}, {-0.09709472999946023, 
        0.05842947509983312}, {-0.09509210686894753, 
        0.05713489616961247}, {-0.09308948373843487, 
        0.05584031723939181}, {-0.09108686060792219, 
        0.054545738309171164`}, {-0.08958011362428764, 
        0.053571714356053506`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08931885523364774, 
        0.05340282606014174}, {-0.08908423747740951, 
        0.05325115937895051}, {-0.08741079845599412, 
        0.052241890111868965`}, {-0.08546626663885155, 
        0.05099765994573169}, {-0.08356046236395571, 
        0.04978699562231666}, {-0.08169338563130663, 
        0.04860989714162387}, {-0.07986372500907178, 
        0.04746477436387238}, {-0.0787781553113838, 0.046790067257396206`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07851393649554696, 
        0.04662584904728081}, {-0.07807016906541872, 
        0.0463500371492812}, {-0.07631271780034742, 
        0.04526568549785035}, {-0.07459137121385788, 
        0.044211719409579825`}, {-0.07290612930595011, 
        0.043188138884469617`}, {-0.07125699207662411, 
        0.04219494392251973}, {-0.06964395952587989, 
        0.04123213452373017}, {-0.06806703165371743, 
        0.040299710688100926`}, {-0.06786825271539534, 
        0.040183126395285415`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06759990751633142, 
        0.04002574133463773}, {-0.06652362163635836, 
        0.039394497253936046`}, {-0.06501114265002433, 
        0.03851331905953957}, {-0.06352959469471534, 
        0.03765617610491151}, {-0.06207897777043136, 
        0.036823068390051845`}, {-0.06065929187717242, 
        0.036013995914960586`}, {-0.05927053701493851, 
        0.03522895867963773}, {-0.057912713183729626`, 
        0.034467956684083284`}, {-0.05679789395433291, 
        0.033848777266829264`}}]}, 
      {Arrowheads[{{0.004602636320315998, 1.}}], 
       ArrowBox[{{-0.05652582203543028, 
        0.03369792670933435}, {-0.05528760826782994, 
        0.033015585708174984`}, {-0.054015826490025086`, 
        0.0323192713196119}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.0658936487593563, 0.09}, {-0.06538849553299429, 
        0.08886398787290255}, {-0.06462459805088981, 
        0.08718045770875096}, {-0.06441852854738507, 
        0.08673095601130248}, {-0.06421265475975738, 
        0.08628399496294534}, {-0.06324632135104676, 
        0.08434675954670362}, {-0.062279987942336135`, 
        0.08240952413046192}, {-0.06131365453362552, 
        0.0804722887142202}, {-0.06047870237251683, 0.07879843693305749}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06033880151447058, 
        0.07852061967770663}, {-0.05944468001903004, 
        0.07700583091753355}, {-0.05848958642846514, 
        0.07514059780172656}, {-0.0575419860499974, 
        0.07332336621954273}, {-0.0566018788836268, 
        0.07155413617098204}, {-0.05566964055163681, 
        0.0698307223606414}, {-0.05474564667631088, 
        0.06815093949311773}, {-0.05442343454249343, 0.06757524925279018}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.05427149579040427, 
        0.06730378319821002}, {-0.05382989725764901, 
        0.06651478756841103}, {-0.052922392295651204`, 
        0.06492226658652128}, {-0.052023131790317464`, 
        0.0633733765474485}, {-0.051132115741647784`, 
        0.06186811745119269}, {-0.05024934414964217, 
        0.06040648929775383}, {-0.04937481701430061, 
        0.05898849208713194}, {-0.04850933510940195, 
        0.057609768548433665`}, {-0.047883603962767446`, 
        0.05662703514460686}}]}, 
      {Arrowheads[{{0.014383803611253871`, 1.}}], 
       ArrowBox[{{-0.047716517923640324`, 
        0.05636462047522929}, {-0.047653699208725045`, 
        0.05626596141076566}, {-0.04680790931226987, 
        0.05495707067412794}, {-0.04597196542003644, 
        0.05368309633852048}, {-0.04514586753202475, 
        0.0524440384039433}, {-0.044329615648234795`, 
        0.05123989687039639}, {-0.04352320976866658, 
        0.05007067173787975}, {-0.04272664989332011, 0.04893636300639338}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.046111684783003634`, 0.09}, {0.04563635834512085, 
        0.08956747781352123}, {0.04399308667391546, 0.08805301791978687}, {
        0.04355656754922513, 0.08764804395767506}, {0.043123541583462655`, 
        0.08724507669682416}, {0.04133523033757311, 0.08548742858008414}, {
        0.03954691909168356, 0.08372978046334412}, {0.037758607845794025`, 
        0.08197213234660408}, {0.03714738991864913, 0.08137139461650633}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.036925519636636005`, 0.08115332861471984}, {
        0.03597029659990448, 0.08021448422986406}, {0.03470280983690351, 
        0.07878456619658492}, {0.03300640879387666, 0.07708475280045564}, {
        0.03137128121942493, 0.07542349588473352}, {0.029797427113548332`, 
        0.07380079544941856}, {0.02828132515517936, 0.07221511132922713}, {
        0.028276725328165483`, 0.07221023354736017}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.028063292093189245`, 0.0719839031309701}, {
        0.026819454023250512`, 0.07066490335887554}, {0.025411813717761793`, 
        0.06915017153836382}, {0.0240584042387132, 0.06767091586769196}, {
        0.02275922558610473, 0.06622713634685996}, {0.021514277759936393`, 
        0.06481883297586782}, {0.02032356076020818, 0.06344600575471555}, {
        0.01972860376240301, 0.06274589483642999}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.01952715149726235, 0.06250883748462367}, {
        0.019187074586920094`, 0.06210865468340314}, {0.018097746238511743`, 
        0.06080372377253286}, {0.01704850271342273, 0.059528157032707}, {
        0.016039344011653054`, 0.05828195446392555}, {0.015070270133202716`, 
        0.0570651160661885}, {0.014141281078071718`, 0.05587764183949587}, {
        0.013252376846260058`, 0.05471953178384764}, {0.012403557437767738`, 
        0.05359078589924383}, {0.011794379321476115`, 
        0.052762678268347435`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01161003636950828, 0.05251208521330498}, {
        0.011594822852594755`, 0.052491404185684425`}, {0.010076744898946575`,
         0.050370675830453175`}, {0.00867727973205529, 0.04834728927690822}, {
        0.007396427351920897, 0.04642124452504955}, {0.006234187758543397, 
        0.04459254157487718}, {0.005089323448394855, 0.04271351917860865}, {
        0.004750278875515395, 0.04213607249049644}}]}, 
      {Arrowheads[{{0.0017652933195863722`, 1.}}], 
       ArrowBox[{{0.0045927656584901335`, 0.041867802496575984`}, {
        0.0040366515989676294`, 0.04092065204034947}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.053605998144226855`, 0.09}, {-0.05354410736358446, 
        0.0897851849521474}, {-0.05304399048013753, 
        0.08810278587835102}, {-0.05290831373475501, 
        0.08765351667388938}, {-0.05277241806732478, 
        0.08720675491753033}, {-0.05210729885848943, 
        0.08526579779457304}, {-0.05144217964965407, 
        0.08332484067161575}, {-0.05077706044081872, 
        0.08138388354865846}, {-0.05011194123198337, 
        0.07944292642570117}, {-0.04958528711579942, 0.0782306549247122}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.049461329223177725`, 
        0.07794532416220575}, {-0.049444510279026604`, 
        0.07790660970798509}, {-0.0487789831153463, 
        0.07603705971536448}, {-0.04811318398176936, 
        0.07421511447630166}, {-0.047447112878295776`, 
        0.07244077399079664}, {-0.046781513503549386`, 
        0.07071189244701023}, {-0.04611712955615402, 
        0.06902632403310327}, {-0.04545396103610967, 
        0.06738406874907574}, {-0.04501538604433838, 0.06632469452779213}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04489638946539274, 
        0.0660372592874771}, {-0.04479200794341634, 
        0.06578512659492766}, {-0.04413127027807403, 
        0.06422949757065903}, {-0.04347174804008274, 
        0.06271718167626983}, {-0.04281344122944247, 
        0.06124817891176009}, {-0.04215634984615322, 
        0.059822489277129784`}, {-0.04150200989034069, 
        0.0584358358320344}, {-0.040851957362130584`, 
        0.05708394163612941}, {-0.040206192261522895`, 
        0.055766806689414826`}, {-0.03969126690840453, 
        0.05473742127716114}}]}, 
      {Arrowheads[{{0.008644843092306773, 1.}}], 
       ArrowBox[{{-0.03955177202903357, 
        0.05445935816261221}, {-0.038294621525314355`, 
        0.05202395734441344}, {-0.03704167817252078, 0.04970252069369783}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.020964059736796842`, -0.01}, {
        0.020732356747099615`, -0.009643514540879996}, {
        0.019602954451875088`, -0.007987648182516892}, {
        0.01952813666332207, -0.00788081871386405}, {
        0.019453517821858047`, -0.007774604833480265}, {
        0.01942664362507935, -0.007736502080997622}, {
        0.019399795481118212`, -0.007698478584231751}, {
        0.019359565616733538`, -0.007641571859692891}, {
        0.019332776122927695`, -0.007603726148723387}, {
        0.019306012709524045`, -0.0075659592143791435`}, {
        0.019039815491424687`, -0.007192574876266313}, {
        0.018776234953302454`, -0.006826895631697037}, {
        0.018515277787654195`, -0.006468767096951754}, {
        0.017249786070780208`, -0.004780852801752165}, {
        0.01604975073719789, -0.003261023896914851}, {
        0.014914550471508924`, -0.0018937124212056286`}, {
        0.013843563958314986`, -0.000663350413390312}, {
        0.013377700867190642`, -0.00015222858007109404`}}]}, 
      {Arrowheads[{{0.0007941616841193409, 1.}}], 
       ArrowBox[{{0.013168139625813683`, 0.00007769160018343782}, {
        0.012835288609057551`, 0.0004428791953113604}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, -0.006174636964379212}, {
        0.049711693853217914`, -0.006050246864432056}, {
        0.0478421836570975, -0.005253827402413474}, {
        0.047594605910184745`, -0.005149072182074649}, {
        0.04734825077956444, -0.005044999625462758}, {
        0.04556964224946935, -0.0043235410312579756`}, {
        0.04379103371937426, -0.003602082437053193}, {
        0.04201242518927917, -0.0028806238428484105`}, {
        0.040233816659184074`, -0.0021591652486436285`}, {
        0.03900453124963063, -0.0017194768958723983`}, {
        0.038467396768188854`, -0.0015049211816373493`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03817849839859091, -0.0013895221555609585`}, {
        0.03732286209374877, -0.0010477424619205961`}, {
        0.035705819187342405`, -0.00040915746813744737`}, {
        0.03415340253041152, 0.00019627808547704887`}, {0.032661493096013135`,
         0.0007711130465960919}, {0.031225971857204257`, 
        0.0013178962628928844`}, {0.029846838813984894`, 
        0.0018366277343674253`}, {0.028524093966355038`, 
        0.002327307461019714}, {0.026551317342271313`, 
        0.003042069631739294}}]}, 
      {Arrowheads[{{0.00036080249362804194`, 1.}}], 
       ArrowBox[{{0.02625882952530116, 0.0031480417040025267`}, {
        0.026047768857863855`, 0.0032245116798575377`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04227744793920881, 0.09}, {-0.04211050302517107, 
        0.08887875607140483}, {-0.041850209354059115`, 
        0.08723332628110643}, {-0.04177857922937289, 
        0.08679386742769742}, {-0.04170637469760865, 
        0.08635683356498171}, {-0.041309365114890736`, 
        0.08441923232953852}, {-0.04091235553217283, 
        0.08248163109409534}, {-0.040515345949454926`, 
        0.08054402985865215}, {-0.04011833636673702, 
        0.07860642862320896}, {-0.03987586473210425, 0.07779737562528542}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0397865552000806, 
        0.07749937728524735}, {-0.03965980850422449, 
        0.07707646268571247}, {-0.03925194275448401, 
        0.0752107970910834}, {-0.0388368395600618, 
        0.07339308859033042}, {-0.03841449892095787, 
        0.07162333718345351}, {-0.03798602083167702, 
        0.06989936407712022}, {-0.03755250528672404, 
        0.06821899047799806}, {-0.03711395228609893, 
        0.06658221638608705}, {-0.03679147739894732, 0.06542403368147623}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.036708033168055286`, 
        0.06512434006541715}, {-0.036670361829801684`, 
        0.06498904180138719}, {-0.03622173391783231, 
        0.06343946672389847}, {-0.0357680685501908, 
        0.06193349115362087}, {-0.03530936572687717, 
        0.06047111509055443}, {-0.03484562544789141, 
        0.059052338534699135`}, {-0.034379101817945644`, 
        0.057672818583410085`}, {-0.033912048941751996`, 
        0.05632821233404238}, {-0.03344446681931047, 
        0.05501851978659604}, {-0.03297635545062107, 
        0.05374374094107105}, {-0.032810303762214464`, 
        0.05331085398558541}}]}, 
      {Arrowheads[{{0.006964468755084863, 1.}}], 
       ArrowBox[{{-0.032698886837463643`, 
        0.053020396635782036`}, {-0.03203854497449862, 
        0.05129892435578514}, {-0.031098617513384667`, 
        0.04899376257818465}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.005552325839209739}, {0.04868504555069893, 
        0.005768957196389571}, {0.04666823160985543, 0.006094066850029587}, {
        0.04640183618377472, 0.006136506018758786}, {0.04613691572316731, 
        0.006178593265308841}, {0.04436833063103239, 0.006440445126829607}, {
        0.04259974553889748, 0.006702296988350373}, {0.040831160446762556`, 
        0.0069641488498711395`}, {0.039062575354627635`, 
        0.007226000711391905}, {0.037856905919812854`, 
        0.007366811648759523}, {0.03769369765254001, 0.007390325384337905}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03738578332685692, 0.007434687205928744}, {
        0.03618765888485208, 0.007607303347194438}, {0.03458463722134073, 
        0.007833554936905454}, {0.03304784092927881, 0.00804556641789257}, {
        0.03157291345674058, 0.00824452575954817}, {0.030155498251800302`, 
        0.008431620931264637}, {0.028795595314457984`, 0.00860685193304197}, {
        0.027493204644713623`, 0.00877021876488017}, {0.025060960108018764`, 
        0.009061359918739171}, {0.025049391147349987`, 
        0.009062640084891369}}]}, 
      {Arrowheads[{{0.006286126684147653, 1.}}], 
       ArrowBox[{{0.02474018487836643, 0.00909685537967305}, {
        0.022858764641715726`, 0.00930504439284164}, {0.02085109205392724, 
        0.00951133705109265}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.047489733297032224`}, {-0.09893518623945069, 
        0.0469630083334705}, {-0.09710014213802651, 
        0.04606131322188608}, {-0.09660926962865521, 
        0.045820940788160874`}, {-0.09612074691202237, 
        0.04558209965708621}, {-0.09412473726203624, 
        0.04463159819343779}, {-0.0921287276120501, 
        0.043681096729789363`}, {-0.09013271796206397, 
        0.042730595266140946`}, {-0.08878881494779606, 
        0.04209062752747192}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08850794198414828, 
        0.04195687558742076}, {-0.08813670831207783, 
        0.04178009380249252}, {-0.08647795445611979, 
        0.04103724746133017}, {-0.08454146053449156, 
        0.04012339101929693}, {-0.08264464376510193, 
        0.03923396459167383}, {-0.0807875041479509, 
        0.03836896817846085}, {-0.07896861326298352, 
        0.03752725836078348}, {-0.07721890439680058, 
        0.036722574730364894`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07693598452087547, 
        0.03659320901899968}, {-0.07544129242943502, 
        0.035910268255412055`}, {-0.07373286248085388, 
        0.035134987967717995`}, {-0.07206125284440149, 
        0.03438185085668504}, {-0.07042646352007784, 
        0.03365085692231319}, {-0.0688284945078829, 
        0.03294200616460244}, {-0.06726734580781674, 
        0.03225529858355279}, {-0.06574018759632275, 
        0.03158845207023587}, {-0.06557502396270729, 0.03151677054325452}}]}, 
      {Arrowheads[{{0.01635801412253641, 1.}}], 
       ArrowBox[{{-0.06528964809195438, 
        0.03139291653416419}, {-0.06424419004984436, 
        0.03093918451572329}, {-0.0627793531683816, 
        0.030307495920015054`}, {-0.06134567695193447, 
        0.02969338628311116}, {-0.05994316140050295, 
        0.02909685560501162}, {-0.05857180651408706, 
        0.028517903885716418`}, {-0.057231612292686786`, 
        0.02795653112522556}, {-0.05592257873630213, 
        0.027412737323539046`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.031169007877470872`, 0.09}, {0.030779754936250042`, 
        0.0895534498254251}, {0.029457935181614953`, 0.08801476703227996}, {
        0.02910722360153911, 0.08760340099174549}, {0.028759513645453896`, 
        0.08719411541151348}, {0.027217811419504176`, 0.08525163734488622}, {
        0.025676109193554453`, 0.08330915927825895}, {0.024134406967604733`, 
        0.0813666812116317}, {0.023322846209530988`, 0.08034414978775538}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.0231294483762217, 0.0801004768896994}, {
        0.022592704741655013`, 0.07942420314500442}, {0.021573776315525334`, 
        0.07788381138991651}, {0.020124328289543858`, 0.07601228973120797}, {
        0.01873638306354121, 0.07418807234444522}, {0.01740994063751739, 
        0.07241115922962828}, {0.016141057421715115`, 0.07067945523367876}, {
        0.01572639607772261, 0.07010329158540511}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.01554467358079021, 0.06985079180860446}, {
        0.0149257898263771, 0.06899086520351827}, {0.013764137851503348`, 
        0.06734538913914682}, {0.012656101497093859`, 0.06574302704056441}, {
        0.011601680763148629`, 0.06418377890777101}, {0.010600875649667663`, 
        0.06266764474076666}, {0.009653686156650956, 0.06119462453955134}, {
        0.008760112284098513, 0.059764718304125046`}, {0.008611499333905582, 
        0.059520931322681846`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0084495716210724, 0.059255302598722366`}, {
        0.007912182394993292, 0.058373761002812684`}, {0.007101924852318265, 
        0.05701758760393913}, {0.0063293396560734246`, 0.0556961981075044}, {
        0.005594426806258773, 0.054409592513508465`}, {0.00489718630287431, 
        0.053157770821951354`}, {0.004237618145920036, 0.05194073303283306}, {
        0.0036157223353959515`, 0.05075847914615357}, {0.0030314988713020553`,
         0.0496110091619129}, {0.002425807462129314, 0.04837270224352412}}]}, 
      {Arrowheads[{{0.008407071779689166, 1.}}], 
       ArrowBox[{{0.002289117940475012, 0.048093247098920114`}, {
        0.0019535016982780602`, 0.04740709585367833}, {0.0009810593427212761, 
        0.04531566806105969}, {0.00011417180463170527`, 
        0.04333672578405697}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.01650051552480703}, {0.049545588845954676`, 
        0.01648258856277242}, {0.04731445352312342, 0.016386711412556185`}, {
        0.045184511473908125`, 0.016286969743918796`}, {0.044903745470903804`,
         0.016273241105010952`}, {0.04462466660478802, 0.01625945982660611}, {
        0.04286540810694297, 0.016152112093547003`}, {0.04110614960909792, 
        0.016044764360487896`}, {0.03934689111125287, 
        0.015937416627428785`}, {0.03758763261340782, 
        0.015830068894369678`}, {0.03757482589235829, 0.01582885010954634}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03726513160168269, 0.0157993772491717}, {
        0.03640236318241227, 0.0157172696549331}, {0.03474439687283478, 
        0.01560895989133679}, {0.033153958688769, 0.015500008774049013`}, {
        0.03163104863021492, 0.01539041630306977}, {0.030171137404908892`, 
        0.015280473205279256`}, {0.028769695720587275`, 
        0.015170470207557673`}, {0.027426723577250067`, 
        0.015060407309905016`}, {0.02614222097489726, 
        0.014950284512321289`}, {0.024859573192703904`, 
        0.014832166021563073`}}]}, 
      {Arrowheads[{{0.007956686451064945, 1.}}], 
       ArrowBox[{{0.024549790414274766`, 0.014803638256763632`}, {
        0.02374862439314487, 0.014729859217360622`}, {0.0215889059753301, 
        0.014509194322675669`}, {0.019625970022868, 0.01429096338557867}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.0028867027938277025`, 0.09}, {-0.0033030923402870764`, 
        0.08889098805102871}, {-0.0034625685658892123`, 
        0.08845999131430304}, {-0.0036201265403607795`, 
        0.08803126865762116}, {-0.0042465457185662265`, 
        0.0860864234624971}, {-0.004872964896771674, 
        0.08414157826737304}, {-0.005499384074977121, 
        0.08219673307224898}, {-0.006125803253182569, 
        0.08025188787712491}, {-0.0064571213819737145`, 
        0.0787077421349278}, {-0.006630165795769888, 0.07814308198025476}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.006721318471033699, 
        0.07784564225027912}, {-0.007031463904400168, 
        0.07683360860796731}, {-0.0075710886563072925`, 
        0.07500661619311588}, {-0.008075995637695087, 
        0.07322676489037351}, {-0.008548656537487742, 
        0.07149196269528885}, {-0.008991543044609447, 
        0.06980011760341057}, {-0.009404655159060206, 
        0.06815122961473864}, {-0.009787992880840014, 
        0.06654529872927309}, {-0.009949578447387076, 0.06583098821313131}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.010018217247543407`, 
        0.06552756125604142}, {-0.010141556209948874`, 
        0.06498232494701392}, {-0.010465345146386784`, 
        0.06346230826796112}, {-0.010759359690153746`, 
        0.061985248692114685`}, {-0.01102359984124976, 
        0.06055114621947462}, {-0.011263068704483563`, 
        0.05915583654900888}, {-0.0114827693846639, 
        0.05779515537968545}, {-0.01168270188179077, 
        0.05646910271150431}, {-0.011862866195864174`, 
        0.05517767854446545}, {-0.012095199712712536`, 
        0.05326438923378711}}]}, 
      {Arrowheads[{{0.004194372746831746, 1.}}], 
       ArrowBox[{{-0.012132700782235651`, 
        0.05295556424619648}, {-0.012163890274850576`, 
        0.052698715713814626`}, {-0.01238584162162311, 
        0.05035826688773297}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.018586381029883223`, 0.09}, {0.017800308438313817`, 
        0.08884398376959822}, {0.017516472516794113`, 0.08842281574587862}, {
        0.0172352660185111, 0.0880038118802707}, {0.016029440239412766`, 
        0.08605852170597786}, {0.014823614460314428`, 0.084113231531685}, {
        0.013617788681216091`, 0.08216794135739215}, {0.012411962902117754`, 
        0.0802226511830993}, {0.012019890982595517`, 0.07943653607354917}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.011881045020567612`, 0.07915814605576069}, {
        0.011641194114121171`, 0.07867723831356226}, {0.01051214309815844, 
        0.0768025147224616}, {0.009434275257619442, 0.07497483552015577}, {
        0.00840759059250418, 0.07319420070664472}, {0.007428740920585354, 
        0.07145853470015434}, {0.006494378059635661, 0.06976576191891048}, {
        0.005727983128449443, 0.06834482320636535}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.005580769075004181, 0.06807076882253117}, {
        0.004759112770643682, 0.06650889603216235}, {0.003958210342601395, 
        0.06494480292665808}, {0.0032017947255282408`, 0.06342360304640034}, {
        0.0024898659194242207`, 0.06194529639138911}, {0.0018224239242893348`,
         0.06050988296162442}, {0.001192701812556405, 
        0.059113234600222817`}, {0.0005939326566582522, 
        0.05775122315030086}, {0.00020883304974313595`, 
        0.05685098216928233}}]}, 
      {Arrowheads[{{0.006785169633446405, 1.}}], 
       ArrowBox[{{0.00008648003211638418, 0.056564959543860226`}, {
        0.000026116456594876564`, 
        0.056423848611858556`}, {-0.0005107467876337205, 
        0.0551311109848959}, {-0.0014916144085865852`, 
        0.052649546465409536`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.1, -0.006060598250332016}, {-0.09996253066220036, \
-0.006058120269803848}, {-0.09933658813323012, -0.006016051405523142}, \
{-0.09871443245955334, -0.0059739275975261835`}, {-0.09671229620733926, \
-0.005824677246190567}, {-0.09471015995512518, -0.005675426894854951}, \
{-0.09270802370291108, -0.005526176543519335}, {-0.09070588745069699, \
-0.005376926192183719}, {-0.08903873180742214, -0.00522696659089071}, \
{-0.08759239559447886, -0.005115775255486879}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.08728221729437632, -0.005091929389571992}, \
{-0.08709570978031497, -0.005077591077797906}, {-0.08519209723661242, \
-0.004928132123533645}, {-0.08332789417631448, -0.004778589728097926}, \
{-0.08150165688772879, -0.004629064347744185}, {-0.07971194165916297, \
-0.0044796564387258545`}, {-0.07795874849061704, -0.004330366001042937}, \
{-0.076242077382091, -0.004181193034695432}, {-0.07488136662284578, \
-0.004060476711362149}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07457149010873959, -0.004032985818667964}, \
{-0.07456192833358484, -0.0040321375396833396`}, {-0.07291830134509857, \
-0.0038831995160066588`}, {-0.07131119641663217, -0.003734378963665391}, \
{-0.06974061354818566, -0.003585675882659535}, {-0.06820368371926164, \
-0.0034372917846967888`}, {-0.06669753790936273, -0.00328942818148485}, \
{-0.06522217611848893, -0.003142085073023719}, {-0.06377759834664024, \
-0.002995262459313395}, {-0.06236380459381664, -0.0028489603403538777`}, \
{-0.06218612172408876, -0.002830230973011067}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.061876742181699834`, -0.0027976195957487167`}, \
{-0.06098079486001816, -0.002703178716145169}, {-0.05962856914524479, \
-0.002557917586687267}, {-0.058307127449496524`, -0.0024131769519801726`}, \
{-0.05576852640089972, -0.002124586596887437}, {-0.0532973867612228, \
-0.0018412075471424512`}, {-0.050939838968986795`, -0.0015604469323454704`}, \
{-0.04951369873563841, -0.0013842196553465168`}}]}, 
      {Arrowheads[{{0.0008321462547187443, 1.}}], 
       ArrowBox[{{-0.049204953422253075`, -0.0013460681856720792`}, \
{-0.04869111090986193, -0.001282572980468881}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.03201321012690179, 0.09}, {-0.031985814095368846`, 
        0.08847917555288815}, {-0.031941212887704504`, 
        0.08685842929562965}, {-0.031927174207736934`, 
        0.08642550598466471}, {-0.031912236277495794`, 
        0.08599494596096598}, {-0.03176579010016286, 
        0.08405872117373887}, {-0.031619343922829925`, 
        0.08212249638651178}, {-0.031472897745497, 
        0.08018627159928468}, {-0.03132645156816406, 
        0.07825004681205759}, {-0.031211864088909146`, 
        0.07758959245401835}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03115868445315666, 
        0.07728307796901485}, {-0.03106145074606487, 
        0.07672264653257299}, {-0.03089408316083201, 
        0.07485856724671222}, {-0.03071276797033253, 
        0.07304258496176234}, {-0.030517505174566435`, 
        0.07127469967772333}, {-0.030309740345220708`, 
        0.06955272042407513}, {-0.030090919053982344`, 
        0.06787445623029766}, {-0.02986104130085134, 
        0.0662399070963909}, {-0.02966305876888214, 0.06493267326125614}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.029616207200458614`, 
        0.06462512933173338}, {-0.029368116408911422`, 
        0.06310195400818955}, {-0.029105069270102504`, 
        0.06159855005389496}, {-0.028830965669400948`, 
        0.06013886115947109}, {-0.02854580560680675, 
        0.05872288732491794}, {-0.028252538816126833`, 
        0.057346261793841745`}, {-0.027954115031168104`, 
        0.056004617809848736`}, {-0.02765053425193057, 
        0.05469795537293891}, {-0.027341796478414226`, 
        0.05342627448311226}, {-0.02708738135361647, 
        0.052446143980296706`}}]}, 
      {Arrowheads[{{0.00576213667513115, 1.}}], 
       ArrowBox[{{-0.02700922020717884, 
        0.052145029320468786`}, {-0.02670884994854511, 
        0.050987857344708516`}, {-0.02605527544156076, 
        0.048689366394637494`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{-0.0225364607125842, 0.09}, {-0.022553934768255984`, 
        0.08984809124152976}, {-0.02272665159866473, 
        0.08821362586336245}, {-0.02288012760829096, 
        0.0866134575866172}, {-0.0229189744601155, 
        0.08618597799555776}, {-0.02295662249570405, 
        0.08576080806623351}, {-0.023046012588901998`, 
        0.08382542114136655}, {-0.023135402682099945`, 
        0.08189003421649961}, {-0.02322479277529789, 
        0.07995464729163265}, {-0.023314182868495837`, 
        0.07801926036676571}, {-0.023290319303592724`, 
        0.07758603764381444}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.023273209018779585`, 
        0.07727541497669348}, {-0.023230131542118358`, 
        0.07649338002873768}, {-0.023288914325979466`, 
        0.07463025897213643}, {-0.023327292236949345`, 
        0.07281531516104564}, {-0.023345265275027997`, 
        0.0710485485954653}, {-0.023344616138330807`, 
        0.06932776215645078}, {-0.02332712752497316, 
        0.0676507587250574}, {-0.02329279943495505, 
        0.06601753830128516}, {-0.023254742029949694`, 
        0.06483534678029441}}]}, 
      {Arrowheads[{{0.018243026704388283`, 1.}}], 
       ArrowBox[{{-0.023244732413628476`, 
        0.06452441429444446}, {-0.023241631868276484`, 
        0.06442810088513407}, {-0.02317362482493746, 
        0.06288244647660411}, {-0.02308877830493797, 
        0.06138057507569531}, {-0.02298709230827803, 
        0.05992248668240765}, {-0.022868566834957627`, 
        0.05850818129674113}, {-0.02259551130474833, 
        0.055793406182350846`}, {-0.02228412556072296, 
        0.05321873636660376}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.0075727827312991785`, 0.09}, {0.007145295983323975, 
        0.08918627113834743}, {0.006337695754188694, 0.08761594119062467}, {
        0.006124250830965275, 0.08719625833046288}, {0.005913016803663897, 
        0.0867787634789826}, {0.005025335993992986, 0.08483867497055546}, {
        0.004137655184322075, 0.08289858646212833}, {0.003249974374651163, 
        0.08095849795370119}, {0.002362293564980252, 0.07901840944527407}, {
        0.002269643985729069, 0.07874793436852542}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0021688312813616206`, 0.07845362840220152}, {
        0.0018363877096768304`, 0.07748311454458046}, {0.0010125495390119464`,
         0.07561446020222394}, {0.00023127312768441517`, 
        0.07379342863724786}, {-0.0005074415243057654, 
        0.07202001984965217}, {-0.001206519662032416, 
        0.07029209864946266}, {-0.001868886530569356, 
        0.06860752984670505}, {-0.002494542129916588, 
        0.06696631344137935}, {-0.0025092353015034765`, 
        0.06692644941885922}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.002616823443961818, 
        0.06663455218561079}, {-0.003083486460074111, 
        0.06536844943348555}, {-0.0036357195210419244`, 
        0.06381393782302366}, {-0.0041512413128200285`, 
        0.06230277860999369}, {-0.004630051835408424, 
        0.06083497179439563}, {-0.005072151088807111, 
        0.05941051737622946}, {-0.005483461312324394, 
        0.058025165546776725`}, {-0.005869904745268575, 
        0.056674666497318935`}, {-0.006231481387639655, 
        0.05535902022785609}, {-0.00638361406924522, 
        0.054780330453573486`}}]}, 
      {Arrowheads[{{0.0006667877352075069, 1.}}], 
       ArrowBox[{{-0.0064627103626938255`, 
        0.054479460083582655`}, {-0.006568191239437634, 
        0.05407822673838819}}]}}}}, 
   {PointSize[0.025], PointBox[{0, 0.08}]}, 
   {PointSize[0.025], PointBox[{0, 0.01}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.08}, {0.05, 0.08}}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.01}, {0.05, 0.01}}]}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0.09}, {0, -0.01}}]}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwVy3k8lAkcx3FF16s1M+TIoBy5jxR2ifph1IZSq9IhuUtExcikw9FjNGbm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      "]]}}},
  AspectRatio->1,
  BaseStyle->{FontWeight -> "Bold", FontSize -> 12},
  Frame->True,
  ImageMargins->{{10., 11.}, {9.5, 10.}},
  ImageSize->{480., Automatic},
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{-0.1027733900410869, 0.0527733900410869}, {-0.0127733900410869,
    0.0927733900410869}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.704148828953949*^9, 3.70449724125562*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"initial", " ", "=", " ", 
   RowBox[{"InitialPoint", "[", 
    RowBox[{
    "0.01", ",", "0.0", ",", "0.33", ",", "1.5", ",", ".01", ",", ".07", ",", 
     ".08"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "\n", 
  RowBox[{
   RowBox[{"StreamPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"BigA", "+", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"BigB", ".", 
            RowBox[{"Inverse", "[", 
             RowBox[{
              RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", "BigB"}], "]"}],
             ".", "BigA"}]}]}], ")"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
          RowBox[{"BigB", ".", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
             RowBox[{"\[Gamma]", " ", 
              RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
           RowBox[{"Inverse", "[", "BigB", "]"}]}]}], ")"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"BigB", ".", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
             RowBox[{"\[Gamma]", " ", 
              RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
           RowBox[{"Inverse", "[", "BigB", "]"}]}], "+", 
          RowBox[{"BigB", "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Lambda]"}], ")"}], "\[Gamma]"}]}], ")"}], 
        ".", 
        RowBox[{"{", 
         RowBox[{"x", ",", "p"}], "}"}]}], "-", 
       RowBox[{"{", 
        RowBox[{"x", ",", "p"}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
        RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
        RowBox[{"\[Pi]bar", "\[Rule]", ".01"}], ",", 
        RowBox[{"\[Lambda]", "\[Rule]", "0.0"}], ",", 
        RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", ".1"}], ",", ".05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"-", "0.01"}], ",", ".09"}], "}"}], ",", 
     RowBox[{"StreamPoints", "\[Rule]", "17"}]}], "]"}], "\n", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.08"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.01"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".1"}], ",", "0.08"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.05", ",", "0.08"}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".1"}], ",", "0.01"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.05", ",", "0.01"}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0.09"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "0.01"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
   ",", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"First", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], ",", 
          RowBox[{"p", "[", "t", "]"}]}], "}"}], " ", "/.", " ", "\n", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"x", "'"}], "[", "t", "]"}], "==", 
              RowBox[{
               FractionBox["1", 
                RowBox[{"1", "+", 
                 RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}]], "\[Gamma]", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"p", "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Lambda]"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]", "+", "\[Lambda]", 
                    "-", 
                    RowBox[{"\[Alpha]", " ", "\[Lambda]"}]}], ")"}], " ", 
                  "\[Pi]bar"}], "-", 
                 RowBox[{
                  RowBox[{"x", "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Lambda]", "+", 
                    RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}], ")"}]}]}], 
                ")"}]}]}], " ", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
               RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
               RowBox[{"\[Pi]bar", "\[Rule]", "0.01"}], ",", 
               RowBox[{"\[Lambda]", "\[Rule]", "0.0"}], ",", 
               RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", "\n", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "'"}], "[", "t", "]"}], "==", 
              RowBox[{
               FractionBox["1", 
                RowBox[{"1", "+", 
                 RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}]], "\[Gamma]", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                    "\[Pi]bar"}]}], ")"}], " ", "\[CurlyPhi]"}], "+", 
                 RowBox[{"\[Lambda]", " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Pi]bar", "-", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], " ", "\[CurlyPhi]"}], "+", 
                    RowBox[{"\[Pi]bar", " ", "\[CurlyPhi]"}]}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"p", "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                    "\[CurlyPhi]"}], "+", 
                    RowBox[{"\[Lambda]", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "\[CurlyPhi]"}], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], " ", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
               RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
               RowBox[{"\[Pi]bar", "\[Rule]", "0.01"}], ",", 
               RowBox[{"\[Lambda]", "\[Rule]", "0.0"}], ",", 
               RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", "\n", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"x", "[", "0", "]"}], "\[Equal]", "0"}], 
              RowBox[{"(*", 
               RowBox[{"initial", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}], "*)"}], ",", 
              RowBox[{
               RowBox[{"p", "[", "0", "]"}], "\[Equal]", 
               RowBox[{"initial", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "p"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "175"}], "}"}]}], "]"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "175"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}], ",", " ", 
   RowBox[{"BaseStyle", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", " ", "->", " ", "\"\<Bold\>\""}], ",", " ", 
      RowBox[{"FontSize", " ", "->", " ", "12"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageMargins", "\[Rule]", "10"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6440106460663033`*^9, 3.6440106584879827`*^9}, {
  3.644010694987618*^9, 3.644010696500828*^9}, {3.703994944894615*^9, 
  3.7039950283048153`*^9}, {3.703997435747147*^9, 3.703997443236147*^9}, {
  3.703997525108947*^9, 3.703997567513747*^9}, {3.7041487752282376`*^9, 
  3.704148778691393*^9}, {3.704148813510147*^9, 3.704148813931341*^9}, {
  3.704148892451143*^9, 3.7041488928879375`*^9}, {3.704149375511469*^9, 
  3.704149375854669*^9}, {3.7041494489296694`*^9, 3.704149477648878*^9}, {
  3.7044971835624847`*^9, 3.704497216508787*^9}, {3.704497264528431*^9, 
  3.70449726498505*^9}, {3.704497457125433*^9, 3.7044975381972327`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.04355424173457737}, {0.04913185850385442, 
        0.04367534731273184}, {0.04715960909903208, 0.04393653164116389}, {
        0.04520346858076563, 0.044181524684116305`}, {0.04326343694905506, 
        0.0444103264415891}, {0.041339514203900384`, 0.04462293691358227}, {
        0.0394317003453016, 0.044819356100095804`}, {0.03764051813617188, 
        0.044990006922867656`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03733067876588822, 0.0450178904947922}, {
        0.035664399287771674`, 0.04516362061668399}, {0.03380491208884055, 
        0.04531146594675864}, {0.03196153377646532, 0.04544311999135366}, {
        0.03013426435064597, 0.04555858275046906}, {0.0283231038113825, 
        0.04565785422410483}, {0.026528052158674938`, 
        0.045740934412260965`}, {0.024913286008855416`, 
        0.0458016502137447}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024602369134233443`, 0.04581204344113782}, {
        0.022986275512927458`, 0.045858520932134356`}, {0.021242445895153967`,
         0.0458947312959816}, {0.019520515914469214`, 
        0.045918158438609205`}, {0.017820485570873193`, 
        0.04592880236001717}, {0.016142354864365892`, 
        0.045926663060205486`}, {0.014486123794947318`, 
        0.04591174053917417}, {0.012851792362617487`, 
        0.045884034796923205`}, {0.012160384859480549`, 
        0.04586667321101276}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011849389330967148`, 0.04585886395878227}, {
        0.011239360567376384`, 0.045843545833452605`}, {0.009648828409224005, 
        0.045790273648762356`}, {0.008080195888160358, 0.04572421824285247}, {
        0.006533463004185443, 0.045645379615722945`}, {0.005008629757299255, 
        0.045553757767373776`}, {0.003505696147501798, 
        0.045449352697804965`}, {0.0020246621747930654`, 
        0.04533216440701651}, {0.0005655278391730675, 
        0.04520219289500842}, {-0.0005675170114323089, 
        0.045089652114056966`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0008770813829522318, 
        0.04505884752961963}, {-0.002287041920800742, 
        0.0449039002073333}, {-0.0036792471753757765`, 
        0.04473701972670754}, {-0.005047092453304531, 
        0.044560237414944644`}, {-0.007709703079223195, 
        0.04417696729800746}, {-0.010274873798556735`, 
        0.04375408985652176}, {-0.01274260461130515, 
        0.04329160509048753}, {-0.013177405204414934`, 
        0.04320491705688123}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.013482494197115683`, 
        0.04314409017377374}, {-0.015161615470761065`, 
        0.042809316662179034`}, {-0.01758062633021698, 
        0.04232702823387053}, {-0.019999637189672896`, 
        0.04184473980556203}, {-0.02161892972857411, 
        0.041107671979860476`}, {-0.02324018517789188, 
        0.04059912457819927}, {-0.024794650841580564`, 
        0.0400727124795877}, {-0.024897346327395927`, 
        0.04003656856102398}, {-0.02499973803881323, 
        0.04000034785238884}, {-0.0254099023350875, 0.03978907707630706}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.025686463726702278`, 
        0.03964662357566974}, {-0.026555758391587567`, 
        0.03919886017899597}, {-0.028111778744361906`, 
        0.03839737250560311}, {-0.029667799097136245`, 
        0.03759588483221024}, {-0.031223819449910584`, 
        0.036794397158817375`}, {-0.03326969170348867, 
        0.03506594832244329}, {-0.03455916994327036, 
        0.03423309227665333}, {-0.035742031337854994`, 
        0.03338768888190454}, {-0.03616344787361893, 0.0330377996731269}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03640279685087912, 
        0.032839075567240805`}, {-0.03780730669498018, 
        0.03167295417339923}, {-0.03948492087841135, 
        0.029935458324796098`}, {-0.04077487388814849, 
        0.028175201336095163`}, {-0.041677165724191605`, 
        0.02639218320729642}, {-0.04222804596690975, 
        0.0246122085068251}, {-0.042463764196672006`, 
        0.022861081803106427`}, {-0.042445692793518154`, 
        0.022469308002744895`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04243135818059695, 
        0.022158544874223945`}, {-0.04238432041347836, 
        0.021138803096140402`}, {-0.04198971461732881, 
        0.019445372385927032`}, {-0.041324663300894446`, 
        0.017798087307603558`}, {-0.04043388295684635, 
        0.016214245496307223`}, {-0.03931737358518452, 
        0.014693846952038027`}, {-0.037975135185908955`, 
        0.013236891674795973`}, {-0.03632329361230004, 0.0117489496625216}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.036084110710015264`, 
        0.01155042370792622}, {-0.03427191714846076, 
        0.01016601398582798}, {-0.03216749792730143, 
        0.00880019702263126}, {-0.029894538571185306`, 
        0.007547461313626064}, {-0.027513818665387883`, 
        0.006411926550886392}, {-0.025279483849588613`, 
        0.005478494447847715}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.024990612602670596`, 
        0.005363253061614298}, {-0.0226114359605757, 
        0.004504818940425647}, {-0.020089773161560947`, 
        0.003733246092704573}, {-0.017460823063882788`, 
        0.003089040580790875}, {-0.015066321561667796`, 
        0.0025379377857001127`}, {-0.01298679357142965, 
        0.002160288896261904}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.012680706402383068`, 
        0.002104702493960827}, {-0.012673084162453148`, 
        0.002103318270974612}, {-0.010305233399941872`, 
        0.0017827633576272324`}, {-0.007986930843317246, 
        0.0015675495840985919`}, {-0.005732813181617, 
        0.0014460132057536024`}, {-0.0035650470266914347`, 
        0.0014127138630418766`}, {-0.0015057989903908475`, 
        0.0014622111964130253`}, {-0.00027543951010812885`, 
        0.0015431396213685183`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.000034983250583417826`, 0.0015635580645111111`}, {
        0.0004227643154344884, 0.0015890648463166611`}, {0.002198476278934272,
         0.0017878344532023956`}, {0.003799170288258203, 
        0.002053079657519839}, {0.005202679731556008, 
        0.0023793600997186054`}, {0.007527314828854515, 
        0.0031855223826300514`}, {0.009305934378599924, 
        0.0041506310475031335`}, {0.010530779505574878`, 
        0.005224526466281742}, {0.011082596604173352`, 
        0.006166685609784839}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011187619521013695`, 0.006447299628755907}, {
        0.011033729175122282`, 0.00859332851131549}, {0.009220076053379466, 
        0.010450175615923011`}, {0.008251348101993999, 
        0.011126960150223941`}, {0.006448255239366939, 
        0.011743038557777797`}, {0.004773179569877332, 
        0.012220349187836061`}, {0.003226121093525168, 
        0.012558892040398733`}, {0.0019479808300218524`, 
        0.012681474023003838`}}]}, 
      {Arrowheads[{{0.006444121908177822, 1.}}], 
       ArrowBox[{{0.0016383082036170089`, 0.01271117364642325}, {
        0.001365453160513722, 
        0.012737342223615025`}, {-0.00022520798279577646`, 
        0.012651991027689779`}, {-0.0014915696773068925`, 
        0.012418323266436184`}, {-0.002297161338165422, 
        0.01213291934538316}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.07575719200089497}, {0.04984190248354503, 
        0.07576461335182694}, {0.047086306121393556`, 0.0758803797420212}, {
        0.04435536912742485, 0.07597687428640165}, {0.0416490915016389, 
        0.07605409698496826}, {0.038967473244035725`, 0.07611204783772103}, {
        0.03756244310087291, 0.07613250173743066}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03725138249962801, 0.07613703004052255}, {
        0.03631051435461532, 0.07615072684465997}, {0.03367821483337768, 
        0.07617013400578507}, {0.0310705746803228, 0.07617026932109633}, {
        0.028487593895450677`, 0.07615113279059377}, {0.02592927247876133, 
        0.07611272441427736}, {0.024808441967478088`, 0.0760880550052712}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02449742373261378, 0.07608120951349792}, {
        0.023398149132107617`, 0.0760570145487312}, {0.020896762557342373`, 
        0.07598597355053942}, {0.01842511275446563, 0.07589960141970199}, {
        0.015983199723477372`, 0.07579789815621893}, {0.013571023464377597`, 
        0.07568086376009023}, {0.012063743854027312`, 0.07559712108217301}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011753129324241919`, 0.07557986370514382}, {
        0.011188583977166308`, 0.07554849823131587}, {0.008835881261843502, 
        0.0754008015698959}, {0.006512915318409182, 0.07523777377583027}, {
        0.004219686146863348, 0.075059414849119}, {0.0019561937472059934`, 
        0.0748657247897621}, {-0.00027756188056288905`, 
        0.07465670359775954}, {-0.0006525040037088566, 
        0.07461853734672594}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009619982545571466, 
        0.07458703319037183}, {-0.0024815807364432715`, 
        0.07443235127311135}, {-0.004655862820435168, 
        0.07419266781581753}, {-0.0068004081325385955`, 
        0.07393765322587806}, {-0.008915216672753534, 
        0.07366730750329295}, {-0.011000288441079961`, 
        0.0733816306480622}, {-0.013054506897299365`, 
        0.07308267494346925}, {-0.013308310922562983`, 0.0730437452546514}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.013615808280620574`, 
        0.07299657982278303}, {-0.015076755501193174`, 
        0.07277249267279749}, {-0.017067034252761386`, 
        0.07245108383604695}, {-0.01902534315200401, 
        0.07211844843321763}, {-0.02095168219892104, 
        0.07177458646430952}, {-0.022846051393512465`, 
        0.07141949792932262}, {-0.024708450735778292`, 
        0.07105318282825693}, {-0.025865156156984793`, 
        0.07081460248658444}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.026169836279317703`, 
        0.07075175961721224}, {-0.026538880225718528`, 
        0.07067564116111247}, {-0.028337339863333165`, 
        0.07028687292788921}, {-0.030103829648622207`, 
        0.06988687812858715}, {-0.03183834958158566, 
        0.06947565676320633}, {-0.03354089966222351, 
        0.0690532088317467}, {-0.03521147989053577, 
        0.0686195343342083}, {-0.03685009026652243, 
        0.0681746332705911}, {-0.03824983016731838, 0.06777724503486673}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.038548778624452565`, 
        0.06769118631480318}, {-0.04003140146151896, 
        0.06725115144512035}, {-0.041573992872756475`, 
        0.06677412779371512}, {-0.043084395616123684`, 
        0.06628899179712776}, {-0.04456260969162058, 
        0.06579574345535825}, {-0.04600863509924718, 
        0.0652943827684066}, {-0.04742247183900346, 
        0.06478490973627282}, {-0.04880411991088943, 
        0.0642673243589569}, {-0.0501535793149051, 
        0.06374162663645884}, {-0.05032117780869975, 0.06367370911513182}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05060949708393663, 
        0.06355687077081539}, {-0.051470850051050454`, 
        0.06320781656877864}, {-0.05277202645326069, 
        0.06266995032850735}, {-0.05407320285547094, 
        0.062132084088236075`}, {-0.055374379257681176`, 
        0.06159421784796479}, {-0.056675555659891415`, 
        0.06105635160769351}, {-0.05797673206210166, 
        0.06051848536742223}, {-0.0592779084643119, 
        0.05998061912715095}, {-0.06086900861778752, 
        0.0587088844687593}, {-0.06175939635520532, 0.05819171698940888}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.062028404564536864`, 
        0.05803546787264989}, {-0.06285665001911794, 
        0.057554394744586186`}, {-0.06472720356246804, 
        0.05638179544620594}, {-0.06484954166029133, 
        0.05630201589539252}, {-0.06497135126624767, 
        0.05622216152847064}, {-0.06510251245446844, 
        0.05613522502562152}, {-0.0652330515499294, 
        0.05604820271247613}, {-0.06536296905215513, 
        0.05596109524391275}, {-0.06549226546315227, 
        0.055873903273992206`}, {-0.0656209412874018, 
        0.05578662745595587}, {-0.06587705277877536, 
        0.05561190942767183}, {-0.0661306859910348, 
        0.05543686122216588}, {-0.06638184501653847, 
        0.05526148804641589}, {-0.06760085581243419, 
        0.05438013906294345}, {-0.06875865859275593, 
        0.05349143572236085}, {-0.06985581872910668, 
        0.052596009083313494`}, {-0.0708929015930894, 
        0.05169449020444679}, {-0.07199404834054257, 0.05063834976343781}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07221856509926036, 
        0.05042300950191994}, {-0.07278927181825492, 
        0.04987562883056093}, {-0.07441324362933602, 
        0.048105614719310276`}, {-0.07584255965666155, 
        0.046334832642319246`}, {-0.07707721990023153, 
        0.04456328259958785}, {-0.07811722436004596, 
        0.04279096459111609}, {-0.07896257303610485, 
        0.041017878616903945`}, {-0.0792369137029541, 
        0.040269998505508955`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.07934404971271791, 
        0.039977935021677756`}, {-0.07961326592840819, 
        0.03924402467695144}, {-0.08006930303695597, 
        0.03746940277125856}, {-0.0803306843617482, 
        0.035694012899825316`}, {-0.08042113893659858, 
        0.03393031439523363}, {-0.08036439579532077, 
        0.03219076659006546}, {-0.08016045493791482, 
        0.030475369484320787`}, {-0.07980931636438068, 
        0.028784123077999622`}, {-0.07950174193087413, 
        0.027755187340652958`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07941264390585265, 
        0.02745712569415512}, {-0.0793109800747184, 
        0.02711702737110196}, {-0.07866544606892793, 
        0.025474082363627804`}, {-0.0778727143470093, 
        0.023855288055577153`}, {-0.0769327849089625, 
        0.02226064444695}, {-0.07587118542169177, 
        0.020698036773760316`}, {-0.07471344355210133, 
        0.01917535027202208}, {-0.07345955930019117, 
        0.017692584941735277`}, {-0.07282672658541238, 
        0.017016243480843005`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07261417820087673, 
        0.016789081892085098`}, {-0.0721095326659613, 
        0.016249740782899917`}, {-0.07066336364941173, 
        0.014846817795515992`}, {-0.06912105225054245, 
        0.013483815979583508`}, {-0.06748259846935345, 
        0.01216073533510246}, {-0.06574800230584475, 
        0.010877575862072851`}, {-0.06368027368591715, 
        0.009463244957758592}, {-0.06295210052457925, 0.00899957893081733}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06268968908916643, 
        0.008832487812740056}, {-0.06155651906534873, 
        0.008110939051141741}, {-0.05937673844413951, 
        0.006820658142222309}, {-0.0571409318222895, 
        0.0055924022310002985`}, {-0.05484909919979868, 
        0.004426171317475706}, {-0.052501240576667066`, 
        0.0033219654016485305`}, {-0.05172110745919461, 
        0.002983746237304874}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.05143568337139959, 
        0.0028600033858664584`}, {-0.05009735595289464, 
        0.002279784483518772}, {-0.04763744532848141, 
        0.0012996285630864257`}, {-0.04515114529558545, 
        0.00038118881016138174`}, {-0.04266809244636484, \
-0.0004758436054464769}, {-0.04018828678081958, -0.0012714686837371528`}, \
{-0.039751635150797014`, -0.00140092146094171}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.039453373100333394`, -0.001489346301506821}, \
{-0.03771172829894966, -0.0020056864247106464`}, {-0.035238417000755085`, \
-0.0026784968283669578`}, {-0.03276835288623584, -0.0032898998947060894`}, \
{-0.030301535955391944`, -0.0038398956237280374`}, {-0.027837966208223403`, \
-0.0043284840154328005`}, {-0.027361751258326666`, -0.004392014454256227}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.027053389621099915`, -0.004433152075268699}, \
{-0.02509123283818399, -0.004694917652947522}, {-0.02281282752263791, \
-0.0050985870940232466`}, {-0.02054844346499462, -0.005443134367068541}, \
{-0.01830346770236784, -0.005729702056726784}, {-0.01608328727187129, \
-0.0059594327476413505`}, {-0.014722935808797112`, -0.006067538096217257}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.014412819940598525`, -0.006092182597980622}, \
{-0.013893289210618696`, -0.006133469024455618}, {-0.011738860555723776`, \
-0.006252953471812963}, {-0.009625388344300235, -0.006319028674356762}, \
{-0.0079893933074165, -0.006335951211656005}, {-0.006383178260363373, \
-0.006324638430351151}, {-0.004809198554134808, -0.006286067739601756}, \
{-0.0032699095397247784`, -0.006221216548567372}, {-0.0019793464582281493`, \
-0.006143760680255079}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0016689359182156074`, -0.006123326329577985}, \
{-0.0003052249903361722, -0.006016582302281845}, {
        0.0011152598426544622`, -0.005878754065349809}, {
        0.002491232579850672, -0.005718554964770995}, {
        0.005099820362883987, -0.005334953809311244}, {
        0.007500895550812047, -0.004873598109179009}, {
        0.009674815335683078, -0.0043423071376507165`}, {
        0.010576914591444296`, -0.004064529132908614}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01087423191735045, -0.003972977994784928}, {
        0.011601936909545318`, -0.00374890016800279}, {
        0.013306462102495012`, -0.003099597351637366}, {
        0.014826083402489318`, -0.002400126802456803}, {
        0.016161393988367845`, -0.0016575697374878627`}, {
        0.01731298703897023, -0.0008790073737572888}, {0.01906739324970505, 
        0.0007578083818817281}, {0.020094047465410766`, 
        0.0024536707282462253`}, {0.020276613771853014`, 
        0.0033203056201942995`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.020340741609684267`, 0.0036247178794592922`}, {
        0.020452705792444223`, 0.00415620733838047}, {0.020234559008956474`, 
        0.00581549011919061}, {0.019491504553355812`, 
        0.0073785356852554525`}, {0.01827543986405054, 
        0.008792360651153797}, {0.017073696998119982`, 
        0.009980261320820742}, {0.014938590999955138`, 
        0.011142364754814435`}, {0.012803734349833444`, 
        0.012117665286684481`}, {0.01265011945218867, 
        0.012174408736671135`}}]}, 
      {Arrowheads[{{0.008443464940275015, 1.}}], 
       ArrowBox[{{0.01235829856123913, 0.01228220377728593}, {
        0.010669127047754877`, 0.01290616291643089}, {0.008981051332127147, 
        0.013397430127314829`}, {0.007325945019207816, 
        0.013761048508431179`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02457703793157891, 0.09}, {-0.026325597599182057`, 
        0.08968599896944049}, {-0.02815544668568036, 
        0.08934395366665882}, {-0.029962881959455533`, 
        0.08899248680279476}, {-0.031747595528936606`, 
        0.08863269696763569}, {-0.03350927950255259, 
        0.08826568275096898}, {-0.0352479338803035, 
        0.08789144415279462}, {-0.03677638528861681, 0.0875515984973399}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.037079880254342786`, 
        0.08748326909625165}, {-0.038656153848210084`, 
        0.08712129381192296}, {-0.04032571943836576, 
        0.08672538206922566}, {-0.04197225543265637, 
        0.0863222459450207}, {-0.04359576183108189, 
        0.0859118854393081}, {-0.045196238633642326`, 
        0.08549430055208784}, {-0.0467736858403377, 
        0.08506949128335994}, {-0.04832810345116799, 
        0.08463745763312439}, {-0.04913534798184733, 0.08440591040915729}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.049434383082079, 
        0.08432013621720447}, {-0.04985949146613319, 
        0.0841981996013812}, {-0.051367849885233324`, 
        0.08375171718813035}, {-0.05285317870846838, 
        0.08329801039337184}, {-0.05431547793583835, 
        0.0828370792171057}, {-0.055754747567343256`, 
        0.0823689236593319}, {-0.0571710218295775, 
        0.08189436187399182}, {-0.0585643349491355, 
        0.08141421201502679}, {-0.059934686926017264`, 
        0.08092847408243682}, {-0.06125688109379126, 0.08044633603948652}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.06154823505277245, 
        0.0803372882596036}, {-0.06260650745175209, 
        0.07994023399638207}, {-0.06390797600060515, 
        0.07943773184291729}, {-0.06644202967028255, 
        0.07841596331511293}, {-0.06893016105460759, 
        0.07738301864005863}, {-0.0714182924389326, 
        0.07635007396500434}, {-0.07307886062206763, 0.07566069113211217}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07336617850338917, 
        0.07554141146809255}, {-0.07390642382325764, 
        0.07531712928995005}, {-0.07567025245022117, 
        0.07413903257577305}, {-0.07704360084886909, 
        0.07341181580602205}, {-0.07837892299483101, 
        0.07267822846958022}, {-0.07967621888810694, 
        0.07193827056644758}, {-0.08093548852869688, 
        0.07119194209662412}, {-0.08110295978362704, 
        0.07109073560636285}, {-0.08126974390027596, 
        0.07098942306708846}, {-0.0829680403297831, 
        0.06963806426877672}, {-0.08386139920752353, 0.06892720581173174}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08410483054348274, 
        0.06873350401037501}, {-0.08466633675929022, 
        0.06828670547046499}, {-0.08636463318879736, 
        0.06693534667215324}, {-0.0880629296183045, 
        0.06558398787384151}, {-0.08888661624387481, 
        0.0641735927880522}, {-0.09043056976680486, 
        0.06281181582136205}, {-0.09187162801868352, 
        0.06144309340908633}, {-0.09306117503599184, 0.06022020679469635}}]}, 
      {Arrowheads[{{0.01946458243691901, 1.}}], 
       ArrowBox[{{-0.09327520687726482, 
        0.05999451744192151}, {-0.09444835684001697, 
        0.058687003904683004`}, {-0.09559062367093232, 
        0.05730402012636528}, {-0.09663659149225685, 
        0.0559184742162718}, {-0.09758626030399059, 
        0.0545303661744026}, {-0.0984396301061335, 
        0.05313969600075766}, {-0.0991967008986856, 
        0.05174646369533698}, {-0.09985747268164688, 
        0.05035066925814057}, {-0.1, 0.04999758932004714}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.018806407467481533`}, {0.049952697526397985`, 
        0.018825091886832637`}, {0.04791678615608232, 
        0.019583794395721225`}, {0.04587010783569828, 
        0.020301269838719625`}, {0.043812662565245894`, 
        0.02097751821582785}, {0.04174983381975927, 0.021633153059990994`}, {
        0.03968700507427264, 0.022288787904154138`}, {0.03820348791099709, 
        0.02276029846763917}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03790700896350569, 0.022854529231565394`}, {
        0.03762417632878602, 0.022944422748317282`}, {0.035593462484981894`, 
        0.023278302180985266`}, {0.03398742944766495, 
        0.023655466893076068`}, {0.03238915638801308, 
        0.024008643268209166`}, {0.03228151058217576, 
        0.024031678261426857`}, {0.03217390678472792, 
        0.024054605122136495`}, {0.0302426803473784, 0.024341646902729806`}, {
        0.02831145391002889, 0.024628688683323113`}, {0.026380227472679374`, 
        0.024915730463916423`}, {0.025663098001842913`, 
        0.02502231875218952}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.025355384787013626`, 0.025068054740154718`}, {
        0.024449001035329862`, 0.02520277224450973}, {0.02279629536380484, 
        0.02521625021527218}, {0.020914219649836124`, 
        0.025455016029424748`}, {0.01906491108478793, 
        0.025661597865950157`}, {0.01724836966866027, 
        0.025835995724848407`}, {0.015544982071242785`, 0.0259742697199157}, {
        0.013875796583310757`, 0.026086492181068354`}, {0.012967226376780097`,
         0.02613437788938177}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012656563990302358`, 0.02615075118482542}, {
        0.012240813204864184`, 0.026172663108306363`}, {0.010640031935903072`,
         0.02623278250162973}, {0.009073452776427415, 
        0.026266850361038457`}, {0.007541075726437212, 
        0.026274866686532537`}, {0.006042900785932469, 0.02625683147811198}, {
        0.004578927954913177, 0.026212744735776776`}, {0.0031533776831574835`,
         0.02614574704611249}, {0.0017704704204435104`, 
        0.026058978995704675`}, {0.00043020616677126415`, 
        0.02595244058455333}, {0.0002251803411778624, 0.02593248363614131}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.00008444983152358643, 
        0.025902344636015234`}, {-0.000867415077859251, 
        0.02582613181265846}, {-0.003334728539995105, 
        0.025514203186638138`}, {-0.0056314699659640545`, 
        0.025123193117643706`}, {-0.007753414117880998, 
        0.024666477894867252`}, {-0.009696335757860832, 
        0.024157433807500874`}, {-0.01146023488590356, 
        0.023596060855544575`}, {-0.012215790875837624`, 
        0.023303491655637838`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.01250589440599906, 
        0.023191156687958132`}, {-0.01304511150200919, 
        0.022982359038998344`}, {-0.01497963895477294, 
        0.022049800522811}, {-0.016566699025135263`, 
        0.0210563732011071}, {-0.01782016874323347, 
        0.0200192401309679}, {-0.01875392513920486, 
        0.018955564369474667`}, {-0.019734842288189853`, 
        0.016805828276456165`}, {-0.019552995493914135`, 
        0.014372260671561124`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01942835863943457, 
        0.014094748472783143`}, {-0.018142764384804812`, 
        0.011994599840697263`}, {-0.017087698510919097`, 
        0.010965223520870359`}, {-0.015852562498846957`, 
        0.010027624567805024`}, {-0.013977933594372882`, 
        0.00888221097175601}, {-0.012027350105416765`, 
        0.007917743266705024}, {-0.010000812031978612`, 
        0.007134221452652067}, {-0.009605692825908433, 
        0.0070209800011694305`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.009306639042943082, 
        0.006935270969732587}, {-0.007898319374058431, 
        0.006531645529597142}, {-0.005820931663728008, 
        0.006095656137651738}, {-0.0038697084330591475`, 
        0.00581189391692735}, {-0.0020446496820518446`, 
        0.005680358867423977}, {-0.0003457554107060964, 
        0.005701050989141619}, {0.0011801955592914831`, 
        0.00583788353291726}, {0.002486424406254276, 0.006054769749587878}, {
        0.0029680908453947707`, 0.006186408124294622}}]}, 
      {Arrowheads[{{0.006653789766015584, 1.}}], 
       ArrowBox[{{0.003268179154866338, 0.00626842159693312}, {
        0.0035729311301822882`, 0.006351709639153475}, {0.00443971573107552, 
        0.006728703201614049}, {0.005607955637895165, 0.007899322085579728}, {
        0.00547270495822267, 0.009116763220660807}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.05936415918793532}, {0.04891242875744275, 
        0.05945105512756192}, {0.046807173507345416`, 0.05960712255352431}, {
        0.044719015361646935`, 0.059749683408964006`}, {0.04264795432034734, 
        0.059878737693881016`}, {0.040593990383446674`, 
        0.05999428540827534}, {0.038557123550944886`, 0.06009632655214697}, {
        0.037581117291240515`, 0.06013910880429509}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03727032217161092, 0.060152732195581975`}, {
        0.03653735382284196, 0.060184861125495925`}, {0.034534681199137926`, 
        0.06025988912832218}, {0.03254910567983281, 0.06032141056062575}, {
        0.03058062726492658, 0.060369425422406635`}, {0.028629245954419204`, 
        0.06040393371366483}, {0.02669496174831075, 0.060424935434400334`}, {
        0.02483066024889409, 0.060432223830909806`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024519568385110095`, 0.060431613683115504`}, {
        0.02287768464929048, 0.06042641916430328}, {0.020994691756378706`, 
        0.060406901173470716`}, {0.018653057749290033`, 
        0.060365482613026065`}, {0.016344420140638662`, 
        0.060307327739181855`}, {0.014068778930424564`, 
        0.06023243655193808}, {0.012079925260482686`, 0.06015117816899436}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01176911196604794, 0.06013801261639435}, {
        0.009616485705308138, 0.060032445237251826`}, {0.007439833690405861, 
        0.05990734510980936}, {0.0052961780739408555`, 0.05976550866896733}, {
        0.0031855188559131026`, 0.059606935914725726`}, {
        0.0011078560363226332`, 
        0.059431626847084564`}, {-0.0006427280185946512, 
        0.059267203164868075`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009524432741126244, 
        0.05923795900257992}, {-0.002948480407546486, 
        0.05903079977160355}, {-0.004927154031825132, 
        0.05880528176376369}, {-0.006872831257666506, 
        0.05856302744252427}, {-0.008785512085070606, 
        0.05830403680788528}, {-0.010665196514037426`, 
        0.058028309859846736`}, {-0.012511884544566986`, 
        0.05773584659840863}, {-0.013286055431186489`, 
        0.05760494002998768}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.013592794704943895`, 
        0.057553072688524026`}, {-0.014324273243834267`, 
        0.05742938508020045}, {-0.016101059679014262`, 
        0.057111663361851715`}, {-0.017842243850106996`, 
        0.05678268144336242}, {-0.01954782575711246, 
        0.05644243932473256}, {-0.021217805400030647`, 
        0.05609093700596214}, {-0.02285218277886156, 
        0.055728174487051155`}, {-0.024450957893605206`, 
        0.05535415176799961}, {-0.025774415937273164`, 
        0.055027952539118075`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.026076275762697682`, 
        0.05495273657991053}, {-0.027541701330830667`, 
        0.05457232572947484}, {-0.02903366965331249, 
        0.054164522410001616`}, {-0.03049003571170704, 
        0.05374545889038782}, {-0.03191079950601432, 
        0.05331513517063347}, {-0.03329596103623432, 
        0.05287355125073856}, {-0.03464552030236705, 
        0.052420707130703084`}, {-0.03723783204237069, 
        0.05148123829021045}, {-0.03793341173032326, 0.0512049690884223}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.038222535304404455`, 
        0.051090135460567725`}, {-0.03969019061921482, 
        0.05050721452520189}, {-0.042005051926089006`, 
        0.049509121711723725`}, {-0.04418241596299327, 
        0.04848695984977595}, {-0.046222282729927594`, 
        0.04744072893935856}, {-0.04812465222689199, 
        0.046370428980471556`}, {-0.049368042018189326`, 
        0.04559942288108005}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04963243132726989, 
        0.04543547930414081}, {-0.04988952445388645, 
        0.04527605997311495}, {-0.05151689941091097, 
        0.044157621917288725`}, {-0.05300677709796556, 
        0.0430151148129929}, {-0.05483171271657529, 
        0.041420955808361457`}, {-0.056415860597600336`, 
        0.0398062786322591}, {-0.05776532457987226, 
        0.038176695666262014`}, {-0.05860551051403017, 
        0.036948484021893026`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAVsKaTJAYrr9TWazQQcmiP9VmLCJi
Jq6/KvF9Fw61oj9LAcdXeDOuv9IKTXiHn6I/xlHFh0RArr9lWUWU/4miP7Ke
Su/GTK6/y5XMlnZ0oj9GAiGJ7FKuv49YsLqxaaI/IVnkx/9Yrr/tFGqo7F6i
P4s5TbMAX66/CgBZZSdUoj/uqRhT72Suv4hG2fZhSaI/CJAHr8tqrr85bURi
nD6iP0SKanHu4K6/+i7AT0JAoT8v/6UQQ+Suv/L43kGtN6E/duXdjoznrr/N
pB1tGC+hP49I2go+7K6/tDFJ524ioT+iYTV11/Cuv205XfnFFaE/mJhb21j1
rr/iVHqrHQmhP/ZOwErC+a6/rRy7BXb8oD8I0t3QE/6uv8gnNBDP76A/07OT
JYcGr78E662VgtagP/EyWEGbDq+/V0ZfHDm9oD+8GZqQUBavv9iHYuTyo6A/
dtRQXmRPr7+xJ2ckOFCfPyuiulZPZa+/knVOHShdnT9StWqlzlmvv6qESll3
cJs/A3MUdKwur7/8nSJOy4uZP+Or+l5KKK+/gcndgGpgmT+sUtTe
        "]]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.060766436461019535`, 
        0.024483422925945738`}, {-0.06043850152324602, 
        0.0233691423845216}, {-0.05982047980661405, 
        0.021824967785373496`}, {-0.059048901511468854`, 
        0.020314811106268486`}, {-0.05812376663781042, 
        0.018838672347206566`}, {-0.05706368742166312, 
        0.017401920439683062`}, {-0.0558872760990513, 
        0.016009924315193286`}, {-0.05459453266997498, 
        0.014662683973737252`}, {-0.054076209996140524`, 
        0.014183570354969888`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.05384776283308445, 
        0.01397240431397996}, {-0.053185457134434136`, 
        0.01336019941531495}, {-0.05163758229349916, 
        0.012098150089936865`}, {-0.05007822227443791, 
        0.010901019114210268`}, {-0.04842050390805585, 
        0.009752100361509022}, {-0.04667341407392483, 
        0.008653122051828933}, {-0.04522361487110341, 
        0.007812558824214166}, {-0.043729793996051064`, 
        0.007002919617674721}, {-0.04362023322288747, 
        0.006947306905361311}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04334283075437394, 
        0.0068064982634449545`}, {-0.042196786338012715`, 
        0.006224769633889603}, {-0.0406294267862333, 
        0.0054786740745378145`}, {-0.03903255022995773, 
        0.004765198141298366}, {-0.037410991558430945`, 
        0.004084907035850268}, {-0.035769585660897864`, 
        0.0034383659598725192`}, {-0.034113167426603405`, 
        0.002826140115044125}, {-0.032446571744792485`, 
        0.0022487947030440953`}, {-0.03185556214570153, 
        0.002057239798344014}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.031559624653828285`, 
        0.001961322104045724}, {-0.030774633504710054`, 
        0.0017068949255514385`}, {-0.029102187595601015`, 
        0.0012010059842451574`}, {-0.027434068906710296`, 
        0.0007316930808042567}, {-0.025775112327282825`, 
        0.0002995214169077442}, {-0.024130152746563535`, \
-0.00009494380576537131}, {-0.02250402505379734, -0.0004511373855360863}, \
{-0.020901564138229158`, -0.0007684941207253959}, {-0.019489625269750087`, \
-0.001020202191967931}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01918296219786623, -0.0010724483293307458`}, \
{-0.017744847375756066`, -0.0013029174052008481`}, {-0.016186081319871128`, \
-0.0015250731704510726`}, {-0.014643582193220702`, -0.0017178597094112443`}, \
{-0.01311975403005488, -0.001881778040857572}, {-0.011617000864623767`, \
-0.002017329183566265}, {-0.010137726731177438`, -0.0021250141563135343`}, \
{-0.00868433566396597, -0.00220533397787559}, {-0.007259231697239463, \
-0.0022587896670286417`}, {-0.006807433672684695, -0.002267567822119679}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0064963988149302505`, -0.0022736110362810906`}, \
{-0.005864818865248012, -0.0022858822425488993`}, {-0.004503501202241699, \
-0.0022871127232125727`}, {-0.0031776827424706026`, -0.0022629821277958726`}, \
{-0.0006421595696344518, -0.0021406417838261906`}, {
        0.0017225183792597557`, -0.001922869360849532}, {
        0.003917527551304258, -0.0016203404324102635`}, {
        0.00588025770449983, -0.0012586923395787025`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.006183749051609659, -0.001190648562157828}, {
        0.007811094861325789, -0.0008062797469116402}, {
        0.009490027270771851, -0.0003089188348882749}, {0.010977308364154111`,
         0.00023921522662712904`}, {0.012263125277207064`, 
        0.0008310370151165701}, {0.013337665145665227`, 
        0.0014594611080620545`}, {0.014191115105263108`, 
        0.0021174020829455888`}, {0.015597566204557163`, 
        0.003253827660172675}, {0.015981717990869462`, 
        0.004845177784679763}, {0.015972509716962457`, 
        0.005097342098108137}}]}, 
      {Arrowheads[{{0.00617569757995067, 1.}}], 
       ArrowBox[{{0.015961157092939555`, 0.005408228445675095}, {
        0.015928014004146403`, 0.006315836572325491}, {0.015436454244387977`, 
        0.007665804023109849}, {0.014547830289125515`, 
        0.008871208244804151}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00007403665322447384, 1.}}], 
       ArrowBox[{{-0.009378374126428638, 
        0.015866371596465055`}, {-0.00941407166293035, 
        0.01583725737214254}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{-0.1, 0.014798515734828276`}, {-0.09831937238805934, 
        0.013461453040655273`}, {-0.09629627190856026, 
        0.011906165581228735`}, {-0.09427317142906119, 
        0.010350878121802194`}, {-0.09326162118931165, 
        0.009573234392088925}, {-0.09225007094956211, 
        0.008795590662375657}, {-0.09123852070981257, 
        0.008017946932662386}, {-0.08992250678146568, 
        0.007656639386511617}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0896328957043681, 
        0.0075497442770028405`}, {-0.08773122869193771, 
        0.006428613770304778}, {-0.08570547680293329, 
        0.005290973684798071}, {-0.08556745384015764, 
        0.005215338616607544}, {-0.08542927557919579, 
        0.005139863111154403}, {-0.0831921111782745, 
        0.004129475739571658}, {-0.08095494677735321, 
        0.003119088367988912}, {-0.07871778237643193, 
        0.002108700996406166}, {-0.0785047267436538, 
        0.0020124770797753906`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07822120783674671, 
        0.0018844293050897683`}, {-0.07648061797551065, 
        0.0010983136248234205`}, {-0.0741411061524323, 
        0.00041186547868829427`}, {-0.07188588044171858, \
-0.000541356147227225}, {-0.06961861385780993, -0.0014564672760312598`}, \
{-0.06733930640070632, -0.002333467907723809}, {-0.0666259962522887, \
-0.002596139035501835}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.06633406684831573, -0.002703639855367155}, \
{-0.06538111475199578, -0.003054557338335936}, {-0.06342036663697022, \
-0.0037485180225421528`}, {-0.06145706205562966, -0.004415349960342461}, \
{-0.05949120100797409, -0.00505505315173686}, {-0.057522783494003506`, \
-0.005667627596725349}, {-0.055551809513717916`, -0.0062530732953079305`}, \
{-0.05450306813798229, -0.0065497649878687725`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0542037229178319, -0.006634450537691883}, \
{-0.05357827906711732, -0.006811390247484602}, {-0.051602192154201705`, \
-0.0073425784532553644`}, {-0.04962986895250993, -0.00784730016827881}, \
{-0.047667629639580836`, -0.008326217648213528}, {-0.045715474215414414`, \
-0.008779330893059522}, {-0.04377340268001067, -0.00920663990281679}, \
{-0.04210972697876066, -0.00955238421371507}}]}, 
      {Arrowheads[{{0.003232094476792022, 1.}}], 
       ArrowBox[{{-0.04180505445601006, -0.00961525257166443}, \
{-0.03991951127549121, -0.009983845217065147}, {-0.039831242166616154`, \
-0.01}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.0002449316124642441, 1.}}], 
       ArrowBox[{{0.03602656720702168, 0.00691012704790293}, {
        0.03599154882317974, 0.006944220771007192}, {0.035956423415429525`, 
        0.006978267248250144}, {0.03591706339574822, 
        0.0070161104013939275`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03533494976736533, 0.010037417552888145`}, {
        0.03367398348302775, 0.011306235938658302`}, {0.03201301719869016, 
        0.01257505432442846}, {0.02960411586500613, 0.013194129196976524`}, {
        0.027965393183331605`, 0.013920077814507567`}, {0.02790954194788482, 
        0.0139436759796987}, {0.027853659665485853`, 0.013967212756632727`}, {
        0.025858438600566837`, 0.014528553506022966`}, {0.024135334359875978`,
         0.01501333619138729}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02383586708298948, 0.015097589103799353`}, {
        0.02186799647072881, 0.015651235004803445`}, {0.019872775405809794`, 
        0.016212575754193687`}, {0.018037103952254704`, 
        0.016512323228999728`}, {0.016201432498699615`, 
        0.016812070703805766`}, {0.014365761045144525`, 
        0.017111818178611807`}, {0.012530089591589435`, 
        0.017411565653417845`}, {0.011644500786393614`, 
        0.01745897994334365}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011333852147154846`, 0.017475612024236618`}, {
        0.010946287009381299`, 0.017496362202761587`}, {0.009362484427173166, 
        0.017581158752105325`}, {0.007778681844965029, 
        0.017665955301449068`}, {0.006194879262756894, 
        0.017750751850792806`}, {0.003733611727718712, 0.01757197710907736}, {
        0.0012723441926805294`, 0.01739320236736192}, {-0.0005919041775656344,
         0.017006219068933615`}, {-0.0010402621255831716`, 
        0.016913148295548703`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0013448622817823245`, 
        0.016849918966759126`}, {-0.002456152547811799, 
        0.016619235770505312`}, {-0.005022552098098628, 
        0.015591093333252294`}, {-0.006559178334981203, 
        0.014447074490595416`}, {-0.007232353877162297, 
        0.013297555811005916`}, {-0.007258619658836178, 
        0.01112057970442753}, {-0.005284324332902702, 
        0.009443704108685185}, {-0.0047947038791418504`, 
        0.009244022007511858}}]}, 
      {Arrowheads[{{0.011748984219772824`, 1.}}], 
       ArrowBox[{{-0.004506645102641923, 
        0.009126542884017114}, {-0.003935256090919837, 
        0.008893513079866518}, {-0.002542822495823766, 
        0.008541776330917432}, {-0.0010278765235779124`, 
        0.008353013800045085}, {0.0002358984540211874, 0.00837260442446099}, {
        0.0018541512308859775`, 0.008834614700886156}, {
        0.0022282474990180175`, 0.009522824505273291}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.08468577721048978}, {0.0488383883561993, 
        0.0847212235685285}, {0.04737649548641609, 0.08476109673845215}, {
        0.04592098915984104, 0.08479603881170013}, {0.04447186937647407, 
        0.0848260497882724}, {0.04302913613631529, 0.084851129668169}, {
        0.04159278943936465, 0.08487127845138989}, {0.040162829285622106`, 
        0.0848864961379351}, {0.03873925567508776, 0.08489678272780461}, {
        0.03755855790115146, 0.08490124453742598}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03724746603295379, 0.08490216066291878}, {
        0.03591126808364343, 0.08490256261751655}, {0.03450685410273349, 
        0.084898055917359}, {0.033108826665031704`, 0.08488861812052573}, {
        0.03171718577053802, 0.08487424922701678}, {0.028953063611175167`, 
        0.0848307181499718}, {0.02720837598213187, 0.08479362557336226}, {
        0.025476213740406647`, 0.0847503064787718}, {0.02480539392511477, 
        0.08473097903845295}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02449442940593249, 0.08472201963080163}, {
        0.02375657688599954, 0.08470076086620042}, {0.02204946541891059, 
        0.08464498873564814}, {0.020354879339139757`, 0.08458299008711494}, {
        0.018672818646687003`, 0.08451476492060084}, {0.017003283341552364`, 
        0.08444031323610582}, {0.015346273423735882`, 0.08435963503362988}, {
        0.013701788893237518`, 0.08427273031317303}, {0.012069829750057229`, 
        0.08417959907473528}, {0.012063005690787722`, 0.08417918039554187}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011752495998016017`, 0.08416012957218563}, {
        0.010450395994195054`, 0.08408024131831661}, {0.008843487625651038, 
        0.08397465704391703}, {0.0072491046444251375`, 0.08386284625153653}, {
        0.005667247050517316, 0.08374480894117513}, {0.004097914843927634, 
        0.08362054511283282}, {0.002541108024656062, 0.08349005476650959}, {
        0.000996826592702612, 0.08335333790220543}, {-0.0005349294519327238, 
        0.08321039451992038}, {-0.0006533831637541566, 
        0.08319876381177647}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009629878786653568, 
        0.08316836440914283}, {-0.002054160109249945, 
        0.08306122461965441}, {-0.0035608653792490452`, 
        0.08290582820140753}, {-0.005055045261930027, 
        0.08274420526517974}, {-0.006536699757292902, 
        0.08257635581097103}, {-0.008005828865337655, 
        0.08240227983878141}, {-0.009462432586064287, 
        0.08222197734861089}, {-0.010906510919472812`, 
        0.08203544834045945}, {-0.012338063865563208`, 
        0.0818426928143271}, {-0.013319387279500734`, 0.08170508749606926}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.013627466726504533`, 
        0.08166188729341278}, {-0.013757091424335496`, 
        0.08164371077021383}, {-0.015163593595789664`, 
        0.08143850220811966}, {-0.016557570379925717`, 
        0.08122706712804456}, {-0.017939021776743655`, 
        0.08100940552998856}, {-0.02066434840842518, 
        0.08055540277993381}, {-0.023337736513843625`, 
        0.08008065974649091}, {-0.025898039813302503`, 
        0.07960046588586524}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02620332662500502, 
        0.07954065244956338}, {-0.02852318621491945, 
        0.07908145019504709}, {-0.03103524781057683, 
        0.07855698367704617}, {-0.033493533902980516`, 
        0.07801594266419258}, {-0.03589804449213052, 
        0.07745832715648633}, {-0.03824877957802683, 
        0.0768841371539274}, {-0.03835275449409582, 0.07685739541693774}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.038654042682955456`, 
        0.07677990586648473}, {-0.04054573916066946, 
        0.0762933726565158}, {-0.042788923240058396`, 
        0.07568603366425153}, {-0.044978331816193644`, 
        0.07506212017713458}, {-0.0471139648890752, 
        0.07442163219516497}, {-0.04919582245870307, 
        0.07376456971834269}, {-0.050597776305084795`, 
        0.07329890417198093}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.050893009796004085`, 
        0.07320084098309063}, {-0.05122390452507726, 
        0.07309093274666774}, {-0.05319821108819775, 
        0.0724007212801401}, {-0.05511874214806455, 
        0.07169393531875981}, {-0.05698549770467767, 
        0.07097057486252685}, {-0.058799547257292084`, 
        0.0702346082404182}, {-0.06056196030516276, 
        0.06949000378141088}, {-0.06227273684828971, 
        0.06873676148550487}, {-0.06246808729480483, 0.06864705620403903}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.06275079843492622, 
        0.0685172347326755}, {-0.06393187688667293, 
        0.06797488135270016}, {-0.06553938042031242, 
        0.06720436338299679}, {-0.06709524744920818, 
        0.06642520757639472}, {-0.0685994779733602, 
        0.06563741393289398}, {-0.07005207199276851, 
        0.06484098245249455}, {-0.0714530295074331, 
        0.06403591313519644}, {-0.07280235051735393, 
        0.06322220598099963}, {-0.07371061203253534, 0.06264663903492418}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.07397338603244002, 
        0.062480118681363946`}, {-0.07410003502253104, 
        0.06239986098990416}, {-0.07534608302296443, 
        0.06156887816190999}, {-0.07654049451865408, 
        0.06072925749701715}, {-0.0776832695096, 
        0.05988099899522562}, {-0.07981390997726066, 
        0.05815856848094652}, {-0.08093556492420077, 
        0.05716561807422095}, {-0.08199442630529, 
        0.0561672295164948}, {-0.08299080713201629, 
        0.05516371805250089}, {-0.08353860395125924, 0.05457299320427078}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA7T46HqZwtb+E+Qi9F9OrP7GgJOwj
fLW/2NG6D0+6qz+ypueFsuq1v1kESuarsKo/AyWzwqBJtr9qJK60p6WpP1mm
a9pGUra/HWktteaKqT/5+uoKxlq2v4HaR98jcKk//MN4bh5jtr8dTVJZX1Wp
P4z0zho8Z7a/vRYSf/xHqT9s7c4dUGu2v89CH0eZOqk/z0HJelpvtr+OoTq2
NS2pP2ozEDVbc7a/nNAi0dEfqT/Ne/dPUne2vxaBlJxtEqk/9/kXf1Wrtr8q
GlwLfVWoP7+zFrcF2La/Uhjwz4SYpz+oqoPPytq2v+0s4mrCi6c/ulHfh4fd
tr8alcY3AH+nP/V9WSmq4La/bWZF/v9vpz8xklBIweO2v9V3AyEAYac/pR69
6czmtr8GbDqmAFKnPxjnmRLN6ba/EFQglAFDpz+J3+PHwey2v6uu5/ACNKc/
YqJSVZTytr8CjpOUBhanPw/8eTw5+La/UrIqJQz4pj9wNHOlsP22v0bH7tMT
2qY/mzOG0CUPt7//1V/9G2amP4JI0kg=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.09016457222790074, 
        0.043449897288789}, {-0.09049551630775243, 
        0.04235069787399732}, {-0.09092190044702189, 
        0.04008129191788069}, {-0.09109741261672982, 
        0.0378296068980198}, {-0.09103208615236268, 
        0.035600674194991265`}, {-0.09071324966803421, 
        0.03322399286757186}, {-0.09022174088358924, 
        0.031182000481847275`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.090147912347626, 
        0.030879848406453296`}, {-0.08934656587901484, 
        0.02859811458042141}, {-0.08829871857432395, 
        0.026348917620690356`}, {-0.08703466093782501, 
        0.024151003508172057`}, {-0.0855811862444975, 
        0.022013160300849804`}, {-0.08407807293509593, 
        0.02011216639730442}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08388065992953554, 
        0.019871921981708958`}, {-0.08210598568735666, 
        0.017917686601793454`}, {-0.08103132615544834, 
        0.01691146248621393}, {-0.0800513543443815, 
        0.015952570214173598`}, {-0.07902731881702371, 
        0.015009444258020858`}, {-0.07796086484733306, 
        0.014082458912549993`}, {-0.0768536377092676, 
        0.01317198847255529}, {-0.07570728267678548, 
        0.01227840723283104}, {-0.074687712949011, 0.011523686311303488`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07443618423545782, 
        0.011340655835877051`}, {-0.07330377002440353, 
        0.010543409533371049`}, {-0.07147532313866797, 
        0.00932808809157928}, {-0.06958442298569217, 
        0.008149206390996564}, {-0.06763660365148781, 
        0.007007614792880591}, {-0.06563739922206657, 
        0.005904163658489034}, {-0.06378009959563334, 
        0.004937431071353366}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06350310693800891, 
        0.0047958580483581335`}, {-0.06150697142162022, 
        0.003815084225909894}, {-0.059386816222618474`, 
        0.0028311566502376697`}, {-0.05723741227244663, 
        0.0018887709833205948`}, {-0.05506429365711635, 
        0.0009887775864163431}, {-0.05287299446263932, 
        0.0001320268207825907}, {-0.05209380621401127, \
-0.000155282158980048}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05180192284220228, -0.0002629079014264691}, \
{-0.05066904877502724, -0.0006806309523229763}, {-0.0484579906802918, \
-0.0014483453716426713`}, {-0.04624535426444469, -0.0021702660759188182`}, \
{-0.044036673613497584`, -0.0028455427038937406`}, {-0.04183748281346218, \
-0.003473324894309751}, {-0.03993171738420927, -0.003978905199540318}}]}, 
      {Arrowheads[{{0.017710729891847042`, 1.}}], 
       ArrowBox[{{-0.039630923252489444`, -0.004058277636197741}, \
{-0.03747946121242479, -0.004588185504258964}, {-0.035309567444309374`, \
-0.005084754132818076}, {-0.033146709716556026`, -0.005542861247166733}, \
{-0.030993963099716793`, -0.005962899922885169}, {-0.02885440266434371, \
-0.0063452632355536255`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAeG5F5qgKpD97FK5H4XqEv+mo9TgZ
IaQ/bKdWKDoXhL90NCpw6qWkPz18a9YNOoG/mKaHzr8LpT/WvZ69BLR8v/YT
pTrZU6U/3Ay4Ghj1dr/yWvychX+lP8EcJb3UPXG/Sgs2FWGCpT9R/X8zK6xw
v8+VjKX3hKU/VXBkoqYacL/hdc2pSYelP+FtJxWREm+/ZQ5HEVmIpT8LaKOv
UIFuvynKRnhXiaU/Nu4rpSTwbb+1wVrqRIqlPyy+eVQNX22/oHkVcyGLpT97
aPEbC85sv9ZPDR7ti6U/ZtGtWR49bL+qC4OK3o6lP6A0eGd4j2G/Cxx5X0OO
pT/eK/9iJthgv033MNNjjaU/pUJVPwwPYL+Z+GD8ZIylP1Hg1A1bjF6/WKiI
/EaLpT91i9dRFvtcvw3SM/UJiqU/nwZvJkxqW7/cRfoHroilP70ZumT+2Vm/
8fIQpbiFpT//rBtfX7pWv5Ii67dIgqU/5B4+p8CcU7/PFk9OX36lP/pa6Mkw
gVC/7FGkXQw+pT+lmKAWVitMP4yFsCN0FKU/oznD44yOWT+g/8tF
        "]]}, 
      {Arrowheads[{{0.008202093215599887, 1.}}], 
       ArrowBox[{{0.041043256057594575`, 0.00184321694036197}, {
        0.04067135832274432, 0.0026638004271877644`}, {0.03955892181982868, 
        0.004394069533749528}, {0.03818409687998502, 
        0.006040920832743355}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00011394708954102493`, 1.}}], 
       ArrowBox[{{0.029898937151325203`, -0.00205622499323521}, {
        0.029926778572723585`, -0.0019910241004521606`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.05098885403379697}, {0.04938465985292061, 
        0.051055022206430996`}, {0.04762080523628718, 
        0.051234921513801185`}, {0.04586919694553468, 0.05140373412781086}, {
        0.0441298349806631, 0.05156146004846002}, {0.04240271934167245, 
        0.05170809927574866}, {0.04068785002856273, 0.05184365180967679}, {
        0.038985227041333934`, 0.0519681176502444}, {0.03760341906062265, 
        0.05206080007661681}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03729302221354512, 0.05208160823553669}, {
        0.035616720044519115`, 0.05218378925129808}, {0.03395083603493306, 
        0.052274995011784155`}, {0.03229719835122796, 
        0.052355114078909706`}, {0.030655806993403794`, 
        0.05242414645267474}, {0.029026661961460525`, 
        0.052482092133079264`}, {0.027409763255398206`, 
        0.05252895112012327}, {0.025805110875216808`, 0.05256472341380676}, {
        0.02486049408516117, 0.05257910890697143}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024549436593131354`, 0.052583845976513825`}, {
        0.02363928310463455, 0.05259770663082931}, {0.021502628336668612`, 
        0.05261419094218446}, {0.019395146571318966`, 0.0526141763478722}, {
        0.017316837808585582`, 0.052597662847892544`}, {0.015267702048468515`,
         0.05256465044224548}, {0.01324773929096774, 0.05251513913093101}, {
        0.012107428192171364`, 0.05247732891874075}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01179650550547021, 0.05246701940516033}, {
        0.011256949536083229`, 0.05244912891394914}, {0.009295332783815034, 
        0.052366619791299876`}, {0.007362889034163128, 
        0.052267611762983196`}, {0.005459618287127495, 0.05215210482899912}, {
        0.0035855205427081684`, 0.05202009898934764}, {0.0017405958009051245`,
         0.051871594244028756`}, {-0.00007515593828162637, 
        0.051706590593042466`}, {-0.0006182815831945451, 
        0.051651413235830036`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009277820683079944, 
        0.05161997038465098}, {-0.0018617346748520773`, 
        0.05152508803638878}, {-0.003619140408806249, 
        0.051327086574067676`}, {-0.005347373140144138, 
        0.05111258620607918}, {-0.007044752925597188, 
        0.05088419696425865}, {-0.008709599821896867, 
        0.05064452888044147}, {-0.010341913829043163`, 
        0.05039358195462763}, {-0.0119416949470361, 
        0.05013135618681712}, {-0.013249586392396689`, 
        0.049903112611325365`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.013555957687739345`, 
        0.049849127512926424`}, {-0.015043658515561848`, 
        0.04957306812520615}, {-0.01654584096609467, 
        0.04927700583140567}, {-0.018015490527474122`, 
        0.04896966469560853}, {-0.019452607199700198`, 
        0.04865104471781474}, {-0.02085719098277291, 
        0.04832114589802429}, {-0.022229241876692243`, 
        0.04797996823623719}, {-0.02356875988145821, 
        0.047627511732453415`}, {-0.025668816310113706`, 
        0.0470265226316029}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02596790358725789, 
        0.04694093055354537}, {-0.026150197223530028`, 
        0.046888762198895914`}, {-0.028601503008988345`, 
        0.046104897297351774`}, {-0.030923945814057625`, 
        0.045286091916773824`}, {-0.033118794214962305`, 
        0.04444252094611489}, {-0.035186048211702375`, 
        0.043574184385374956`}, {-0.03712570780427784, 
        0.04268108223455404}, {-0.0375619356091224, 0.042460119196186516`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.037839457338460614`, 
        0.04231954575303007}, {-0.0389377729926887, 
        0.041763214493652126`}, {-0.04062224377693495, 
        0.04082058116266923}, {-0.0421791201570166, 
        0.039853182241605334`}, {-0.04360840213293364, 
        0.03886101773046045}, {-0.04540885106080353, 
        0.037434324566857566`}, {-0.04697273940426653, 
        0.03598420623480768}, {-0.047833133435421914`, 
        0.035037191446654944`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAA+GevAAGZqL8b6WD/NtKhPwYJ/xKU
u6i/RHqf1iisoT96EXeJ+0ypv+j7XwxA6qA/kUWbhfFZqb+Qn7JxzdagP+he
vuieZqm/M2N76VjDoD9LC+jwA3Opv7eJd6Hir6A/4xtjZBt5qb/DE1viJqag
Pw1qhdggf6m/pZxcxGqcoD/YSCdVFIWpvyX8JE2ukqA/NC4m4vWKqb/wtVmC
8YigP0ILZIfFkKm/nmOdaTR/oD+T5eodo/+pv5nFinYsUJ8/b1Sf9tACqr/o
pTOapUGfP8+d+kP1Baq/vdyx8x4znz/IfRldBAuqv4pm/Kn5Gp8/Oa6nR/kP
qr86wJ411QKfP9ImqBPUFKq/E76YqrHqnj+K0ifRlBmqv+b02RyP0p4/O3o9
kDseqr+ntUGgbbqePyfC3zFVJ6q/fhjs8CyKnj+GBA9bBzCqv1xpVyTxWZ4/
eSBgjVI4qr/SMwfYuimeP2aUvoqSdaq/iup4oEpJnD8SXAQL2Yyqv3Tc04KJ
bZo/vSr76T6Aqr8+PvyTmZiYP/RqrIKvbqq/Q/dqKyPqlz99ldlW
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.051564320644137844`, 
        0.023049125225896153`}, {-0.05140633787110301, 
        0.02226433571047382}, {-0.0504289604993101, 
        0.019669409161501505`}, {-0.049753085610784994`, 
        0.01841507906751103}, {-0.04895241992050746, 
        0.01718950442718434}, {-0.048042142180405464`, 
        0.015996970330217183`}, {-0.04703743114240697, 
        0.014841761866305293`}, {-0.04593828680651199, 
        0.013723879035448675`}, {-0.04491333403479077, 
        0.012795979531022053`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04467944319712227, 
        0.012591027662745405`}, {-0.043438410256267185`, 
        0.01159665359458439}, {-0.04212302197082238, 
        0.010603348816722053`}, {-0.040727830775293364`, 
        0.009650119014568468}, {-0.039260151863586286`, 
        0.008738338859450382}, {-0.037974253258891075`, 
        0.008002407359440085}, {-0.03664838395345479, 
        0.007294883168117459}, {-0.03528712062306332, 
        0.00661627815102054}, {-0.03412512436885579, 0.006074400269180983}}]}, 
      {Arrowheads[{{0.017385544127269406`, 1.}}], 
       ArrowBox[{{-0.03384259911214696, 
        0.005944208803642243}, {-0.03247671859055847, 
        0.005347873101655976}, {-0.03103673324001688, 
        0.0047590968004643935`}, {-0.029579660567663726`, 
        0.004201287135650661}, {-0.028110077249284916`, 
        0.003674955972752817}, {-0.026632559960666338`, 
        0.003180615177308892}, {-0.0251516853775939, 
        0.00271877661485692}, {-0.02367203017585351, 
        0.002289952150934939}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.06780554032162533}, {0.04982312347124909, 
        0.06782079447216335}, {0.04707608062931595, 0.06805770439651096}, {
        0.04432903778738281, 0.06829461432085858}, {0.041581994945449674`, 
        0.06853152424520619}, {0.03958924302618612, 0.06812851814798392}, {
        0.03762855513760812, 0.06818120116703189}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03731757381813086, 0.06818955712968816}, {
        0.03724796038257881, 0.068191427619108}, {0.034928622005697414`, 
        0.06823869129477153}, {0.03263122789554191, 0.0682703091749745}, {
        0.030355778052112307`, 0.06828628125971689}, {0.030050017151190152`, 
        0.06828738160296668}, {0.029744667427548437`, 0.06828820400064596}, {
        0.027843929917373146`, 0.06820014013133695}, {0.025943192407197863`, 
        0.06811207626202795}, {0.024879833390363974`, 0.06806280932801644}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024569073190405525`, 0.06804841136644148}, {
        0.024042454897022572`, 0.06802401239271895}, {0.02214171738684728, 
        0.06793594852340995}, {0.020240979876671995`, 0.06784788465410095}, {
        0.018340242366496704`, 0.06775982078479194}, {0.016439504856321417`, 
        0.06767175691548294}, {0.014538767346146128`, 0.06758369304617394}, {
        0.013324919973275286`, 0.06716714269906762}, {0.01220727786697345, 
        0.06710541652939847}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011896657678228497`, 0.06708826131095688}, {
        0.011455885084821742`, 0.06706391791539874}, {0.00960798527751603, 
        0.06695058585548995}, {0.007781220551358141, 0.06682714651934124}, {
        0.0059755909063480845`, 0.0666935999069526}, {0.0041910963424858574`, 
        0.06654994601832406}, {0.002427736859771455, 0.0663961848534556}, {
        0.0006855124582048865, 0.06623231641234721}, {-0.0005076529051414639, 
        0.06611213998691066}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0008171804022160771, 
        0.06608096416726701}, {-0.0010353876011744388`, 
        0.06605898619004699}, {-0.002734774057327114, 
        0.06587683968160304}, {-0.004412646910253129, 
        0.06568587688701534}, {-0.0060690061599524975`, 
        0.06548609780628388}, {-0.0077038518064252125`, 
        0.06527750243940869}, {-0.009317183849671264, 
        0.06506009078638976}, {-0.010909002289690667`, 
        0.06483386284722707}, {-0.012479307126483418`, 
        0.06459881862192064}, {-0.01315756678733273, 0.06449202517926285}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.013464874409045754`, 
        0.06444363893315082}, {-0.014028098360049507`, 
        0.06435495811047047}, {-0.015555375990388948`, 
        0.06410228131287656}, {-0.01706114001750173, 
        0.06384078822913888}, {-0.01854539044138786, 
        0.06357047885925748}, {-0.020008127262047336`, 
        0.06329135320323233}, {-0.021449350479480163`, 
        0.06300341126106343}, {-0.022869060093686326`, 
        0.06270665303275079}, {-0.02426725610466584, 
        0.0624010785182944}, {-0.02564358900089361, 
        0.06208793973909709}, {-0.02567925322229581, 0.06207952617920313}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02598203538223215, 
        0.0620080967258942}, {-0.02699770927084454, 
        0.061768488716561695`}, {-0.02832961691451865, 
        0.06144272545068821}, {-0.02963931193191592, 
        0.061110649941476636`}, {-0.03219206408787997, 
        0.06042756219303921}, {-0.034655965738736694`, 
        0.059719225471249415`}, {-0.03703101688448609, 
        0.05898563977610726}, {-0.03796667746887907, 0.05867507574390498}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.038261931722836394`, 
        0.05857707508729578}, {-0.03931721752512815, 
        0.058226805107612745`}, {-0.04151456766066289, 
        0.057442721465765866`}, {-0.0436230672910903, 
        0.056633388850566624`}, {-0.04564409782006646, 
        0.055803563190176736`}, {-0.04757904065124746, 
        0.054958000412757904`}, {-0.0494278957846333, 
        0.05409670051831014}, {-0.04978984789087161, 
        0.053916616981966294`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.050068372606760156`, 
        0.053778041422018176`}, {-0.05119066322022397, 
        0.05321966350683344}, {-0.05286734295801948, 
        0.0523268893783278}, {-0.05445793499801983, 
        0.05141837813279323}, {-0.05596243934022501, 
        0.05049412977022972}, {-0.057380855984635035`, 
        0.04955414429063727}, {-0.05863034184668729, 
        0.04866587080384044}, {-0.05981019427340062, 
        0.04777123423877238}, {-0.06056945518797262, 
        0.047155055071828066`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06081101137401666, 
        0.04695901983989364}, {-0.06092041326477502, 
        0.04687023459543309}, {-0.06196099882081049, 
        0.04596287187382256}, {-0.06383326962686466, 
        0.04412905719578781}, {-0.0654270066915631, 
        0.04226979020466814}, {-0.06675742224245047, 
        0.04039750536599532}, {-0.0678397285070714, 
        0.038524637145301126`}, {-0.06840623358220964, 
        0.03725237187881967}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06853277718759558, 
        0.03696817842514479}, {-0.0686739254854259, 
        0.036651185542585576`}, {-0.06926001317751398, 
        0.03477715055784864}, {-0.06961607406725152, 
        0.03291288059022965}, {-0.06976019063855446, 
        0.031068724038867908`}, {-0.06969236289142278, 
        0.02924468090376341}, {-0.06941259082585648, 
        0.02744075118491616}, {-0.06865934261666261, 
        0.024813505990256973`}, {-0.06865871726012338, 
        0.024812076272289395`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06853404937696785, 
        0.02452705500626658}, {-0.06754816152543457, 
        0.022273074297779073`}, {-0.06685834614905772, 
        0.021035413514858103`}, {-0.06607904755217235, 
        0.019819456107482467`}, {-0.06521026573477842, 
        0.01862520207565215}, {-0.06425200069687596, 
        0.01745265141936716}, {-0.0632202505694845, 
        0.01630589604560853}, {-0.06213101348362361, 
        0.015189027861357311`}, {-0.06138448644231052, 
        0.014481394050082743`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06115870729352353, 
        0.014267377744281632`}, {-0.06098428943929327, 
        0.014102046866613493`}, {-0.05978007843649348, 
        0.013044953061377075`}, {-0.05851838047522425, 
        0.012017746445648063`}, {-0.05719919555548558, 
        0.011020427019426461`}, {-0.05582252367727747, 
        0.010052994782712266`}, {-0.05438836484059992, 
        0.009115449735505474}, {-0.05269617331775597, 
        0.008183711951098151}, {-0.05127214589270283, 
        0.007320962929974753}, {-0.05098687688308677, 
        0.007159947977241838}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05071595928995546, 
        0.007007033422971596}, {-0.049798175549093604`, 
        0.006489006926322693}, {-0.04827803430688499, 
        0.005688296854123941}, {-0.04671549418603365, 
        0.004919285627360463}, {-0.04511432720649628, 
        0.004182426160014225}, {-0.04347830538822957, 
        0.003478171366067197}, {-0.041811200751190186`, 
        0.0028069741595013447`}, {-0.03998519014241869, 
        0.002119301418289559}, {-0.03938336578445284, 
        0.0019072192945691427`}}]}, 
      {Arrowheads[{{0.007955119459641224, 1.}}], 
       ArrowBox[{{-0.039089957644925157`, 
        0.00180382264648695}, {-0.038135293854590614`, 
        0.0014674003641162864`}, {-0.03626658285081287, 
        0.0008514237021442529}, {-0.03438412809419236, 
        0.00027152413753618425`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.000178972576297702, 1.}}], 
       ArrowBox[{{0.02813484093774985, 0.00551103465335591}, {
        0.028098883054196968`, 0.005566140452287644}, {0.028073696752789715`, 
        0.005604099264079505}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.018922023806045057`, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAA0J+hnKICiz97FK5H4XqEv4l8qkXk
EI8/EGK906tBg7/qDF9R2cSRP019iBAboIG/hDp1UsDGkz9m7kXxPMd/v1tg
/GbrjpU/sbQY22AgfL8Nfx2EY7mVP/haLA+bwHu/bDTgnkrjlT8tSC6wdWB7
v1VTqQWhDJY/XToXrvL/er8rdO8LFiGWPxuGA5uOz3q/2WFAA2c1lj8cJm/Y
E596v9HU1vWTSZY//Pjbo4Juer9Z0QXunF2WP45wrzrbPXq/mJE19oFxlj/4
EDbaHQ16vw8LsK1JtZc/M/GAdiWxdr8/1A6Cgr+XP74MHR25k3a/q15XO6/J
lz9PKwavRnZ2v5pEEqaM05c/NtcoWHRZdr/deEuIXt2XP62voVmcPHa/80+9
oQbslz820yA+TxF2vyZ8spi+9Zc/ChHUq2r0db+ysykOa/+XP6B8JpOA13W/
Ooqmp7FdmD8WyVfAOLV0v+EHreU=
        "]]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.009388626296956044}, {0.04895160340911363, 
        0.010152812442330536`}, {0.047180415202168376`, 
        0.01144384820147385}, {0.04540922699522312, 0.012734883960617161`}, {
        0.04305736893210842, 0.013516197418736525`}, {0.04082162896563594, 
        0.01458909592554593}, {0.04074524307693273, 0.0146240566994313}, {
        0.04066880253799799, 0.014658932295889758`}, {0.039116925699704236`, 
        0.015179070502851862`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03882195911495751, 0.015277933625696443`}, {
        0.03858020208789961, 0.015358962650340332`}, {0.03649160163780124, 
        0.016058993004790904`}, {0.03440300118770287, 
        0.016759023359241475`}, {0.0323144007376045, 0.017459053713692045`}, {
        0.030287282220377177`, 0.017937993235558433`}, {0.02826016370314986, 
        0.01841693275742482}, {0.02688353220027116, 0.018742184205809177`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.026580774129721367`, 0.018813715694628412`}, {
        0.026233045185922538`, 0.018895872279291213`}, {0.02420592666869522, 
        0.0193748118011576}, {0.02233977359086555, 0.019646674200608845`}, {
        0.020473620513035886`, 0.019918536600060092`}, {0.018607467435206224`,
         0.020190398999511337`}, {0.01674131435737656, 0.02046226139896258}, {
        0.015066529627151944`, 0.020568279773210598`}, {0.01428612432216911, 
        0.020617681526281104`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.013975652206683025`, 0.020637335245555676`}, {
        0.013391744896927332`, 0.020674298147458615`}, {0.011716960166702718`,
         0.020780316521706636`}, {0.0100421754364781, 
        0.020886334895954654`}, {0.008848923618967029, 0.02069982365807015}, {
        0.007259115285103629, 0.0207542191595889}, {0.005725957882147704, 
        0.02077419941262147}, {0.004249451410099253, 0.02075976441716786}, {
        0.002430644615593835, 0.020694460532580686`}, {0.0015584902787249668`,
         0.02063662110879155}}]}, 
      {Arrowheads[{{0.0177385582087401, 1.}}], 
       ArrowBox[{{0.0012480785744421196`, 0.02061603526365595}, {
        0.0007060464855536712, 0.02058008884640934}, {-0.0009243429800212478, 
        0.02041664935865381}, {-0.002460523781130926, 
        0.020204142069314104`}, {-0.003895480200483289, 
        0.019949625624156114`}, {-0.005222196520786262, 
        0.019660158668945747`}, {-0.00644067274203985, 
        0.019335741203682998`}, {-0.007550908864244057, 
        0.018976373228367868`}, {-0.009452789599394365, 
        0.018182406220128466`}}]}}}}, 
   {PointSize[0.025], PointBox[{0, 0.08}]}, 
   {PointSize[0.025], PointBox[{0, 0.01}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.08}, {0.05, 0.08}}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.01}, {0.05, 0.01}}]}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0.09}, {0, -0.01}}]}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0mHc81u/3x/HRElFJJVIqlIyIUjj2nhnJysretz2K27iNW9Ztl733ulWo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      "]]}}},
  AspectRatio->1,
  BaseStyle->{FontWeight -> "Bold", FontSize -> 12},
  Frame->True,
  ImageMargins->10,
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{-0.1027733900410869, 0.0527733900410869}, {-0.0127733900410869,
    0.0927733900410869}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.703997454140547*^9, 3.703997548791747*^9, 3.703997580040547*^9, 
   3.704148842010981*^9, 3.7041489037765975`*^9, 3.704149490097439*^9, {
   3.7044972044277687`*^9, 3.704497218554038*^9}, {3.7044972530465407`*^9, 
   3.704497277378004*^9}, 3.704497468212633*^9, {3.7044975016230326`*^9, 
   3.704497544103233*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.06375540156406266}, {0.04847018569975361, 
        0.06359245569303934}, {0.04682369520325236, 0.0634102364224886}, {
        0.04519865840786221, 0.06322345645083209}, {0.04359507531358317, 
        0.0630321157780698}, {0.042012945920415254`, 0.06283621440420176}, {
        0.04045227022835844, 0.06263575232922795}, {0.03891304823741274, 
        0.062430729553148365`}, {0.03764754414755514, 0.06225598038404196}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.037339413526920814`, 0.06221315078617844}, {
        0.0358989653588547, 0.062007001897671894`}, {0.034424104471242334`, 
        0.061788297018275005`}, {0.0329706972847411, 0.06156503143777235}, {
        0.031538743799350975`, 0.06133720515616393}, {0.03012824401507195, 
        0.06110481817344974}, {0.028739197931904055`, 0.06086787048962978}, {
        0.02602546686890158, 0.06038029301867255}, {0.025061757681972194`, 
        0.06019479865798595}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02475627154353461, 0.060135998807661135`}, {
        0.02339755061034357, 0.05987447274329226}, {0.020855449156230006`, 
        0.05935040966348889}, {0.0183991625065609, 0.05880810377926245}, {
        0.01602869066133624, 0.05824755509061292}, {0.013734073281434365`, 
        0.05767508616540931}, {0.01262256686798378, 0.057386793428551144`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.012321437456209573`, 0.05730868913583782}, {
        0.011505350027733596`, 0.0570970195715206}, {0.009342520900233933, 
        0.05651335530894678}, {0.0072455858989353816`, 0.05592409337768785}, {
        0.005214545023837938, 0.05532923377774381}, {0.0032493982749415944`, 
        0.05472877650911467}, {0.0013501456522463564`, 0.05412272157180041}, {
        0.00038495179459348164`, 0.05380070962516974}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.00008984828325272483, 
        0.05370225597734456}, {-0.0004832128442477761, 
        0.05351106896580105}, {-0.0022506772145408013`, 
        0.05289381869111658}, {-0.003952247458632721, 
        0.052270970747747}, {-0.005587923576523535, 
        0.05164252513569232}, {-0.007157705568213244, 
        0.05100848185495253}, {-0.00866159343370184, 
        0.05036884090552762}, {-0.010099587172989335`, 
        0.049723602287417616`}, {-0.011454737526880565`, 
        0.04908080564498454}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.011732891448282257`, 
        0.04894149752003223}, {-0.012777892272961002`, 
        0.04841633204514228}, {-0.014104963341028898`, 
        0.04771240834782761}, {-0.015370730007587255`, 
        0.047008269627320944`}, {-0.01772226111705717, 
        0.04560076437090827}, {-0.019844062347687017`, 
        0.04419782299044949}, {-0.02174744385665079, 
        0.04280311961318051}, {-0.021926206589841492`, 
        0.04266423686768413}, {-0.022102908010413185`, 
        0.04252547397475509}, {-0.022277559081907514`, 
        0.04238683412692753}, {-0.022281925345811977`, 0.0423833398495208}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAYdHCFp0Ql79TB/+gtZmlPyc8rS2a
E5e/wxiLIoCYpT/hk58B5SmXv4NsRPpuj6U/b/0H/A1Al7+7eHHuXoalP6Lb
FYi5Z5i/MeSJ2IwIpT/cLfnDtnaZv3wJGRu2i6Q/ol9pPS2Imb/+X6bhUIOk
P9IdJAWImZm/k5K18+x6pD8JkYP7OrGZv0v/fCRQb6Q/tNISabnImb8s+APo
tWOkPzjXen8D4Jm/U1uJRB5YpD86pk5wGfeZv6qlQUCJTKQ/d04LbfsNmr9n
+1bh9kCkP9NrDuFXO5q/Bg1xetcppD8W5n4P5meav+iFytnCEqQ/iGJJgqeT
mr+QScgvufujPxDGWvB+Hpy/H5EmstkXoz+4qFt61l+dv0mNRRABOaI/SPAC
lU5dnr93wxynxF+hP0gnsdxf+56/hPIi4xCxoD+l3KLJ
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0303832990343501, 
        0.03231719541263745}, {-0.03097564757005364, 
        0.03039410566606359}, {-0.03125454425977527, 
        0.02854003373415867}, {-0.03125282766059874, 
        0.02676575663997592}, {-0.031005132044969737`, 
        0.02507622152501705}, {-0.030546091685333985`, 
        0.023476375530783754`}, {-0.029910340854137192`, 
        0.02197116579877775}, {-0.029132513823825066`, 
        0.020565539470500733`}, {-0.029036973281856344`, 
        0.02042512180953442}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.02886197145324743, 
        0.020167918459713184`}, {-0.028247244866843317`, 
        0.01926444368745441}, {-0.027259960326405173`, 
        0.01805992957398718}, {-0.026167099490575406`, 
        0.0169400802491695}, {-0.024989816049077036`, 
        0.01590389084658617}, {-0.023749263691633098`, 
        0.014950356499821977`}, {-0.02246659610796661, 
        0.014078472342461719`}, {-0.0211629669878006, 
        0.013287233508090187`}, {-0.019859530020858086`, 
        0.012575635130292176`}, {-0.019379937149045214`, 
        0.012338862224378388`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.019100986724182166`, 
        0.012201145618101388`}, {-0.018577438896862107`, 
        0.011942672342652484`}, {-0.016064144991190722`, 
        0.010881852708623225`}, {-0.013638685731496049`, 
        0.01005465067479448}, {-0.011386492968067046`, 
        0.009430071855361176}, {-0.009392998551192688, 
        0.00897712186451824}, {-0.007694073413352469, 
        0.008553468273942485}, {-0.007258173255036703, 
        0.00852577149304221}}]}, 
      {Arrowheads[{{0.01334725156663747, 1.}}], 
       ArrowBox[{{-0.006947705779407829, 
        0.00850604461411108}, {-0.006127148063617891, 
        0.008453906970119216}, {-0.004786546406354747, 
        0.008400794359089473}, {-0.0036722684415630303`, 
        0.008394130440853255}, {-0.0018862130038180996`, 
        0.008481540723989725}, {-0.0006098886683136167, 
        0.00867624988477385}, {0.0007279462065027066, 0.009180335844381906}, {
        0.0009687441942775167, 0.009638273728337227}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02272862190909416, 0.09}, {-0.023968301607341685`, 
        0.08939409285230887}, {-0.026290907856007937`, 
        0.08821222044415193}, {-0.028525354340501033`, 
        0.08702821641302483}, {-0.030674064959656466`, 
        0.08584369076779927}, {-0.03273933404599016, 
        0.08466008337434067}, {-0.03368003368084053, 0.08409930370757418}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.033947249306508095`, 
        0.0839400083448833}, {-0.03472264614252076, 
        0.08347777070472504}, {-0.03662548579226691, 
        0.08229712923102839}, {-0.03844933753824724, 
        0.08111853542532677}, {-0.040195685923480384`, 
        0.07994236575969621}, {-0.04186601549098498, 
        0.07876899670621271}, {-0.04346181078377967, 
        0.07759880473695231}, {-0.044259197010552344`, 
        0.07698789413843765}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04450614545854892, 
        0.076798696709259}, {-0.04498455634488309, 
        0.07643216632399105}, {-0.046435736717313866`, 
        0.07526945793940493}, {-0.04781683644409065, 
        0.07411105605526999}, {-0.049129340068232066`, 
        0.07295733714366225}, {-0.05037473213275677, 
        0.07180867767665775}, {-0.051554497180683376`, 
        0.07066545412633249}, {-0.052670119755030526`, 
        0.06952804296476252}, {-0.05369294907275525, 0.0684291956854285}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05389948019411822, 
        0.06819656891832997}, {-0.054771211585877444`, 
        0.06720694366860272}, {-0.05575304268128419, 
        0.06602534979609517}, {-0.056670280217396805`, 
        0.06485242355836478}, {-0.05752459790218079, 
        0.06368852621261945}, {-0.05905108244741446, 
        0.06138919223775153}, {-0.060345425680753045`, 
        0.05912990758548523}, {-0.06046258966459914, 
        0.05890627392505671}, {-0.06057757179209154, 
        0.05868306634978469}, {-0.060690384459800635`, 
        0.05846028700589795}, {-0.06074598072528027, 
        0.05834905851923068}, {-0.06080103925971742, 
        0.058237937885134684`}, {-0.06085556160264003, 
        0.05812692536505699}, {-0.06090954929132534, 
        0.05801602121892754}, {-0.06092846523777898, 0.05797681405643954}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.061057579074276946`, 
        0.05769380617113697}, {-0.06174730391882623, 
        0.056151950747902295`}, {-0.062402249961924915`, 
        0.054427369693942844`}, {-0.06244210208528398, 
        0.05431190292153315}, {-0.062481392299568596`, 
        0.05419657124735505}, {-0.06252618223795263, 
        0.05406125030942723}, {-0.06257020559020866, 
        0.05392611787152494}, {-0.06261346530161684, 
        0.053791174344632715`}, {-0.06265596431157035, 
        0.053656420136215355`}, {-0.06269770555357451, 
        0.053521855650229516`}, {-0.0627796783510287, 
        0.05325310692053311}, {-0.06285864346816529, 
        0.05298512026681975}, {-0.06293462423754966, 
        0.052717898840659985`}, {-0.0635352133600162, 
        0.05008839457414276}, {-0.06386241825297412, 
        0.04753848868519727}, {-0.06391902093567137, 0.04568821263320145}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.06392853329809411, 
        0.04537726453763425}, {-0.06393791899061092, 
        0.04507045713438561}, {-0.06378254635227475, 
        0.042686105130228545`}, {-0.06357518020670712, 
        0.04123837464741713}, {-0.06328614841514489, 
        0.039822837115033025`}, {-0.06291993589912755, 
        0.03843971321873477}, {-0.06248102758019454, 
        0.03708922364418086}, {-0.06197390837988534, 
        0.03577158907702981}, {-0.06140306321973939, 
        0.03448703020294014}, {-0.06087604602213154, 
        0.033440448234614444`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0607328176290617, 
        0.033164358690750864`}, {-0.0600881347060951, 
        0.032018022276579}, {-0.05935302119567569, 
        0.030834014595624563`}, {-0.058572121411577374`, 
        0.029683965350365563`}, {-0.05774992027533962, 
        0.028568095226460512`}, {-0.05689090270850189, 
        0.027486624909567933`}, {-0.055080357969184326`, 
        0.025427766439454234`}, {-0.053176366565940374`, 
        0.023509155425292593`}, {-0.053077434462501676`, 
        0.023420427880124148`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.052845838377824486`, 
        0.02321272025691806}, {-0.05118450926958715, 
        0.021722752406571868`}, {-0.049101044204326844`, 
        0.020057501016387307`}, {-0.04694786677255273, 
        0.018510641380416616`}, {-0.04474687237665808, 
        0.017079413624337483`}, {-0.04279494761217066, 
        0.015923855315539585`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04252724804011371, 
        0.01576537458391503}, {-0.04251995641903617, 
        0.015761057873827606`}, {-0.04028901430208027, 
        0.01455281425456468}, {-0.03807594142818364, 
        0.013451922892226397`}, {-0.035902633199739575`, 
        0.012455623912490452`}, {-0.03376664393230127, 
        0.011556518846800385`}, {-0.031658038376240365`, 
        0.010745781966835382`}, {-0.03122498621099735, 
        0.010593675535039718`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03093147186926971, 
        0.010490580751583338`}, {-0.029587477586177805`, 
        0.0100185125086266}, {-0.027565622616734523`, 
        0.009369809708205206}, {-0.025603134522531452`, 
        0.008794772801602357}, {-0.023710674358189528`, 
        0.008288501024849215}, {-0.02189890317832968, 
        0.007846093613976944}, {-0.020178482037572856`, 
        0.007462649805016704}, {-0.018993212399272916`, 
        0.00702285279282081}}]}, 
      {Arrowheads[{{0.015439246695132428`, 1.}}], 
       ArrowBox[{{-0.018701549628465364`, 
        0.006914630654140264}, {-0.0186556897183802, 
        0.006897614229536697}, {-0.017045535794123476`, 
        0.006710626816453872}, {-0.015518758860065844`, 
        0.006547497289604}, {-0.014075358916207304`, 
        0.006408225648987078}, {-0.011438689999087499`, 
        0.0062012560264520875`}, {-0.009135529042764061, 
        0.006089717948848903}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.02927331629063959}, {0.04874489140247781, 
        0.02936135175003393}, {0.04608106869128314, 0.02951337626713623}, {
        0.04349424469860538, 0.029630128714754546`}, {0.04098323991919844, 
        0.029716641132244013`}, {0.03854805435306229, 
        0.029772913519604635`}, {0.03756850875170922, 0.02978372145580677}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03725743412620881, 0.029787153735735206`}, {
        0.03618868800019695, 0.029798945876836406`}, {0.033867231253966935`, 
        0.029809858219003758`}, {0.03154577450773692, 
        0.029820770561171106`}, {0.029224317761506902`, 
        0.029831682903338458`}, {0.027484286252001118`, 
        0.029647576728729513`}, {0.025410071595105443`, 
        0.02954641130838685}, {0.024827121425423666`, 
        0.029510429165670687`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024516618791679292`, 0.029491263633756985`}, {
        0.023411083388997413`, 0.02942302532676964}, {0.023278661121604195`, 
        0.029413944809184387`}, {0.023146576343272364`, 
        0.02940476932808866}, {0.021419767470029098`, 
        0.029197593447675804`}, {0.019692958596785833`, 
        0.028990417567262946`}, {0.017966149723542567`, 
        0.028783241686850085`}, {0.0162393408502993, 0.028576065806437227`}, {
        0.015080107544435638`, 0.028261655582295094`}, {0.013453459065435831`,
         0.028035555994165306`}, {0.01219728825896738, 
        0.027843317942648972`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011889783909381658`, 0.027796200907368167`}, {
        0.010400482895923137`, 0.027545509402471868`}, {0.008970965803608772, 
        0.027283301029148766`}, {0.007601843503853763, 
        0.027011954111162136`}, {0.006293115996658105, 
        0.026731468648511978`}, {0.005044783282021802, 
        0.026441844641198295`}, {0.0027293022304272596`, 
        0.025835180992580347`}, {0.0006554003490701304, 
        0.025191963165308293`}, {-0.00019119422591761513`, 
        0.024888204121341583`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0004840099585914578, 
        0.02478314152155265}, {-0.0012009600770930655`, 
        0.024525899047997915`}, {-0.0028638167631058115`, 
        0.023850696529264998`}, {-0.0043331697089681095`, 
        0.02316635560910954}, {-0.005609018914679956, 
        0.022472876287531546`}, {-0.007656644548616862, 
        0.02108734548737956}, {-0.009144282862252742, 
        0.01974602161389796}, {-0.010200056318696641`, 
        0.01811050225033172}, {-0.010288729086808935`, 
        0.017728445885487318`}}]}, 
      {Arrowheads[{{0.009717129018051527, 1.}}], 
       ArrowBox[{{-0.010359062366925579`, 
        0.01742540721982935}, {-0.010559568773483264`, 
        0.016561503335375982`}, {-0.01041567303680735, 
        0.015155700862343848`}, {-0.009961221918863644, 
        0.013949770824548418`}, {-0.008360196180192474, 
        0.01208583539896821}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.1, 0.023701226832228105`}, {-0.09963069905430787, 
        0.023478348654742385`}, {-0.09745106826523249, 
        0.022214715192128177`}, {-0.0952722017707497, 
        0.02099589693608495}, {-0.09309409957085948, 
        0.0198218938866127}, {-0.09091676166556185, 
        0.018692706043711434`}, {-0.08907217580546292, 
        0.01775490509266844}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08879486409675946, 
        0.017613917790432747`}, {-0.08873980590756045, 
        0.01758592580409562}, {-0.08656285014955903, 
        0.0164791455644798}, {-0.08438589439155762, 
        0.015372365324863985`}, {-0.08228474406443916, 
        0.014596789145442546`}, {-0.07980784473201762, 
        0.013528712064118693`}, {-0.07744152725415338, 
        0.012550385153823378`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0771534014086301, 
        0.012433076172870903`}, {-0.07702049770867271, 
        0.012379477861656055`}, {-0.07498502025177631, 
        0.011662883822625338`}, {-0.0729495427948799, 
        0.010946289783594623`}, {-0.07091406533798349, 
        0.010229695744563906`}, {-0.06887858788108708, 
        0.009513101705533189}, {-0.0670582868208029, 
        0.009063483011413919}, {-0.06535756910547476, 
        0.008493473087509073}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06506260174403677, 
        0.008394612282019527}, {-0.065060781669191, 
        0.008394002268544047}, {-0.06308859138776877, 
        0.007755930389781404}, {-0.061141715976536226`, 
        0.007149267375125988}, {-0.05922119600771276, 
        0.0065723937304114285`}, {-0.05732807205351778, 
        0.006023689961471353}, {-0.0554623441139513, 
        0.005503156068305757}, {-0.0536240121890133, 
        0.005010792050914644}, {-0.053126747077673606`, 
        0.004883328925245677}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05282539604654532, 
        0.0048060841246850795`}, {-0.051813076278703796`, 
        0.004546597909298013}, {-0.05002953638302279, 
        0.004110573643455864}, {-0.04827339250197026, 
        0.003702719253388197}, {-0.04654464463554623, 
        0.0033230347390950125`}, {-0.04484544221521722, 
        0.0029683866488233496`}, {-0.04317793467244975, 
        0.0026356415308202456`}, {-0.041542122007243824`, 
        0.0023247993850857023`}, {-0.040667683029396745`, 
        0.0021672924504630283`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0403615165254056, 
        0.0021121446943022553`}, {-0.039938004219599435`, 
        0.0020358602116197196`}, {-0.038365581309516596`, 
        0.0017688240104222963`}, {-0.0368248532769953, 
        0.0015236907814934345`}, {-0.035315820122035546`, 
        0.0013004605248331318`}, {-0.03383848184463733, 
        0.0010991332404413894`}, {-0.03239321395900533, 
        0.0009169587448287737}, {-0.030980391979344213`, 
        0.000751186854505849}, {-0.029600015905653983`, 
        0.0006018175694726162}, {-0.028252085737934637`, 
        0.00046885088972907594`}, {-0.028033047883306003`, 
        0.00045058239447060174`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.027723030713162, 
        0.0004247259176875202}, {-0.025653563120408583`, 
        0.0002521253461110694}, {-0.023184824126766073`, 
        0.00010101022365183044`}, {-0.02102982215783793, 
        0.000012244337989676736`}, {-0.018979712991249825`, \
-0.00003676577748104755}, {-0.017034496627001752`, -0.00004602012276034239}, \
{-0.015293768437806284`, -0.000017169386262607516`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.014982831648035192`, -7.740326629716603*^-6}, \
{-0.013454323966365214`, 0.000048516039603751886`}, {-0.011810530991655755`, 
        0.000139861631943932}, {-0.010262794140965337`, 
        0.00025851807917233265`}, {-0.00881111341429396, 
        0.0004044853812889538}, {-0.0061741210251708735`, 
        0.0007581606849528851}, {-0.0038777545164490478`, 
        0.001180695677701754}, {-0.0026495391804679295`, 
        0.0014666786592500115`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0023465506981320853`, 
        0.001537227810538673}, {-0.002267930540904117, 
        0.0015555340686639117`}, {-0.000834460318614101, 
        0.0019501271976075192`}, {0.00042265615042100095`, 
        0.002364475064532576}, {0.001503418866201189, 
        0.0027985776694390827`}, {0.003226300317629058, 
        0.0036834824965480376`}, {0.0044246013153017415`, 
        0.004562277082285973}, {0.005582706138688244, 
        0.0062053540041795315`}, {0.0051351743108775695`, 
        0.008699129812461967}, {0.004794679741262911, 
        0.008947130741943542}}]}, 
      {Arrowheads[{{0.002741325013861389, 1.}}], 
       ArrowBox[{{0.004543216674979223, 0.009130285128926038}, {
        0.0031645326876477047`, 0.01013445653379317}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.06565271245053071, 0.09}, {-0.06585008995059619, 
        0.08981616356123173}, {-0.06759076448239151, 
        0.08809802851405092}, {-0.06922038022529213, 
        0.08639007495319993}, {-0.070446468325555, 
        0.0850319196394488}, {-0.07160556785004556, 
        0.08368183436275035}, {-0.07269917778777268, 
        0.08234016398070014}, {-0.07372877518708995, 
        0.08100723522083625}, {-0.07393124278316462, 0.08073006190282214}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07411474461355803, 
        0.08047885226642658}, {-0.07469582626257094, 
        0.07968336532522434}, {-0.07560177501503852, 
        0.0783688542467599}, {-0.07644803019738533, 
        0.07706398785760454}, {-0.07723602663086293, 
        0.07576904561304727}, {-0.07738676300877288, 
        0.07551127208642609}, {-0.07753523607103341, 
        0.07525390819017552}, {-0.07768145687840441, 
        0.07499695595391451}, {-0.07775372579164413, 
        0.07486863477504876}, {-0.07782543577767581, 
        0.07474041726426593}, {-0.07789658821145119, 
        0.07461230366984616}, {-0.07796718446620897, 
        0.07448429423886416}, {-0.07803722591368858, 
        0.07435638921734108}, {-0.07921978570804196, 
        0.07204647586382366}, {-0.08022693867106584, 
        0.06977260990104431}, {-0.08025901600561036, 0.06969390910957703}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0803625028420222, 
        0.06940169068916476}, {-0.08071019460101281, 
        0.06750287773662014}, {-0.08107006020631635, 
        0.06553758101946622}, {-0.08142992581161991, 
        0.0635722843023123}, {-0.08178979141692347, 
        0.061606987585158396`}, {-0.0812844251235889, 
        0.05995651651811629}, {-0.08149160274677984, 
        0.05804677726862917}, {-0.08154061858819987, 0.05717576660300116}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.08155809762217363, 
        0.05686516446754959}, {-0.08159698838189572, 
        0.056174076330919906`}, {-0.08160058202893651, 
        0.0543384137049885}, {-0.08151133499885785, 
        0.0525398710740575}, {-0.08133819860261536, 
        0.05077853012134945}, {-0.08108117284020903, 
        0.04905439084686433}, {-0.08074025771163888, 
        0.04736745325060217}, {-0.08031545321690489, 
        0.04571771733256295}, {-0.07996119759001497, 0.04459474461376634}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07986760581229632, 
        0.044298063333063985`}, {-0.07980675935600706, 
        0.04410518309274668}, {-0.07921417612894541, 
        0.042529850531153345`}, {-0.07853770353571991, 
        0.04099171964778296}, {-0.07779483293474958, 
        0.039491109076156994`}, {-0.07700305568445336, 
        0.03802833744979689}, {-0.07616237178483126, 
        0.03660340476870267}, {-0.0752727812358833, 
        0.03521631103287432}, {-0.07433428403760946, 
        0.03386705624231185}, {-0.0739766959124833, 0.03339212723072221}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0737895741284062, 
        0.033143602300182984`}, {-0.07334688019000975, 
        0.03255564039701525}, {-0.07231056969308416, 
        0.03128206349698453}, {-0.07122535254683271, 
        0.030046325542219685`}, {-0.06992061932532075, 
        0.028864314857775405`}, {-0.06884401921195671, 
        0.027694343267881234`}, {-0.06772493035870635, 
        0.026561612943313575`}, {-0.06656656172028942, 
        0.025465825044102747`}, {-0.06537212225142573, 
        0.024406680730279077`}, {-0.06515126325177231, 
        0.024222622845457422`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06491227919861246, 
        0.02402346003389106}, {-0.06414482090683503, 
        0.023383881161872875`}, {-0.0628878666412371, 
        0.022397127498914465`}, {-0.061604468409351715`, 
        0.021446120901434166`}, {-0.06040965274000637, 
        0.020605925356235275`}, {-0.05919856500778184, 
        0.019793453714541345`}, {-0.057973747461266635`, 
        0.019008282893053383`}, {-0.056737742349049276`, 
        0.018249989808472408`}, {-0.05549309191971828, 
        0.017518151377499437`}, {-0.05463828257540715, 
        0.017035777911577815`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.054367350294518384`, 
        0.016882889382419674`}, {-0.05424233842186218, 
        0.016812344516835498`}, {-0.052988024104069484`, 
        0.0161321461431816}, {-0.0517326912149287, 
        0.015477133173238749`}, {-0.05047888200302836, 
        0.014846882523707977`}, {-0.049229138716956986`, 
        0.014240971111290301`}, {-0.0479860036053031, 
        0.013658975852686736`}, {-0.046752018916655196`, 
        0.013100473664598293`}, {-0.04432166980273148, 
        0.01205225616677086}, {-0.04312517587947094, 
        0.011566557300816543`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.042836926451460984`, 
        0.01144954674390966}, {-0.04195842936389398, 
        0.011092933951416143`}, {-0.03965321048951083, 
        0.010218575625908359`}, {-0.03738787219223013, 
        0.009425081574165134}, {-0.035169171645680015`, 
        0.008708814794609719}, {-0.03300386602348863, 
        0.008066138285665367}, {-0.0310356603112241, 0.007530672753400432}}]}, 
      {Arrowheads[{{0.009431459267186745, 1.}}], 
       ArrowBox[{{-0.0307345357448412, 
        0.007452624913238643}, {-0.028860468246694568`, 
        0.006987008073302858}, {-0.026895890439348168`, 
        0.006543280366731204}, {-0.025011736250873037`, 
        0.006158594924463619}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.047778451975826856`, -0.01}, {
        0.04757462144574251, -0.009002471476341745}, {
        0.04658211484210806, -0.007931391499354444}, {
        0.04575279476602486, -0.006315416948110312}, {
        0.044923474689941664`, -0.00469944239686618}, {
        0.04409415461385847, -0.0030834678456220484`}, {
        0.04252543370501806, -0.0020654596689448452`}, {
        0.04132641321255626, -0.000748468304984177}, {
        0.0407439683161279, -0.00010871702183124171`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.04053453630195495, 0.00012132087638378996`}, {
        0.04012739272009445, 0.0005685230589764913}, {0.038928372227632645`, 
        0.0018855144229371597`}, {0.037328609088752344`, 
        0.0026431134972241407`}, {0.03532711951279063, 0.00412671197552143}, {
        0.033325629936828916`, 0.005610310453818719}, {0.031324140360867204`, 
        0.007093908932116009}, {0.0305323717614937, 0.007281407714569286}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03022965057626133, 0.007353095141550849}, {
        0.02925713388551011, 0.0075833968933197715`}, {0.0275923816186635, 
        0.00835834149319234}, {0.027536489536922896`, 0.008383259470267775}, {
        0.027480622499758602`, 0.008408095622455685}, {0.0274220858585876, 
        0.008433993395156096}, {0.027344078287153323`, 
        0.008468394561992696}, {0.02726611889803239, 0.008502646935777323}, {
        0.026877125293708316`, 0.008671545000861789}, {0.026489524112595027`, 
        0.008836531781703875}, {0.02610340354754031, 0.008997654935020392}, {
        0.024200601604488416`, 0.00974895270011649}, {0.022345781307526957`, 
        0.010410813435115213`}, {0.0205464930623592, 0.010989055061066903`}, {
        0.018810287274688413`, 0.011489495499021904`}, {0.01854330667868749, 
        0.011558030536011033`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01824198290833488, 0.01163538160967014}, {
        0.017142139571913947`, 0.011917715999782872`}, {0.015547025581435165`,
         0.012279297814152454`}, {0.013472497122461811`, 
        0.012680401049564298`}, {0.011547225492509913`, 
        0.012978425444168511`}, {0.009772890469580171, 
        0.013185593241371864`}, {0.00815117183167329, 
        0.013314126684581132`}, {0.006679163849450646, 
        0.013374659587842085`}, {0.005954104409085903, 
        0.013376391901070163`}}]}, 
      {Arrowheads[{{0.013149243501654756`, 1.}}], 
       ArrowBox[{{0.005643011736823049, 0.013377135164203248`}, {
        0.005353960793573616, 0.013377825765200494`}, {0.0030065757920405512`,
         0.013236432697472713`}, {0.0012252465511775777`, 
        0.012954240152765513`}, {-0.00006582061193242548, 
        0.012591661633225962`}, {-0.0014577192347023924`, 
        0.011865904593419484`}, {-0.0019257503125700345`, 
        0.011184941238445623`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.08891552052073104}, {0.048252237465932185`, 
        0.08861939117718882}, {0.04634689618088071, 0.08828663667084281}, {
        0.04446774086729963, 0.08794839288289298}, {0.04261477152518892, 
        0.08760465981333934}, {0.040786645497957276`, 0.08725639137098361}, {
        0.03898202012901332, 0.08690454146462752}, {0.037762715584384765`, 
        0.08666122381113231}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03745763713928646, 0.08660034404838535}, {
        0.03720089541835707, 0.08654911009427105}, {0.03544327136598852, 
        0.08619009725991422}, {0.03370914797190769, 0.08582750296155704}, {
        0.031998525236114565`, 0.0854613271991995}, {0.030311403158609147`, 
        0.08509156997284158}, {0.02864778173939142, 0.0847182312824833}, {
        0.027007660978461405`, 0.08434131112812467}, {0.0253910408758191, 
        0.08396080950976567}, {0.02530239235915858, 0.08393943735487408}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.024999963808382993`, 0.0838665252512732}, {
        0.0237979214314645, 0.0835767264274063}, {0.022228302645397605`, 
        0.08318906188104658}, {0.020682184517618413`, 0.08279781587068648}, {
        0.01915956704812693, 0.08240298839632602}, {0.01766045023692314, 
        0.0820045794579652}, {0.016184834084007067`, 0.08160258905560402}, {
        0.014731675196907625`, 0.08119763916119879}, {0.01329993018315374, 
        0.08079035174670583}, {0.012968596673125674`, 0.08069411727844447}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012669849014933239`, 0.08060734723810643}, {
        0.011889599042745422`, 0.08038072681212513}, {0.010500681775682665`, 
        0.07996876435745669}, {0.009133178381965472, 0.07955446438270052}, {
        0.007787088861593839, 0.0791378268878566}, {0.005159151440887256, 
        0.07829753933790559}, {0.002574041766871668, 0.07745257674777906}, {
        0.0008005371671353176, 0.07687289339613743}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0005048384693194467, 
        0.07677624204702255}, {-0.000011067907143919899`, 
        0.07660761415765252}, {-0.0025961775811595084`, 
        0.07576265156752597}, {-0.004540604488980784, 
        0.07486596846829156}, {-0.006399919997449445, 
        0.07413958466741641}, {-0.008207208823256117, 
        0.07341028557753132}, {-0.009962470966400797, 
        0.07267807119863628}, {-0.011057927455592038`, 0.0722052636604024}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.011343552609741018`, 
        0.07208198562305146}, {-0.01166570642688349, 
        0.07194294153073134}, {-0.011892177840136181`, 
        0.07184348185409063}, {-0.012117729365243008`, 
        0.0717439816262285}, {-0.014263174617883505`, 
        0.07059822487158189}, {-0.016408619870524, 
        0.0694524681169353}, {-0.01855406512316449, 
        0.0683067113622887}, {-0.020699510375804985`, 
        0.06716095460764211}, {-0.02200410067054069, 
        0.06603618865612534}, {-0.02213222644601006, 0.06596291773350466}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.022402280260686195`, 
        0.06580848282697574}, {-0.024001159754139162`, 
        0.0648941361608546}, {-0.025899294725042953`, 
        0.06375455317183443}, {-0.027698505583252063`, 
        0.06261743968906482}, {-0.029403818409116607`, 
        0.061484119996211443`}, {-0.031020259282986705`, 
        0.06035591837693997}, {-0.03254782820486235, 
        0.059232834831250386`}, {-0.03282004024371001, 
        0.059021307548650453`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.033065687098300725`, 
        0.058830423222406995`}, {-0.03398652517474354, 
        0.0581148693591427}, {-0.03533635019263029, 
        0.05700202196061692}, {-0.03659730325852258, 
        0.05589429263567303}, {-0.037769384372420424`, 
        0.054791681384311036`}, {-0.03885259353432382, 
        0.05369418820653095}, {-0.03985672922855267, 
        0.05260444369380615}, {-0.0407915899394269, 
        0.051525078437610033`}, {-0.0416571756669465, 
        0.050456092437942614`}, {-0.04190560291829822, 
        0.050125835982925006`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04209261292790029, 
        0.049877226933442965`}, {-0.04245348641111148, 
        0.04939748569480388}, {-0.04383828294937755, 
        0.047311409978112486`}, {-0.044945979554225114`, 
        0.045266851287535846`}, {-0.045734031541302976`, 
        0.04325620747877445}, {-0.04644352545526793, 
        0.04132255736952555}, {-0.04690995518329534, 
        0.039436506001831025`}, {-0.04702060596383968, 
        0.03859164844751738}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.047061004799929446`, 
        0.03828318915163165}, {-0.04715033859912568, 
        0.03760109423341068}, {-0.04716274674132056, 
        0.03537273281086854}, {-0.04689005462744404, 
        0.03322738410917588}, {-0.04636780801533163, 
        0.03116956699852852}, {-0.045631552662818806`, 
        0.029203800349122323`}, {-0.044716834327741053`, 
        0.02733460303115313}, {-0.04417185395704566, 
        0.026423528556854495`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04401215638829918, 
        0.02615655310908412}, {-0.04365919876793386, 
        0.025566493914816787`}, {-0.042494191741232715`, 
        0.023903991870309154`}, {-0.04125735900547311, 
        0.022351615767826072`}, {-0.0399447664137574, 
        0.02090170035548817}, {-0.038540332156193145`, 
        0.019542831420777562`}, {-0.03706138049612362, 
        0.018273904392932302`}, {-0.03556850480529772, 
        0.017127054685354626`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.035314397785895124`, 
        0.016947680022239783`}, {-0.03394922202184185, 
        0.016001457774790052`}, {-0.03235066373431616, 
        0.014995729042969181`}, {-0.0307468850976583, 
        0.014075523934965884`}, {-0.02915521037521155, 
        0.013239737880018223`}, {-0.027575935029522564`, 
        0.0124810367153801}, {-0.026004114892123634`, 
        0.011790169480771825`}, {-0.024449214779836526`, 
        0.011163156409131082`}, {-0.02435384760988434, 
        0.01112777147610204}}]}, 
      {Arrowheads[{{0.004492724325266578, 1.}}], 
       ArrowBox[{{-0.024062183568658652`, 
        0.011019552761308204`}, {-0.022920699509482993`, 
        0.010596017733395547`}, {-0.02142803389788479, 
        0.010084773686502896`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.08170540179978186, 0.09}, {-0.0823649184779512, 
        0.08917056944931884}, {-0.08381714949302496, 
        0.08719784520819686}, {-0.08513948770827234, 
        0.08524212931418851}, {-0.08633193312369335, 
        0.08330342176729374}, {-0.08740611308009395, 
        0.08138409290236302}, {-0.08835915753914077, 0.07951494586554192}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08849010407665918, 
        0.07923278093937824}, {-0.0892345586382519, 
        0.07761068222294486}, {-0.08998882424000924, 
        0.0757566004084574}, {-0.09068977078265938, 
        0.07391339310237717}, {-0.09139071732530951, 
        0.07207018579629694}, {-0.09209166386795965, 
        0.0702269784902167}, {-0.09204859434166233, 
        0.06857362586932957}, {-0.09224967082852147, 0.06750492158459145}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.09230719370654496, 
        0.06719919242065772}, {-0.0924752347905554, 
        0.06630606846917442}, {-0.09290187523944846, 
        0.06403851106901927}, {-0.09332851568834152, 
        0.06177095366886413}, {-0.09271049116787812, 
        0.05984908969465541}, {-0.09254916751234797, 
        0.05768004231540133}, {-0.0922656080257985, 
        0.05555980983288026}, {-0.09224233714070375, 
        0.055418310264712604`}, {-0.09221854124417408, 
        0.0552770351426337}, {-0.09211297649232965, 0.05499552331556861}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.09200374623142572, 
        0.054704236595516716`}, {-0.0915120301360896, 
        0.05339296655531085}, {-0.09080551902800514, 
        0.051508897967988014`}, {-0.09009900791992066, 
        0.049624829380665175`}, {-0.0893924968118362, 
        0.04774076079334233}, {-0.08809629416159413, 
        0.04626457492951085}, {-0.08728571984018774, 
        0.04445248564633355}, {-0.08681385195615843, 0.04350649578345103}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.08667499208115698, 
        0.043228112705139314`}, {-0.08640577004323338, 
        0.04268838256591993}, {-0.08545644477073108, 
        0.040972265688270004`}, {-0.0844460698991668, 
        0.03930314005771456}, {-0.0833829713050265, 
        0.0376800107185844}, {-0.0822671489883102, 
        0.03610287767087952}, {-0.08109860294901787, 
        0.03457174091459992}, {-0.07987733318714954, 
        0.033086600449745596`}, {-0.07974002374194696, 0.0329314912671376}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07953381916569509, 
        0.032698555920080696`}, {-0.07860333970270521, 
        0.03164745627631655}, {-0.07727662249568484, 
        0.030254308394312788`}, {-0.07589718156608848, 
        0.028907156803734305`}, {-0.07448138049286682, 
        0.027604261923736766`}, {-0.07304558285497058, 
        0.02634388417347584}, {-0.07158978865239975, 
        0.02512602355295153}, {-0.07045131370506512, 
        0.024219323803587853`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07020796559441585, 
        0.02402551745637715}, {-0.07011399788515435, 
        0.023950680062163828`}, {-0.06861821055323436, 
        0.022817853701112743`}, {-0.06710242665663979, 
        0.021727544469798268`}, {-0.06556664619537064, 
        0.020679752368220408`}, {-0.06401086916942693, 
        0.019674477396379165`}, {-0.06244594776682712, 
        0.018708909334613322`}, {-0.0608827341755897, 
        0.017780237963261666`}, {-0.059830682859598625`, 
        0.017179412312316664`}}]}, 
      {Arrowheads[{{0.0004429341853454313, 1.}}], 
       ArrowBox[{{-0.05956053968746551, 
        0.01702513376641482}, {-0.05932122839571469, 
        0.016888463282324198`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.04686620065159261}, {0.04979572995121129, 
        0.04685934317436889}, {0.04820755556727138, 0.046806027136458594`}, {
        0.046619381183331476`, 0.04675271109854829}, {0.04503120679939157, 
        0.046699395060637985`}, {0.042544971519684886`, 
        0.04638820018524865}, {0.040746748531922644`, 
        0.046249793409361487`}, {0.03898247366365759, 0.04610245119608976}, {
        0.037595562330522664`, 0.04597718974187872}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.037285729875986856`, 0.04594920665248453}, {
        0.037252146914889726`, 0.04594617354543346}, {0.03555576828561905, 
        0.045780960457392605`}, {0.035329001965956335`, 
        0.045758048829808294`}, {0.03510284363056715, 
        0.045734985272806526`}, {0.03241817092710913, 
        0.045329582907559576`}, {0.029733498223651105`, 
        0.044924180542312626`}, {0.02704882552019308, 0.04451877817706568}, {
        0.024967385338709378`, 0.04420446769459732}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024659779164618364`, 0.04415801723887494}, {
        0.02436415281673506, 0.044113375811818734`}, {0.02251407438932159, 
        0.04356798930710987}, {0.01997668302869496, 0.04313788385842846}, {
        0.017537479229955924`, 0.04269130968745742}, {0.015196462993104483`, 
        0.042228266794196744`}, {0.012949256461313964`, 
        0.04175102927847647}, {0.012482161942787968`, 0.04164514100378898}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012178766596721657`, 0.041576362612116655`}, {
        0.010791481777757702`, 0.04126187124012666}, {0.008723138942435696, 
        0.040760792679147305`}, {0.006744227955347944, 0.04024779359553841}, {
        0.0048547488164944474`, 0.03972287398929997}, {0.0030547015258752053`,
         0.039186033860431985`}, {0.0013440860834902178`, 
        0.03863727320893446}, {0.00019785423364094223`, 
        0.03824085258038005}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.00009615274126057143, 
        0.038139171206053236`}, {-0.00027709751066051433`, 
        0.03807659203480739}, {-0.001817209470436931, 
        0.0375084733720804}, {-0.0032846100096989676`, 
        0.036937400254783107`}, {-0.004679299128446629, 
        0.03636337268291551}, {-0.00600127682667991, 
        0.03578639065647761}, {-0.008427097961603342, 
        0.034623563239890895`}, {-0.010562073414469263`, 
        0.03344891800502297}, {-0.01136004297124736, 0.03291772191668094}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.011619005771092504`, 
        0.03274533435485558}, {-0.012366505081251528`, 
        0.032247735535173724`}, {-0.014065348884764968`, 
        0.031103425858310423`}, {-0.015505105489441815`, 
        0.029959073896525988`}, {-0.01670165413689253, 
        0.028820567416500464`}, {-0.01784208685353121, 
        0.027471864320655525`}, {-0.018698847738162296`, 
        0.026143988041289402`}, {-0.01930202023272432, 
        0.024845809873330918`}, {-0.01965661554783121, 
        0.023669382312068818`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01970141468857282, 
        0.02336285470773}, {-0.019890841795381285`, 
        0.021218176987189585`}, {-0.01956697732234699, 
        0.01911088602716203}, {-0.01881689058056489, 
        0.017263252044738938`}, {-0.017670879896263387`, 
        0.015633029397994217`}, {-0.016254865963525354`, 
        0.014229434263800264`}, {-0.014694769476433656`, 
        0.013061682819029473`}, {-0.014497067072345349`, 
        0.012945418578663567`}}]}, 
      {Arrowheads[{{0.002164723429134719, 1.}}], 
       ArrowBox[{{-0.014228906342101843`, 
        0.012787719415916906`}, {-0.013067918711037853`, 
        0.012104969271211657`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, 0.004536209563205161}, {-0.09947557990906132, 
        0.004355882547044862}, {-0.09741478531766196, 
        0.003647258018718431}, {-0.09586168642870307, 
        0.003583538530026147}, {-0.09406477272148986, 
        0.003080679738980602}, {-0.0922831773773489, 
        0.0025937012271481166`}, {-0.09051690039628019, 
        0.0021226029945286915`}, {-0.08876594177828373, 
        0.0016673850411223247`}, {-0.0885305477584061, 
        0.0016069900680096164`}, {-0.08829544112385378, 
        0.0015468750202675882`}, {-0.08798351664105042, 
        0.0014764483330198307`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.08768006158139673, 
        0.0014079338823812986`}, {-0.08624723646761262, 
        0.0010844288940510963`}, {-0.08419903181137148, 
        0.0006219827678346044}, {-0.08215082715513032, 
        0.00015953664161811253`}, {-0.08010262249888916, \
-0.0003029094845983795}, {-0.07827543836101296, -0.0005983868303564169}, \
{-0.07626623732565974, -0.0010313678776684755`}, {-0.07551310148922553, \
-0.0011883362226272147`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07520855223797865, -0.0012518102861546953`}, \
{-0.0742830387042318, -0.0014447055390442453`}, {-0.07232584249672915, \
-0.001838399814483727}, {-0.0703948029052332, -0.0022133048215871786`}, \
{-0.06849007413182538, -0.0025702746779548598`}, {-0.06661165617650569, \
-0.0029093093835867714`}, {-0.06475954903927411, -0.003230408938482912}, \
{-0.0629755253330229, -0.0035266372078921505`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.06266831744640265, -0.003575646426818505}, \
{-0.061134267219075326`, -0.0038188025960678835`}, {-0.05936109253610812, \
-0.004086096698756714}, {-0.057614228671229034`, -0.0043354556507097745`}, \
{-0.05589399018724254, -0.004568557402024309}, {-0.05420069164695312, \
-0.004787079902797561}, {-0.05253433305036076, -0.004991023153029532}, \
{-0.05089491439746546, -0.00518038715272022}, {-0.05033782806885453, \
-0.0052407725665836015`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05002854615544496, -0.005274297202501814}, \
{-0.049282435688267234`, -0.0053551719018696264`}, {-0.04769689692276607, \
-0.005515377400477752}, {-0.04613829810096197, -0.005661003648544594}, \
{-0.04460663922285493, -0.005792050646070156}, {-0.04310168268413794, \
-0.005910008140635467}, {-0.04162319088050397, -0.0060163658798215594`}, \
{-0.04017116381195303, -0.006111123863628434}, {-0.0387456014784851, \
-0.00619428209205609}, {-0.03762504458775064, -0.00625159427682249}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.03731434577657208, -0.006267245280598211}, \
{-0.03597387101679832, -0.006325799282773747}, {-0.03462770288857946, \
-0.0063741582450637475`}, {-0.03330799949544362, -0.00641091745197453}, \
{-0.031138657794648427`, -0.006451461128814958}, {-0.02903893613992237, \
-0.006468628979465234}, {-0.027008834531265447`, -0.006462421003925357}, \
{-0.025048352968677655`, -0.006432837202195327}, {-0.024874011880163277`, \
-0.0064279542220837425`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.024563040268370907`, -0.006419244466921669}, \
{-0.023157491452159, -0.006379877574275144}, {-0.02133624998170947, \
-0.006303542120164807}, {-0.019584628557329075`, -0.0062038308398643174`}, \
{-0.01790262717901782, -0.006080743733373675}, {-0.016285980850483335`, \
-0.005939216937222673}, {-0.014730424575433262`, -0.005784186587941108}, \
{-0.013235958353867601`, -0.0056156526855289796`}, {-0.012160779732623946`, \
-0.005479105989118437}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.011852165004752474`, -0.005439912202410007}, \
{-0.011802582185786347`, -0.005433615229986285}, {-0.009119100010077078, \
-0.005029029659509206}, {-0.006679978048305458, -0.004570429876509871}, \
{-0.004464155378964191, -0.00407258461970816}, {-0.002450571080545989, \
-0.0035502626278239554`}, {-0.0006392251530508515, -0.0030034639008572565`}, {
        0.000260480136681948, -0.002684044883153335}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0005536460053631691, -0.00257996329680823}, {
        0.0009698824035212278, -0.002432188438808061}, {
        0.002966725819649179, -0.0015994124237872828`}, {
        0.004661996695914487, -0.0007631285253010601}, {0.006055695032317156, 
        0.00007666325665060911}, {0.00714782082885718, 
        0.0009199629220677224}, {0.008635978918722267, 
        0.0025494341907752504`}, {0.009335095081882721, 
        0.0040576335682984965`}, {0.009220261508274756, 
        0.005123566661489777}}]}, 
      {Arrowheads[{{0.0058801659874549665`, 1.}}], 
       ArrowBox[{{0.009186940028151206, 0.005432870528484848}, {
        0.009060446858206714, 0.006607032854624911}, {0.00736913571208962, 
        0.008417558869425442}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.014383502332158063`}, {0.04791311253986339, 
        0.014964826718225402`}, {0.0456685805367361, 0.01559006464487481}, {
        0.04378718143259549, 0.01587578672948052}, {0.04197926484224332, 
        0.016264257775774518`}, {0.04020887143795908, 0.01662305115019407}, {
        0.040090609749294154`, 0.016646273293274384`}, {0.03997252152010287, 
        0.016669365137566814`}, {0.03813971797560074, 0.01694003527040661}, {
        0.03784753943958342, 0.01698318446847204}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03753978380035675, 0.017028634107633615`}, {
        0.03630691443109862, 0.017210705403246405`}, {0.03447411088659649, 
        0.017481375536086204`}, {0.032641307342094375`, 0.017752045668926}, {
        0.03125280663187457, 0.0177914636002474}, {0.029498409469892857`, 
        0.01802132452105454}, {0.027796283229591417`, 
        0.018223979300506576`}, {0.02614642791097025, 
        0.018399427938603503`}, {0.02519028361335468, 
        0.018489526722974138`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02488056210799713, 0.018518712203864154`}, {
        0.024547597515131768`, 0.018550087912667153`}, {0.022998546043178383`,
         0.018678376700019348`}, {0.021499273495110098`, 
        0.018784294300660087`}, {0.02004977987092691, 0.01886784071458937}, {
        0.017300129394215834`, 0.01896781998231357}, {0.01474959461304515, 
        0.018978314503191953`}, {0.012452330589801816`, 
        0.018919545508011934`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012141589781341616`, 0.01890509538233783}, {
        0.010213937807980918`, 0.01880537566245869}, {0.008220832201751356, 
        0.01864057389035891}, {0.006410875126390166, 0.01842355055043703}, {
        0.004769662252600929, 0.01816762517862227}, {0.0032827892510872295`, 
        0.01788611731084385}, {0.0019502561218490704`, 
        0.017579026947101773`}, {0.0007720628648864446, 
        0.017246354087396037`}, {-0.00009746838200474844, 
        0.016931941918754297`}}]}, 
      {Arrowheads[{{0.010477108177705271`, 1.}}], 
       ArrowBox[{{-0.00039002403684295815`, 
        0.016826157269594248`}, {-0.0013213506416372709`, 
        0.01648940063367801}, {-0.002868187452930144, 
        0.015703723245015653`}, {-0.004636950862660082, 
        0.01416253314082778}, {-0.005122280018878814, 
        0.012798892634375558`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.0763656583560365}, {0.04941377788378459, 
        0.07628133160762139}, {0.04800344291615781, 0.07607326407980557}, {
        0.046607983727486, 0.07586214242223782}, {0.04522740031776918, 
        0.07564796663491812}, {0.04386169268700735, 0.07543073671784646}, {
        0.04117490476234863, 0.07498711449444732}, {0.04081614437063317, 
        0.07492639064202596}, {0.04045844576056461, 0.07486546196952684}, {
        0.03888220712533153, 0.07453057667883643}, {0.03773455024276096, 
        0.07428674722297764}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03743024875583602, 0.07422209578655899}, {
        0.03730596849009846, 0.07419569138814602}, {0.03572972985486539, 
        0.07386080609745561}, {0.03415349121963231, 0.0735259208067652}, {
        0.03257725258439924, 0.0731910355160748}, {0.03100101394916617, 
        0.0728561502253844}, {0.029424775313933095`, 0.07252126493469399}, {
        0.027848536678700023`, 0.07218637964400358}, {0.025477510220836132`, 
        0.07141238906852172}, {0.025327278169908003`, 0.07137850542450806}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02502380752585161, 0.0713100600348041}, {
        0.023958731204176756`, 0.07106984054297094}, {0.022462936034946857`, 
        0.07072422672347602}, {0.020990124713146437`, 0.07037554761003695}, {
        0.019540297238775494`, 0.07002380320265372}, {0.018113453611834026`, 
        0.06966899350132635}, {0.01670959383232204, 0.06931111850605483}, {
        0.015327931331570347`, 0.0689505647796568}, {0.013967679540909776`, 
        0.0685877188849499}, {0.012948407464772417`, 0.06830973590626166}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.012648275629375254`, 0.06822788186203134}, {
        0.012628838460340323`, 0.06822258082193411}, {0.011311408089861984`, 
        0.06785515059060945}, {0.008740779479178663, 0.0671134136230335}, {
        0.006255793708859815, 0.06636250798222203}, {0.0038564507789054375`, 
        0.06560243366817506}, {0.0015427506893155264`, 0.06483319068089259}, {
        0.0007598132070362884, 0.06455965746451109}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.0004661271133673887, 
        0.06445705297357024}, {-0.0006853065599099145, 
        0.06405477902037461}, {-0.0028277209687708853`, 
        0.06326719868662112}, {-0.004890641844014209, 
        0.06247349599195652}, {-0.00688021849238671, 
        0.061676717248705194`}, {-0.00879645091388839, 
        0.06087686245686715}, {-0.010639339108519243`, 
        0.06007393161644239}, {-0.011095509237904661`, 
        0.059866151378400984`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.011378617726093674`, 
        0.059737198723945714`}, {-0.012408883076279275`, 
        0.0592679247274309}, {-0.014105082817168484`, 
        0.0584588417898327}, {-0.015727938331186866`, 
        0.05764668280364777}, {-0.01727744961833443, 
        0.05683144776887612}, {-0.01867520910885595, 
        0.05598324813876508}, {-0.020126944501450854`, 
        0.05518050621310144}, {-0.021508285168231563`, 
        0.054375812572898204`}, {-0.022338427805867953`, 
        0.05386594250764842}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.022603513795642374`, 
        0.05370312782403222}, {-0.022820705859726384`, 
        0.05356972938517893}, {-0.024065681326463632`, 
        0.05276281881696717}, {-0.025244686318971605`, 
        0.0519556430352865}, {-0.026359195587778623`, 
        0.05114876420716048}, {-0.027410683883413004`, 
        0.050342744499612666`}, {-0.028798159361113386`, 
        0.049201962625891875`}, {-0.030069858501626388`, 
        0.0480645333234743}, {-0.03123040190083336, 
        0.046931936018291244`}, {-0.03222226645154924, 
        0.04587205528553996}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03242710669839397, 
        0.04563801393122369}, {-0.033236503858854675`, 
        0.04468715510335382}, {-0.034091303609431745`, 
        0.04357793034546203}, {-0.03485343000222825, 
        0.04247945528852989}, {-0.03552750363312555, 
        0.04139320935848869}, {-0.03662997499274796, 
        0.03926332258280428}, {-0.0374356824553499, 
        0.03720010542585908}, {-0.03798159078798228, 
        0.03521539329510338}, {-0.03806692898204833, 0.0347150055366437}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.03811922903220195, 
        0.034408339744730655`}, {-0.03830466475769599, 
        0.03332102159798747}, {-0.03841026232424109, 
        0.03150947458907377}, {-0.03829401627589042, 
        0.029767282322036133`}, {-0.03797830362247911, 
        0.02809734890299198}, {-0.03748550137384227, 
        0.026502578438058737`}, {-0.03683798653981502, 
        0.024985875033353838`}, {-0.0360581361302325, 
        0.023550142794994712`}, {-0.03543776911154341, 0.0226076399669673}}]}, 
      {Arrowheads[{{0.013038759291734488`, 1.}}], 
       ArrowBox[{{-0.03526672935641015, 
        0.022347784997148207`}, {-0.03516832715492983, 
        0.022198285829098784`}, {-0.034190936623742126`, 
        0.02093320824178348}, {-0.03313447074808328, 
        0.019748136551874438`}, {-0.032003167801391445`, 
        0.0186333195590306}, {-0.03081300288653809, 
        0.017587194790619327`}, {-0.029579951106394692`, 
        0.016608199774008}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.046804692337708065`, 0.09}, {-0.04799248033967469, 
        0.08918037925686843}, {-0.04986462320139737, 
        0.0878885265684821}, {-0.05173676606312005, 
        0.08659667388009579}, {-0.05299785198484908, 
        0.08533610117890857}, {-0.05435800497715157, 
        0.08420768795735874}, {-0.05566277411445887, 
        0.08308361504085934}, {-0.056540645189563116`, 
        0.08229684342976525}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAANshZukIRrb+TGfSCzAO1P4MutS6X
I62/Ps18wpX7tD+PA984F8Ctv3xiApV8srQ//T2ulrvUrb/CsgGqoqi0P7qP
+l4/6a2/Qn3zP8qetD+RmDyDVvqtv3F4zsCAlrQ/vFTzvVYLrr9XnWVaOI60
PxBZQBxAHK6/aABkDvGFtD9xvEGrEi2uvwoJc96qfbQ/nhYSeM49rr9tcjrM
ZXW0PyNoe6cYX66/G3qE5t1ktD/Bx8c2CICuv3wu2IRaVLQ/Ukd7jp2grr9Y
G02020O0Py91BhxMPq+/kPnNt6fxsz8arDvvZ9Ovv94NoVPtn7M/BACi/BEw
sL+z2+mZsk6zPwStSGlYcrC/S4jDG/39sj+tAYnBn7CwvwmJ1lnSrbI/06Ob
4/SwsL+AM4NCXq2yP4Uxnls=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06538411228501921, 
        0.07270702102989378}, {-0.06608582542187937, 
        0.07175013512137826}, {-0.06691846838657448, 
        0.07054434069108642}, {-0.06769440306340523, 
        0.06934770746718089}, {-0.06858608318415121, 
        0.06786485009431317}, {-0.06939273214881049, 
        0.06639648328767564}, {-0.07011696033685685, 
        0.0649430819458746}, {-0.07076137812776415, 
        0.0635051209675164}, {-0.07132859590100618, 
        0.06208307525120738}, {-0.07140445239129392, 0.06186662781465488}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0715073429724458, 
        0.061573041828126306`}, {-0.0718212240360568, 
        0.06067741969555386}, {-0.07224187291238983, 
        0.05928862919916217}, {-0.0725931529094791, 
        0.05791717866063865}, {-0.07309804778382167, 
        0.05522819705162143}, {-0.07335679169487513, 
        0.052614274057352854`}, {-0.07339026767843011, 
        0.050079208866683586`}, {-0.07333952150202981, 
        0.04935104121072339}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07331789377453612, 
        0.049040700358467054`}, {-0.07321935877027726, 
        0.04762680066846428}, {-0.07285458526191495, 
        0.04525497375457823}, {-0.07230327890813627, 
        0.04295984475630338}, {-0.07158153993967392, 
        0.04074250137158239}, {-0.07070546858726057, 
        0.0386040312983579}, {-0.06998790330691575, 0.037147746640712374`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.06985040183770438, 
        0.03686869010676191}, {-0.06969116508162888, 
        0.03654552223457254}, {-0.06855472965351155, 
        0.034568061878168965`}, {-0.06731226253364123, 
        0.032672737927089815`}, {-0.0659798639527506, 
        0.030860638079277736`}, {-0.06456305375336753, 
        0.029128639628683194`}, {-0.06306409627395684, 
        0.027472324360335976`}, {-0.06248945585081143, 
        0.026893437931587265`}}]}, 
      {Arrowheads[{{0.019328203884793796`, 1.}}], 
       ArrowBox[{{-0.062270290678394194`, 
        0.02667265335247212}, {-0.06149420848915668, 
        0.025890836708797722`}, {-0.05986460737360519, 
        0.024383321108630077`}, {-0.05818650990194051, 
        0.022948921994394668`}, {-0.05647113304880078, 
        0.02158678380065314}, {-0.05472969378882416, 
        0.02029605096196713}, {-0.05297340909664877, 
        0.019075867912898267`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00010526251095724533`, 1.}}], 
       ArrowBox[{{0.019353194669156727`, -0.0015705268026039569`}, {
        0.01935974062531648, -0.0015053617759403896`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.007331085591050865, 0.09}, {0.00671522400736641, 
        0.08980473642916986}, {0.005219033121499208, 0.08932064809332857}, {
        0.0037464078837963852`, 0.08883432171964976}, {0.002297348294257935, 
        0.08834575730813343}, {0.0008718543528838628, 
        0.0878549548587796}, {-0.000530073940325837, 
        0.08736191437158825}, {-0.0019084365853711538`, 
        0.08686663584655938}, {-0.0032632335822521015`, 
        0.086369119283693}, {-0.00442733880087834, 0.08593210513189078}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.004718237086910213, 
        0.08582185046654003}, {-0.00590213063152086, 
        0.08536737204444769}, {-0.008451454619677742, 
        0.08435893134339038}, {-0.01091589507826836, 
        0.08334605587005915}, {-0.013295452007292721`, 
        0.08232874562445398}, {-0.015590125406750824`, 
        0.08130700060657489}, {-0.01619990744876243, 0.08102976718348867}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.016483106139709075`, 
        0.08090101274814047}, {-0.01784235704142591, 
        0.08028303820255878}, {-0.020094588676101, 
        0.07925907579854265}, {-0.02234682031077609, 
        0.07823511339452653}, {-0.023969039428570735`, 
        0.07719631664910843}, {-0.02557249995053479, 
        0.0763288764032193}, {-0.027124099475058235`, 
        0.07546153502440751}, {-0.027535746385040166`, 
        0.07522349506363192}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.02780505487219093, 
        0.07506776407145536}, {-0.028623838002141078`, 
        0.07459429251267309}, {-0.030071715531783314`, 
        0.07372714886801603}, {-0.030263719299414637`, 
        0.07361006619770158}, {-0.030454809401937826`, 
        0.07349299671120127}, {-0.03211596461444689, 
        0.07226034296715385}, {-0.03377711982695595, 
        0.07102768922310643}, {-0.03543827503946501, 
        0.06979503547905899}, {-0.03709943025197407, 
        0.06856238173501157}, {-0.03777986507596149, 0.0677145989235448}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03797458882795572, 
        0.06747198428345683}, {-0.0380402504845533, 
        0.06739017362081372}, {-0.03957428775942768, 
        0.06616818675262211}, {-0.04102357974254561, 
        0.06495331113500102}, {-0.042388126433907096`, 
        0.06374554676795048}, {-0.0436722962346668, 
        0.0625458117835721}, {-0.044880457545979406`, 
        0.06135502431396752}, {-0.04601261036784491, 
        0.06017318435913672}, {-0.04706572972400325, 0.0590036512816951}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.047266225967867025`, 
        0.05876578801692692}, {-0.04804889054323461, 
        0.057836346993796486`}, {-0.04895301789675881, 
        0.056681349583287056`}, {-0.049781136760835905`, 
        0.05553529968755141}, {-0.0505332471354659, 
        0.054398197306589555`}, {-0.05184363032329075, 
        0.05215813644991948}, {-0.05291835536713951, 
        0.04996846837420911}, {-0.05363045856573355, 0.04815289826854015}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05374405083317223, 
        0.04786328473302451}, {-0.05375742226701218, 
        0.047829193079458446`}, {-0.05436083102290878, 
        0.04574031056566748}, {-0.05469184276598942, 
        0.04369689343178919}, {-0.05495864441968001, 
        0.04172686361709005}, {-0.055019179024466396`, 
        0.03981116850418823}, {-0.05488814212788454, 
        0.037951779053502534`}, {-0.05446791946344144, 
        0.03565465573474737}, {-0.05445077413899221, 0.03559833829827014}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.05436017031633499, 
        0.0353007309218568}, {-0.053796855471144614`, 
        0.03345040443170354}, {-0.05290735406841833, 
        0.03134181637618498}, {-0.05183181917268688, 
        0.02933168280000566}, {-0.05060265470137455, 
        0.02742279493497952}, {-0.04925226457190563, 
        0.025617944012920512`}, {-0.04833623066129791, 
        0.02453718137491337}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04813508488124376, 
        0.024299863911708203`}, {-0.0478130527017044, 
        0.023919921265642567`}, {-0.046317423008195156`, 
        0.022331517924959656`}, {-0.04476169143061717, 
        0.020846032192199663`}, {-0.04313106991492201, 
        0.019453841336233228`}, {-0.04144130638860243, 
        0.018153355190188437`}, {-0.03970814877915118, 
        0.01694298358719336}, {-0.038677043091359435`, 
        0.016286043228853405`}}]}, 
      {Arrowheads[{{0.0008906031916963419, 1.}}], 
       ArrowBox[{{-0.03841467562317884, 
        0.016118883081640525`}, {-0.03794734501406098, 
        0.01582113636037608}}]}}}}, 
   {PointSize[0.025], PointBox[{0, 0.08}]}, 
   {PointSize[0.025], PointBox[{0, 0.01}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.08}, {0.05, 0.08}}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.01}, {0.05, 0.01}}]}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0.09}, {0, -0.01}}]}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwV13c81P8fAHBtRWhIiMyMQlP2q9KUiux5ZGRmrzvO3edKVkj2yLhzOHsU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      "]]}}},
  AspectRatio->1,
  BaseStyle->{FontWeight -> "Bold", FontSize -> 12},
  Frame->True,
  ImageMargins->10,
  ImageSize->{425.5, Automatic},
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{-0.1027733900410869, 0.0527733900410869}, {-0.0127733900410869,
    0.0927733900410869}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.644010673404679*^9, 3.6440107106163197`*^9, 3.703994793154415*^9, {
   3.7039949598112154`*^9, 3.7039950043280153`*^9}, {3.703995035133015*^9, 
   3.703995051722215*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InitialPoint", "[", 
  RowBox[{
  "0.01", ",", "0.0", ",", "0.33", ",", "1.5", ",", ".01", ",", ".07", ",", 
   ".08"}], "]"}]], "Input",
 CellChangeTimes->{{3.704497418394333*^9, 3.704497447296033*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "0.03448275862068966`"}], ",", "0.07965517241379311`"}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7044973660902376`*^9, {3.7044974194325585`*^9, 3.7044974479468327`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"initial", " ", "=", " ", 
   RowBox[{"InitialPoint", "[", 
    RowBox[{
    "0.01", ",", "0.0", ",", "0.33", ",", "1.5", ",", ".1", ",", ".07", ",", 
     ".08"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "\n", 
  RowBox[{
   RowBox[{"StreamPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"BigA", "+", 
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"BigB", ".", 
            RowBox[{"Inverse", "[", 
             RowBox[{
              RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", "BigB"}], "]"}],
             ".", "BigA"}]}]}], ")"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
          RowBox[{"BigB", ".", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
             RowBox[{"\[Gamma]", " ", 
              RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
           RowBox[{"Inverse", "[", "BigB", "]"}]}]}], ")"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"BigB", ".", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"IdentityMatrix", "[", "2", "]"}], "-", 
             RowBox[{"\[Gamma]", " ", 
              RowBox[{"IdentityMatrix", "[", "2", "]"}]}]}], ")"}], ".", 
           RowBox[{"Inverse", "[", "BigB", "]"}]}], "+", 
          RowBox[{"BigB", "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Lambda]"}], ")"}], "\[Gamma]"}]}], ")"}], 
        ".", 
        RowBox[{"{", 
         RowBox[{"x", ",", "p"}], "}"}]}], "-", 
       RowBox[{"{", 
        RowBox[{"x", ",", "p"}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
        RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
        RowBox[{"\[Pi]bar", "\[Rule]", ".01"}], ",", 
        RowBox[{"\[Lambda]", "\[Rule]", "0.0"}], ",", 
        RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", ".1"}], ",", ".05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"-", "0.01"}], ",", ".09"}], "}"}]}], "]"}], "\n", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.08"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.01"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".1"}], ",", "0.08"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.05", ",", "0.08"}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".1"}], ",", "0.01"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.05", ",", "0.01"}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0.09"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "0.01"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
   ",", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"First", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], ",", 
          RowBox[{"p", "[", "t", "]"}]}], "}"}], " ", "/.", " ", "\n", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"x", "'"}], "[", "t", "]"}], "==", 
              RowBox[{
               FractionBox["1", 
                RowBox[{"1", "+", 
                 RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}]], "\[Gamma]", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"p", "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Lambda]"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]", "+", "\[Lambda]", 
                    "-", 
                    RowBox[{"\[Alpha]", " ", "\[Lambda]"}]}], ")"}], " ", 
                  "\[Pi]bar"}], "-", 
                 RowBox[{
                  RowBox[{"x", "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Lambda]", "+", 
                    RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}], ")"}]}]}], 
                ")"}]}]}], " ", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
               RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
               RowBox[{"\[Pi]bar", "\[Rule]", "0.01"}], ",", 
               RowBox[{"\[Lambda]", "\[Rule]", "0.0"}], ",", 
               RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", "\n", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"p", "'"}], "[", "t", "]"}], "==", 
              RowBox[{
               FractionBox["1", 
                RowBox[{"1", "+", 
                 RowBox[{"\[Alpha]", " ", "\[CurlyPhi]"}]}]], "\[Gamma]", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                    "\[Pi]bar"}]}], ")"}], " ", "\[CurlyPhi]"}], "+", 
                 RowBox[{"\[Lambda]", " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Pi]bar", "-", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], " ", "\[CurlyPhi]"}], "+", 
                    RowBox[{"\[Pi]bar", " ", "\[CurlyPhi]"}]}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"p", "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Alpha]"}], ")"}], " ", 
                    "\[CurlyPhi]"}], "+", 
                    RowBox[{"\[Lambda]", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "\[CurlyPhi]"}], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], " ", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Alpha]", "\[Rule]", "1.5"}], ",", 
               RowBox[{"\[CurlyPhi]", "\[Rule]", ".1"}], ",", 
               RowBox[{"\[Pi]bar", "\[Rule]", "0.01"}], ",", 
               RowBox[{"\[Lambda]", "\[Rule]", "0.0"}], ",", 
               RowBox[{"\[Gamma]", "\[Rule]", "0.33"}]}], "}"}]}], ",", "\n", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
               RowBox[{"initial", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"p", "[", "0", "]"}], "\[Equal]", 
               RowBox[{"initial", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "p"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "120"}], "}"}]}], "]"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "120"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}], ",", " ", 
   RowBox[{"BaseStyle", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", " ", "->", " ", "\"\<Bold\>\""}], ",", " ", 
      RowBox[{"FontSize", " ", "->", " ", "12"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageMargins", "\[Rule]", "10"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.64401073397567*^9, 3.6440107423163357`*^9}, {
  3.644010773569337*^9, 3.6440107794193745`*^9}, {3.6440108121095843`*^9, 
  3.6440108634987154`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.04355424173457737}, {0.04913185850385442, 
        0.04367534731273184}, {0.04715960909903208, 0.04393653164116389}, {
        0.04520346858076563, 0.044181524684116305`}, {0.04326343694905506, 
        0.0444103264415891}, {0.041339514203900384`, 0.04462293691358227}, {
        0.0394317003453016, 0.044819356100095804`}, {0.03764051813617188, 
        0.044990006922867656`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03733067876588822, 0.0450178904947922}, {
        0.035664399287771674`, 0.04516362061668399}, {0.03380491208884055, 
        0.04531146594675864}, {0.03196153377646532, 0.04544311999135366}, {
        0.03013426435064597, 0.04555858275046906}, {0.0283231038113825, 
        0.04565785422410483}, {0.026528052158674938`, 
        0.045740934412260965`}, {0.024913286008855416`, 
        0.0458016502137447}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024602369134233443`, 0.04581204344113782}, {
        0.022986275512927458`, 0.045858520932134356`}, {0.021242445895153967`,
         0.0458947312959816}, {0.019520515914469214`, 
        0.045918158438609205`}, {0.017820485570873193`, 
        0.04592880236001717}, {0.016142354864365892`, 
        0.045926663060205486`}, {0.014486123794947318`, 
        0.04591174053917417}, {0.012851792362617487`, 
        0.045884034796923205`}, {0.012160384859480549`, 
        0.04586667321101276}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011849389330967148`, 0.04585886395878227}, {
        0.011239360567376384`, 0.045843545833452605`}, {0.009648828409224005, 
        0.045790273648762356`}, {0.008080195888160358, 0.04572421824285247}, {
        0.006533463004185443, 0.045645379615722945`}, {0.005008629757299255, 
        0.045553757767373776`}, {0.003505696147501798, 
        0.045449352697804965`}, {0.0020246621747930654`, 
        0.04533216440701651}, {0.0005655278391730675, 
        0.04520219289500842}, {-0.0005675170114323089, 
        0.045089652114056966`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0008770813829522318, 
        0.04505884752961963}, {-0.002287041920800742, 
        0.0449039002073333}, {-0.0036792471753757765`, 
        0.04473701972670754}, {-0.005047092453304531, 
        0.044560237414944644`}, {-0.007709703079223195, 
        0.04417696729800746}, {-0.010274873798556735`, 
        0.04375408985652176}, {-0.01274260461130515, 
        0.04329160509048753}, {-0.013177405204414934`, 
        0.04320491705688123}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.013482494197115683`, 
        0.04314409017377374}, {-0.015161615470761065`, 
        0.042809316662179034`}, {-0.01758062633021698, 
        0.04232702823387053}, {-0.019999637189672896`, 
        0.04184473980556203}, {-0.02161892972857411, 
        0.041107671979860476`}, {-0.02324018517789188, 
        0.04059912457819927}, {-0.024794650841580564`, 
        0.0400727124795877}, {-0.024897346327395927`, 
        0.04003656856102398}, {-0.02499973803881323, 
        0.04000034785238884}, {-0.0254099023350875, 0.03978907707630706}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.025686463726702278`, 
        0.03964662357566974}, {-0.026555758391587567`, 
        0.03919886017899597}, {-0.028111778744361906`, 
        0.03839737250560311}, {-0.029667799097136245`, 
        0.03759588483221024}, {-0.031223819449910584`, 
        0.036794397158817375`}, {-0.03326969170348867, 
        0.03506594832244329}, {-0.03455916994327036, 
        0.03423309227665333}, {-0.035742031337854994`, 
        0.03338768888190454}, {-0.03616344787361893, 0.0330377996731269}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03640279685087912, 
        0.032839075567240805`}, {-0.03780730669498018, 
        0.03167295417339923}, {-0.03948492087841135, 
        0.029935458324796098`}, {-0.04077487388814849, 
        0.028175201336095163`}, {-0.041677165724191605`, 
        0.02639218320729642}, {-0.04222804596690975, 
        0.0246122085068251}, {-0.042463764196672006`, 
        0.022861081803106427`}, {-0.042445692793518154`, 
        0.022469308002744895`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04243135818059695, 
        0.022158544874223945`}, {-0.04238432041347836, 
        0.021138803096140402`}, {-0.04198971461732881, 
        0.019445372385927032`}, {-0.041324663300894446`, 
        0.017798087307603558`}, {-0.04043388295684635, 
        0.016214245496307223`}, {-0.03931737358518452, 
        0.014693846952038027`}, {-0.037975135185908955`, 
        0.013236891674795973`}, {-0.03632329361230004, 0.0117489496625216}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.036084110710015264`, 
        0.01155042370792622}, {-0.03427191714846076, 
        0.01016601398582798}, {-0.03216749792730143, 
        0.00880019702263126}, {-0.029894538571185306`, 
        0.007547461313626064}, {-0.027513818665387883`, 
        0.006411926550886392}, {-0.025279483849588613`, 
        0.005478494447847715}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.024990612602670596`, 
        0.005363253061614298}, {-0.0226114359605757, 
        0.004504818940425647}, {-0.020089773161560947`, 
        0.003733246092704573}, {-0.017460823063882788`, 
        0.003089040580790875}, {-0.015066321561667796`, 
        0.0025379377857001127`}, {-0.01298679357142965, 
        0.002160288896261904}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.012680706402383068`, 
        0.002104702493960827}, {-0.012673084162453148`, 
        0.002103318270974612}, {-0.010305233399941872`, 
        0.0017827633576272324`}, {-0.007986930843317246, 
        0.0015675495840985919`}, {-0.005732813181617, 
        0.0014460132057536024`}, {-0.0035650470266914347`, 
        0.0014127138630418766`}, {-0.0015057989903908475`, 
        0.0014622111964130253`}, {-0.00027543951010812885`, 
        0.0015431396213685183`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.000034983250583417826`, 0.0015635580645111111`}, {
        0.0004227643154344884, 0.0015890648463166611`}, {0.002198476278934272,
         0.0017878344532023956`}, {0.003799170288258203, 
        0.002053079657519839}, {0.005202679731556008, 
        0.0023793600997186054`}, {0.007527314828854515, 
        0.0031855223826300514`}, {0.009305934378599924, 
        0.0041506310475031335`}, {0.010530779505574878`, 
        0.005224526466281742}, {0.011082596604173352`, 
        0.006166685609784839}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011187619521013695`, 0.006447299628755907}, {
        0.011033729175122282`, 0.00859332851131549}, {0.009220076053379466, 
        0.010450175615923011`}, {0.008251348101993999, 
        0.011126960150223941`}, {0.006448255239366939, 
        0.011743038557777797`}, {0.004773179569877332, 
        0.012220349187836061`}, {0.003226121093525168, 
        0.012558892040398733`}, {0.0019479808300218524`, 
        0.012681474023003838`}}]}, 
      {Arrowheads[{{0.006444121908177822, 1.}}], 
       ArrowBox[{{0.0016383082036170089`, 0.01271117364642325}, {
        0.001365453160513722, 
        0.012737342223615025`}, {-0.00022520798279577646`, 
        0.012651991027689779`}, {-0.0014915696773068925`, 
        0.012418323266436184`}, {-0.002297161338165422, 
        0.01213291934538316}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.07575719200089497}, {0.04984190248354503, 
        0.07576461335182694}, {0.047086306121393556`, 0.0758803797420212}, {
        0.04435536912742485, 0.07597687428640165}, {0.0416490915016389, 
        0.07605409698496826}, {0.038967473244035725`, 0.07611204783772103}, {
        0.03756244310087291, 0.07613250173743066}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03725138249962801, 0.07613703004052255}, {
        0.03631051435461532, 0.07615072684465997}, {0.03367821483337768, 
        0.07617013400578507}, {0.0310705746803228, 0.07617026932109633}, {
        0.028487593895450677`, 0.07615113279059377}, {0.02592927247876133, 
        0.07611272441427736}, {0.024808441967478088`, 0.0760880550052712}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02449742373261378, 0.07608120951349792}, {
        0.023398149132107617`, 0.0760570145487312}, {0.020896762557342373`, 
        0.07598597355053942}, {0.01842511275446563, 0.07589960141970199}, {
        0.015983199723477372`, 0.07579789815621893}, {0.013571023464377597`, 
        0.07568086376009023}, {0.012063743854027312`, 0.07559712108217301}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011753129324241919`, 0.07557986370514382}, {
        0.011188583977166308`, 0.07554849823131587}, {0.008835881261843502, 
        0.0754008015698959}, {0.006512915318409182, 0.07523777377583027}, {
        0.004219686146863348, 0.075059414849119}, {0.0019561937472059934`, 
        0.0748657247897621}, {-0.00027756188056288905`, 
        0.07465670359775954}, {-0.0006525040037088566, 
        0.07461853734672594}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009619982545571466, 
        0.07458703319037183}, {-0.0024815807364432715`, 
        0.07443235127311135}, {-0.004655862820435168, 
        0.07419266781581753}, {-0.0068004081325385955`, 
        0.07393765322587806}, {-0.008915216672753534, 
        0.07366730750329295}, {-0.011000288441079961`, 
        0.0733816306480622}, {-0.013054506897299365`, 
        0.07308267494346925}, {-0.013308310922562983`, 0.0730437452546514}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.013615808280620574`, 
        0.07299657982278303}, {-0.015076755501193174`, 
        0.07277249267279749}, {-0.017067034252761386`, 
        0.07245108383604695}, {-0.01902534315200401, 
        0.07211844843321763}, {-0.02095168219892104, 
        0.07177458646430952}, {-0.022846051393512465`, 
        0.07141949792932262}, {-0.024708450735778292`, 
        0.07105318282825693}, {-0.025865156156984793`, 
        0.07081460248658444}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.026169836279317703`, 
        0.07075175961721224}, {-0.026538880225718528`, 
        0.07067564116111247}, {-0.028337339863333165`, 
        0.07028687292788921}, {-0.030103829648622207`, 
        0.06988687812858715}, {-0.03183834958158566, 
        0.06947565676320633}, {-0.03354089966222351, 
        0.0690532088317467}, {-0.03521147989053577, 
        0.0686195343342083}, {-0.03685009026652243, 
        0.0681746332705911}, {-0.03824983016731838, 0.06777724503486673}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.038548778624452565`, 
        0.06769118631480318}, {-0.04003140146151896, 
        0.06725115144512035}, {-0.041573992872756475`, 
        0.06677412779371512}, {-0.043084395616123684`, 
        0.06628899179712776}, {-0.04456260969162058, 
        0.06579574345535825}, {-0.04600863509924718, 
        0.0652943827684066}, {-0.04742247183900346, 
        0.06478490973627282}, {-0.04880411991088943, 
        0.0642673243589569}, {-0.0501535793149051, 
        0.06374162663645884}, {-0.05032117780869975, 0.06367370911513182}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05060949708393663, 
        0.06355687077081539}, {-0.051470850051050454`, 
        0.06320781656877864}, {-0.05277202645326069, 
        0.06266995032850735}, {-0.05407320285547094, 
        0.062132084088236075`}, {-0.055374379257681176`, 
        0.06159421784796479}, {-0.056675555659891415`, 
        0.06105635160769351}, {-0.05797673206210166, 
        0.06051848536742223}, {-0.0592779084643119, 
        0.05998061912715095}, {-0.06086900861778752, 
        0.0587088844687593}, {-0.06175939635520532, 0.05819171698940888}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.062028404564536864`, 
        0.05803546787264989}, {-0.06285665001911794, 
        0.057554394744586186`}, {-0.06472720356246804, 
        0.05638179544620594}, {-0.06484954166029133, 
        0.05630201589539252}, {-0.06497135126624767, 
        0.05622216152847064}, {-0.06510251245446844, 
        0.05613522502562152}, {-0.0652330515499294, 
        0.05604820271247613}, {-0.06536296905215513, 
        0.05596109524391275}, {-0.06549226546315227, 
        0.055873903273992206`}, {-0.0656209412874018, 
        0.05578662745595587}, {-0.06587705277877536, 
        0.05561190942767183}, {-0.0661306859910348, 
        0.05543686122216588}, {-0.06638184501653847, 
        0.05526148804641589}, {-0.06760085581243419, 
        0.05438013906294345}, {-0.06875865859275593, 
        0.05349143572236085}, {-0.06985581872910668, 
        0.052596009083313494`}, {-0.0708929015930894, 
        0.05169449020444679}, {-0.07199404834054257, 0.05063834976343781}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.07221856509926036, 
        0.05042300950191994}, {-0.07278927181825492, 
        0.04987562883056093}, {-0.07441324362933602, 
        0.048105614719310276`}, {-0.07584255965666155, 
        0.046334832642319246`}, {-0.07707721990023153, 
        0.04456328259958785}, {-0.07811722436004596, 
        0.04279096459111609}, {-0.07896257303610485, 
        0.041017878616903945`}, {-0.0792369137029541, 
        0.040269998505508955`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.07934404971271791, 
        0.039977935021677756`}, {-0.07961326592840819, 
        0.03924402467695144}, {-0.08006930303695597, 
        0.03746940277125856}, {-0.0803306843617482, 
        0.035694012899825316`}, {-0.08042113893659858, 
        0.03393031439523363}, {-0.08036439579532077, 
        0.03219076659006546}, {-0.08016045493791482, 
        0.030475369484320787`}, {-0.07980931636438068, 
        0.028784123077999622`}, {-0.07950174193087413, 
        0.027755187340652958`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.07941264390585265, 
        0.02745712569415512}, {-0.0793109800747184, 
        0.02711702737110196}, {-0.07866544606892793, 
        0.025474082363627804`}, {-0.0778727143470093, 
        0.023855288055577153`}, {-0.0769327849089625, 
        0.02226064444695}, {-0.07587118542169177, 
        0.020698036773760316`}, {-0.07471344355210133, 
        0.01917535027202208}, {-0.07345955930019117, 
        0.017692584941735277`}, {-0.07282672658541238, 
        0.017016243480843005`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07261417820087673, 
        0.016789081892085098`}, {-0.0721095326659613, 
        0.016249740782899917`}, {-0.07066336364941173, 
        0.014846817795515992`}, {-0.06912105225054245, 
        0.013483815979583508`}, {-0.06748259846935345, 
        0.01216073533510246}, {-0.06574800230584475, 
        0.010877575862072851`}, {-0.06368027368591715, 
        0.009463244957758592}, {-0.06295210052457925, 0.00899957893081733}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06268968908916643, 
        0.008832487812740056}, {-0.06155651906534873, 
        0.008110939051141741}, {-0.05937673844413951, 
        0.006820658142222309}, {-0.0571409318222895, 
        0.0055924022310002985`}, {-0.05484909919979868, 
        0.004426171317475706}, {-0.052501240576667066`, 
        0.0033219654016485305`}, {-0.05172110745919461, 
        0.002983746237304874}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.05143568337139959, 
        0.0028600033858664584`}, {-0.05009735595289464, 
        0.002279784483518772}, {-0.04763744532848141, 
        0.0012996285630864257`}, {-0.04515114529558545, 
        0.00038118881016138174`}, {-0.04266809244636484, \
-0.0004758436054464769}, {-0.04018828678081958, -0.0012714686837371528`}, \
{-0.039751635150797014`, -0.00140092146094171}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.039453373100333394`, -0.001489346301506821}, \
{-0.03771172829894966, -0.0020056864247106464`}, {-0.035238417000755085`, \
-0.0026784968283669578`}, {-0.03276835288623584, -0.0032898998947060894`}, \
{-0.030301535955391944`, -0.0038398956237280374`}, {-0.027837966208223403`, \
-0.0043284840154328005`}, {-0.027361751258326666`, -0.004392014454256227}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.027053389621099915`, -0.004433152075268699}, \
{-0.02509123283818399, -0.004694917652947522}, {-0.02281282752263791, \
-0.0050985870940232466`}, {-0.02054844346499462, -0.005443134367068541}, \
{-0.01830346770236784, -0.005729702056726784}, {-0.01608328727187129, \
-0.0059594327476413505`}, {-0.014722935808797112`, -0.006067538096217257}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.014412819940598525`, -0.006092182597980622}, \
{-0.013893289210618696`, -0.006133469024455618}, {-0.011738860555723776`, \
-0.006252953471812963}, {-0.009625388344300235, -0.006319028674356762}, \
{-0.0079893933074165, -0.006335951211656005}, {-0.006383178260363373, \
-0.006324638430351151}, {-0.004809198554134808, -0.006286067739601756}, \
{-0.0032699095397247784`, -0.006221216548567372}, {-0.0019793464582281493`, \
-0.006143760680255079}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0016689359182156074`, -0.006123326329577985}, \
{-0.0003052249903361722, -0.006016582302281845}, {
        0.0011152598426544622`, -0.005878754065349809}, {
        0.002491232579850672, -0.005718554964770995}, {
        0.005099820362883987, -0.005334953809311244}, {
        0.007500895550812047, -0.004873598109179009}, {
        0.009674815335683078, -0.0043423071376507165`}, {
        0.010576914591444296`, -0.004064529132908614}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01087423191735045, -0.003972977994784928}, {
        0.011601936909545318`, -0.00374890016800279}, {
        0.013306462102495012`, -0.003099597351637366}, {
        0.014826083402489318`, -0.002400126802456803}, {
        0.016161393988367845`, -0.0016575697374878627`}, {
        0.01731298703897023, -0.0008790073737572888}, {0.01906739324970505, 
        0.0007578083818817281}, {0.020094047465410766`, 
        0.0024536707282462253`}, {0.020276613771853014`, 
        0.0033203056201942995`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.020340741609684267`, 0.0036247178794592922`}, {
        0.020452705792444223`, 0.00415620733838047}, {0.020234559008956474`, 
        0.00581549011919061}, {0.019491504553355812`, 
        0.0073785356852554525`}, {0.01827543986405054, 
        0.008792360651153797}, {0.017073696998119982`, 
        0.009980261320820742}, {0.014938590999955138`, 
        0.011142364754814435`}, {0.012803734349833444`, 
        0.012117665286684481`}, {0.01265011945218867, 
        0.012174408736671135`}}]}, 
      {Arrowheads[{{0.008443464940275015, 1.}}], 
       ArrowBox[{{0.01235829856123913, 0.01228220377728593}, {
        0.010669127047754877`, 0.01290616291643089}, {0.008981051332127147, 
        0.013397430127314829`}, {0.007325945019207816, 
        0.013761048508431179`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02457703793157891, 0.09}, {-0.026325597599182057`, 
        0.08968599896944049}, {-0.02815544668568036, 
        0.08934395366665882}, {-0.029962881959455533`, 
        0.08899248680279476}, {-0.031747595528936606`, 
        0.08863269696763569}, {-0.03350927950255259, 
        0.08826568275096898}, {-0.0352479338803035, 
        0.08789144415279462}, {-0.03677638528861681, 0.0875515984973399}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.037079880254342786`, 
        0.08748326909625165}, {-0.038656153848210084`, 
        0.08712129381192296}, {-0.04032571943836576, 
        0.08672538206922566}, {-0.04197225543265637, 
        0.0863222459450207}, {-0.04359576183108189, 
        0.0859118854393081}, {-0.045196238633642326`, 
        0.08549430055208784}, {-0.0467736858403377, 
        0.08506949128335994}, {-0.04832810345116799, 
        0.08463745763312439}, {-0.04913534798184733, 0.08440591040915729}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.049434383082079, 
        0.08432013621720447}, {-0.04985949146613319, 
        0.0841981996013812}, {-0.051367849885233324`, 
        0.08375171718813035}, {-0.05285317870846838, 
        0.08329801039337184}, {-0.05431547793583835, 
        0.0828370792171057}, {-0.055754747567343256`, 
        0.0823689236593319}, {-0.0571710218295775, 
        0.08189436187399182}, {-0.0585643349491355, 
        0.08141421201502679}, {-0.059934686926017264`, 
        0.08092847408243682}, {-0.06125688109379126, 0.08044633603948652}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.06154823505277245, 
        0.0803372882596036}, {-0.06260650745175209, 
        0.07994023399638207}, {-0.06390797600060515, 
        0.07943773184291729}, {-0.06644202967028255, 
        0.07841596331511293}, {-0.06893016105460759, 
        0.07738301864005863}, {-0.0714182924389326, 
        0.07635007396500434}, {-0.07307886062206763, 0.07566069113211217}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07336617850338917, 
        0.07554141146809255}, {-0.07390642382325764, 
        0.07531712928995005}, {-0.07567025245022117, 
        0.07413903257577305}, {-0.07704360084886909, 
        0.07341181580602205}, {-0.07837892299483101, 
        0.07267822846958022}, {-0.07967621888810694, 
        0.07193827056644758}, {-0.08093548852869688, 
        0.07119194209662412}, {-0.08110295978362704, 
        0.07109073560636285}, {-0.08126974390027596, 
        0.07098942306708846}, {-0.0829680403297831, 
        0.06963806426877672}, {-0.08386139920752353, 0.06892720581173174}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08410483054348274, 
        0.06873350401037501}, {-0.08466633675929022, 
        0.06828670547046499}, {-0.08636463318879736, 
        0.06693534667215324}, {-0.0880629296183045, 
        0.06558398787384151}, {-0.08888661624387481, 
        0.0641735927880522}, {-0.09043056976680486, 
        0.06281181582136205}, {-0.09187162801868352, 
        0.06144309340908633}, {-0.09306117503599184, 0.06022020679469635}}]}, 
      {Arrowheads[{{0.01946458243691901, 1.}}], 
       ArrowBox[{{-0.09327520687726482, 
        0.05999451744192151}, {-0.09444835684001697, 
        0.058687003904683004`}, {-0.09559062367093232, 
        0.05730402012636528}, {-0.09663659149225685, 
        0.0559184742162718}, {-0.09758626030399059, 
        0.0545303661744026}, {-0.0984396301061335, 
        0.05313969600075766}, {-0.0991967008986856, 
        0.05174646369533698}, {-0.09985747268164688, 
        0.05035066925814057}, {-0.1, 0.04999758932004714}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.018806407467481533`}, {0.049952697526397985`, 
        0.018825091886832637`}, {0.04791678615608232, 
        0.019583794395721225`}, {0.04587010783569828, 
        0.020301269838719625`}, {0.043812662565245894`, 
        0.02097751821582785}, {0.04174983381975927, 0.021633153059990994`}, {
        0.03968700507427264, 0.022288787904154138`}, {0.03820348791099709, 
        0.02276029846763917}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.03790700896350569, 0.022854529231565394`}, {
        0.03762417632878602, 0.022944422748317282`}, {0.035593462484981894`, 
        0.023278302180985266`}, {0.03398742944766495, 
        0.023655466893076068`}, {0.03238915638801308, 
        0.024008643268209166`}, {0.03228151058217576, 
        0.024031678261426857`}, {0.03217390678472792, 
        0.024054605122136495`}, {0.0302426803473784, 0.024341646902729806`}, {
        0.02831145391002889, 0.024628688683323113`}, {0.026380227472679374`, 
        0.024915730463916423`}, {0.025663098001842913`, 
        0.02502231875218952}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.025355384787013626`, 0.025068054740154718`}, {
        0.024449001035329862`, 0.02520277224450973}, {0.02279629536380484, 
        0.02521625021527218}, {0.020914219649836124`, 
        0.025455016029424748`}, {0.01906491108478793, 
        0.025661597865950157`}, {0.01724836966866027, 
        0.025835995724848407`}, {0.015544982071242785`, 0.0259742697199157}, {
        0.013875796583310757`, 0.026086492181068354`}, {0.012967226376780097`,
         0.02613437788938177}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012656563990302358`, 0.02615075118482542}, {
        0.012240813204864184`, 0.026172663108306363`}, {0.010640031935903072`,
         0.02623278250162973}, {0.009073452776427415, 
        0.026266850361038457`}, {0.007541075726437212, 
        0.026274866686532537`}, {0.006042900785932469, 0.02625683147811198}, {
        0.004578927954913177, 0.026212744735776776`}, {0.0031533776831574835`,
         0.02614574704611249}, {0.0017704704204435104`, 
        0.026058978995704675`}, {0.00043020616677126415`, 
        0.02595244058455333}, {0.0002251803411778624, 0.02593248363614131}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.00008444983152358643, 
        0.025902344636015234`}, {-0.000867415077859251, 
        0.02582613181265846}, {-0.003334728539995105, 
        0.025514203186638138`}, {-0.0056314699659640545`, 
        0.025123193117643706`}, {-0.007753414117880998, 
        0.024666477894867252`}, {-0.009696335757860832, 
        0.024157433807500874`}, {-0.01146023488590356, 
        0.023596060855544575`}, {-0.012215790875837624`, 
        0.023303491655637838`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.01250589440599906, 
        0.023191156687958132`}, {-0.01304511150200919, 
        0.022982359038998344`}, {-0.01497963895477294, 
        0.022049800522811}, {-0.016566699025135263`, 
        0.0210563732011071}, {-0.01782016874323347, 
        0.0200192401309679}, {-0.01875392513920486, 
        0.018955564369474667`}, {-0.019734842288189853`, 
        0.016805828276456165`}, {-0.019552995493914135`, 
        0.014372260671561124`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01942835863943457, 
        0.014094748472783143`}, {-0.018142764384804812`, 
        0.011994599840697263`}, {-0.017087698510919097`, 
        0.010965223520870359`}, {-0.015852562498846957`, 
        0.010027624567805024`}, {-0.013977933594372882`, 
        0.00888221097175601}, {-0.012027350105416765`, 
        0.007917743266705024}, {-0.010000812031978612`, 
        0.007134221452652067}, {-0.009605692825908433, 
        0.0070209800011694305`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.009306639042943082, 
        0.006935270969732587}, {-0.007898319374058431, 
        0.006531645529597142}, {-0.005820931663728008, 
        0.006095656137651738}, {-0.0038697084330591475`, 
        0.00581189391692735}, {-0.0020446496820518446`, 
        0.005680358867423977}, {-0.0003457554107060964, 
        0.005701050989141619}, {0.0011801955592914831`, 
        0.00583788353291726}, {0.002486424406254276, 0.006054769749587878}, {
        0.0029680908453947707`, 0.006186408124294622}}]}, 
      {Arrowheads[{{0.006653789766015584, 1.}}], 
       ArrowBox[{{0.003268179154866338, 0.00626842159693312}, {
        0.0035729311301822882`, 0.006351709639153475}, {0.00443971573107552, 
        0.006728703201614049}, {0.005607955637895165, 0.007899322085579728}, {
        0.00547270495822267, 0.009116763220660807}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.05936415918793532}, {0.04891242875744275, 
        0.05945105512756192}, {0.046807173507345416`, 0.05960712255352431}, {
        0.044719015361646935`, 0.059749683408964006`}, {0.04264795432034734, 
        0.059878737693881016`}, {0.040593990383446674`, 
        0.05999428540827534}, {0.038557123550944886`, 0.06009632655214697}, {
        0.037581117291240515`, 0.06013910880429509}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03727032217161092, 0.060152732195581975`}, {
        0.03653735382284196, 0.060184861125495925`}, {0.034534681199137926`, 
        0.06025988912832218}, {0.03254910567983281, 0.06032141056062575}, {
        0.03058062726492658, 0.060369425422406635`}, {0.028629245954419204`, 
        0.06040393371366483}, {0.02669496174831075, 0.060424935434400334`}, {
        0.02483066024889409, 0.060432223830909806`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024519568385110095`, 0.060431613683115504`}, {
        0.02287768464929048, 0.06042641916430328}, {0.020994691756378706`, 
        0.060406901173470716`}, {0.018653057749290033`, 
        0.060365482613026065`}, {0.016344420140638662`, 
        0.060307327739181855`}, {0.014068778930424564`, 
        0.06023243655193808}, {0.012079925260482686`, 0.06015117816899436}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01176911196604794, 0.06013801261639435}, {
        0.009616485705308138, 0.060032445237251826`}, {0.007439833690405861, 
        0.05990734510980936}, {0.0052961780739408555`, 0.05976550866896733}, {
        0.0031855188559131026`, 0.059606935914725726`}, {
        0.0011078560363226332`, 
        0.059431626847084564`}, {-0.0006427280185946512, 
        0.059267203164868075`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009524432741126244, 
        0.05923795900257992}, {-0.002948480407546486, 
        0.05903079977160355}, {-0.004927154031825132, 
        0.05880528176376369}, {-0.006872831257666506, 
        0.05856302744252427}, {-0.008785512085070606, 
        0.05830403680788528}, {-0.010665196514037426`, 
        0.058028309859846736`}, {-0.012511884544566986`, 
        0.05773584659840863}, {-0.013286055431186489`, 
        0.05760494002998768}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.013592794704943895`, 
        0.057553072688524026`}, {-0.014324273243834267`, 
        0.05742938508020045}, {-0.016101059679014262`, 
        0.057111663361851715`}, {-0.017842243850106996`, 
        0.05678268144336242}, {-0.01954782575711246, 
        0.05644243932473256}, {-0.021217805400030647`, 
        0.05609093700596214}, {-0.02285218277886156, 
        0.055728174487051155`}, {-0.024450957893605206`, 
        0.05535415176799961}, {-0.025774415937273164`, 
        0.055027952539118075`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.026076275762697682`, 
        0.05495273657991053}, {-0.027541701330830667`, 
        0.05457232572947484}, {-0.02903366965331249, 
        0.054164522410001616`}, {-0.03049003571170704, 
        0.05374545889038782}, {-0.03191079950601432, 
        0.05331513517063347}, {-0.03329596103623432, 
        0.05287355125073856}, {-0.03464552030236705, 
        0.052420707130703084`}, {-0.03723783204237069, 
        0.05148123829021045}, {-0.03793341173032326, 0.0512049690884223}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.038222535304404455`, 
        0.051090135460567725`}, {-0.03969019061921482, 
        0.05050721452520189}, {-0.042005051926089006`, 
        0.049509121711723725`}, {-0.04418241596299327, 
        0.04848695984977595}, {-0.046222282729927594`, 
        0.04744072893935856}, {-0.04812465222689199, 
        0.046370428980471556`}, {-0.049368042018189326`, 
        0.04559942288108005}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04963243132726989, 
        0.04543547930414081}, {-0.04988952445388645, 
        0.04527605997311495}, {-0.05151689941091097, 
        0.044157621917288725`}, {-0.05300677709796556, 
        0.0430151148129929}, {-0.05483171271657529, 
        0.041420955808361457`}, {-0.056415860597600336`, 
        0.0398062786322591}, {-0.05776532457987226, 
        0.038176695666262014`}, {-0.05860551051403017, 
        0.036948484021893026`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAVsKaTJAYrr9TWazQQcmiP9VmLCJi
Jq6/KvF9Fw61oj9LAcdXeDOuv9IKTXiHn6I/xlHFh0RArr9lWUWU/4miP7Ke
Su/GTK6/y5XMlnZ0oj9GAiGJ7FKuv49YsLqxaaI/IVnkx/9Yrr/tFGqo7F6i
P4s5TbMAX66/CgBZZSdUoj/uqRhT72Suv4hG2fZhSaI/CJAHr8tqrr85bURi
nD6iP0SKanHu4K6/+i7AT0JAoT8v/6UQQ+Suv/L43kGtN6E/duXdjoznrr/N
pB1tGC+hP49I2go+7K6/tDFJ524ioT+iYTV11/Cuv205XfnFFaE/mJhb21j1
rr/iVHqrHQmhP/ZOwErC+a6/rRy7BXb8oD8I0t3QE/6uv8gnNBDP76A/07OT
JYcGr78E662VgtagP/EyWEGbDq+/V0ZfHDm9oD+8GZqQUBavv9iHYuTyo6A/
dtRQXmRPr7+xJ2ckOFCfPyuiulZPZa+/knVOHShdnT9StWqlzlmvv6qESll3
cJs/A3MUdKwur7/8nSJOy4uZP+Or+l5KKK+/gcndgGpgmT+sUtTe
        "]]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.060766436461019535`, 
        0.024483422925945738`}, {-0.06043850152324602, 
        0.0233691423845216}, {-0.05982047980661405, 
        0.021824967785373496`}, {-0.059048901511468854`, 
        0.020314811106268486`}, {-0.05812376663781042, 
        0.018838672347206566`}, {-0.05706368742166312, 
        0.017401920439683062`}, {-0.0558872760990513, 
        0.016009924315193286`}, {-0.05459453266997498, 
        0.014662683973737252`}, {-0.054076209996140524`, 
        0.014183570354969888`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.05384776283308445, 
        0.01397240431397996}, {-0.053185457134434136`, 
        0.01336019941531495}, {-0.05163758229349916, 
        0.012098150089936865`}, {-0.05007822227443791, 
        0.010901019114210268`}, {-0.04842050390805585, 
        0.009752100361509022}, {-0.04667341407392483, 
        0.008653122051828933}, {-0.04522361487110341, 
        0.007812558824214166}, {-0.043729793996051064`, 
        0.007002919617674721}, {-0.04362023322288747, 
        0.006947306905361311}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.04334283075437394, 
        0.0068064982634449545`}, {-0.042196786338012715`, 
        0.006224769633889603}, {-0.0406294267862333, 
        0.0054786740745378145`}, {-0.03903255022995773, 
        0.004765198141298366}, {-0.037410991558430945`, 
        0.004084907035850268}, {-0.035769585660897864`, 
        0.0034383659598725192`}, {-0.034113167426603405`, 
        0.002826140115044125}, {-0.032446571744792485`, 
        0.0022487947030440953`}, {-0.03185556214570153, 
        0.002057239798344014}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.031559624653828285`, 
        0.001961322104045724}, {-0.030774633504710054`, 
        0.0017068949255514385`}, {-0.029102187595601015`, 
        0.0012010059842451574`}, {-0.027434068906710296`, 
        0.0007316930808042567}, {-0.025775112327282825`, 
        0.0002995214169077442}, {-0.024130152746563535`, \
-0.00009494380576537131}, {-0.02250402505379734, -0.0004511373855360863}, \
{-0.020901564138229158`, -0.0007684941207253959}, {-0.019489625269750087`, \
-0.001020202191967931}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.01918296219786623, -0.0010724483293307458`}, \
{-0.017744847375756066`, -0.0013029174052008481`}, {-0.016186081319871128`, \
-0.0015250731704510726`}, {-0.014643582193220702`, -0.0017178597094112443`}, \
{-0.01311975403005488, -0.001881778040857572}, {-0.011617000864623767`, \
-0.002017329183566265}, {-0.010137726731177438`, -0.0021250141563135343`}, \
{-0.00868433566396597, -0.00220533397787559}, {-0.007259231697239463, \
-0.0022587896670286417`}, {-0.006807433672684695, -0.002267567822119679}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0064963988149302505`, -0.0022736110362810906`}, \
{-0.005864818865248012, -0.0022858822425488993`}, {-0.004503501202241699, \
-0.0022871127232125727`}, {-0.0031776827424706026`, -0.0022629821277958726`}, \
{-0.0006421595696344518, -0.0021406417838261906`}, {
        0.0017225183792597557`, -0.001922869360849532}, {
        0.003917527551304258, -0.0016203404324102635`}, {
        0.00588025770449983, -0.0012586923395787025`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.006183749051609659, -0.001190648562157828}, {
        0.007811094861325789, -0.0008062797469116402}, {
        0.009490027270771851, -0.0003089188348882749}, {0.010977308364154111`,
         0.00023921522662712904`}, {0.012263125277207064`, 
        0.0008310370151165701}, {0.013337665145665227`, 
        0.0014594611080620545`}, {0.014191115105263108`, 
        0.0021174020829455888`}, {0.015597566204557163`, 
        0.003253827660172675}, {0.015981717990869462`, 
        0.004845177784679763}, {0.015972509716962457`, 
        0.005097342098108137}}]}, 
      {Arrowheads[{{0.00617569757995067, 1.}}], 
       ArrowBox[{{0.015961157092939555`, 0.005408228445675095}, {
        0.015928014004146403`, 0.006315836572325491}, {0.015436454244387977`, 
        0.007665804023109849}, {0.014547830289125515`, 
        0.008871208244804151}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00007403665322447384, 1.}}], 
       ArrowBox[{{-0.009378374126428638, 
        0.015866371596465055`}, {-0.00941407166293035, 
        0.01583725737214254}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{-0.1, 0.014798515734828276`}, {-0.09831937238805934, 
        0.013461453040655273`}, {-0.09629627190856026, 
        0.011906165581228735`}, {-0.09427317142906119, 
        0.010350878121802194`}, {-0.09326162118931165, 
        0.009573234392088925}, {-0.09225007094956211, 
        0.008795590662375657}, {-0.09123852070981257, 
        0.008017946932662386}, {-0.08992250678146568, 
        0.007656639386511617}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0896328957043681, 
        0.0075497442770028405`}, {-0.08773122869193771, 
        0.006428613770304778}, {-0.08570547680293329, 
        0.005290973684798071}, {-0.08556745384015764, 
        0.005215338616607544}, {-0.08542927557919579, 
        0.005139863111154403}, {-0.0831921111782745, 
        0.004129475739571658}, {-0.08095494677735321, 
        0.003119088367988912}, {-0.07871778237643193, 
        0.002108700996406166}, {-0.0785047267436538, 
        0.0020124770797753906`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.07822120783674671, 
        0.0018844293050897683`}, {-0.07648061797551065, 
        0.0010983136248234205`}, {-0.0741411061524323, 
        0.00041186547868829427`}, {-0.07188588044171858, \
-0.000541356147227225}, {-0.06961861385780993, -0.0014564672760312598`}, \
{-0.06733930640070632, -0.002333467907723809}, {-0.0666259962522887, \
-0.002596139035501835}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.06633406684831573, -0.002703639855367155}, \
{-0.06538111475199578, -0.003054557338335936}, {-0.06342036663697022, \
-0.0037485180225421528`}, {-0.06145706205562966, -0.004415349960342461}, \
{-0.05949120100797409, -0.00505505315173686}, {-0.057522783494003506`, \
-0.005667627596725349}, {-0.055551809513717916`, -0.0062530732953079305`}, \
{-0.05450306813798229, -0.0065497649878687725`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0542037229178319, -0.006634450537691883}, \
{-0.05357827906711732, -0.006811390247484602}, {-0.051602192154201705`, \
-0.0073425784532553644`}, {-0.04962986895250993, -0.00784730016827881}, \
{-0.047667629639580836`, -0.008326217648213528}, {-0.045715474215414414`, \
-0.008779330893059522}, {-0.04377340268001067, -0.00920663990281679}, \
{-0.04210972697876066, -0.00955238421371507}}]}, 
      {Arrowheads[{{0.003232094476792022, 1.}}], 
       ArrowBox[{{-0.04180505445601006, -0.00961525257166443}, \
{-0.03991951127549121, -0.009983845217065147}, {-0.039831242166616154`, \
-0.01}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.0002449316124642441, 1.}}], 
       ArrowBox[{{0.03602656720702168, 0.00691012704790293}, {
        0.03599154882317974, 0.006944220771007192}, {0.035956423415429525`, 
        0.006978267248250144}, {0.03591706339574822, 
        0.0070161104013939275`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03533494976736533, 0.010037417552888145`}, {
        0.03367398348302775, 0.011306235938658302`}, {0.03201301719869016, 
        0.01257505432442846}, {0.02960411586500613, 0.013194129196976524`}, {
        0.027965393183331605`, 0.013920077814507567`}, {0.02790954194788482, 
        0.0139436759796987}, {0.027853659665485853`, 0.013967212756632727`}, {
        0.025858438600566837`, 0.014528553506022966`}, {0.024135334359875978`,
         0.01501333619138729}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02383586708298948, 0.015097589103799353`}, {
        0.02186799647072881, 0.015651235004803445`}, {0.019872775405809794`, 
        0.016212575754193687`}, {0.018037103952254704`, 
        0.016512323228999728`}, {0.016201432498699615`, 
        0.016812070703805766`}, {0.014365761045144525`, 
        0.017111818178611807`}, {0.012530089591589435`, 
        0.017411565653417845`}, {0.011644500786393614`, 
        0.01745897994334365}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011333852147154846`, 0.017475612024236618`}, {
        0.010946287009381299`, 0.017496362202761587`}, {0.009362484427173166, 
        0.017581158752105325`}, {0.007778681844965029, 
        0.017665955301449068`}, {0.006194879262756894, 
        0.017750751850792806`}, {0.003733611727718712, 0.01757197710907736}, {
        0.0012723441926805294`, 0.01739320236736192}, {-0.0005919041775656344,
         0.017006219068933615`}, {-0.0010402621255831716`, 
        0.016913148295548703`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0013448622817823245`, 
        0.016849918966759126`}, {-0.002456152547811799, 
        0.016619235770505312`}, {-0.005022552098098628, 
        0.015591093333252294`}, {-0.006559178334981203, 
        0.014447074490595416`}, {-0.007232353877162297, 
        0.013297555811005916`}, {-0.007258619658836178, 
        0.01112057970442753}, {-0.005284324332902702, 
        0.009443704108685185}, {-0.0047947038791418504`, 
        0.009244022007511858}}]}, 
      {Arrowheads[{{0.011748984219772824`, 1.}}], 
       ArrowBox[{{-0.004506645102641923, 
        0.009126542884017114}, {-0.003935256090919837, 
        0.008893513079866518}, {-0.002542822495823766, 
        0.008541776330917432}, {-0.0010278765235779124`, 
        0.008353013800045085}, {0.0002358984540211874, 0.00837260442446099}, {
        0.0018541512308859775`, 0.008834614700886156}, {
        0.0022282474990180175`, 0.009522824505273291}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.08468577721048978}, {0.0488383883561993, 
        0.0847212235685285}, {0.04737649548641609, 0.08476109673845215}, {
        0.04592098915984104, 0.08479603881170013}, {0.04447186937647407, 
        0.0848260497882724}, {0.04302913613631529, 0.084851129668169}, {
        0.04159278943936465, 0.08487127845138989}, {0.040162829285622106`, 
        0.0848864961379351}, {0.03873925567508776, 0.08489678272780461}, {
        0.03755855790115146, 0.08490124453742598}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03724746603295379, 0.08490216066291878}, {
        0.03591126808364343, 0.08490256261751655}, {0.03450685410273349, 
        0.084898055917359}, {0.033108826665031704`, 0.08488861812052573}, {
        0.03171718577053802, 0.08487424922701678}, {0.028953063611175167`, 
        0.0848307181499718}, {0.02720837598213187, 0.08479362557336226}, {
        0.025476213740406647`, 0.0847503064787718}, {0.02480539392511477, 
        0.08473097903845295}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02449442940593249, 0.08472201963080163}, {
        0.02375657688599954, 0.08470076086620042}, {0.02204946541891059, 
        0.08464498873564814}, {0.020354879339139757`, 0.08458299008711494}, {
        0.018672818646687003`, 0.08451476492060084}, {0.017003283341552364`, 
        0.08444031323610582}, {0.015346273423735882`, 0.08435963503362988}, {
        0.013701788893237518`, 0.08427273031317303}, {0.012069829750057229`, 
        0.08417959907473528}, {0.012063005690787722`, 0.08417918039554187}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011752495998016017`, 0.08416012957218563}, {
        0.010450395994195054`, 0.08408024131831661}, {0.008843487625651038, 
        0.08397465704391703}, {0.0072491046444251375`, 0.08386284625153653}, {
        0.005667247050517316, 0.08374480894117513}, {0.004097914843927634, 
        0.08362054511283282}, {0.002541108024656062, 0.08349005476650959}, {
        0.000996826592702612, 0.08335333790220543}, {-0.0005349294519327238, 
        0.08321039451992038}, {-0.0006533831637541566, 
        0.08319876381177647}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009629878786653568, 
        0.08316836440914283}, {-0.002054160109249945, 
        0.08306122461965441}, {-0.0035608653792490452`, 
        0.08290582820140753}, {-0.005055045261930027, 
        0.08274420526517974}, {-0.006536699757292902, 
        0.08257635581097103}, {-0.008005828865337655, 
        0.08240227983878141}, {-0.009462432586064287, 
        0.08222197734861089}, {-0.010906510919472812`, 
        0.08203544834045945}, {-0.012338063865563208`, 
        0.0818426928143271}, {-0.013319387279500734`, 0.08170508749606926}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.013627466726504533`, 
        0.08166188729341278}, {-0.013757091424335496`, 
        0.08164371077021383}, {-0.015163593595789664`, 
        0.08143850220811966}, {-0.016557570379925717`, 
        0.08122706712804456}, {-0.017939021776743655`, 
        0.08100940552998856}, {-0.02066434840842518, 
        0.08055540277993381}, {-0.023337736513843625`, 
        0.08008065974649091}, {-0.025898039813302503`, 
        0.07960046588586524}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02620332662500502, 
        0.07954065244956338}, {-0.02852318621491945, 
        0.07908145019504709}, {-0.03103524781057683, 
        0.07855698367704617}, {-0.033493533902980516`, 
        0.07801594266419258}, {-0.03589804449213052, 
        0.07745832715648633}, {-0.03824877957802683, 
        0.0768841371539274}, {-0.03835275449409582, 0.07685739541693774}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.038654042682955456`, 
        0.07677990586648473}, {-0.04054573916066946, 
        0.0762933726565158}, {-0.042788923240058396`, 
        0.07568603366425153}, {-0.044978331816193644`, 
        0.07506212017713458}, {-0.0471139648890752, 
        0.07442163219516497}, {-0.04919582245870307, 
        0.07376456971834269}, {-0.050597776305084795`, 
        0.07329890417198093}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.050893009796004085`, 
        0.07320084098309063}, {-0.05122390452507726, 
        0.07309093274666774}, {-0.05319821108819775, 
        0.0724007212801401}, {-0.05511874214806455, 
        0.07169393531875981}, {-0.05698549770467767, 
        0.07097057486252685}, {-0.058799547257292084`, 
        0.0702346082404182}, {-0.06056196030516276, 
        0.06949000378141088}, {-0.06227273684828971, 
        0.06873676148550487}, {-0.06246808729480483, 0.06864705620403903}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.06275079843492622, 
        0.0685172347326755}, {-0.06393187688667293, 
        0.06797488135270016}, {-0.06553938042031242, 
        0.06720436338299679}, {-0.06709524744920818, 
        0.06642520757639472}, {-0.0685994779733602, 
        0.06563741393289398}, {-0.07005207199276851, 
        0.06484098245249455}, {-0.0714530295074331, 
        0.06403591313519644}, {-0.07280235051735393, 
        0.06322220598099963}, {-0.07371061203253534, 0.06264663903492418}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.07397338603244002, 
        0.062480118681363946`}, {-0.07410003502253104, 
        0.06239986098990416}, {-0.07534608302296443, 
        0.06156887816190999}, {-0.07654049451865408, 
        0.06072925749701715}, {-0.0776832695096, 
        0.05988099899522562}, {-0.07981390997726066, 
        0.05815856848094652}, {-0.08093556492420077, 
        0.05716561807422095}, {-0.08199442630529, 
        0.0561672295164948}, {-0.08299080713201629, 
        0.05516371805250089}, {-0.08353860395125924, 0.05457299320427078}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA7T46HqZwtb+E+Qi9F9OrP7GgJOwj
fLW/2NG6D0+6qz+ypueFsuq1v1kESuarsKo/AyWzwqBJtr9qJK60p6WpP1mm
a9pGUra/HWktteaKqT/5+uoKxlq2v4HaR98jcKk//MN4bh5jtr8dTVJZX1Wp
P4z0zho8Z7a/vRYSf/xHqT9s7c4dUGu2v89CH0eZOqk/z0HJelpvtr+OoTq2
NS2pP2ozEDVbc7a/nNAi0dEfqT/Ne/dPUne2vxaBlJxtEqk/9/kXf1Wrtr8q
GlwLfVWoP7+zFrcF2La/Uhjwz4SYpz+oqoPPytq2v+0s4mrCi6c/ulHfh4fd
tr8alcY3AH+nP/V9WSmq4La/bWZF/v9vpz8xklBIweO2v9V3AyEAYac/pR69
6czmtr8GbDqmAFKnPxjnmRLN6ba/EFQglAFDpz+J3+PHwey2v6uu5/ACNKc/
YqJSVZTytr8CjpOUBhanPw/8eTw5+La/UrIqJQz4pj9wNHOlsP22v0bH7tMT
2qY/mzOG0CUPt7//1V/9G2amP4JI0kg=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.09016457222790074, 
        0.043449897288789}, {-0.09049551630775243, 
        0.04235069787399732}, {-0.09092190044702189, 
        0.04008129191788069}, {-0.09109741261672982, 
        0.0378296068980198}, {-0.09103208615236268, 
        0.035600674194991265`}, {-0.09071324966803421, 
        0.03322399286757186}, {-0.09022174088358924, 
        0.031182000481847275`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.090147912347626, 
        0.030879848406453296`}, {-0.08934656587901484, 
        0.02859811458042141}, {-0.08829871857432395, 
        0.026348917620690356`}, {-0.08703466093782501, 
        0.024151003508172057`}, {-0.0855811862444975, 
        0.022013160300849804`}, {-0.08407807293509593, 
        0.02011216639730442}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08388065992953554, 
        0.019871921981708958`}, {-0.08210598568735666, 
        0.017917686601793454`}, {-0.08103132615544834, 
        0.01691146248621393}, {-0.0800513543443815, 
        0.015952570214173598`}, {-0.07902731881702371, 
        0.015009444258020858`}, {-0.07796086484733306, 
        0.014082458912549993`}, {-0.0768536377092676, 
        0.01317198847255529}, {-0.07570728267678548, 
        0.01227840723283104}, {-0.074687712949011, 0.011523686311303488`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.07443618423545782, 
        0.011340655835877051`}, {-0.07330377002440353, 
        0.010543409533371049`}, {-0.07147532313866797, 
        0.00932808809157928}, {-0.06958442298569217, 
        0.008149206390996564}, {-0.06763660365148781, 
        0.007007614792880591}, {-0.06563739922206657, 
        0.005904163658489034}, {-0.06378009959563334, 
        0.004937431071353366}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06350310693800891, 
        0.0047958580483581335`}, {-0.06150697142162022, 
        0.003815084225909894}, {-0.059386816222618474`, 
        0.0028311566502376697`}, {-0.05723741227244663, 
        0.0018887709833205948`}, {-0.05506429365711635, 
        0.0009887775864163431}, {-0.05287299446263932, 
        0.0001320268207825907}, {-0.05209380621401127, \
-0.000155282158980048}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05180192284220228, -0.0002629079014264691}, \
{-0.05066904877502724, -0.0006806309523229763}, {-0.0484579906802918, \
-0.0014483453716426713`}, {-0.04624535426444469, -0.0021702660759188182`}, \
{-0.044036673613497584`, -0.0028455427038937406`}, {-0.04183748281346218, \
-0.003473324894309751}, {-0.03993171738420927, -0.003978905199540318}}]}, 
      {Arrowheads[{{0.017710729891847042`, 1.}}], 
       ArrowBox[{{-0.039630923252489444`, -0.004058277636197741}, \
{-0.03747946121242479, -0.004588185504258964}, {-0.035309567444309374`, \
-0.005084754132818076}, {-0.033146709716556026`, -0.005542861247166733}, \
{-0.030993963099716793`, -0.005962899922885169}, {-0.02885440266434371, \
-0.0063452632355536255`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAeG5F5qgKpD97FK5H4XqEv+mo9TgZ
IaQ/bKdWKDoXhL90NCpw6qWkPz18a9YNOoG/mKaHzr8LpT/WvZ69BLR8v/YT
pTrZU6U/3Ay4Ghj1dr/yWvychX+lP8EcJb3UPXG/Sgs2FWGCpT9R/X8zK6xw
v8+VjKX3hKU/VXBkoqYacL/hdc2pSYelP+FtJxWREm+/ZQ5HEVmIpT8LaKOv
UIFuvynKRnhXiaU/Nu4rpSTwbb+1wVrqRIqlPyy+eVQNX22/oHkVcyGLpT97
aPEbC85sv9ZPDR7ti6U/ZtGtWR49bL+qC4OK3o6lP6A0eGd4j2G/Cxx5X0OO
pT/eK/9iJthgv033MNNjjaU/pUJVPwwPYL+Z+GD8ZIylP1Hg1A1bjF6/WKiI
/EaLpT91i9dRFvtcvw3SM/UJiqU/nwZvJkxqW7/cRfoHroilP70ZumT+2Vm/
8fIQpbiFpT//rBtfX7pWv5Ii67dIgqU/5B4+p8CcU7/PFk9OX36lP/pa6Mkw
gVC/7FGkXQw+pT+lmKAWVitMP4yFsCN0FKU/oznD44yOWT+g/8tF
        "]]}, 
      {Arrowheads[{{0.008202093215599887, 1.}}], 
       ArrowBox[{{0.041043256057594575`, 0.00184321694036197}, {
        0.04067135832274432, 0.0026638004271877644`}, {0.03955892181982868, 
        0.004394069533749528}, {0.03818409687998502, 
        0.006040920832743355}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00011394708954102493`, 1.}}], 
       ArrowBox[{{0.029898937151325203`, -0.00205622499323521}, {
        0.029926778572723585`, -0.0019910241004521606`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.05098885403379697}, {0.04938465985292061, 
        0.051055022206430996`}, {0.04762080523628718, 
        0.051234921513801185`}, {0.04586919694553468, 0.05140373412781086}, {
        0.0441298349806631, 0.05156146004846002}, {0.04240271934167245, 
        0.05170809927574866}, {0.04068785002856273, 0.05184365180967679}, {
        0.038985227041333934`, 0.0519681176502444}, {0.03760341906062265, 
        0.05206080007661681}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03729302221354512, 0.05208160823553669}, {
        0.035616720044519115`, 0.05218378925129808}, {0.03395083603493306, 
        0.052274995011784155`}, {0.03229719835122796, 
        0.052355114078909706`}, {0.030655806993403794`, 
        0.05242414645267474}, {0.029026661961460525`, 
        0.052482092133079264`}, {0.027409763255398206`, 
        0.05252895112012327}, {0.025805110875216808`, 0.05256472341380676}, {
        0.02486049408516117, 0.05257910890697143}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024549436593131354`, 0.052583845976513825`}, {
        0.02363928310463455, 0.05259770663082931}, {0.021502628336668612`, 
        0.05261419094218446}, {0.019395146571318966`, 0.0526141763478722}, {
        0.017316837808585582`, 0.052597662847892544`}, {0.015267702048468515`,
         0.05256465044224548}, {0.01324773929096774, 0.05251513913093101}, {
        0.012107428192171364`, 0.05247732891874075}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.01179650550547021, 0.05246701940516033}, {
        0.011256949536083229`, 0.05244912891394914}, {0.009295332783815034, 
        0.052366619791299876`}, {0.007362889034163128, 
        0.052267611762983196`}, {0.005459618287127495, 0.05215210482899912}, {
        0.0035855205427081684`, 0.05202009898934764}, {0.0017405958009051245`,
         0.051871594244028756`}, {-0.00007515593828162637, 
        0.051706590593042466`}, {-0.0006182815831945451, 
        0.051651413235830036`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009277820683079944, 
        0.05161997038465098}, {-0.0018617346748520773`, 
        0.05152508803638878}, {-0.003619140408806249, 
        0.051327086574067676`}, {-0.005347373140144138, 
        0.05111258620607918}, {-0.007044752925597188, 
        0.05088419696425865}, {-0.008709599821896867, 
        0.05064452888044147}, {-0.010341913829043163`, 
        0.05039358195462763}, {-0.0119416949470361, 
        0.05013135618681712}, {-0.013249586392396689`, 
        0.049903112611325365`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.013555957687739345`, 
        0.049849127512926424`}, {-0.015043658515561848`, 
        0.04957306812520615}, {-0.01654584096609467, 
        0.04927700583140567}, {-0.018015490527474122`, 
        0.04896966469560853}, {-0.019452607199700198`, 
        0.04865104471781474}, {-0.02085719098277291, 
        0.04832114589802429}, {-0.022229241876692243`, 
        0.04797996823623719}, {-0.02356875988145821, 
        0.047627511732453415`}, {-0.025668816310113706`, 
        0.0470265226316029}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02596790358725789, 
        0.04694093055354537}, {-0.026150197223530028`, 
        0.046888762198895914`}, {-0.028601503008988345`, 
        0.046104897297351774`}, {-0.030923945814057625`, 
        0.045286091916773824`}, {-0.033118794214962305`, 
        0.04444252094611489}, {-0.035186048211702375`, 
        0.043574184385374956`}, {-0.03712570780427784, 
        0.04268108223455404}, {-0.0375619356091224, 0.042460119196186516`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.037839457338460614`, 
        0.04231954575303007}, {-0.0389377729926887, 
        0.041763214493652126`}, {-0.04062224377693495, 
        0.04082058116266923}, {-0.0421791201570166, 
        0.039853182241605334`}, {-0.04360840213293364, 
        0.03886101773046045}, {-0.04540885106080353, 
        0.037434324566857566`}, {-0.04697273940426653, 
        0.03598420623480768}, {-0.047833133435421914`, 
        0.035037191446654944`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAA+GevAAGZqL8b6WD/NtKhPwYJ/xKU
u6i/RHqf1iisoT96EXeJ+0ypv+j7XwxA6qA/kUWbhfFZqb+Qn7JxzdagP+he
vuieZqm/M2N76VjDoD9LC+jwA3Opv7eJd6Hir6A/4xtjZBt5qb/DE1viJqag
Pw1qhdggf6m/pZxcxGqcoD/YSCdVFIWpvyX8JE2ukqA/NC4m4vWKqb/wtVmC
8YigP0ILZIfFkKm/nmOdaTR/oD+T5eodo/+pv5nFinYsUJ8/b1Sf9tACqr/o
pTOapUGfP8+d+kP1Baq/vdyx8x4znz/IfRldBAuqv4pm/Kn5Gp8/Oa6nR/kP
qr86wJ411QKfP9ImqBPUFKq/E76YqrHqnj+K0ifRlBmqv+b02RyP0p4/O3o9
kDseqr+ntUGgbbqePyfC3zFVJ6q/fhjs8CyKnj+GBA9bBzCqv1xpVyTxWZ4/
eSBgjVI4qr/SMwfYuimeP2aUvoqSdaq/iup4oEpJnD8SXAQL2Yyqv3Tc04KJ
bZo/vSr76T6Aqr8+PvyTmZiYP/RqrIKvbqq/Q/dqKyPqlz99ldlW
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.051564320644137844`, 
        0.023049125225896153`}, {-0.05140633787110301, 
        0.02226433571047382}, {-0.0504289604993101, 
        0.019669409161501505`}, {-0.049753085610784994`, 
        0.01841507906751103}, {-0.04895241992050746, 
        0.01718950442718434}, {-0.048042142180405464`, 
        0.015996970330217183`}, {-0.04703743114240697, 
        0.014841761866305293`}, {-0.04593828680651199, 
        0.013723879035448675`}, {-0.04491333403479077, 
        0.012795979531022053`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.04467944319712227, 
        0.012591027662745405`}, {-0.043438410256267185`, 
        0.01159665359458439}, {-0.04212302197082238, 
        0.010603348816722053`}, {-0.040727830775293364`, 
        0.009650119014568468}, {-0.039260151863586286`, 
        0.008738338859450382}, {-0.037974253258891075`, 
        0.008002407359440085}, {-0.03664838395345479, 
        0.007294883168117459}, {-0.03528712062306332, 
        0.00661627815102054}, {-0.03412512436885579, 0.006074400269180983}}]}, 
      {Arrowheads[{{0.017385544127269406`, 1.}}], 
       ArrowBox[{{-0.03384259911214696, 
        0.005944208803642243}, {-0.03247671859055847, 
        0.005347873101655976}, {-0.03103673324001688, 
        0.0047590968004643935`}, {-0.029579660567663726`, 
        0.004201287135650661}, {-0.028110077249284916`, 
        0.003674955972752817}, {-0.026632559960666338`, 
        0.003180615177308892}, {-0.0251516853775939, 
        0.00271877661485692}, {-0.02367203017585351, 
        0.002289952150934939}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.06780554032162533}, {0.04982312347124909, 
        0.06782079447216335}, {0.04707608062931595, 0.06805770439651096}, {
        0.04432903778738281, 0.06829461432085858}, {0.041581994945449674`, 
        0.06853152424520619}, {0.03958924302618612, 0.06812851814798392}, {
        0.03762855513760812, 0.06818120116703189}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03731757381813086, 0.06818955712968816}, {
        0.03724796038257881, 0.068191427619108}, {0.034928622005697414`, 
        0.06823869129477153}, {0.03263122789554191, 0.0682703091749745}, {
        0.030355778052112307`, 0.06828628125971689}, {0.030050017151190152`, 
        0.06828738160296668}, {0.029744667427548437`, 0.06828820400064596}, {
        0.027843929917373146`, 0.06820014013133695}, {0.025943192407197863`, 
        0.06811207626202795}, {0.024879833390363974`, 0.06806280932801644}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024569073190405525`, 0.06804841136644148}, {
        0.024042454897022572`, 0.06802401239271895}, {0.02214171738684728, 
        0.06793594852340995}, {0.020240979876671995`, 0.06784788465410095}, {
        0.018340242366496704`, 0.06775982078479194}, {0.016439504856321417`, 
        0.06767175691548294}, {0.014538767346146128`, 0.06758369304617394}, {
        0.013324919973275286`, 0.06716714269906762}, {0.01220727786697345, 
        0.06710541652939847}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011896657678228497`, 0.06708826131095688}, {
        0.011455885084821742`, 0.06706391791539874}, {0.00960798527751603, 
        0.06695058585548995}, {0.007781220551358141, 0.06682714651934124}, {
        0.0059755909063480845`, 0.0666935999069526}, {0.0041910963424858574`, 
        0.06654994601832406}, {0.002427736859771455, 0.0663961848534556}, {
        0.0006855124582048865, 0.06623231641234721}, {-0.0005076529051414639, 
        0.06611213998691066}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0008171804022160771, 
        0.06608096416726701}, {-0.0010353876011744388`, 
        0.06605898619004699}, {-0.002734774057327114, 
        0.06587683968160304}, {-0.004412646910253129, 
        0.06568587688701534}, {-0.0060690061599524975`, 
        0.06548609780628388}, {-0.0077038518064252125`, 
        0.06527750243940869}, {-0.009317183849671264, 
        0.06506009078638976}, {-0.010909002289690667`, 
        0.06483386284722707}, {-0.012479307126483418`, 
        0.06459881862192064}, {-0.01315756678733273, 0.06449202517926285}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.013464874409045754`, 
        0.06444363893315082}, {-0.014028098360049507`, 
        0.06435495811047047}, {-0.015555375990388948`, 
        0.06410228131287656}, {-0.01706114001750173, 
        0.06384078822913888}, {-0.01854539044138786, 
        0.06357047885925748}, {-0.020008127262047336`, 
        0.06329135320323233}, {-0.021449350479480163`, 
        0.06300341126106343}, {-0.022869060093686326`, 
        0.06270665303275079}, {-0.02426725610466584, 
        0.0624010785182944}, {-0.02564358900089361, 
        0.06208793973909709}, {-0.02567925322229581, 0.06207952617920313}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02598203538223215, 
        0.0620080967258942}, {-0.02699770927084454, 
        0.061768488716561695`}, {-0.02832961691451865, 
        0.06144272545068821}, {-0.02963931193191592, 
        0.061110649941476636`}, {-0.03219206408787997, 
        0.06042756219303921}, {-0.034655965738736694`, 
        0.059719225471249415`}, {-0.03703101688448609, 
        0.05898563977610726}, {-0.03796667746887907, 0.05867507574390498}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.038261931722836394`, 
        0.05857707508729578}, {-0.03931721752512815, 
        0.058226805107612745`}, {-0.04151456766066289, 
        0.057442721465765866`}, {-0.0436230672910903, 
        0.056633388850566624`}, {-0.04564409782006646, 
        0.055803563190176736`}, {-0.04757904065124746, 
        0.054958000412757904`}, {-0.0494278957846333, 
        0.05409670051831014}, {-0.04978984789087161, 
        0.053916616981966294`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.050068372606760156`, 
        0.053778041422018176`}, {-0.05119066322022397, 
        0.05321966350683344}, {-0.05286734295801948, 
        0.0523268893783278}, {-0.05445793499801983, 
        0.05141837813279323}, {-0.05596243934022501, 
        0.05049412977022972}, {-0.057380855984635035`, 
        0.04955414429063727}, {-0.05863034184668729, 
        0.04866587080384044}, {-0.05981019427340062, 
        0.04777123423877238}, {-0.06056945518797262, 
        0.047155055071828066`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06081101137401666, 
        0.04695901983989364}, {-0.06092041326477502, 
        0.04687023459543309}, {-0.06196099882081049, 
        0.04596287187382256}, {-0.06383326962686466, 
        0.04412905719578781}, {-0.0654270066915631, 
        0.04226979020466814}, {-0.06675742224245047, 
        0.04039750536599532}, {-0.0678397285070714, 
        0.038524637145301126`}, {-0.06840623358220964, 
        0.03725237187881967}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06853277718759558, 
        0.03696817842514479}, {-0.0686739254854259, 
        0.036651185542585576`}, {-0.06926001317751398, 
        0.03477715055784864}, {-0.06961607406725152, 
        0.03291288059022965}, {-0.06976019063855446, 
        0.031068724038867908`}, {-0.06969236289142278, 
        0.02924468090376341}, {-0.06941259082585648, 
        0.02744075118491616}, {-0.06865934261666261, 
        0.024813505990256973`}, {-0.06865871726012338, 
        0.024812076272289395`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06853404937696785, 
        0.02452705500626658}, {-0.06754816152543457, 
        0.022273074297779073`}, {-0.06685834614905772, 
        0.021035413514858103`}, {-0.06607904755217235, 
        0.019819456107482467`}, {-0.06521026573477842, 
        0.01862520207565215}, {-0.06425200069687596, 
        0.01745265141936716}, {-0.0632202505694845, 
        0.01630589604560853}, {-0.06213101348362361, 
        0.015189027861357311`}, {-0.06138448644231052, 
        0.014481394050082743`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06115870729352353, 
        0.014267377744281632`}, {-0.06098428943929327, 
        0.014102046866613493`}, {-0.05978007843649348, 
        0.013044953061377075`}, {-0.05851838047522425, 
        0.012017746445648063`}, {-0.05719919555548558, 
        0.011020427019426461`}, {-0.05582252367727747, 
        0.010052994782712266`}, {-0.05438836484059992, 
        0.009115449735505474}, {-0.05269617331775597, 
        0.008183711951098151}, {-0.05127214589270283, 
        0.007320962929974753}, {-0.05098687688308677, 
        0.007159947977241838}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05071595928995546, 
        0.007007033422971596}, {-0.049798175549093604`, 
        0.006489006926322693}, {-0.04827803430688499, 
        0.005688296854123941}, {-0.04671549418603365, 
        0.004919285627360463}, {-0.04511432720649628, 
        0.004182426160014225}, {-0.04347830538822957, 
        0.003478171366067197}, {-0.041811200751190186`, 
        0.0028069741595013447`}, {-0.03998519014241869, 
        0.002119301418289559}, {-0.03938336578445284, 
        0.0019072192945691427`}}]}, 
      {Arrowheads[{{0.007955119459641224, 1.}}], 
       ArrowBox[{{-0.039089957644925157`, 
        0.00180382264648695}, {-0.038135293854590614`, 
        0.0014674003641162864`}, {-0.03626658285081287, 
        0.0008514237021442529}, {-0.03438412809419236, 
        0.00027152413753618425`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.000178972576297702, 1.}}], 
       ArrowBox[{{0.02813484093774985, 0.00551103465335591}, {
        0.028098883054196968`, 0.005566140452287644}, {0.028073696752789715`, 
        0.005604099264079505}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.018922023806045057`, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAA0J+hnKICiz97FK5H4XqEv4l8qkXk
EI8/EGK906tBg7/qDF9R2cSRP019iBAboIG/hDp1UsDGkz9m7kXxPMd/v1tg
/GbrjpU/sbQY22AgfL8Nfx2EY7mVP/haLA+bwHu/bDTgnkrjlT8tSC6wdWB7
v1VTqQWhDJY/XToXrvL/er8rdO8LFiGWPxuGA5uOz3q/2WFAA2c1lj8cJm/Y
E596v9HU1vWTSZY//Pjbo4Juer9Z0QXunF2WP45wrzrbPXq/mJE19oFxlj/4
EDbaHQ16vw8LsK1JtZc/M/GAdiWxdr8/1A6Cgr+XP74MHR25k3a/q15XO6/J
lz9PKwavRnZ2v5pEEqaM05c/NtcoWHRZdr/deEuIXt2XP62voVmcPHa/80+9
oQbslz820yA+TxF2vyZ8spi+9Zc/ChHUq2r0db+ysykOa/+XP6B8JpOA13W/
Ooqmp7FdmD8WyVfAOLV0v+EHreU=
        "]]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.009388626296956044}, {0.04895160340911363, 
        0.010152812442330536`}, {0.047180415202168376`, 
        0.01144384820147385}, {0.04540922699522312, 0.012734883960617161`}, {
        0.04305736893210842, 0.013516197418736525`}, {0.04082162896563594, 
        0.01458909592554593}, {0.04074524307693273, 0.0146240566994313}, {
        0.04066880253799799, 0.014658932295889758`}, {0.039116925699704236`, 
        0.015179070502851862`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03882195911495751, 0.015277933625696443`}, {
        0.03858020208789961, 0.015358962650340332`}, {0.03649160163780124, 
        0.016058993004790904`}, {0.03440300118770287, 
        0.016759023359241475`}, {0.0323144007376045, 0.017459053713692045`}, {
        0.030287282220377177`, 0.017937993235558433`}, {0.02826016370314986, 
        0.01841693275742482}, {0.02688353220027116, 0.018742184205809177`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.026580774129721367`, 0.018813715694628412`}, {
        0.026233045185922538`, 0.018895872279291213`}, {0.02420592666869522, 
        0.0193748118011576}, {0.02233977359086555, 0.019646674200608845`}, {
        0.020473620513035886`, 0.019918536600060092`}, {0.018607467435206224`,
         0.020190398999511337`}, {0.01674131435737656, 0.02046226139896258}, {
        0.015066529627151944`, 0.020568279773210598`}, {0.01428612432216911, 
        0.020617681526281104`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.013975652206683025`, 0.020637335245555676`}, {
        0.013391744896927332`, 0.020674298147458615`}, {0.011716960166702718`,
         0.020780316521706636`}, {0.0100421754364781, 
        0.020886334895954654`}, {0.008848923618967029, 0.02069982365807015}, {
        0.007259115285103629, 0.0207542191595889}, {0.005725957882147704, 
        0.02077419941262147}, {0.004249451410099253, 0.02075976441716786}, {
        0.002430644615593835, 0.020694460532580686`}, {0.0015584902787249668`,
         0.02063662110879155}}]}, 
      {Arrowheads[{{0.0177385582087401, 1.}}], 
       ArrowBox[{{0.0012480785744421196`, 0.02061603526365595}, {
        0.0007060464855536712, 0.02058008884640934}, {-0.0009243429800212478, 
        0.02041664935865381}, {-0.002460523781130926, 
        0.020204142069314104`}, {-0.003895480200483289, 
        0.019949625624156114`}, {-0.005222196520786262, 
        0.019660158668945747`}, {-0.00644067274203985, 
        0.019335741203682998`}, {-0.007550908864244057, 
        0.018976373228367868`}, {-0.009452789599394365, 
        0.018182406220128466`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAmpmZmZmZqT8Ypz91Bntgv2l+SA+n
hak/F6NmyFXdVr+jGP1/wy+pP8CoA3bD6zE/cBXOp5y9qD/PS2JxpAhfP685
lxm7sKg/Pid5hCzSYD/1qm6Tl6OoP1I/8q3iHmI/sw2cqTKWqD/5hor0cWpj
P7W1Btlnj6g/sQxUPsoPZD+BvCDnjIioP7B3mcrXtGQ/6BNy5qGBqD+i1phD
mlllP0xCgummeqg/8GwUVBH+ZT8WadgCnHOoP/0fQqc8omY/jr+HJXPtpz+z
F8AmOeFwPzlYnrqb6Kc/ixaP4HwQcT8QVdUiv+OnP72GmB2yP3E/xEloFPnc
pz/tsn+nwoBxPxmSPkMp1qc/DO9oTLfBcT9SnWu+4cunP6KwFc34InI/OgHV
GfzEpz/TgrZprmNyP3/uX9EMvqc/MiMq5Eekcj9wKNFnqnanPxMsPr0qJHU/
BToIPLArpz9ZrDIRvJh3P1M7uAxG3aY/DE0cTLQBej977oWPk4umP+2IgPvP
Xnw/Gn98tSnxpT+2n21xKjmAP7nFvtY=
        "]]}, 
      {Arrowheads[{{0.011315963589152258`, 1.}}], 
       ArrowBox[{{0.04261790243740178, 0.008122288276078334}, {
        0.04238819226509631, 0.00831633461187302}, {0.04062901242623458, 
        0.009629566643955846}, {0.03875609397294561, 0.010866053776919541`}, {
        0.036769436905229394`, 0.012025796010764101`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAE9b1gb42nz97FK5H4XqEv6s0Mhrl
qZ8/twBQvHjVg78ymYW7WIagP9cl/ADMdoG/rviSHYGWoD+oDm+pgjmBvwGy
DARhpqA/y/85RyH8gL+uZdmn+LWgPwlwPLOovoC/D5LbcKm9oD9L2l7z45+A
v0Tkvz5IxaA/lRn/txmBgL8aKsgY1cygP9U/9RtKYoC/hlQ+BlDUoD8WEwo6
dUOAv01ucw6526A/BPP4LJskgL+zQguILlyhPxKEMxlFp3u/fAS1MRhgoT9e
IJqyCX97v34C+Kb6Y6E/ZzfHsstWe799hTpf1GehPyQ7DLlgLnu/KUgZ3KZr
oT84rBlR8wV7v43qktpWcaE/MTdLWUvJer/Mky0ZGXWhP4erxafYoHq/HYfx
ItR4oT8730CxY3h6v9JcRMiYnKE/2yLiTmXjeL+1NRdblr2hP+JeViO+TXe/
BQVSs9XboT/zPyRVord1v6NA8vLVTKI/MLKJ/a+ga7+Ds5cQ/n6iP6EAR8RT
5Ve/nPY+ekh3oj/UOQfuC5M7P6zm0Z/FdqI/W4EqIVeVPD/q/81E
        "]]}, 
      {Arrowheads[{{0.005627739036032879, 1.}}], 
       ArrowBox[{{0.03598601978561795, 0.0007377167190624673}, {
        0.035603988670407614`, 0.002245914132638968}, {0.03477166441436566, 
        0.004004576706837542}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAmpmZmZmZub/iBWWnu8GdP5w6MIR/
c7m/1a/ZTQOdnD/31Ll8jUS5v80hWL/EVps/0IJoxcURub+FReWepxSaP40F
wP4qB7m/QzS6yb3UmT8j2kSAavy4v/C/2xgAlZk/ofIPjITxuL8vaR3YblWZ
P2lPZpgD7Li/Xn749rY1mT/KdhZgeea4v/lBAU4KFpk/u6xi6+XguL9uQoDm
aPaYP9P3jEJJ27i/huqyydLWmD82J9dto9W4v6vmzABIt5g/Ud+maWiRuL/E
VDwnsEuXPwziGAiLSLi/v2M9ck/mlT/wj/OXd0O4v2eU8kRkzpU/sciP+l4+
uL8yqFKWgLaVP/0NKwYs97e/bMtO+xDQlD9JU8YR+a+3v6XuSmCh6ZM/oVUO
wlOot78o9taH4tCTPwXCp6Y=
        "]]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.09217037600389037, 
        0.01915583872137811}, {-0.09144247262301726, 
        0.018566873231763977`}, {-0.09035606146505117, 
        0.017687829808712058`}, {-0.08926965030708507, 
        0.016808786385660142`}, {-0.08818323914911896, 
        0.015929742962608223`}, {-0.08709682799115287, 
        0.015050699539556307`}, {-0.08601041683318678, 
        0.014171656116504389`}, {-0.08431141324912148, 
        0.013816386845745788`}, {-0.08319672859456619, 
        0.012961517614338176`}, {-0.08208787535720002, 
        0.012141026672180871`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08183498495187733, 
        0.011959855101762668`}, {-0.08091081229227721, 
        0.011300127534811568`}, {-0.07973958064454355, 
        0.010493606686692572`}, {-0.07854949999908374, 
        0.009703201966336446}, {-0.0773405703558978, 
        0.008928913373743191}, {-0.07611279171498574, 
        0.008170740908912809}, {-0.07392464442328714, 
        0.006880081710700578}, {-0.07169883056284233, 
        0.005638607749235873}, {-0.07126543113134165, 
        0.005410314520448474}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.07099018806465306, 
        0.005265330185378836}, {-0.06943535013365135, 
        0.0044463190245186916`}, {-0.06713420313571417, 
        0.0033032155365490313`}, {-0.06479538956903079, 
        0.002209297285326896}, {-0.06241890943360122, 
        0.0011645642708522847`}, {-0.06000476272942546, 
        0.00016901649312519738`}, {-0.059699124911201266`, 
        0.000051044955297037094`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.05940890046770866, -0.00006097725488976028}, \
{-0.05755294945650351, -0.0007773460478543632}, {-0.05508320864864688, \
-0.001674272461346979}, {-0.052615279339667115`, -0.002521511856613233}, \
{-0.050149161529564196`, -0.003319064233653123}, {-0.04768485521833814, \
-0.004066929592466647}, {-0.047636464848902944`, -0.0040806494621139795`}}]}, 
      {Arrowheads[{{0.015736864089541065`, 1.}}], 
       ArrowBox[{{-0.04733716845463875, -0.004165507411394997}, \
{-0.04522236040598894, -0.004765107933053805}, {-0.04276167709251659, \
-0.0054135992554146}, {-0.0403028052779211, -0.006012403559549029}, \
{-0.03784574496220247, -0.006561520845457092}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.06842175814333067, 0.09}, {-0.06884371314922912, 
        0.08984736732764766}, {-0.07028115743784755, 
        0.08931291278076658}, {-0.07169491977789656, 
        0.08877253303043822}, {-0.07308500016937615, 
        0.08822622807666258}, {-0.07446323958657108, 
        0.08767696052116326}, {-0.07584147900376602, 
        0.08712769296566394}, {-0.07721971842096095, 
        0.08657842541016463}, {-0.07859795783815589, 
        0.0860291578546653}, {-0.07997619725535084, 
        0.08547989029916599}, {-0.08000969800909385, 0.08546653929723828}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08029868754254957, 
        0.08535136875964826}, {-0.08135443667254577, 
        0.08493062274366667}, {-0.08336228562732934, 
        0.08367572559966865}, {-0.08497591847766373, 
        0.08286413654411813}, {-0.08654628292640675, 
        0.0820449048549977}, {-0.0880733789735584, 
        0.08121803053230735}, {-0.08955720661911869, 
        0.0803835135760471}, {-0.08975464499690484, 
        0.08027031367814116}, {-0.0899513010347956, 
        0.08015698598040832}, {-0.09114108359650391, 0.07929622507734586}}]}, 
      {Arrowheads[{{0.01788286739773963, 1.}}], 
       ArrowBox[{{-0.09139313243886432, 
        0.07911387765005251}, {-0.0917379121952076, 
        0.0788644430525227}, {-0.0935245233556196, 
        0.07757190012463706}, {-0.09531113451603161, 
        0.07627935719675143}, {-0.09709774567644361, 
        0.07498681426886579}, {-0.09814087876486086, 
        0.07362865943709751}, {-0.09979628791256791, 
        0.07232453793793847}, {-0.1, 0.0721540992846921}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00011995339195699382`, 1.}}], 
       ArrowBox[{{-0.029939457288541416`, 
        0.02284271973697591}, {-0.029974318768222593`, 
        0.022776728601839397`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.03161100969749756}, {0.048373597924836635`, 
        0.031958188113914265`}, {0.04620248514289684, 
        0.032396053903047166`}, {0.04404481806800401, 
        0.032805460721674486`}, {0.04190059670015816, 0.03318640856979622}, {
        0.03976982103935927, 0.03353889744741237}, {0.03776103494935623, 
        0.03384631612299257}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03745316646745303, 0.03389095849272331}, {
        0.0351365604176634, 0.03421674416304723}, {0.03265589187360991, 
        0.034534428974795105`}, {0.030210485453446897`, 
        0.03481598178976656}, {0.027800341157174318`, 0.03506140260796161}, {
        0.02542545898479219, 0.03527069142938024}, {0.025091215294703633`, 
        0.03529542902558512}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024780970269783143`, 0.035318390464734575`}, {
        0.023085838936300524`, 0.03544384825402246}, {0.0207814810116993, 
        0.035580873081888266`}, {0.01851238521098853, 0.03568176591297766}, {
        0.016284505991164256`, 0.03574982929190849}, {0.014103797809222511`, 
        0.03578836576329859}, {0.012349572013445565`, 0.03579577355995087}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012038481226999414`, 0.03579708724333869}, {
        0.0119702606651633, 0.03579737532714797}, {0.009883894558986634, 
        0.03577685798345662}, {0.0078446994906925, 0.03572681373222454}, {
        0.005852675460280897, 0.03564724257345175}, {0.003907822467751829, 
        0.03553814450713823}, {0.0020101405131053027`, 0.03539951953328398}, {
        0.00016278385129514863`, 
        0.035235008816020465`}, {-0.0003845742778197562, 
        0.03517802496304734}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0006939955592614397, 
        0.035145812018960915`}, {-0.0016310932627248056`, 
        0.03504825351947913}, {-0.003371490828954553, 
        0.03483925364365999}, {-0.005058408847394092, 
        0.03460800918856302}, {-0.006691847318043423, 
        0.034354520154188245`}, {-0.008271806240902551, 
        0.03407878654053565}, {-0.009798285615971472, 
        0.03378080834760524}, {-0.011271285443250182`, 
        0.033460585575397016`}, {-0.012702951555182567`, 
        0.03311722012660981}, {-0.012948807276267448`, 
        0.033052654661005224`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAqHmLX6gii78ngbih6+GgP3/vBRsi
1Yy/4fLmPGXFoD+I9KqbeQ+Rv6QjnFouYKA//iDdqo55k7/q6ShCKeafP6EK
XYQjtJO/srw5QIjPnz/iHYDKIu6Tv7W+UUzEuJ8/PokSo4wnlL/ei6bi3aGf
PylzPpEJRJS/qkmH5F2Wnz8ziN8yYWCUv06JbHfVip8/ceMjjZN8lL+t7seq
RH+fPxxuU6WgmJS/3UsGjqtznz+Ym8yAiLSUv483kDAKaJ8/GfEOK2eelr9F
taVroIueP/TltEAbrpa/rKpVgwOEnj+wRtkFwb2Wvz4Pg9djfJ4/XiKjMPLX
lr+20/rsdG+ePyl575P68Za/IN1dVX5inj/lv8042guXv+KnKSKAVZ4/SUxq
KJEll7/BqNRkekiePxw2DmwfP5e/A0POLm07nj/C/Eyu6nGXv7goKPRDIZ4/
jqdljBOkl7/8+dph/QaeP7IhMFOa1Ze/rUC9AprsnT9AUQxyoFmZvy5jqzy8
CZ0/OorGIQ==
        "]]}, 
      {Arrowheads[{{0.008486513130578332, 1.}}], 
       ArrowBox[{{-0.025024520953089692`, 
        0.028200430747404314`}, {-0.025033734274305122`, 
        0.02819504398622175}, {-0.026555988019017478`, 
        0.027132934111463315`}, {-0.027848555208710494`, 
        0.02604414914685481}, {-0.029045904368858167`, 
        0.024804689698229212`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00009820940096230894, 1.}}], 
       ArrowBox[{{-0.02754130010533793, 
        0.015285100321872868`}, {-0.027514177224869242`, 
        0.015230345189921952`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.1, 0.0002991732462123814}, {-0.09951263979018063, 
        7.667222520033913*^-6}, {-0.09737314605340266, \
-0.0003531649267688084}, {-0.0960404479021513, -0.0009672306231945136}, \
{-0.09470120498238764, -0.001570266310887317}, {-0.09335541729411168, \
-0.0021622719898472193`}, {-0.09200308483732345, -0.0027432476600742195`}, \
{-0.09182003859974804, -0.0028209516535752017`}, {-0.09163688896071782, \
-0.002898454291421488}, {-0.08945064382267695, -0.0036969064700342774`}, \
{-0.08841483571892084, -0.004075200387161056}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0881226205907266, -0.004181922090811992}, \
{-0.08726439868463608, -0.004495358648647067}, {-0.0850781535465952, \
-0.005293810827259857}, {-0.08289190840855433, -0.006092263005872647}, \
{-0.08069121569838474, -0.006660457374978683}, {-0.07850242098879173, \
-0.007418275822502046}, {-0.07633392595966401, -0.008141666315160197}}]}, 
      {Arrowheads[{{0.009575808549268258, 1.}}], 
       ArrowBox[{{-0.07603779911023088, -0.00823699325396715}, \
{-0.07411973242650148, -0.008852645255369917}, {-0.07192841632022356, \
-0.00952961664358501}, {-0.07034689388861477, -0.01}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08666112798840683, 0.09}, {-0.0879929224763907, 
        0.08919456210211583}, {-0.08974378909840723, 
        0.08833295046760602}, {-0.0914483329589197, 
        0.08746297642360583}, {-0.09310655405792813, 
        0.08658463997011528}, {-0.09471845239543251, 
        0.08569794110713437}, {-0.09493297717747258, 
        0.08557764690012892}, {-0.09514666417741043, 
        0.08545721260787331}, {-0.09697361470700547, 
        0.08418766634134896}, {-0.0974581821197343, 0.08385094088559969}}]}, 
      {Arrowheads[{{0.004474817038996201, 1.}}], 
       ArrowBox[{{-0.09771365059830758, 
        0.0836734160714717}, {-0.09880056523660051, 
        0.0829181200748246}, {-0.1, 0.08208463394526264}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.045048645655189505`, 0.09}, {-0.04511228164884258, 
        0.08998420338413304}, {-0.04661336171173992, 
        0.08960205898260395}, {-0.04809566761791015, 
        0.0892150496389043}, {-0.04955919936735326, 
        0.08882317535303404}, {-0.05100395696006925, 
        0.08842643612499321}, {-0.05242994039605812, 
        0.0880248319547818}, {-0.05383714967531987, 
        0.08761836284239981}, {-0.0552255847978545, 
        0.08720702878784724}, {-0.05659524576366201, 
        0.0867908297911241}, {-0.057032606355491275`, 0.08665450691619879}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.05732960696239486, 
        0.08656193347143935}, {-0.05794613257274239, 
        0.08636976585223037}, {-0.05927824522509567, 
        0.08594383697116606}, {-0.061886148059620866`, 
        0.08507738438252571}, {-0.06441895426723758, 
        0.08419147202520304}, {-0.06687666384794583, 
        0.08328609989919805}, {-0.06906639183060179, 0.08243613797994472}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.06935570270146997, 
        0.08232180818696513}, {-0.07156679312863687, 
        0.08141697634114112}, {-0.07379921282861969, 
        0.08045322490908918}, {-0.07595653590169402, 
        0.07947001370835492}, {-0.07803876234785989, 
        0.07846734273893835}, {-0.08004589216711727, 
        0.07744521200083945}, {-0.0806530224605705, 0.07711982002485442}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.08092721820168612, 
        0.07697286459375441}, {-0.08182190596807445, 
        0.07649335595560217}, {-0.08353632091106877, 
        0.07553096098239633}, {-0.08518948571667717, 
        0.07455857820279821}, {-0.08678174910547658, 
        0.07357675873838408}, {-0.08831349620944876, 
        0.07258604310478617}, {-0.08978511216057553, 
        0.07158697181763671}, {-0.09007222852291544, 
        0.07138616664354332}, {-0.09035695915377012, 
        0.07118505288020797}, {-0.0906393074542995, 
        0.07098363474964821}, {-0.09077958919281896, 
        0.07088281273218824}, {-0.09091927663515172, 
        0.07078191620239388}, {-0.09105837021384572, 
        0.07068094568544592}, {-0.09119687036309168, 
        0.07057990170594622}, {-0.0913347775185158, 
        0.07047878478798958}, {-0.09146654357181158, 0.07037797036269873}}]}, 
      {Arrowheads[{{0.01793363989431582, 1.}}], 
       ArrowBox[{{-0.09171361598633178, 
        0.07018893484974181}, {-0.09348138030198981, 
        0.06883641544830925}, {-0.09547530774946476, 
        0.06717731311267128}, {-0.09560477405964311, 
        0.06706473374896357}, {-0.09573355335793564, 
        0.06695208798258667}, {-0.09585757747034522, 
        0.06684232453334377}, {-0.0959809531494857, 
        0.06673250061668662}, {-0.09610368098923658, 
        0.0666226168312276}, {-0.09622576158532817, 
        0.0665126737747889}, {-0.09634719553533556, 
        0.06640267204440128}, {-0.09658877134385482, 
        0.06618255242741297}, {-0.09682776537251418, 
        0.0659622028805637}, {-0.09706418244403697, 
        0.06574162816183073}, {-0.09820799341898229, 
        0.06463573441485879}, {-0.0992881283163124, 
        0.0635249143436315}, {-0.1, 0.06274440410761323}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.05, 0.08975393715139722}, {0.04937678696170988, 
        0.08977009592027205}, {0.04753323432669975, 0.08981047232515153}, {
        0.04569911852931579, 0.08984318052291401}, {0.043874439569557944`, 
        0.08986822051355947}, {0.042059197447426325`, 0.08988559229708792}, {
        0.04025339216292087, 0.08989529587349934}, {0.03845702371604154, 
        0.08989733124279377}, {0.03755748738037798, 0.08989449568810992}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03724639536581118, 0.08989351505132623}, {
        0.03667009210678842, 0.08989169840497116}, {0.03489259733516148, 
        0.08987839736003155}, {0.033124539401160655`, 0.08985742810797492}, {
        0.03136591830478605, 0.08982879064880127}, {0.029617886082716153`, 
        0.08979336030325501}, {0.02788159477162946, 0.08975201239208053}, {
        0.026157044371526064`, 0.08970474691527783}, {0.024805213461042693`, 
        0.08966277232258182}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02449426975730344, 0.0896531174647038}, {
        0.024444234882405914`, 0.08965156387284691}, {0.022743166304268973`, 
        0.08959246326478776}, {0.021053838637115324`, 0.0895274450911004}, {
        0.019376251880944922`, 0.08945650935178483}, {0.017710406035757728`, 
        0.08937965604684103}, {0.016056301101553823`, 0.08929688517626902}, {
        0.014413937078333171`, 0.08920819674006879}, {0.012783313966095729`, 
        0.08911359073824032}, {0.01206468818476817, 0.08906896807999538}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011754192640379031`, 0.08904968803616192}, {
        0.011164431764841574`, 0.08901306717078365}, {0.009557290474570667, 
        0.08890662603769876}, {0.007961890095282975, 0.08879426733898566}, {
        0.006378230626978568, 0.08867599107464433}, {0.004806312069657408, 
        0.08855179724467478}, {0.003246134423319464, 0.088421685849077}, {
        0.0016976976879648047`, 0.08828565688785102}, {
        0.00016100186359339214`, 
        0.08814371036099682}, {-0.0006499076602305736, 
        0.08806508219974897}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009595490311537622, 
        0.08803505846599487}, {-0.0013639530497948013`, 
        0.0879958462685144}, {-0.0028771670521997098`, 
        0.08784206461040375}, {-0.004378640143621375, 
        0.08768236538666489}, {-0.005868372324059824, 
        0.0875167485972978}, {-0.007346363593514989, 
        0.0873452142423025}, {-0.008812613951986896, 
        0.08716776232167898}, {-0.010267123399475601`, 
        0.08698439283542725}, {-0.011709891935981015`, 
        0.0867951057835473}, {-0.013140919561503178`, 
        0.08659990116603912}, {-0.013316451133487308`, 
        0.08657502719758357}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.013624467467429985`, 
        0.08653137927437705}, {-0.014560206276042112`, 
        0.08639877898290271}, {-0.015967752079597802`, 
        0.0861917392341381}, {-0.017363556972170235`, 
        0.08597878191974527}, {-0.01874762095375942, 
        0.08575990703972422}, {-0.021127497975405883`, 
        0.08536744281863295}, {-0.02346925414797654, 
        0.0849623148199689}, {-0.025772889471471386`, 
        0.08454452304373204}, {-0.02590351911002996, 0.08451970296244604}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.026209144837248757`, 
        0.08446163302153242}, {-0.028038403945890425`, 
        0.08411406748992238}, {-0.030265797571233658`, 
        0.08367094815853993}, {-0.03245507034750108, 
        0.08321516504958468}, {-0.03460622227469269, 
        0.08274671816305662}, {-0.036719253352808484`, 
        0.08226560749895577}, {-0.0383787329638759, 0.08187069469407614}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0386813749860667, 
        0.08179867379724756}, {-0.03879416358184847, 
        0.08177183305728211}, {-0.04083095296181266, 
        0.08126539483803566}, {-0.042829621492701045`, 
        0.08074629284121641}, {-0.04479016917451363, 
        0.08021452706682436}, {-0.0467125960072504, 
        0.07967009751485951}, {-0.04859690199091135, 
        0.07911300418532186}, {-0.050443087125496514`, 
        0.07854324707821142}, {-0.05066921027652278, 0.07847040738621397}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.05096532018142597, 
        0.07837502328169989}, {-0.05225115141100585, 
        0.07796082619352816}, {-0.05402134364418018, 
        0.077368092309667}, {-0.0557539126217603, 
        0.07676739620502283}, {-0.057448858343746204`, 
        0.07615873787959564}, {-0.05910618081013789, 
        0.07554211733338544}, {-0.060725880020935354`, 
        0.0749175345663922}, {-0.062307955976138606`, 
        0.07428498957861596}, {-0.06266199637600624, 0.07413816382714178}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06294935841010015, 
        0.07401899057285566}, {-0.06385240867574765, 
        0.0736444823700567}, {-0.06535923811976245, 
        0.07299601294071442}, {-0.06682844430818305, 
        0.07233958129058914}, {-0.06826002724100944, 
        0.07167518741968082}, {-0.06965398691824161, 
        0.07100283132798949}, {-0.07101032333987957, 
        0.07032251301551513}, {-0.07232903650592332, 
        0.06963423248225778}, {-0.07361012641637284, 
        0.06893798972821738}, {-0.07415625671057642, 0.06862870305086399}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.07442695479133699, 
        0.06847540023859926}, {-0.07485359307122814, 
        0.06823378475339398}, {-0.07605943647048924, 
        0.06752161755778756}, {-0.07836378283429084, 
        0.06608197709517162}, {-0.0805286948398397, 
        0.06462764893131553}, {-0.08255417248713583, 
        0.0631586330662193}, {-0.08444021577617922, 
        0.061674929499882895`}, {-0.08468768048797337, 
        0.06146263299970534}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.08492379361053923, 
        0.06126007486847401}, {-0.08618682470696988, 
        0.06017653823230634}, {-0.08779399927950779, 
        0.058663459263489634`}, {-0.08926173949379297, 
        0.05713569259343278}, {-0.09059004534982541, 
        0.055593238222135764`}, {-0.09223198148154856, 
        0.05340635429758081}, {-0.09313149085803993, 
        0.051983364331359014`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAGHTu7Fvit78AimbAGHuqP/373dpx
97e/IUb7G2I4qj8CJ2NAI0K4v71AABxGGKk/ehu2iwx9uL9dsYopXfinPx6T
hDEXgri/Ypind5vbpz9v1FTG+oa4v3tJOfbbvqc//n/AabeLuL83HRvLHqKn
P96q2CkHjri/41WHIMGTpz9H2no5TZC4v8MrqRlkhac/ULCgnImSuL+7ujC7
B3enP+k4RVe8lLi/mpXLCaxopz+7u2Rt5Za4vw4XJQpRWqc/7ALYlzyxuL92
66J1GpKmP+sX9TNnxLi/c2zvGp/KpT/cUOt5dMW4vydEdZktvaU/CxVgk3nG
uL+0RJwqva+lP+U/L0iex7i/+oo4gJKfpT+1kuQ6t8i4v+NVJntpj6U/5h2X
ccTJuL9b+LkhQn+lP+rMX/LFyri/VHpDehxvpT91YlnDu8u4v1uYDov4XqU/
P17pEZDNuL+VorIptD6lP1W0KtI1z7i/uyWD23YepT97DR01rdC4v3oqe9JA
/qQ/KoVWYLbSuL+XrblaLXikP5070jI=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.09697465913865837, 
        0.039668428799127874`}, {-0.09700838303893895, 
        0.03855792381121835}, {-0.09681903653522726, 
        0.03614140381491621}, {-0.09637784214611926, 
        0.03375801401267934}, {-0.09569675256617077, 
        0.031412737185861996`}, {-0.09520177440601608, 
        0.030075133259995397`}, {-0.09463999294056313, 
        0.02875482301578118}, {-0.0941265802929029, 0.027690550996383456`}}]}, 
      {Arrowheads[{{0.017089402846169603`, 1.}}], 
       ArrowBox[{{-0.09398951468951589, 
        0.027411326972007478`}, {-0.0933160200937625, 
        0.02616608357230986}, {-0.09255382871241481, 
        0.02489765437305276}, {-0.09172483402576886, 
        0.023646518855448034`}, {-0.09082903603382467, 
        0.022412677019495682`}, {-0.08986643473658222, 
        0.0211961288651957}, {-0.08884636308773985, 
        0.01999927900810321}, {-0.0877781540409959, 
        0.018824532063773314`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00011424989079731345`, 1.}}], 
       ArrowBox[{{-0.033420938598657066`, 
        0.017591232280901134`}, {-0.033398703902668, 0.01752371436782885}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.037365829693401166`}, {0.049070583368843276`, 
        0.03752844272172061}, {0.04748061348401853, 0.037794644293405226`}, {
        0.04589799426520686, 0.038047576289754706`}, {0.04432272571240825, 
        0.038287238710769056`}, {0.042754807825622736`, 
        0.03851363155644826}, {0.0411942406048503, 0.038726754826792324`}, {
        0.03964102405009093, 0.038926608521801256`}, {0.03809515816134465, 
        0.039113192641475045`}, {0.03768810133945799, 
        0.039159394088637625`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03737899245966844, 0.03919447832457031}, {
        0.03655945780695467, 0.03928749651004076}, {0.035036737855264205`, 
        0.039450509451725464`}, {0.03352699830627329, 0.03960223146652915}, {
        0.03203023915998189, 0.03974266255445182}, {0.030546460416390003`, 
        0.03987180271549349}, {0.02907566207549766, 0.039989651949654134`}, {
        0.027617844137304844`, 0.04009621025693377}, {0.026173006601811537`, 
        0.0401914776373324}, {0.02498278558637784, 0.04026128246456626}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02467219765707164, 0.04027898632071716}, {
        0.023322272738923535`, 0.0403481396174866}, {0.021916376411528805`, 
        0.040409534217242186`}, {0.020523460486833622`, 
        0.04045963789011676}, {0.017776569845541816`, 0.04052597245522287}, {
        0.015081600815048116`, 0.040547143312804915`}, {0.0124455348626667, 
        0.04052794310450788}, {0.012233468167341605`, 0.04052342329763982}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011922445240220039`, 0.04051679442288901}, {
        0.009875353455711746, 0.040473164471976714`}, {0.0073710565941832755`,
         0.04038280741521143}, {0.004932644278081251, 0.04025687193421201}, {
        0.0025601165074056933`, 0.04009535802897848}, {0.0002534732821566129, 
        0.03989826569951081}, {-0.0004980161363471142, 
        0.039820234267131834`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0008074460547800894, 
        0.03978810439389382}, {-0.0019872853976660165`, 
        0.03966559494580902}, {-0.004162159532062167, 
        0.039397345767873106`}, {-0.006030318673531319, 
        0.0391339746773497}, {-0.007842232042655639, 
        0.03885032892510274}, {-0.009597899639435125, 
        0.038546408511132224`}, {-0.011297321463869778`, 
        0.03822221343543815}, {-0.012940497515959597`, 
        0.037877743698020515`}, {-0.01309141228009022, 
        0.03784305703555844}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.013394600534768231`, 
        0.03777337141723564}, {-0.014527427795704585`, 
        0.03751299929887932}, {-0.01605811230310474, 
        0.03712798023801458}, {-0.01753255103816007, 
        0.03672268651542627}, {-0.018950712417090954`, 
        0.03630059679638946}, {-0.02031256485611779, 
        0.035865189746179194`}, {-0.02286734291445932, 
        0.034954423652238296`}, {-0.02519688521318467, 
        0.03399038823360359}, {-0.025224864623281506`, 
        0.033976861883674034`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.02550494574121326, 
        0.033841459629062716`}, {-0.027301191752293837`, 
        0.032973083490275064`}, {-0.02918703077732324, 
        0.031915385971666446`}, {-0.030861170533809296`, 
        0.030830172227191463`}, {-0.03232361102175201, 
        0.029717442256850107`}, {-0.03357435224115138, 
        0.02857719606064238}, {-0.034713104053286134`, 
        0.027299822632955852`}, {-0.0353157962496975, 
        0.026440128217019895`}}]}, 
      {Arrowheads[{{0.012637170285288149`, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAACzFrp1Esor9dWso4WNCaPyxz8G9S
PKK/ma16ubCimj82cn4QEpWivxaiWpHHT5k/qAcQZ23Ror+8yAjWd/2XP7Zp
OR301aK/+bBW7bvblz/oaqzqNdqiv6jFZiQGupc/rAWQKTPeor8FegjhVpiX
P6rT+SwY4KK/nLrtzYGHlz9mc7Mu7OGivwDoHIKudpc/zZUaOq/jor9R6R4K
3WWXP5NPklph5aK/iqZxcg1Vlz/UZoKbAueiv39nicc/RJc/yJLoR2/5or94
gnqy0RSWP39hmBLx+aK/oeEZ9nAAlj+8W2uEVPqiv6YLHRon6JU/BKZ2Gpb6
or9p5AKw48+VP3Ij6Pm1+qK/dUFe26a3lT9Cxv9HtPqiv+DVjr9wn5U/WzoP
KpH6or81LcF/QYeVPxaf9WAI+qK/8vfo/fBWlT+rFSkT+/iivwrP4gK9JpU/
K1q9bGr3or8mhXmjpvaUP31i8HGLzKK/k5O+EP8ckz8TCMVJ
        "]]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.02542692475293521}, {0.048446996649347485`, 
        0.025852770094528417`}, {0.04640820822487098, 
        0.026381971974223754`}, {0.04627071270631603, 0.02641665136629908}, {
        0.0461332469934407, 0.026451190256507096`}, {0.044126092901043135`, 
        0.026846655253844894`}, {0.04211893880864557, 
        0.027242120251182687`}, {0.040111784716248, 0.027637585248520485`}, {
        0.03810463062385044, 0.02803305024585828}, {0.037845012918833396`, 
        0.0280551171208855}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.037535037067393306`, 0.028081464316176884`}, {
        0.036268638002380164`, 0.028189105164093637`}, {0.03429168887544035, 
        0.028542321323942767`}, {0.03233487639213905, 
        0.028867371592132787`}, {0.03039820055247625, 
        0.029164255968663698`}, {0.028483942326391662`, 
        0.029434086316730966`}, {0.02659438268382499, 
        0.029677974499530066`}, {0.025220553154897674`, 
        0.029838533739663924`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.024911562620884245`, 0.029874645414588025`}, {
        0.024729521624776228`, 0.02989592051706099}, {0.022889359149245385`, 
        0.030087924369323744`}, {0.021073895257232456`, 
        0.030253986056318325`}, {0.019283129948737446`, 
        0.030394105578044735`}, {0.017517063223760353`, 
        0.03050828293450297}, {0.015775695082301172`, 
        0.030596518125693035`}, {0.014063389550893505`, 0.0306609598740707}, {
        0.012499742691816512`, 0.030700819472430828`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.012188702743306605`, 0.0307062740150576}, {
        0.010739058397833498`, 0.030724909209756145`}, {0.009127032776181154, 
        0.030724416797063923`}, {0.00754843379111392, 
        0.030702279664015075`}, {0.006003261442631794, 
        0.030658497810609597`}, {0.004491515730734777, 
        0.030593071236847492`}, {0.003013196655422868, 0.03050599994272876}, {
        0.0015705985529399485`, 0.030399723848948686`}, {
        0.00016601575952990624`, 
        0.030276682876202565`}, {-0.00023876634685924116`, 
        0.03023527189007111}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.000548244593801941, 
        0.0302036109070636}, {-0.001200551724807256, 
        0.030136877024490392`}, {-0.002529103900071549, 
        0.029980306293812174`}, {-0.005072162323381506, 
        0.029616870195557587`}, {-0.007463159510399969, 
        0.029186374581438808`}, {-0.009747826148350621, 
        0.028687425549042113`}, {-0.01186747895754868, 
        0.028139558539164826`}, {-0.012751318886362665`, 
        0.027869706967585388`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.013048853509899271`, 
        0.02777886451620577}, {-0.013822117937994158`, 
        0.027542773551806943`}, {-0.015611743089687054`, 
        0.026897070586968466`}, {-0.017239070289709012`, 
        0.026212570311727783`}, {-0.01870681541514167, 
        0.02549939339316329}, {-0.02001497846598503, 
        0.02475753983127499}, {-0.021163559442239094`, 
        0.023987009626062872`}, {-0.02301097210033841, 
        0.02239612220131007}, {-0.023630360981546694`, 
        0.021597766916943522`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02382105568532088, 
        0.02135197283009804}, {-0.02427805031879871, 
        0.020762934034547736`}, {-0.024926156171884425`, 
        0.019360871471514038`}, {-0.025208344151744253`, 
        0.017969397734641342`}, {-0.02479706367240659, 
        0.015280141965448345`}, {-0.024166220154838658`, 
        0.01400955737288369}, {-0.023294708647303958`, 
        0.012803956485991336`}, {-0.022306574156316313`, 
        0.011747394591912541`}, {-0.021190374181206936`, 
        0.010763678614233796`}, {-0.021051065776974496`, 
        0.010661697277567703`}}]}, 
      {Arrowheads[{{0.004285318621366186, 1.}}], 
       ArrowBox[{{-0.02080004537190189, 
        0.010477936674028986`}, {-0.01994610872197583, 
        0.009852808552955103}, {-0.018573777778622985`, 
        0.009014784408076456}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.1, -0.005799217396176757}, {-0.09988734133119026, \
-0.00584501081682493}, {-0.09834634925733957, -0.006456839091123209}, \
{-0.09680009729593479, -0.007056252243689715}, {-0.09659095393339918, \
-0.007136351967050246}, {-0.09638173182174067, -0.007216225567577212}, \
{-0.09420208400044464, -0.00794449468587752}, {-0.09202243617914858, \
-0.008672763804177825}, {-0.08984278835785253, -0.009401032922478132}, \
{-0.08826496896373347, -0.009928217694148702}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.05, 0.08008653138226347}, {0.04759475827143357, 
        0.08017234361289921}, {0.044898504606091114`, 0.08025111720297966}, {
        0.04222420748257513, 0.08031168632125026}, {0.0395718669008856, 
        0.080354050967711}, {0.037560047343635605`, 0.0803725296047209}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.03724896690533019, 0.08037538689004732}, {
        0.03694148286102254, 0.0803782111423619}, {0.03433305536298602, 
        0.08038416684520296}, {0.032605793139501446`, 0.0803788698155082}, {
        0.030890663762455618`, 0.08036717821247388}, {0.029187667231848492`, 
        0.08034909203610002}, {0.02749680354768003, 0.0803246112863866}, {
        0.02581807270995027, 0.08029373596333361}, {0.024806102402625502`, 
        0.08027110541373293}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.02449508660184906, 0.08026415021113942}, {
        0.02415147471865925, 0.08025646606694109}, {0.02249700957380693, 
        0.080212801597209}, {0.020854677275393273`, 0.08016274255413737}, {
        0.019224477823418323`, 0.08010628893772617}, {0.017606411217882114`, 
        0.08004344074797543}, {0.0160004774587846, 0.07997419798488511}, {
        0.014406676546125756`, 0.07989856064845527}, {0.01282500847990561, 
        0.07981652873868585}, {0.012061588521489412`, 0.07977351820843007}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011750987512347948`, 0.07975601917142706}, {
        0.011255473260124167`, 0.07972810225557689}, {0.009698070886781433, 
        0.07963328119912837}, {0.008152801359877428, 0.0795320655693403}, {
        0.006619664679412111, 0.07942445536621266}, {0.005098660845385503, 
        0.07931045058974548}, {0.0035897898577975686`, 0.07919005123993873}, {
        0.0020930517166483573`, 0.07906325731679245}, {0.0006084464219378513, 
        0.0789300688203066}, {-0.0006559478515836641, 0.07881021052728732}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009656023686353782, 
        0.07878033203347465}, {-0.0023243656281670758`, 
        0.07864450810731624}, {-0.003772572383561483, 
        0.07849213589081173}, {-0.0052086462925171745`, 
        0.07833336910096766}, {-0.006632587355034178, 
        0.07816820773778405}, {-0.008044395571112466, 
        0.07799665180126088}, {-0.009444070940752065, 
        0.07781870129139816}, {-0.010831613463952956`, 
        0.07763435620819586}, {-0.012207023140715145`, 
        0.07744361655165403}, {-0.01331724710808092, 0.07727974155487413}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.013625006108308626`, 
        0.07723431468006889}, {-0.014921443954923435`, 
        0.0770429535185517}, {-0.017585107376720886`, 
        0.07662092003435872}, {-0.020195787399451458`, 
        0.07618172394134269}, {-0.022753484023115167`, 
        0.07572536523950361}, {-0.025258197247712007`, 
        0.07525184392884147}, {-0.025887547985263944`, 
        0.07512588702958724}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.02619259222980471, 
        0.07506483613239251}, {-0.027709927073241984`, 
        0.07476116000935627}, {-0.030108673499705113`, 
        0.07425331348104802}, {-0.03245443652710138, 
        0.07372830434391671}, {-0.034747216155430756`, 
        0.07318613259796235}, {-0.03698701238469328, 
        0.07262679824318492}, {-0.03831756693774349, 0.07227603175364058}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.03861838304082095, 
        0.07219672932426405}, {-0.039173825214888935`, 
        0.07205030127958444}, {-0.041307654646017725`, 
        0.0714566417071609}, {-0.04338850067807966, 
        0.07084581952591432}, {-0.04541636331107474, 
        0.07021783473584466}, {-0.04739124254500293, 
        0.06957268733695196}, {-0.04931313837986426, 
        0.0689103773292362}, {-0.05049028515749207, 0.06848240703714223}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.050782655466200644`, 
        0.06837611119638926}, {-0.05118205081565873, 
        0.06823090471269738}, {-0.052998838918095356`, 
        0.06753831415712268}, {-0.05476436175288316, 
        0.06683665033229927}, {-0.056478619320022155`, 
        0.06612591323822715}, {-0.05814161161951233, 
        0.06540610287490632}, {-0.059753338651353696`, 
        0.06467721924233678}, {-0.06131380041554624, 
        0.06393926234051853}, {-0.06222052104865946, 0.0634904489015689}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06249932858755523, 
        0.06335244325157365}, {-0.06282299691208995, 
        0.06319223216945156}, {-0.06428092814098486, 
        0.0624361287291359}, {-0.06568759410223095, 
        0.06167095201957151}, {-0.06704299479582822, 
        0.06089670204075842}, {-0.06834713022177667, 
        0.060113378792696626`}, {-0.0696000003800763, 
        0.05932098227538611}, {-0.07080160527072712, 
        0.05851951248882689}, {-0.07195194489372911, 
        0.05770896943301896}, {-0.07308039288867593, 0.05684258448055317}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.0733271475755416, 
        0.056653134414082984`}, {-0.07409882833678666, 
        0.05606066351365697}, {-0.07522883198455588, 
        0.055110448659937014`}, {-0.07629652208491075, 
        0.054154377483740385`}, {-0.07824664134465648, 
        0.05222635838390567}, {-0.07995447498859701, 
        0.050281569654029225`}, {-0.08142560474938967, 
        0.04832480077200333}, {-0.08155992875956275, 
        0.048128648335155774`}, {-0.08169195076537362, 
        0.047932427503201286`}, {-0.08182167684607677, 
        0.047736142822646974`}, {-0.08186160497405356, 
        0.047674903552403086`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAlzVF8un/tL9Gk2bxjUaoPyFcn6vR
ArW/uiG64GQ9qD/kUgIw3Qa1v9P3pDSFMKg/7kQzA+c6tb9QzHxT9n6nP+/l
2lH+Z7W/TOAIzErNpj90kKWhzWq1v6Yadv5KwaY/YADS/pRttb/4aXxHS7Wm
P4Z/msfacLW/bBBozs6mpj8qCYEMFXS1v2Rw3o1SmKY/vOWH0kN3tb9Uj0mM
1ommP/u9sx5nerW/RbwP0Fp7pj9Xlwv2fn21vwuPk1/fbKY/HmYoxZeDtb+t
iNAi6U+mP23ZS+mCibW/NnzoR/Qypj9DtuOKQI+1v0uJmgEBFqY/GRDbTwS/
tb8BrwzgAPWkPxLaWXSz3bW/GFWmvnLVoz8PV9eS8+u1v2Aj0dQMuKI/OXf3
LVXrtb/ndpHWzUSiP+/dors=
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.0856188023556202, 
        0.035370107655089134`}, {-0.0856084358592072, 
        0.034404658858134506`}, {-0.0853463477108886, 
        0.03216924859918414}, {-0.08485468692133756, 
        0.029972918211798788`}, {-0.0841334534905541, 
        0.027815667695978454`}, {-0.08318264741853819, 
        0.02569749705172314}, {-0.08202731545598076, 
        0.02362673068814669}, {-0.08202225488922443, 0.02361909123066368}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.08185045359517318, 
        0.023359739117624203`}, {-0.08069250435357271, 
        0.02161169301436295}, {-0.07917821411131405, 
        0.019652384030371915`}, {-0.07748444472920477, 
        0.017748803736173595`}, {-0.07558037775290773, 
        0.015893821871171245`}, {-0.07364065109033341, 
        0.014127843245413057`}, {-0.07360872734318538, 
        0.014101863698581994`}}]}, 
      {Arrowheads[{{0.0037741582072388395`, 1.}}], 
       ArrowBox[{{-0.07336743687243094, 
        0.01390550150288529}, {-0.07154610005137818, 
        0.012423297517924975`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.009820651143451202, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAA3EMusOGJpz97FK5H4XqEv48bhS0o
tqc//mRkXZhCg7+NPw2FVL+nP57RU4Le9oK/D9OnbjnIpz8twCDLJauCv3NT
KzLX0Kc/Jk2F825fgr/PL+p5C9WnP6JLKHCUOYK/rRY2Ey7Zpz8WNa+quhOC
v9HxIAc/3ac/XuBKuuHtgb9WusFePuGnPwRVHLYJyIG/ztIzIyzlpz9Wwza1
MqKBv/EGJfbMJ6g/Kf8aMQ8efb8J7jjcjimoP15/NU8H6Xy/Mxx0ckgrqD/h
9RFSArR8vwur9jpELqg/9fQ42TxTfL/t7JCIJDGoP9e2SiKC8nu//0Olb+kz
qD9eSuyH0pF7vy4EoQSTNqg/30BqZC4xe7/cVPxbITmoP6ScuBGW0Hq/uaOC
uAc+qD8XU9TAfQ96vz4L08KBQqg/KjRRfpdOeb+Yn6EfkEaoP5z21hHmjXi/
iGr6LYpYqD8KHkZYkRRxv6S/q40=
        "]]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.07116493183566111}, {0.04790117271338311, 
        0.07126954758696588}, {0.04524724727232502, 0.07138388557513647}, {
        0.042619740558918616`, 0.07148097362078587}, {0.04001865257316393, 
        0.07156081172391406}, {0.03756506806403943, 0.07162045641063902}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0372540403363524, 0.07162677933096466}, {
        0.034895732784609695`, 0.07166873810260686}, {0.03237390098181016, 
        0.07169682637817147}, {0.029878487906662334`, 0.07170766471121487}, {
        0.027409493559166227`, 0.07170125310173708}, {0.02496691793932184, 
        0.07167759154973809}, {0.024810996398711767`, 0.07167495141354707}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02449994742552945, 0.07166968458737243}, {
        0.022550761047129168`, 0.07163668005521791}, {0.020161022882588215`, 
        0.07157851861817652}, {0.01779770344569901, 0.07150310723861394}, {
        0.01546080273646152, 0.07141044591653016}, {0.013150320754875718`, 
        0.0713005346519252}, {0.012064525501404234`, 0.07124008490961377}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011753912942165172`, 0.07122279210131989}, {
        0.010866257500941626`, 0.07117337344479902}, {0.008608612974659258, 
        0.07102896229515164}, {0.006164844722759136, 0.07085325391713514}, {
        0.003757565482068099, 0.07066187194763494}, {0.001386775252586148, 
        0.07045481638665106}, {-0.0006516541156430292, 
        0.07026031807512355}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009613297969157114, 
        0.07023065505829378}, {-0.0032453381727504706`, 
        0.06999368449023222}, {-0.005506661368605167, 
        0.06973960815479727}, {-0.00773149555325078, 
        0.06946985822787861}, {-0.00991984072668729, 
        0.06918443470947627}, {-0.012071696888914716`, 
        0.06888333759959024}, {-0.013308995461988531`, 
        0.06869805537252736}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.013616658584855803`, 
        0.06865198362409856}, {-0.014187064039933073`, 
        0.06856656689822052}, {-0.016265942179742348`, 
        0.0682341226053671}, {-0.018308331308342533`, 
        0.06788600472103}, {-0.020314231425733634`, 
        0.0675222132452092}, {-0.022283642531915632`, 
        0.06714274817790471}, {-0.024216564626888558`, 
        0.06674760951911653}, {-0.025851334172573622`, 
        0.06639347977866406}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02615527445614443, 
        0.06632716115544673}, {-0.027972313230721264`, 
        0.06591300459073286}, {-0.02979388263460924, 
        0.06547892464842486}, {-0.03157770592231633, 
        0.06503455744192066}, {-0.03332378309384253, 
        0.06457990297122028}, {-0.03503211414918784, 
        0.06411496123632371}, {-0.03670269908835228, 
        0.06363973223723095}, {-0.03819565172684385, 0.06319581041463283}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.038493249243814254`, 
        0.06310519447529574}, {-0.03993063061813851, 
        0.06265841244645685}, {-0.04148797720876029, 
        0.06215232165477553}, {-0.04300757768320118, 
        0.06163594359889801}, {-0.04448943204146119, 
        0.0611092782788243}, {-0.045933540283540325`, 
        0.060572325694554396`}, {-0.04733990240943857, 
        0.06002508584608831}, {-0.04870851841915594, 
        0.059467558733426025`}, {-0.05003938831269242, 
        0.05889974435656756}, {-0.05017529256893247, 0.05883898723885424}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.050459297276978496`, 
        0.05871202059369331}, {-0.051332512090048, 
        0.05832164271551289}, {-0.053809543061041805`, 
        0.057144658825981395`}, {-0.05614363309696263, 
        0.05594668824999792}, {-0.05833478219781048, 
        0.054727730987562465`}, {-0.06038299036358533, 
        0.05348778703867503}, {-0.06139999438319402, 
        0.052814720550193255`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.06165941955505385, 
        0.05264302959707916}, {-0.06228825759428721, 
        0.05222685640333562}, {-0.0640505838899161, 
        0.050944939081544224`}, {-0.065669969250472, 
        0.04964203507330086}, {-0.06714641367595492, 
        0.048318144378605515`}, {-0.06893672067595802, 
        0.046489203522147284`}, {-0.07048068928293372, 
        0.04464449569265341}, {-0.07075898977741782, 
        0.044248536897056816`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAoCclFvwosr+w3ppfYoamP2q9kTN6
YLK/E8W6LnropT9e0cqqoqayv2f3gNKY9KQ/YWVQ4tOssr9Hh0TjMdykPyby
ZTrfsrK/gn4g78rDpD9oUbzRxLiyv7lY3x5kq6Q/YdbHfam7sr/GmaPPMJ+k
P4tHMsWEvrK/kE+amP2SpD+xGNqrVsGyv+5w0H7KhqQ/mZOfNR/Esr+CL1CH
l3qkPyScZGbexrK/F1Aht2RupD/JI2YC2wCzvzLaV63QN6M/JNVu1msCs79S
JQY8WS2jPz6xsAr2A7O/2uqyR+Iioz9cw0tD8gWzvyupZibZFKM/NDN8pOIH
s799ZIL/0AajPyE4kTTHCbO/9uc72sn4oj97r9z5nwuzvzXvw73D6qI/axez
+mwNs795JUaxvtyiP+WcJoDvELO/wxOHxrbAoj+fo4smQxSzv1w0zFSzpKI/
KYPBIGgXs7/DPf6UtIiiP5wV/zv+LLO/NCJn2PFxoT804eBiQjCzvyJs6QDF
nKA/7TzN9w==
        "]]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0749646573313513, 
        0.032135109109911825`}, {-0.0749698177999128, 
        0.03196670583294962}, {-0.07478181712266903, 
        0.029887967866499526`}, {-0.07435391955722895, 
        0.02784187347683697}, {-0.07371982947236393, 
        0.025863843832495667`}, {-0.07289008776791094, 
        0.023931034884861695`}, {-0.07186469444386998, 
        0.02204344663393505}, {-0.07088742451146621, 
        0.020568897785778997`}}]}, 
      {Arrowheads[{{0.015309998507262163`, 1.}}], 
       ArrowBox[{{-0.07071556307748883, 
        0.020309585520957282`}, {-0.07064364950024105, 
        0.02020107907971574}, {-0.06925176621349946, 
        0.018410874935392126`}, {-0.06771385786012052, 
        0.01667977691415257}, {-0.06602992444010422, 
        0.015007785015997078`}, {-0.06419996595345057, 
        0.013394899240925646`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00009015678293829535, 1.}}], 
       ArrowBox[{{0.025284041868528017`, 0.0008142746802885773}, {
        0.02529843260222475, 0.0008684917189229743}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.1, 0.006432081638800444}, {-0.0977546154769617, 
        0.0051482818095980026`}, {-0.09759954479275125, 
        0.005061777911954728}, {-0.09744429270164538, 
        0.004975453977643996}, {-0.09518177378330585, 
        0.0039171692537318704`}, {-0.09291925486496631, 
        0.0028588845298197444`}, {-0.09065673594662679, 
        0.0018005998059076186`}, {-0.08883725417473606, 
        0.0009495440427842432}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{-0.08855546312496672, 
        0.0008177373379258739}, {-0.08839421702828726, 
        0.0007423150819954923}, {-0.08601262371549788, \
-0.000017498902195722116`}, {-0.08372909166872602, -0.0010231123190982743`}, \
{-0.08143155086966594, -0.0019936115313277797`}, {-0.07912000131831765, \
-0.002928996538884236}, {-0.0769918667539866, -0.0037554557639129073`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{-0.07670086378407735, -0.003865423856152722}, \
{-0.07468294076084772, -0.004618867206787987}, {-0.0724566221073476, \
-0.0054169401826568795`}, {-0.07022511120400406, -0.006183771586470451}, \
{-0.06798840805081707, -0.006919361418228703}, {-0.06574651264778665, \
-0.007623709677931635}, {-0.06492208102155632, -0.007870665082814985}}]}, 
      {Arrowheads[{{0.012277297238940839`, 1.}}], 
       ArrowBox[{{-0.06462407024140528, -0.007959933095504298}, \
{-0.0634994249949128, -0.008296816365579246}, {-0.061247145092195525`, \
-0.008938681481171534}, {-0.05899706511575323, -0.009550016851414685}, \
{-0.05726335654835347, -0.01}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00019966544210640944`, 1.}}], 
       ArrowBox[{{0.024450541839931415`, 0.00938187150560952}, {
        0.02438952861111705, 0.00942676916230478}, {0.024350361036321426`, 
        0.009455333399136248}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{-0.0214648162499491, 
        0.04402205636682661}, {-0.023034512458892688`, 
        0.04357615361712532}, {-0.024552925860463384`, 
        0.0431195205776184}, {-0.02602005645466119, 
        0.04265215724830583}, {-0.0274359042414861, 
        0.042174063629187616`}, {-0.02880046922093812, 
        0.041685239720263764`}, {-0.03011375139301725, 
        0.04118568552153427}, {-0.03258646731505683, 
        0.04015438625465835}, {-0.03318153777030754, 0.03987248417616101}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03346267992995381, 
        0.0397392990071475}, {-0.034854052007604844`, 
        0.03908016582855986}, {-0.03691650547066129, 
        0.037963024243238795`}, {-0.03877382770422617, 
        0.03680296149869516}, {-0.04042601870829948, 
        0.03559997759492896}, {-0.04201093168901203, 
        0.03424491655046908}, {-0.04336785670164444, 
        0.03286995252319467}, {-0.0435627659413497, 0.03263149273117009}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAArTTcBKpnpr8X9Q35gJWgP7cKclUe
yaa/yMHaM0YeoD+8W1yJbdamv0JY6Yv9C6A/vk8l4XTjpr/1qFCUZPOfP0KY
PZo08Ka/h2KFO8nOnz9ag6Ksefamvz2Jldl5vJ8/NaeL7qz8pr/LR4ZlKaqf
PzfDwGfOAqe/15UD69eXnz/oOg8g3ginv+V/snWFhZ8/zV1JH9wOp7+fAzIR
MnOfP3q4V1Jdfqe/1XyOuH/snT+wedoPnIGnvyuycxxM350/38YmAdKEp7+D
V+2GGNKdP4JctUNMiqe/UBiBgeS6nT/jbqWMq4+nvzbynNWwo50/JvXj7O+U
p79aySOZfYydPwrGaXUZmqe/ajHm4Up1nT8Cfjs3KJ+nv9tnosUYXp0/XhKj
TxCpp78l3lPutS+dPyJf9tWNsqe//LDvL1YBnT9gymNTobunv/3iwDb60pw/
qVOkLxIAqL+xZ7LwvQSbP/DTuFp6Hai/Zo97f786mT/6Fcp3FhaovydMUcBR
d5c/EmwJkDfsp7+9XsSum7yVPzqWM7jt2ae/WO/jMRVZlT9NQ9xp
        "]]}, 
      {Arrowheads[{{0.01588261154002295, 1.}}], 
       ArrowBox[{{-0.04647722488409305, 
        0.020555638005269883`}, {-0.04586854038589033, 
        0.018899414141280726`}, {-0.04456969723647243, 
        0.016672205372293095`}, {-0.04288040012387045, 
        0.014560760690031024`}, {-0.04190915441897297, 
        0.013554109215780444`}, {-0.04085351061501118, 
        0.012580171652783498`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.05, 0.055208537137222166`}, {0.04854379471814769, 
        0.05534224118249441}, {0.04666315644944978, 0.05550409753431935}, {
        0.04479572562954956, 0.05565392346753493}, {0.04294150225844706, 
        0.055791718982141136`}, {0.04110048633614226, 0.05591748407813798}, {
        0.03927267786263511, 0.05603121875552546}, {0.0375909140462956, 
        0.05612547779101127}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03728024916520202, 0.05614177532204723}, {
        0.035656683262013905`, 0.05622259685447233}, {0.03386849713489985, 
        0.05630024027603172}, {0.03209351845658346, 0.05636585327898174}, {
        0.030331747227064762`, 0.056419435863322404`}, {0.028583183446343776`,
         0.056460988029053694`}, {0.02619908941594279, 0.05650081271381014}, {
        0.024843112094926022`, 0.05651323360564917}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.02453203158547963, 0.056516083135137}, {
        0.023847183804911805`, 0.05652235641130231}, {0.02152746661325088, 
        0.0565256191215302}, {0.01923993784095998, 0.056510600844493816`}, {
        0.01698459748803912, 0.05647730158019316}, {0.014761445554488285`, 
        0.05642572132862822}, {0.01257048204030748, 0.056355860089799}, {
        0.012090726846029656`, 0.05633627180989657}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011779892269112807`, 0.05632358051490149}, {
        0.010411706945496708`, 0.05626771786370551}, {0.008285120270055967, 
        0.05616129465034774}, {0.006190722013985257, 0.0560365904497257}, {
        0.004128512177284566, 0.055893605261839376`}, {0.002098490759953907, 
        0.05573233908668877}, {0.00010065776199328844`, 
        0.0555527919242739}, {-0.0006332338811501523, 0.0554789309488924}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009427637781255782, 
        0.055447778965743474`}, {-0.001864986816597313, 
        0.05535496377459474}, {-0.0037984429758178735`, 
        0.05513885463765131}, {-0.005699710715668412, 
        0.0549044645134436}, {-0.00756690757755737, 
        0.05465469488930976}, {-0.009398151102893236, 
        0.05439244725258793}, {-0.011193441291676, 
        0.054117721603278116`}, {-0.01295277814390565, 
        0.05383051794138031}, {-0.013271135692223365`, 0.0537751582827221}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.013577629841210564`, 
        0.053721861567885804`}, {-0.014676161659582198`, 
        0.05353083626689452}, {-0.016363591838705654`, 
        0.05321867657982073}, {-0.018015068681276006`, 
        0.052894038880158964`}, {-0.019630592187293246`, 
        0.052556923167909206`}, {-0.021210162356757382`, 
        0.052207329443071465`}, {-0.02275377918966843, 
        0.05184525770564573}, {-0.02426144268602637, 
        0.05147070795563201}, {-0.0257331528458312, 
        0.0510836801930303}, {-0.025733839780581684`, 
        0.051083489050355195`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.026033547124086304`, 
        0.05100009413788967}, {-0.02716890966908292, 
        0.0506841744178406}, {-0.02856871315578155, 
        0.05027219063006291}, {-0.02993256330592707, 
        0.04984772882969724}, {-0.031260460119519495`, 
        0.04941078901674358}, {-0.03380980827328736, 
        0.048510788934513174`}, {-0.036218172153327455`, 
        0.04758350396481257}, {-0.03778083623830933, 0.04692562028787806}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.03806755632752745, 
        0.046804910745527506`}, {-0.0384855517596398, 
        0.04662893410764177}, {-0.04061194709222439, 
        0.045647079363000775`}, {-0.04259735815108122, 
        0.044637939730889586`}, {-0.04444178493621029, 
        0.0436015152113082}, {-0.04614522744761159, 
        0.04253780580425662}, {-0.04770768568528514, 
        0.041446811509734845`}, {-0.04879661047890935, 
        0.04058080151280317}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAOv7XcMgbqb+hlIZRoK2kP2pio93k
Y6m/lXuu8UZ0pD8PLYbJZzuqv+1IyoXyrKM/zrZ6FHH0qr+nIQDYR+OiPw+m
GdnSj6u/yxgmCwAYoj9rrhHUw52rv5WAdWScA6I//U6zXmurq78z5dSVNu+h
PzfgprTJuKu/guvHy87aoT9PU7d8Xb+rvzOX8zSa0KE/cx0cDt/Fq7/fTuEv
ZcahP9dRYHBOzKu/EcwTwi+8oT+w3BOrq9Krv6GyCvH5saE/FuXKxfbYq7/3
8kLCw6ehP11PdXaCVqy/Z6gBj+S8oD9JkMQkIVqsvySsdtv1tKA/iGR6WbVd
rL9p2IQ8B62gPwirh80BY6y/dByWQvCgoD/MgJsWNmisv3qTzpTZlKA/mPMa
QlJtrL8nZKk7w4igP7Docl1Wcqy/yXSbP618oD+iDRh2Qnesv6ppE6mXcKA/
3Uz9vOqArL9Gm9lXbVigP4XSIGUziqy/Iwnb30RAoD+j9NfaHJOsv+CT/IMe
KKA/GrjMD8O9rL9/8vKEpSafP/I+2S0=
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.056220985739419534`, 
        0.0301218108931275}, {-0.05633653348473252, 
        0.029718684577006504`}, {-0.05659378434290853, 
        0.027895822259395894`}, {-0.056594979270161494`, 
        0.026094489348345653`}, {-0.05635389729227448, 
        0.024321236769101123`}, {-0.0559890385043393, 
        0.022884812492635964`}, {-0.055484966697766105`, 
        0.021477400264796245`}, {-0.05484168187255489, 
        0.02009900008558197}, {-0.054059184028705666`, 
        0.01874961195499314}, {-0.05375606704351816, 
        0.018309265063639193`}}]}, 
      {Arrowheads[{{0.012135574704814665`, 1.}}], 
       ArrowBox[{{-0.053579674039170085`, 
        0.018053013797900294`}, {-0.05315362363503151, 
        0.017434077940820376`}, {-0.052141151160345525`, 
        0.016157240110854298`}, {-0.0510217666046477, 
        0.014919098465094906`}, {-0.04979546996793805, 
        0.013719653003542201`}, {-0.048442647920352515`, 
        0.012554900242086883`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.05, 0.06300079501570595}, {0.04781744791386313, 
        0.06315102269388485}, {0.04565171545435212, 0.06328710703813845}, {
        0.043502874604384324`, 0.06340904309379615}, {0.041370925363959664`, 
        0.06351683086085796}, {0.039255867733078174`, 0.06361047033932392}, {
        0.03757515039542711, 0.06367414605404163}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.03726427985952178, 0.06368592370583055}, {
        0.03715770171173989, 0.06368996152919398}, {0.03507642729994474, 
        0.06375530443046819}, {0.03301204449769278, 0.0638064990431465}, {
        0.03096455330498401, 0.06384354536722894}, {0.02893395372181838, 
        0.0638664434027155}, {0.026920245748195924`, 0.06387519314960619}, {
        0.024822765879515794`, 0.06386920206247325}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.024511673588387725`, 0.0638683134813477}, {
        0.024297024591483068`, 0.06386770037375003}, {0.021710291821247923`, 
        0.06384080761473435}, {0.019160047437490457`, 0.06379451487255915}, {
        0.016646291440210646`, 0.06372882214722442}, {0.014169023829408512`, 
        0.06364372943873019}, {0.01207273138347738, 0.06355398464002582}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.011761922518013085`, 0.06354067853899933}, {
        0.011728244605084061`, 0.06353923674707643}, {0.009323953767237294, 
        0.06341534407226314}, {0.006956151315868232, 0.06327205141429035}, {
        0.004624837250976857, 0.06310935877315803}, {0.002330011572563132, 
        0.06292726614886619}, {0.00007167428062708828, 
        0.06272577354141484}, {-0.0006488610929722652, 
        0.06265413909097578}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{-0.0009584285308186722, 
        0.06262336240172986}, {-0.002150174624831268, 
        0.06250488095080396}, {-0.004335535143811929, 
        0.06226458837703357}, {-0.006484407276314934, 
        0.06200489582010365}, {-0.008596791022340233, 
        0.06172580328001421}, {-0.010672686381887852`, 
        0.06142731075676526}, {-0.012710375175394011`, 
        0.061112566860972384`}, {-0.013295786859917601`, 
        0.061016496824891964`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.013602774139564764`, 
        0.06096611812591548}, {-0.01470813922329492, 
        0.06078472020325117}, {-0.01666597852559059, 
        0.06044377078360163}, {-0.018583893082281, 
        0.060089718602023764`}, {-0.02046188289336616, 
        0.05972256365851756}, {-0.022299947958846076`, 
        0.05934230595308303}, {-0.024098088278720734`, 
        0.05894894548572017}, {-0.025807770089609054`, 0.0585537022629414}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.02611012643956653, 
        0.05848050478244478}, {-0.0275745946816543, 
        0.05812291626520946}, {-0.029252960764713207`, 
        0.05769024751206161}, {-0.030891402102166864`, 
        0.05724447599698543}, {-0.03248991869401527, 
        0.05678560171998092}, {-0.034048510540258425`, 
        0.05631362468104808}, {-0.035567177640896334`, 
        0.05582854488018691}, {-0.037045919995929, 
        0.0553303623173974}, {-0.03804358879679524, 0.05497583967778727}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.0383367246385346, 
        0.054871673553430624`}, {-0.038484737605356416`, 
        0.054819076992679565`}, {-0.03988421649400595, 
        0.05429772366065149}, {-0.041244942686705, 
        0.05376933707593125}, {-0.04256691618345354, 
        0.05323391723851884}, {-0.043850136984251595`, 
        0.05269146414841428}, {-0.04630032049799622, 
        0.05158545821012867}, {-0.04859549322793886, 
        0.05045131926107441}, {-0.049707775347716594`, 
        0.049847264824184105`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{-0.04998115582640793, 
        0.04969879827223981}, {-0.050735655174079526`, 
        0.0492890473012515}, {-0.052720806336418215`, 
        0.04809864233065995}, {-0.05455094671495492, 
        0.04688010434929975}, {-0.056226076309689656`, 
        0.0456334333571709}, {-0.05816718852567784, 
        0.043991985439368185`}, {-0.05986648008612499, 
        0.04232868849419299}, {-0.05990831557966089, 0.04228066527286235}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAB61dLBbHrr/KYUnkEIelP4+U8m6c
Zq+/QBqeZvLPpD9bQg66IgSwv30KTERU8qM/Y5S6HmgLsL+0g3oJHdyjP4J8
ZCeIErC/lqTk9OPFoz+tfRHxghmwvw/WCzGpr6M/nA96ZvIcsL+MalE5i6Sj
P6H7E5dYILC/NWCk5WyZoz+ut4mGtSOwv4NkSDtOjqM/iOCHOAknsL9cVn4/
L4OjP6jzvLBTKrC/hZ+E9w94oz+ktIXfyG+wvzNdWR8raKI/9XaSEcZxsL+Q
nWIT/V6iP5PfYT29c7C/0LrOK89Voj/pHKAUbXawv4dwhmPkSKI/fZTAERF5
sL9kXbr9+TuiP+EM5zqpe7C/ByoVAhAvoj8niDqWNX6wvyc5PHgmIqI//j3l
KbaAsL9aps9nPRWiP0MjR86fhbC/O5z/SGz7oT9y/4CFWoqwv4c0nUyd4aE/
mi8tgeaOsL8KqS+v0MehP7jv5W9+srC/Cm+gcobGoD+ClXpmY8Kwv8q/N47e
zp8/3QLCXQ==
        "]]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{-0.06550202047927633, 
        0.030753981447582582`}, {-0.06552554869232478, 
        0.028888726154923227`}, {-0.06530906874657127, 
        0.026988171667111795`}, {-0.06492673700176337, 
        0.025307169517751835`}, {-0.06437884569901205, 
        0.023659431939909048`}, {-0.06366539483831732, 
        0.02204495893358344}, {-0.06278638441967917, 
        0.020463750498775003`}, {-0.061883287725142844`, 
        0.019105689842930478`}}]}, 
      {Arrowheads[{{0.006003987037049321, 1.}}], 
       ArrowBox[{{-0.06170594738773423, 
        0.018850280605822015`}, {-0.06060800525644129, 
        0.01742444938329337}, {-0.05932771659880871, 
        0.015972187212516097`}}]}}, 
     {Hue[0.67, 0.6, 0.6], 
      {Arrowheads[{{0.00023804937524010892`, 1.}}], 
       ArrowBox[{{0.028031580117960128`, -0.0062892629165373784`}, {
        0.028067332125730135`, -0.006256435331797213}, {
        0.028102886524922564`, -0.006223590198870344}, {
        0.028140282824719746`, -0.0061886627636506585`}}]}}}}, 
   {PointSize[0.025], PointBox[{0, 0.08}]}, 
   {PointSize[0.025], PointBox[{0, 0.01}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.08}, {0.05, 0.08}}]}, 
   {Dashing[{Small, Small}], LineBox[{{-0.1, 0.01}, {0.05, 0.01}}]}, 
   {Dashing[{Small, Small}], LineBox[{{0, 0.09}, {0, -0.01}}]}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwV13c81d8bAHAhIZQRGRWFpFL2qh5lr0L2ntnzXntk38u9thvJ3nu7Kulo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      "]]}}},
  AspectRatio->1,
  BaseStyle->{FontWeight -> "Bold", FontSize -> 12},
  Frame->True,
  ImageMargins->10,
  ImageSize->{636.5, Automatic},
  Method->{"TransparentPolygonMesh" -> True},
  PlotRange->{{-0.1027733900410869, 0.0527733900410869}, {-0.0127733900410869,
    0.0927733900410869}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.644010758310439*^9, 3.644010793467465*^9, {3.6440108276738853`*^9, 
   3.6440108793428183`*^9}, 3.703994804220815*^9, 3.7041488532452416`*^9, 
   3.704497263997218*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1440, 788},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 2., 2. Inherited],
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 177, 2, 292, "Title"],
Cell[759, 26, 107, 1, 101, "Subtitle"],
Cell[869, 29, 1273, 41, 176, "Text"],
Cell[2145, 72, 1064, 36, 189, "Input"],
Cell[3212, 110, 396, 7, 90, "Input"],
Cell[3611, 119, 2380, 56, 354, "Input"],
Cell[5994, 177, 92, 1, 56, "Input"],
Cell[CellGroupData[{
Cell[6111, 182, 11232, 271, 1171, "Input"],
Cell[17346, 455, 161093, 2868, 959, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178476, 3328, 160897, 2865, 1009, "Input"],
Cell[339376, 6195, 160895, 2865, 1009, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[500308, 9065, 9797, 249, 1105, "Input"],
Cell[510108, 9316, 97265, 1707, 770, "Output"],
Cell[607376, 11025, 80132, 1425, 901, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[687545, 12455, 227, 5, 56, "Input"],
Cell[687775, 12462, 256, 7, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[688068, 12474, 9214, 241, 1072, "Input"],
Cell[697285, 12717, 157102, 2785, 1323, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
